// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'auth_service.swagger.chopper.dart';
part 'auth_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class AuthService extends ChopperService {
  static AuthService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$AuthService(client);
    }

    final newClient = ChopperClient(
        services: [_$AuthService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$AuthService(newClient);
  }

  ///Updates customer HGO status
  ///@param householdId
  Future<chopper.Response> v1CcHouseholdIdHgosuspendPut({
    required String? householdId,
    String? cacheControl,
    required String? body,
  }) {
    return _v1CcHouseholdIdHgosuspendPut(
        householdId: householdId, cacheControl: cacheControl, body: body);
  }

  ///Updates customer HGO status
  ///@param householdId
  @Put(
    path: '/v1/cc/{householdId}/hgosuspend',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CcHouseholdIdHgosuspendPut({
    @Path('householdId') required String? householdId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required String? body,
  });

  ///Deletes all customer's refresh tokens
  ///@param householdId
  Future<chopper.Response> v1CcHouseholdIdTokensDelete({
    required String? householdId,
    String? cacheControl,
  }) {
    return _v1CcHouseholdIdTokensDelete(
        householdId: householdId, cacheControl: cacheControl);
  }

  ///Deletes all customer's refresh tokens
  ///@param householdId
  @Delete(path: '/v1/cc/{householdId}/tokens')
  Future<chopper.Response> _v1CcHouseholdIdTokensDelete({
    @Path('householdId') required String? householdId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates a specific customer and their devices
  Future<chopper.Response> v1CustomersPut({
    String? cacheControl,
    required CpsCustomerData? body,
  }) {
    return _v1CustomersPut(cacheControl: cacheControl, body: body);
  }

  ///Updates a specific customer and their devices
  @Put(
    path: '/v1/customers',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomersPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CpsCustomerData? body,
  });

  ///Creates a customer and their devices
  Future<chopper.Response> v1CustomersPost({
    String? cacheControl,
    required CpsCustomerData? body,
  }) {
    return _v1CustomersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a customer and their devices
  @Post(
    path: '/v1/customers',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CpsCustomerData? body,
  });

  ///Deletes a specific customer from DB
  ///@param customerId
  Future<chopper.Response> v1CustomersCustomerIdDelete({
    required String? customerId,
    String? cacheControl,
  }) {
    return _v1CustomersCustomerIdDelete(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Deletes a specific customer from DB
  ///@param customerId
  @Delete(path: '/v1/customers/{customerId}')
  Future<chopper.Response> _v1CustomersCustomerIdDelete({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Migrates a specific customer from DB
  ///@param customerId
  Future<chopper.Response> v1CustomersCustomerIdMigratePost({
    required String? customerId,
    String? cacheControl,
    required CustomerMigrationData? body,
  }) {
    return _v1CustomersCustomerIdMigratePost(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Migrates a specific customer from DB
  ///@param customerId
  @Post(
    path: '/v1/customers/{customerId}/migrate',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomersCustomerIdMigratePost({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CustomerMigrationData? body,
  });

  ///Changes the status of a customer to either suspended or active
  ///@param customerId
  Future<chopper.Response> v1CustomersCustomerIdStatusPut({
    required String? customerId,
    String? cacheControl,
    required String? body,
  }) {
    return _v1CustomersCustomerIdStatusPut(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Changes the status of a customer to either suspended or active
  ///@param customerId
  @Put(
    path: '/v1/customers/{customerId}/status',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomersCustomerIdStatusPut({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required String? body,
  });

  ///Stops pre-provision running job
  Future<chopper.Response> v1PreprovisionPut({String? cacheControl}) {
    return _v1PreprovisionPut(cacheControl: cacheControl);
  }

  ///Stops pre-provision running job
  @Put(
    path: '/v1/preprovision',
    optionalBody: true,
  )
  Future<chopper.Response> _v1PreprovisionPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Pre-provision the customer based on the csv file URL
  Future<chopper.Response> v1PreprovisionPost({
    String? cacheControl,
    required PreProvisioningRequest? body,
  }) {
    return _v1PreprovisionPost(cacheControl: cacheControl, body: body);
  }

  ///Pre-provision the customer based on the csv file URL
  @Post(
    path: '/v1/preprovision',
    optionalBody: true,
  )
  Future<chopper.Response> _v1PreprovisionPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PreProvisioningRequest? body,
  });

  ///Pre-provision all jobs data. The number of jobs shown is specified in the request body, otherwise it is 20 by default
  Future<chopper.Response> v1PreprovisionJobsPost({
    String? cacheControl,
    required PreProvisioningStatisticsRequest? body,
  }) {
    return _v1PreprovisionJobsPost(cacheControl: cacheControl, body: body);
  }

  ///Pre-provision all jobs data. The number of jobs shown is specified in the request body, otherwise it is 20 by default
  @Post(
    path: '/v1/preprovision/jobs',
    optionalBody: true,
  )
  Future<chopper.Response> _v1PreprovisionJobsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PreProvisioningStatisticsRequest? body,
  });

  ///Pre-provision current job status
  Future<chopper.Response> v1PreprovisionStatusGet({String? cacheControl}) {
    return _v1PreprovisionStatusGet(cacheControl: cacheControl);
  }

  ///Pre-provision current job status
  @Get(path: '/v1/preprovision/status')
  Future<chopper.Response> _v1PreprovisionStatusGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Authenticate and create tokens
  ///@param X-Device-Code
  Future<chopper.Response<AuthorizationResponse>> v1AuthorizationPost({
    String? xDeviceCode,
    String? cacheControl,
    required AuthorizationRequestBody? body,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _v1AuthorizationPost(
        xDeviceCode: xDeviceCode, cacheControl: cacheControl, body: body);
  }

  ///Authenticate and create tokens
  ///@param X-Device-Code
  @Post(
    path: '/v1/authorization',
    optionalBody: true,
  )
  Future<chopper.Response<AuthorizationResponse>> _v1AuthorizationPost({
    @Header('X-Device-Code') String? xDeviceCode,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AuthorizationRequestBody? body,
  });

  ///Logout (revoke tokens and refresh tokens)
  ///@param X-Refresh-Token
  Future<chopper.Response> v1AuthorizationDelete({
    String? xRefreshToken,
    String? cacheControl,
  }) {
    return _v1AuthorizationDelete(
        xRefreshToken: xRefreshToken, cacheControl: cacheControl);
  }

  ///Logout (revoke tokens and refresh tokens)
  ///@param X-Refresh-Token
  @Delete(path: '/v1/authorization')
  Future<chopper.Response> _v1AuthorizationDelete({
    @Header('X-Refresh-Token') String? xRefreshToken,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create an authentication token for a device
  Future<chopper.Response<DeviceAuthenticationResponse>>
      v1AuthorizationDevicePost({
    String? cacheControl,
    required DeviceAuthenticationRequest? body,
  }) {
    generatedMapping.putIfAbsent(DeviceAuthenticationResponse,
        () => DeviceAuthenticationResponse.fromJsonFactory);

    return _v1AuthorizationDevicePost(cacheControl: cacheControl, body: body);
  }

  ///Create an authentication token for a device
  @Post(
    path: '/v1/authorization/device',
    optionalBody: true,
  )
  Future<chopper.Response<DeviceAuthenticationResponse>>
      _v1AuthorizationDevicePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeviceAuthenticationRequest? body,
  });

  ///Create a refresh token for a device
  Future<chopper.Response<DeviceRefreshTokenResponse>>
      v1AuthorizationDeviceRefreshPost({
    String? cacheControl,
    required DeviceRefreshTokenRequestBody? body,
  }) {
    generatedMapping.putIfAbsent(DeviceRefreshTokenResponse,
        () => DeviceRefreshTokenResponse.fromJsonFactory);

    return _v1AuthorizationDeviceRefreshPost(
        cacheControl: cacheControl, body: body);
  }

  ///Create a refresh token for a device
  @Post(
    path: '/v1/authorization/device/refresh',
    optionalBody: true,
  )
  Future<chopper.Response<DeviceRefreshTokenResponse>>
      _v1AuthorizationDeviceRefreshPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeviceRefreshTokenRequestBody? body,
  });

  ///Create a refresh token for a device
  ///@param deviceId
  ///@param authenticationToken
  ///@param X-Device-Code
  Future<chopper.Response<DeviceRefreshTokenResponse>>
      v1AuthorizationDeviceRefreshtokenDeviceIdAuthenticationTokenGet({
    required String? deviceId,
    required String? authenticationToken,
    String? xDeviceCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(DeviceRefreshTokenResponse,
        () => DeviceRefreshTokenResponse.fromJsonFactory);

    return _v1AuthorizationDeviceRefreshtokenDeviceIdAuthenticationTokenGet(
        deviceId: deviceId,
        authenticationToken: authenticationToken,
        xDeviceCode: xDeviceCode,
        cacheControl: cacheControl);
  }

  ///Create a refresh token for a device
  ///@param deviceId
  ///@param authenticationToken
  ///@param X-Device-Code
  @Get(
      path:
          '/v1/authorization/device/refreshtoken/{deviceId}/{authenticationToken}')
  Future<chopper.Response<DeviceRefreshTokenResponse>>
      _v1AuthorizationDeviceRefreshtokenDeviceIdAuthenticationTokenGet({
    @Path('deviceId') required String? deviceId,
    @Path('authenticationToken') required String? authenticationToken,
    @Header('X-Device-Code') String? xDeviceCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create an OneConnect token
  Future<chopper.Response<OneConnectAuthenticationResponse>>
      v1AuthorizationOneconnectPost({
    String? cacheControl,
    required OneConnectRequest? body,
  }) {
    generatedMapping.putIfAbsent(OneConnectAuthenticationResponse,
        () => OneConnectAuthenticationResponse.fromJsonFactory);

    return _v1AuthorizationOneconnectPost(
        cacheControl: cacheControl, body: body);
  }

  ///Create an OneConnect token
  @Post(
    path: '/v1/authorization/oneconnect',
    optionalBody: true,
  )
  Future<chopper.Response<OneConnectAuthenticationResponse>>
      _v1AuthorizationOneconnectPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required OneConnectRequest? body,
  });

  ///Refresh auth, get new tokens
  Future<chopper.Response<AuthorizationResponse>> v1AuthorizationRefreshPost({
    String? cacheControl,
    required RefreshSignInRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _v1AuthorizationRefreshPost(cacheControl: cacheControl, body: body);
  }

  ///Refresh auth, get new tokens
  @Post(
    path: '/v1/authorization/refresh',
    optionalBody: true,
  )
  Future<chopper.Response<AuthorizationResponse>> _v1AuthorizationRefreshPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RefreshSignInRequest? body,
  });

  ///Get MQTT JWT token
  Future<chopper.Response<MqttTokenResponse>> v1MqttTokenGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        MqttTokenResponse, () => MqttTokenResponse.fromJsonFactory);

    return _v1MqttTokenGet(cacheControl: cacheControl);
  }

  ///Get MQTT JWT token
  @Get(path: '/v1/mqtt/token')
  Future<chopper.Response<MqttTokenResponse>> _v1MqttTokenGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get auth details
  ///@param X-Device-Code
  ///@param code_challenge
  Future<chopper.Response<AuthorizationDetails>> v1SsoAuthorizationGet({
    String? xDeviceCode,
    String? codeChallenge,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationDetails, () => AuthorizationDetails.fromJsonFactory);

    return _v1SsoAuthorizationGet(
        xDeviceCode: xDeviceCode,
        codeChallenge: codeChallenge,
        cacheControl: cacheControl);
  }

  ///Get auth details
  ///@param X-Device-Code
  ///@param code_challenge
  @Get(path: '/v1/sso/authorization')
  Future<chopper.Response<AuthorizationDetails>> _v1SsoAuthorizationGet({
    @Header('X-Device-Code') String? xDeviceCode,
    @Query('code_challenge') String? codeChallenge,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Complete auth, create tokens
  ///@param X-Device-Code
  Future<chopper.Response<AuthorizationResponse>> v1SsoAuthorizationPost({
    String? xDeviceCode,
    String? cacheControl,
    required SsoSignInRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _v1SsoAuthorizationPost(
        xDeviceCode: xDeviceCode, cacheControl: cacheControl, body: body);
  }

  ///Complete auth, create tokens
  ///@param X-Device-Code
  @Post(
    path: '/v1/sso/authorization',
    optionalBody: true,
  )
  Future<chopper.Response<AuthorizationResponse>> _v1SsoAuthorizationPost({
    @Header('X-Device-Code') String? xDeviceCode,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SsoSignInRequest? body,
  });

  ///Logout (revoke tokens)
  ///@param X-Refresh-Token
  Future<chopper.Response> v1SsoAuthorizationDelete({
    String? xRefreshToken,
    String? cacheControl,
  }) {
    return _v1SsoAuthorizationDelete(
        xRefreshToken: xRefreshToken, cacheControl: cacheControl);
  }

  ///Logout (revoke tokens)
  ///@param X-Refresh-Token
  @Delete(path: '/v1/sso/authorization')
  Future<chopper.Response> _v1SsoAuthorizationDelete({
    @Header('X-Refresh-Token') String? xRefreshToken,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Refresh auth, get new tokens
  ///@param ACCESSTOKEN
  Future<chopper.Response<AuthorizationResponse>>
      v1SsoAuthorizationRefreshPost({
    String? cacheControl,
    required SvcRefreshTokenPayload? body,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _v1SsoAuthorizationRefreshPost(
        cacheControl: cacheControl, body: body);
  }

  ///Refresh auth, get new tokens
  ///@param ACCESSTOKEN
  @Post(
    path: '/v1/sso/authorization/refresh',
    optionalBody: true,
  )
  Future<chopper.Response<AuthorizationResponse>>
      _v1SsoAuthorizationRefreshPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SvcRefreshTokenPayload? body,
  });
}

@JsonSerializable(explicitToJson: true)
class AuthorizationDetails {
  AuthorizationDetails({
    this.authorizationUri,
    this.logoutUri,
    this.redirectUri,
    this.resetParentalPinUri,
    this.state,
    this.validityToken,
  });

  factory AuthorizationDetails.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationDetailsFromJson(json);

  static const toJsonFactory = _$AuthorizationDetailsToJson;
  Map<String, dynamic> toJson() => _$AuthorizationDetailsToJson(this);

  @JsonKey(name: 'authorizationUri', includeIfNull: false, defaultValue: '')
  final String? authorizationUri;
  @JsonKey(name: 'logoutUri', includeIfNull: false, defaultValue: '')
  final String? logoutUri;
  @JsonKey(name: 'redirectUri', includeIfNull: false, defaultValue: '')
  final String? redirectUri;
  @JsonKey(name: 'resetParentalPinUri', includeIfNull: false, defaultValue: '')
  final String? resetParentalPinUri;
  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$AuthorizationDetailsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationDetails &&
            (identical(other.authorizationUri, authorizationUri) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationUri, authorizationUri)) &&
            (identical(other.logoutUri, logoutUri) ||
                const DeepCollectionEquality()
                    .equals(other.logoutUri, logoutUri)) &&
            (identical(other.redirectUri, redirectUri) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUri, redirectUri)) &&
            (identical(other.resetParentalPinUri, resetParentalPinUri) ||
                const DeepCollectionEquality()
                    .equals(other.resetParentalPinUri, resetParentalPinUri)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorizationUri) ^
      const DeepCollectionEquality().hash(logoutUri) ^
      const DeepCollectionEquality().hash(redirectUri) ^
      const DeepCollectionEquality().hash(resetParentalPinUri) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $AuthorizationDetailsExtension on AuthorizationDetails {
  AuthorizationDetails copyWith(
      {String? authorizationUri,
      String? logoutUri,
      String? redirectUri,
      String? resetParentalPinUri,
      String? state,
      String? validityToken}) {
    return AuthorizationDetails(
        authorizationUri: authorizationUri ?? this.authorizationUri,
        logoutUri: logoutUri ?? this.logoutUri,
        redirectUri: redirectUri ?? this.redirectUri,
        resetParentalPinUri: resetParentalPinUri ?? this.resetParentalPinUri,
        state: state ?? this.state,
        validityToken: validityToken ?? this.validityToken);
  }

  AuthorizationDetails copyWithWrapped(
      {Wrapped<String?>? authorizationUri,
      Wrapped<String?>? logoutUri,
      Wrapped<String?>? redirectUri,
      Wrapped<String?>? resetParentalPinUri,
      Wrapped<String?>? state,
      Wrapped<String?>? validityToken}) {
    return AuthorizationDetails(
        authorizationUri: (authorizationUri != null
            ? authorizationUri.value
            : this.authorizationUri),
        logoutUri: (logoutUri != null ? logoutUri.value : this.logoutUri),
        redirectUri:
            (redirectUri != null ? redirectUri.value : this.redirectUri),
        resetParentalPinUri: (resetParentalPinUri != null
            ? resetParentalPinUri.value
            : this.resetParentalPinUri),
        state: (state != null ? state.value : this.state),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationRequestBody {
  AuthorizationRequestBody({
    this.password,
    this.stayLoggedIn,
    this.username,
  });

  factory AuthorizationRequestBody.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationRequestBodyFromJson(json);

  static const toJsonFactory = _$AuthorizationRequestBodyToJson;
  Map<String, dynamic> toJson() => _$AuthorizationRequestBodyToJson(this);

  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  @JsonKey(name: 'stayLoggedIn', includeIfNull: false)
  final bool? stayLoggedIn;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  static const fromJsonFactory = _$AuthorizationRequestBodyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationRequestBody &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.stayLoggedIn, stayLoggedIn) ||
                const DeepCollectionEquality()
                    .equals(other.stayLoggedIn, stayLoggedIn)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(stayLoggedIn) ^
      const DeepCollectionEquality().hash(username) ^
      runtimeType.hashCode;
}

extension $AuthorizationRequestBodyExtension on AuthorizationRequestBody {
  AuthorizationRequestBody copyWith(
      {String? password, bool? stayLoggedIn, String? username}) {
    return AuthorizationRequestBody(
        password: password ?? this.password,
        stayLoggedIn: stayLoggedIn ?? this.stayLoggedIn,
        username: username ?? this.username);
  }

  AuthorizationRequestBody copyWithWrapped(
      {Wrapped<String?>? password,
      Wrapped<bool?>? stayLoggedIn,
      Wrapped<String?>? username}) {
    return AuthorizationRequestBody(
        password: (password != null ? password.value : this.password),
        stayLoggedIn:
            (stayLoggedIn != null ? stayLoggedIn.value : this.stayLoggedIn),
        username: (username != null ? username.value : this.username));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationResponse {
  AuthorizationResponse({
    this.accessToken,
    this.householdId,
    this.refreshToken,
    this.refreshTokenExpiry,
    this.username,
  });

  factory AuthorizationResponse.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationResponseFromJson(json);

  static const toJsonFactory = _$AuthorizationResponseToJson;
  Map<String, dynamic> toJson() => _$AuthorizationResponseToJson(this);

  @JsonKey(name: 'accessToken', includeIfNull: false, defaultValue: '')
  final String? accessToken;
  @JsonKey(name: 'householdId', includeIfNull: false, defaultValue: '')
  final String? householdId;
  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  @JsonKey(name: 'refreshTokenExpiry', includeIfNull: false)
  final int? refreshTokenExpiry;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  static const fromJsonFactory = _$AuthorizationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationResponse &&
            (identical(other.accessToken, accessToken) ||
                const DeepCollectionEquality()
                    .equals(other.accessToken, accessToken)) &&
            (identical(other.householdId, householdId) ||
                const DeepCollectionEquality()
                    .equals(other.householdId, householdId)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)) &&
            (identical(other.refreshTokenExpiry, refreshTokenExpiry) ||
                const DeepCollectionEquality()
                    .equals(other.refreshTokenExpiry, refreshTokenExpiry)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accessToken) ^
      const DeepCollectionEquality().hash(householdId) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      const DeepCollectionEquality().hash(refreshTokenExpiry) ^
      const DeepCollectionEquality().hash(username) ^
      runtimeType.hashCode;
}

extension $AuthorizationResponseExtension on AuthorizationResponse {
  AuthorizationResponse copyWith(
      {String? accessToken,
      String? householdId,
      String? refreshToken,
      int? refreshTokenExpiry,
      String? username}) {
    return AuthorizationResponse(
        accessToken: accessToken ?? this.accessToken,
        householdId: householdId ?? this.householdId,
        refreshToken: refreshToken ?? this.refreshToken,
        refreshTokenExpiry: refreshTokenExpiry ?? this.refreshTokenExpiry,
        username: username ?? this.username);
  }

  AuthorizationResponse copyWithWrapped(
      {Wrapped<String?>? accessToken,
      Wrapped<String?>? householdId,
      Wrapped<String?>? refreshToken,
      Wrapped<int?>? refreshTokenExpiry,
      Wrapped<String?>? username}) {
    return AuthorizationResponse(
        accessToken:
            (accessToken != null ? accessToken.value : this.accessToken),
        householdId:
            (householdId != null ? householdId.value : this.householdId),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken),
        refreshTokenExpiry: (refreshTokenExpiry != null
            ? refreshTokenExpiry.value
            : this.refreshTokenExpiry),
        username: (username != null ? username.value : this.username));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsCustomerData {
  CpsCustomerData({
    required this.customerId,
    this.devices,
    this.serviceType,
  });

  factory CpsCustomerData.fromJson(Map<String, dynamic> json) =>
      _$CpsCustomerDataFromJson(json);

  static const toJsonFactory = _$CpsCustomerDataToJson;
  Map<String, dynamic> toJson() => _$CpsCustomerDataToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'devices', includeIfNull: false, defaultValue: <Device>[])
  final List<Device>? devices;
  @JsonKey(name: 'serviceType', includeIfNull: false, defaultValue: '')
  final String? serviceType;
  static const fromJsonFactory = _$CpsCustomerDataFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsCustomerData &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.devices, devices) ||
                const DeepCollectionEquality()
                    .equals(other.devices, devices)) &&
            (identical(other.serviceType, serviceType) ||
                const DeepCollectionEquality()
                    .equals(other.serviceType, serviceType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(devices) ^
      const DeepCollectionEquality().hash(serviceType) ^
      runtimeType.hashCode;
}

extension $CpsCustomerDataExtension on CpsCustomerData {
  CpsCustomerData copyWith(
      {String? customerId, List<Device>? devices, String? serviceType}) {
    return CpsCustomerData(
        customerId: customerId ?? this.customerId,
        devices: devices ?? this.devices,
        serviceType: serviceType ?? this.serviceType);
  }

  CpsCustomerData copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<List<Device>?>? devices,
      Wrapped<String?>? serviceType}) {
    return CpsCustomerData(
        customerId: (customerId != null ? customerId.value : this.customerId),
        devices: (devices != null ? devices.value : this.devices),
        serviceType:
            (serviceType != null ? serviceType.value : this.serviceType));
  }
}

@JsonSerializable(explicitToJson: true)
class Customer {
  Customer({
    this.countryCode,
    this.credentials,
    this.customerId,
    this.householdId,
    this.name,
  });

  factory Customer.fromJson(Map<String, dynamic> json) =>
      _$CustomerFromJson(json);

  static const toJsonFactory = _$CustomerToJson;
  Map<String, dynamic> toJson() => _$CustomerToJson(this);

  @JsonKey(name: 'countryCode', includeIfNull: false, defaultValue: '')
  final String? countryCode;
  @JsonKey(name: 'credentials', includeIfNull: false, defaultValue: '')
  final String? credentials;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'householdId', includeIfNull: false, defaultValue: '')
  final String? householdId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$CustomerFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Customer &&
            (identical(other.countryCode, countryCode) ||
                const DeepCollectionEquality()
                    .equals(other.countryCode, countryCode)) &&
            (identical(other.credentials, credentials) ||
                const DeepCollectionEquality()
                    .equals(other.credentials, credentials)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.householdId, householdId) ||
                const DeepCollectionEquality()
                    .equals(other.householdId, householdId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(countryCode) ^
      const DeepCollectionEquality().hash(credentials) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(householdId) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $CustomerExtension on Customer {
  Customer copyWith(
      {String? countryCode,
      String? credentials,
      String? customerId,
      String? householdId,
      String? name}) {
    return Customer(
        countryCode: countryCode ?? this.countryCode,
        credentials: credentials ?? this.credentials,
        customerId: customerId ?? this.customerId,
        householdId: householdId ?? this.householdId,
        name: name ?? this.name);
  }

  Customer copyWithWrapped(
      {Wrapped<String?>? countryCode,
      Wrapped<String?>? credentials,
      Wrapped<String?>? customerId,
      Wrapped<String?>? householdId,
      Wrapped<String?>? name}) {
    return Customer(
        countryCode:
            (countryCode != null ? countryCode.value : this.countryCode),
        credentials:
            (credentials != null ? credentials.value : this.credentials),
        customerId: (customerId != null ? customerId.value : this.customerId),
        householdId:
            (householdId != null ? householdId.value : this.householdId),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerMigrationData {
  CustomerMigrationData({
    required this.newCustomerId,
  });

  factory CustomerMigrationData.fromJson(Map<String, dynamic> json) =>
      _$CustomerMigrationDataFromJson(json);

  static const toJsonFactory = _$CustomerMigrationDataToJson;
  Map<String, dynamic> toJson() => _$CustomerMigrationDataToJson(this);

  @JsonKey(name: 'newCustomerId', includeIfNull: false, defaultValue: '')
  final String newCustomerId;
  static const fromJsonFactory = _$CustomerMigrationDataFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerMigrationData &&
            (identical(other.newCustomerId, newCustomerId) ||
                const DeepCollectionEquality()
                    .equals(other.newCustomerId, newCustomerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(newCustomerId) ^ runtimeType.hashCode;
}

extension $CustomerMigrationDataExtension on CustomerMigrationData {
  CustomerMigrationData copyWith({String? newCustomerId}) {
    return CustomerMigrationData(
        newCustomerId: newCustomerId ?? this.newCustomerId);
  }

  CustomerMigrationData copyWithWrapped({Wrapped<String>? newCustomerId}) {
    return CustomerMigrationData(
        newCustomerId:
            (newCustomerId != null ? newCustomerId.value : this.newCustomerId));
  }
}

@JsonSerializable(explicitToJson: true)
class Device {
  Device({
    this.deviceId,
    this.deviceType,
    this.platformType,
    this.serialNumber,
    this.smartCardId,
  });

  factory Device.fromJson(Map<String, dynamic> json) => _$DeviceFromJson(json);

  static const toJsonFactory = _$DeviceToJson;
  Map<String, dynamic> toJson() => _$DeviceToJson(this);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  static const fromJsonFactory = _$DeviceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Device &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      runtimeType.hashCode;
}

extension $DeviceExtension on Device {
  Device copyWith(
      {String? deviceId,
      String? deviceType,
      String? platformType,
      String? serialNumber,
      String? smartCardId}) {
    return Device(
        deviceId: deviceId ?? this.deviceId,
        deviceType: deviceType ?? this.deviceType,
        platformType: platformType ?? this.platformType,
        serialNumber: serialNumber ?? this.serialNumber,
        smartCardId: smartCardId ?? this.smartCardId);
  }

  Device copyWithWrapped(
      {Wrapped<String?>? deviceId,
      Wrapped<String?>? deviceType,
      Wrapped<String?>? platformType,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? smartCardId}) {
    return Device(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceAuthenticationRequest {
  DeviceAuthenticationRequest({
    required this.deviceId,
  });

  factory DeviceAuthenticationRequest.fromJson(Map<String, dynamic> json) =>
      _$DeviceAuthenticationRequestFromJson(json);

  static const toJsonFactory = _$DeviceAuthenticationRequestToJson;
  Map<String, dynamic> toJson() => _$DeviceAuthenticationRequestToJson(this);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  static const fromJsonFactory = _$DeviceAuthenticationRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceAuthenticationRequest &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^ runtimeType.hashCode;
}

extension $DeviceAuthenticationRequestExtension on DeviceAuthenticationRequest {
  DeviceAuthenticationRequest copyWith({String? deviceId}) {
    return DeviceAuthenticationRequest(deviceId: deviceId ?? this.deviceId);
  }

  DeviceAuthenticationRequest copyWithWrapped({Wrapped<String>? deviceId}) {
    return DeviceAuthenticationRequest(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceAuthenticationResponse {
  DeviceAuthenticationResponse({
    this.authenticationToken,
  });

  factory DeviceAuthenticationResponse.fromJson(Map<String, dynamic> json) =>
      _$DeviceAuthenticationResponseFromJson(json);

  static const toJsonFactory = _$DeviceAuthenticationResponseToJson;
  Map<String, dynamic> toJson() => _$DeviceAuthenticationResponseToJson(this);

  @JsonKey(name: 'authenticationToken', includeIfNull: false, defaultValue: '')
  final String? authenticationToken;
  static const fromJsonFactory = _$DeviceAuthenticationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceAuthenticationResponse &&
            (identical(other.authenticationToken, authenticationToken) ||
                const DeepCollectionEquality()
                    .equals(other.authenticationToken, authenticationToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authenticationToken) ^
      runtimeType.hashCode;
}

extension $DeviceAuthenticationResponseExtension
    on DeviceAuthenticationResponse {
  DeviceAuthenticationResponse copyWith({String? authenticationToken}) {
    return DeviceAuthenticationResponse(
        authenticationToken: authenticationToken ?? this.authenticationToken);
  }

  DeviceAuthenticationResponse copyWithWrapped(
      {Wrapped<String?>? authenticationToken}) {
    return DeviceAuthenticationResponse(
        authenticationToken: (authenticationToken != null
            ? authenticationToken.value
            : this.authenticationToken));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceRefreshTokenRequestBody {
  DeviceRefreshTokenRequestBody({
    required this.deviceRefreshToken,
  });

  factory DeviceRefreshTokenRequestBody.fromJson(Map<String, dynamic> json) =>
      _$DeviceRefreshTokenRequestBodyFromJson(json);

  static const toJsonFactory = _$DeviceRefreshTokenRequestBodyToJson;
  Map<String, dynamic> toJson() => _$DeviceRefreshTokenRequestBodyToJson(this);

  @JsonKey(name: 'deviceRefreshToken', includeIfNull: false, defaultValue: '')
  final String deviceRefreshToken;
  static const fromJsonFactory = _$DeviceRefreshTokenRequestBodyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceRefreshTokenRequestBody &&
            (identical(other.deviceRefreshToken, deviceRefreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.deviceRefreshToken, deviceRefreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceRefreshToken) ^
      runtimeType.hashCode;
}

extension $DeviceRefreshTokenRequestBodyExtension
    on DeviceRefreshTokenRequestBody {
  DeviceRefreshTokenRequestBody copyWith({String? deviceRefreshToken}) {
    return DeviceRefreshTokenRequestBody(
        deviceRefreshToken: deviceRefreshToken ?? this.deviceRefreshToken);
  }

  DeviceRefreshTokenRequestBody copyWithWrapped(
      {Wrapped<String>? deviceRefreshToken}) {
    return DeviceRefreshTokenRequestBody(
        deviceRefreshToken: (deviceRefreshToken != null
            ? deviceRefreshToken.value
            : this.deviceRefreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceRefreshTokenResponse {
  DeviceRefreshTokenResponse({
    this.accessToken,
    this.householdId,
    this.refreshToken,
  });

  factory DeviceRefreshTokenResponse.fromJson(Map<String, dynamic> json) =>
      _$DeviceRefreshTokenResponseFromJson(json);

  static const toJsonFactory = _$DeviceRefreshTokenResponseToJson;
  Map<String, dynamic> toJson() => _$DeviceRefreshTokenResponseToJson(this);

  @JsonKey(name: 'accessToken', includeIfNull: false, defaultValue: '')
  final String? accessToken;
  @JsonKey(name: 'householdId', includeIfNull: false, defaultValue: '')
  final String? householdId;
  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  static const fromJsonFactory = _$DeviceRefreshTokenResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceRefreshTokenResponse &&
            (identical(other.accessToken, accessToken) ||
                const DeepCollectionEquality()
                    .equals(other.accessToken, accessToken)) &&
            (identical(other.householdId, householdId) ||
                const DeepCollectionEquality()
                    .equals(other.householdId, householdId)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accessToken) ^
      const DeepCollectionEquality().hash(householdId) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      runtimeType.hashCode;
}

extension $DeviceRefreshTokenResponseExtension on DeviceRefreshTokenResponse {
  DeviceRefreshTokenResponse copyWith(
      {String? accessToken, String? householdId, String? refreshToken}) {
    return DeviceRefreshTokenResponse(
        accessToken: accessToken ?? this.accessToken,
        householdId: householdId ?? this.householdId,
        refreshToken: refreshToken ?? this.refreshToken);
  }

  DeviceRefreshTokenResponse copyWithWrapped(
      {Wrapped<String?>? accessToken,
      Wrapped<String?>? householdId,
      Wrapped<String?>? refreshToken}) {
    return DeviceRefreshTokenResponse(
        accessToken:
            (accessToken != null ? accessToken.value : this.accessToken),
        householdId:
            (householdId != null ? householdId.value : this.householdId),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    this.allErrors,
    this.correlationId,
    this.details,
    required this.httpStatusCode,
    required this.message,
    this.statusCode,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(statusCode) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {List<String>? allErrors,
      String? correlationId,
      String? details,
      int? httpStatusCode,
      String? message,
      int? statusCode}) {
    return KrakenError(
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId,
        details: details ?? this.details,
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        message: message ?? this.message,
        statusCode: statusCode ?? this.statusCode);
  }

  KrakenError copyWithWrapped(
      {Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId,
      Wrapped<String?>? details,
      Wrapped<int>? httpStatusCode,
      Wrapped<String>? message,
      Wrapped<int?>? statusCode}) {
    return KrakenError(
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId),
        details: (details != null ? details.value : this.details),
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        message: (message != null ? message.value : this.message),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode));
  }
}

@JsonSerializable(explicitToJson: true)
class MqttTokenResponse {
  MqttTokenResponse({
    this.token,
  });

  factory MqttTokenResponse.fromJson(Map<String, dynamic> json) =>
      _$MqttTokenResponseFromJson(json);

  static const toJsonFactory = _$MqttTokenResponseToJson;
  Map<String, dynamic> toJson() => _$MqttTokenResponseToJson(this);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$MqttTokenResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MqttTokenResponse &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^ runtimeType.hashCode;
}

extension $MqttTokenResponseExtension on MqttTokenResponse {
  MqttTokenResponse copyWith({String? token}) {
    return MqttTokenResponse(token: token ?? this.token);
  }

  MqttTokenResponse copyWithWrapped({Wrapped<String?>? token}) {
    return MqttTokenResponse(token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class OneConnectAuthenticationResponse {
  OneConnectAuthenticationResponse({
    this.oneConnectToken,
  });

  factory OneConnectAuthenticationResponse.fromJson(
          Map<String, dynamic> json) =>
      _$OneConnectAuthenticationResponseFromJson(json);

  static const toJsonFactory = _$OneConnectAuthenticationResponseToJson;
  Map<String, dynamic> toJson() =>
      _$OneConnectAuthenticationResponseToJson(this);

  @JsonKey(name: 'oneConnectToken', includeIfNull: false, defaultValue: '')
  final String? oneConnectToken;
  static const fromJsonFactory = _$OneConnectAuthenticationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OneConnectAuthenticationResponse &&
            (identical(other.oneConnectToken, oneConnectToken) ||
                const DeepCollectionEquality()
                    .equals(other.oneConnectToken, oneConnectToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(oneConnectToken) ^
      runtimeType.hashCode;
}

extension $OneConnectAuthenticationResponseExtension
    on OneConnectAuthenticationResponse {
  OneConnectAuthenticationResponse copyWith({String? oneConnectToken}) {
    return OneConnectAuthenticationResponse(
        oneConnectToken: oneConnectToken ?? this.oneConnectToken);
  }

  OneConnectAuthenticationResponse copyWithWrapped(
      {Wrapped<String?>? oneConnectToken}) {
    return OneConnectAuthenticationResponse(
        oneConnectToken: (oneConnectToken != null
            ? oneConnectToken.value
            : this.oneConnectToken));
  }
}

@JsonSerializable(explicitToJson: true)
class OneConnectRequest {
  OneConnectRequest({
    required this.deviceId,
  });

  factory OneConnectRequest.fromJson(Map<String, dynamic> json) =>
      _$OneConnectRequestFromJson(json);

  static const toJsonFactory = _$OneConnectRequestToJson;
  Map<String, dynamic> toJson() => _$OneConnectRequestToJson(this);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  static const fromJsonFactory = _$OneConnectRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OneConnectRequest &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^ runtimeType.hashCode;
}

extension $OneConnectRequestExtension on OneConnectRequest {
  OneConnectRequest copyWith({String? deviceId}) {
    return OneConnectRequest(deviceId: deviceId ?? this.deviceId);
  }

  OneConnectRequest copyWithWrapped({Wrapped<String>? deviceId}) {
    return OneConnectRequest(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class PreProvisioningRequest {
  PreProvisioningRequest({
    this.doubleCheck,
    this.offset,
    required this.url,
  });

  factory PreProvisioningRequest.fromJson(Map<String, dynamic> json) =>
      _$PreProvisioningRequestFromJson(json);

  static const toJsonFactory = _$PreProvisioningRequestToJson;
  Map<String, dynamic> toJson() => _$PreProvisioningRequestToJson(this);

  @JsonKey(name: 'doubleCheck', includeIfNull: false)
  final bool? doubleCheck;
  @JsonKey(name: 'offset', includeIfNull: false)
  final int? offset;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$PreProvisioningRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PreProvisioningRequest &&
            (identical(other.doubleCheck, doubleCheck) ||
                const DeepCollectionEquality()
                    .equals(other.doubleCheck, doubleCheck)) &&
            (identical(other.offset, offset) ||
                const DeepCollectionEquality().equals(other.offset, offset)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(doubleCheck) ^
      const DeepCollectionEquality().hash(offset) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $PreProvisioningRequestExtension on PreProvisioningRequest {
  PreProvisioningRequest copyWith(
      {bool? doubleCheck, int? offset, String? url}) {
    return PreProvisioningRequest(
        doubleCheck: doubleCheck ?? this.doubleCheck,
        offset: offset ?? this.offset,
        url: url ?? this.url);
  }

  PreProvisioningRequest copyWithWrapped(
      {Wrapped<bool?>? doubleCheck,
      Wrapped<int?>? offset,
      Wrapped<String>? url}) {
    return PreProvisioningRequest(
        doubleCheck:
            (doubleCheck != null ? doubleCheck.value : this.doubleCheck),
        offset: (offset != null ? offset.value : this.offset),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class PreProvisioningStatisticsRequest {
  PreProvisioningStatisticsRequest({
    this.limit,
  });

  factory PreProvisioningStatisticsRequest.fromJson(
          Map<String, dynamic> json) =>
      _$PreProvisioningStatisticsRequestFromJson(json);

  static const toJsonFactory = _$PreProvisioningStatisticsRequestToJson;
  Map<String, dynamic> toJson() =>
      _$PreProvisioningStatisticsRequestToJson(this);

  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  static const fromJsonFactory = _$PreProvisioningStatisticsRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PreProvisioningStatisticsRequest &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(limit) ^ runtimeType.hashCode;
}

extension $PreProvisioningStatisticsRequestExtension
    on PreProvisioningStatisticsRequest {
  PreProvisioningStatisticsRequest copyWith({int? limit}) {
    return PreProvisioningStatisticsRequest(limit: limit ?? this.limit);
  }

  PreProvisioningStatisticsRequest copyWithWrapped({Wrapped<int?>? limit}) {
    return PreProvisioningStatisticsRequest(
        limit: (limit != null ? limit.value : this.limit));
  }
}

@JsonSerializable(explicitToJson: true)
class RefreshSignInRequest {
  RefreshSignInRequest({
    required this.refreshToken,
    this.username,
  });

  factory RefreshSignInRequest.fromJson(Map<String, dynamic> json) =>
      _$RefreshSignInRequestFromJson(json);

  static const toJsonFactory = _$RefreshSignInRequestToJson;
  Map<String, dynamic> toJson() => _$RefreshSignInRequestToJson(this);

  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String refreshToken;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  static const fromJsonFactory = _$RefreshSignInRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RefreshSignInRequest &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(refreshToken) ^
      const DeepCollectionEquality().hash(username) ^
      runtimeType.hashCode;
}

extension $RefreshSignInRequestExtension on RefreshSignInRequest {
  RefreshSignInRequest copyWith({String? refreshToken, String? username}) {
    return RefreshSignInRequest(
        refreshToken: refreshToken ?? this.refreshToken,
        username: username ?? this.username);
  }

  RefreshSignInRequest copyWithWrapped(
      {Wrapped<String>? refreshToken, Wrapped<String?>? username}) {
    return RefreshSignInRequest(
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken),
        username: (username != null ? username.value : this.username));
  }
}

@JsonSerializable(explicitToJson: true)
class SsoCredentials {
  SsoCredentials({
    this.authorizationCode,
    this.codeVerifier,
    this.validityToken,
  });

  factory SsoCredentials.fromJson(Map<String, dynamic> json) =>
      _$SsoCredentialsFromJson(json);

  static const toJsonFactory = _$SsoCredentialsToJson;
  Map<String, dynamic> toJson() => _$SsoCredentialsToJson(this);

  @JsonKey(name: 'authorizationCode', includeIfNull: false, defaultValue: '')
  final String? authorizationCode;
  @JsonKey(name: 'codeVerifier', includeIfNull: false, defaultValue: '')
  final String? codeVerifier;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$SsoCredentialsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SsoCredentials &&
            (identical(other.authorizationCode, authorizationCode) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationCode, authorizationCode)) &&
            (identical(other.codeVerifier, codeVerifier) ||
                const DeepCollectionEquality()
                    .equals(other.codeVerifier, codeVerifier)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorizationCode) ^
      const DeepCollectionEquality().hash(codeVerifier) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $SsoCredentialsExtension on SsoCredentials {
  SsoCredentials copyWith(
      {String? authorizationCode,
      String? codeVerifier,
      String? validityToken}) {
    return SsoCredentials(
        authorizationCode: authorizationCode ?? this.authorizationCode,
        codeVerifier: codeVerifier ?? this.codeVerifier,
        validityToken: validityToken ?? this.validityToken);
  }

  SsoCredentials copyWithWrapped(
      {Wrapped<String?>? authorizationCode,
      Wrapped<String?>? codeVerifier,
      Wrapped<String?>? validityToken}) {
    return SsoCredentials(
        authorizationCode: (authorizationCode != null
            ? authorizationCode.value
            : this.authorizationCode),
        codeVerifier:
            (codeVerifier != null ? codeVerifier.value : this.codeVerifier),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class SsoSignInRequest {
  SsoSignInRequest({
    this.authorizationGrant,
  });

  factory SsoSignInRequest.fromJson(Map<String, dynamic> json) =>
      _$SsoSignInRequestFromJson(json);

  static const toJsonFactory = _$SsoSignInRequestToJson;
  Map<String, dynamic> toJson() => _$SsoSignInRequestToJson(this);

  @JsonKey(name: 'authorizationGrant', includeIfNull: false)
  final SsoCredentials? authorizationGrant;
  static const fromJsonFactory = _$SsoSignInRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SsoSignInRequest &&
            (identical(other.authorizationGrant, authorizationGrant) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationGrant, authorizationGrant)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorizationGrant) ^
      runtimeType.hashCode;
}

extension $SsoSignInRequestExtension on SsoSignInRequest {
  SsoSignInRequest copyWith({SsoCredentials? authorizationGrant}) {
    return SsoSignInRequest(
        authorizationGrant: authorizationGrant ?? this.authorizationGrant);
  }

  SsoSignInRequest copyWithWrapped(
      {Wrapped<SsoCredentials?>? authorizationGrant}) {
    return SsoSignInRequest(
        authorizationGrant: (authorizationGrant != null
            ? authorizationGrant.value
            : this.authorizationGrant));
  }
}

@JsonSerializable(explicitToJson: true)
class SvcRefreshTokenPayload {
  SvcRefreshTokenPayload({
    required this.refreshToken,
  });

  factory SvcRefreshTokenPayload.fromJson(Map<String, dynamic> json) =>
      _$SvcRefreshTokenPayloadFromJson(json);

  static const toJsonFactory = _$SvcRefreshTokenPayloadToJson;
  Map<String, dynamic> toJson() => _$SvcRefreshTokenPayloadToJson(this);

  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String refreshToken;
  static const fromJsonFactory = _$SvcRefreshTokenPayloadFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SvcRefreshTokenPayload &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(refreshToken) ^ runtimeType.hashCode;
}

extension $SvcRefreshTokenPayloadExtension on SvcRefreshTokenPayload {
  SvcRefreshTokenPayload copyWith({String? refreshToken}) {
    return SvcRefreshTokenPayload(
        refreshToken: refreshToken ?? this.refreshToken);
  }

  SvcRefreshTokenPayload copyWithWrapped({Wrapped<String>? refreshToken}) {
    return SvcRefreshTokenPayload(
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
