// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'bookmark_service.enums.swagger.dart' as enums;
export 'bookmark_service.enums.swagger.dart';

part 'bookmark_service.swagger.chopper.dart';
part 'bookmark_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class BookmarkService extends ChopperService {
  static BookmarkService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$BookmarkService(client);
    }

    final newClient = ChopperClient(
        services: [_$BookmarkService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$BookmarkService(newClient);
  }

  ///Get latest bookmark for given profile id and content id
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param profileId profile identifier
  ///@param contentId content identifier should be Crid plus Imi, Crid for vod content type also is possible but is only meant for older clients
  ///@param contentType content type
  Future<chopper.Response<LatestBookmarkView>> latestProfileIdContentIdGet({
    String? xCus = 'X-Cus',
    required String? profileId,
    required String? contentId,
    enums.LatestProfileIdContentIdGetContentType? contentType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LatestBookmarkView, () => LatestBookmarkView.fromJsonFactory);

    return _latestProfileIdContentIdGet(
        xCus: xCus,
        profileId: profileId,
        contentId: contentId,
        contentType: contentType?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Get latest bookmark for given profile id and content id
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param profileId profile identifier
  ///@param contentId content identifier should be Crid plus Imi, Crid for vod content type also is possible but is only meant for older clients
  ///@param contentType content type
  @Get(path: '/latest/{profileId}/{contentId}')
  Future<chopper.Response<LatestBookmarkView>> _latestProfileIdContentIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Path('profileId') required String? profileId,
    @Path('contentId') required String? contentId,
    @Query('contentType') String? contentType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get all bookmarks for given profile with given content type.
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param profileId profile identifier
  ///@param contentType content source type
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<BookmarkArray>> profilesProfileIdBookmarksGet({
    String? xCus = 'X-Cus',
    required String? profileId,
    enums.ProfilesProfileIdBookmarksGetContentType? contentType,
    String? ifModifiedSince,
    String? xBMSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Bookmark, () => Bookmark.fromJsonFactory);

    return _profilesProfileIdBookmarksGet(
        xCus: xCus,
        profileId: profileId,
        contentType: contentType?.value?.toString(),
        ifModifiedSince: ifModifiedSince,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Get all bookmarks for given profile with given content type.
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param profileId profile identifier
  ///@param contentType content source type
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/profiles/{profileId}/bookmarks')
  Future<chopper.Response<BookmarkArray>> _profilesProfileIdBookmarksGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Path('profileId') required String? profileId,
    @Query('contentType') String? contentType,
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete all bookmarks for given profile and belonging customer (x-cus)
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param profileId profile identifier
  Future<chopper.Response> profilesProfileIdBookmarksDelete({
    String? xCus = 'X-Cus',
    required String? profileId,
    String? cacheControl,
  }) {
    return _profilesProfileIdBookmarksDelete(
        xCus: xCus, profileId: profileId, cacheControl: cacheControl);
  }

  ///Delete all bookmarks for given profile and belonging customer (x-cus)
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param profileId profile identifier
  @Delete(path: '/profiles/{profileId}/bookmarks')
  Future<chopper.Response> _profilesProfileIdBookmarksDelete({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Stores a bookmark for a given profile and content (which can be either vod, replay, or a recording)
  ///@param profileId profile identifier
  ///@param contentId content identifier should be Crid plus Imi, Crid for vod content type also is possible but is only meant for older clients
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param X-Dev Contains device identifier - used for informational purposes
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  ///@param X-Go-Dev Contains HZNGO device identifier
  Future<chopper.Response> profilesProfileIdBookmarksContentIdPut({
    required String? profileId,
    required String? contentId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xBMSExplicitLogging,
    String? xGoDev,
    String? cacheControl,
    required BookmarkParams? body,
  }) {
    return _profilesProfileIdBookmarksContentIdPut(
        profileId: profileId,
        contentId: contentId,
        xCus: xCus,
        xDev: xDev,
        xBMSExplicitLogging: xBMSExplicitLogging,
        xGoDev: xGoDev,
        cacheControl: cacheControl,
        body: body);
  }

  ///Stores a bookmark for a given profile and content (which can be either vod, replay, or a recording)
  ///@param profileId profile identifier
  ///@param contentId content identifier should be Crid plus Imi, Crid for vod content type also is possible but is only meant for older clients
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param X-Dev Contains device identifier - used for informational purposes
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  ///@param X-Go-Dev Contains HZNGO device identifier
  @Put(
    path: '/profiles/{profileId}/bookmarks/{contentId}',
    optionalBody: true,
  )
  Future<chopper.Response> _profilesProfileIdBookmarksContentIdPut({
    @Path('profileId') required String? profileId,
    @Path('contentId') required String? contentId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('Cache-Control') String? cacheControl,
    @Body() required BookmarkParams? body,
  });

  ///Check whether bookmarks exist for given profile and request params.
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param X-Dev Contains device identifier - used for informational purposes
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<BookmarksExist>> profilesProfileIdBookmarksExistPost({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xBMSExplicitLogging,
    required String? profileId,
    String? cacheControl,
    required CheckBookmarksExist? body,
  }) {
    generatedMapping.putIfAbsent(
        BookmarksExist, () => BookmarksExist.fromJsonFactory);

    return _profilesProfileIdBookmarksExistPost(
        xCus: xCus,
        xDev: xDev,
        xBMSExplicitLogging: xBMSExplicitLogging,
        profileId: profileId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Check whether bookmarks exist for given profile and request params.
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param X-Dev Contains device identifier - used for informational purposes
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Post(
    path: '/profiles/{profileId}/bookmarks/exist',
    optionalBody: true,
  )
  Future<chopper.Response<BookmarksExist>>
      _profilesProfileIdBookmarksExistPost({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CheckBookmarksExist? body,
  });

  ///Get continue watching list for given profile, apply grouping by show and apply grouping by title id(with fallback by content id) for single titles
  ///@param profileId profile identifier
  ///@param contentTypes Content types
  ///@param limit number of bookmarks
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<List<ContinueWatchingItem>>>
      profilesProfileIdContinueWatchingGet({
    required String? profileId,
    List<String>? contentTypes,
    int? limit,
    String? xBMSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContinueWatchingItem, () => ContinueWatchingItem.fromJsonFactory);

    return _profilesProfileIdContinueWatchingGet(
        profileId: profileId,
        contentTypes: contentTypes,
        limit: limit,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Get continue watching list for given profile, apply grouping by show and apply grouping by title id(with fallback by content id) for single titles
  ///@param profileId profile identifier
  ///@param contentTypes Content types
  ///@param limit number of bookmarks
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/profiles/{profileId}/continue-watching')
  Future<chopper.Response<List<ContinueWatchingItem>>>
      _profilesProfileIdContinueWatchingGet({
    @Path('profileId') required String? profileId,
    @Query('contentTypes') List<String>? contentTypes,
    @Query('limit') int? limit,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete items from continue watching list for given profile and belonging customer (x-cus)
  ///@param X-Cus Contains customer identifier
  ///@param profileId profile identifier
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response> profilesProfileIdContinueWatchingDeletePost({
    String? xCus = 'X-Cus',
    required String? profileId,
    String? xBMSExplicitLogging,
    String? cacheControl,
    required ContinueWatchingDeleteParams? body,
  }) {
    return _profilesProfileIdContinueWatchingDeletePost(
        xCus: xCus,
        profileId: profileId,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Delete items from continue watching list for given profile and belonging customer (x-cus)
  ///@param X-Cus Contains customer identifier
  ///@param profileId profile identifier
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Post(
    path: '/profiles/{profileId}/continue-watching/delete',
    optionalBody: true,
  )
  Future<chopper.Response> _profilesProfileIdContinueWatchingDeletePost({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Path('profileId') required String? profileId,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ContinueWatchingDeleteParams? body,
  });

  ///Delete all bookmarks for given customer
  ///@param customerId customer identifier
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response> customersCustomerIdBookmarksDelete({
    required String? customerId,
    String? xBMSExplicitLogging,
    String? cacheControl,
  }) {
    return _customersCustomerIdBookmarksDelete(
        customerId: customerId,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Delete all bookmarks for given customer
  ///@param customerId customer identifier
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Delete(path: '/customers/{customerId}/bookmarks')
  Future<chopper.Response> _customersCustomerIdBookmarksDelete({
    @Path('customerId') required String? customerId,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Upsert bookmarks for given profile
  ///@param customerId customer identifier
  ///@param profileId profile identifier
  ///@param X-Cus Contains customer identifier - used for informational purposes
  Future<chopper.Response> customersCustomerIdProfilesProfileIdBookmarksPut({
    required String? customerId,
    required String? profileId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required BulkBookmarkParamsArray? body,
  }) {
    generatedMapping.putIfAbsent(
        BulkBookmarkParams, () => BulkBookmarkParams.fromJsonFactory);

    return _customersCustomerIdProfilesProfileIdBookmarksPut(
        customerId: customerId,
        profileId: profileId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Upsert bookmarks for given profile
  ///@param customerId customer identifier
  ///@param profileId profile identifier
  ///@param X-Cus Contains customer identifier - used for informational purposes
  @Put(
    path: '/customers/{customerId}/profiles/{profileId}/bookmarks',
    optionalBody: true,
  )
  Future<chopper.Response> _customersCustomerIdProfilesProfileIdBookmarksPut({
    @Path('customerId') required String? customerId,
    @Path('profileId') required String? profileId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required BulkBookmarkParamsArray? body,
  });

  ///Migrate customer to new customer id
  Future<chopper.Response> v1CustomersMigratePost({
    String? cacheControl,
    required MigrateCustomerParam? body,
  }) {
    return _v1CustomersMigratePost(cacheControl: cacheControl, body: body);
  }

  ///Migrate customer to new customer id
  @Post(
    path: '/v1/customers/migrate',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomersMigratePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required MigrateCustomerParam? body,
  });

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<List<BookmarkAdvanced>>> bookmarksSearchPost({
    String? xCus = 'X-Cus',
    String? ifModifiedSince,
    String? xBMSExplicitLogging,
    String? cacheControl,
    required BookmarkSearchFilter? body,
  }) {
    generatedMapping.putIfAbsent(
        BookmarkAdvanced, () => BookmarkAdvanced.fromJsonFactory);

    return _bookmarksSearchPost(
        xCus: xCus,
        ifModifiedSince: ifModifiedSince,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Post(
    path: '/bookmarks/search',
    optionalBody: true,
  )
  Future<chopper.Response<List<BookmarkAdvanced>>> _bookmarksSearchPost({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
    @Body() required BookmarkSearchFilter? body,
  });

  ///Delete from all profiles the given contentId from the give content type
  ///@param contentType Content type of the content id. Recording content type groups local-recording and network-recording.
  ///@param contentId Must be Crid:imi when setting the bookmark Example `crid:~~2F~~2Fe2e-si.lgi.com~~2F1111,imi:4f628ba8588d7bafb` but crid only when getting the Bookmark for content type VOD Example `crid:~~2F~~2Fe2e-si.lgi.com~~2F1111`
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response> bookmarksContentTypeContentIdDelete({
    required enums.BookmarksContentTypeContentIdDeleteContentType? contentType,
    required String? contentId,
    String? ifModifiedSince,
    String? xBMSExplicitLogging,
    String? cacheControl,
  }) {
    return _bookmarksContentTypeContentIdDelete(
        contentType: contentType?.value?.toString(),
        contentId: contentId,
        ifModifiedSince: ifModifiedSince,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Delete from all profiles the given contentId from the give content type
  ///@param contentType Content type of the content id. Recording content type groups local-recording and network-recording.
  ///@param contentId Must be Crid:imi when setting the bookmark Example `crid:~~2F~~2Fe2e-si.lgi.com~~2F1111,imi:4f628ba8588d7bafb` but crid only when getting the Bookmark for content type VOD Example `crid:~~2F~~2Fe2e-si.lgi.com~~2F1111`
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Delete(path: '/bookmarks/{contentType}/{contentId}')
  Future<chopper.Response> _bookmarksContentTypeContentIdDelete({
    @Path('contentType') required String? contentType,
    @Path('contentId') required String? contentId,
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<List<BookmarkAdvancedV2>>> v2BookmarksSearchPost({
    String? xCus = 'X-Cus',
    String? ifModifiedSince,
    String? xBMSExplicitLogging,
    String? cacheControl,
    required BookmarkSearchFilterV2? body,
  }) {
    generatedMapping.putIfAbsent(
        BookmarkAdvancedV2, () => BookmarkAdvancedV2.fromJsonFactory);

    return _v2BookmarksSearchPost(
        xCus: xCus,
        ifModifiedSince: ifModifiedSince,
        xBMSExplicitLogging: xBMSExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param If-Modified-Since Can be ignored based on deployment configuration. Last modification date returned from this api for further validation following the format 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  ///@param X-BMS-Explicit-Logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Post(
    path: '/v2/bookmarks/search',
    optionalBody: true,
  )
  Future<chopper.Response<List<BookmarkAdvancedV2>>> _v2BookmarksSearchPost({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('X-BMS-Explicit-Logging') String? xBMSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
    @Body() required BookmarkSearchFilterV2? body,
  });
}

@JsonSerializable(explicitToJson: true)
class BookmarkParams {
  BookmarkParams({
    required this.customerId,
    required this.titleId,
    required this.position,
    required this.duration,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.isAdult,
    this.minimumAge,
    required this.contentType,
    this.deletionDate,
    this.channelId,
    this.cpeId,
    this.timestamp,
    this.partiallyWatchedBreakId,
    this.timingBasis,
  });

  factory BookmarkParams.fromJson(Map<String, dynamic> json) =>
      _$BookmarkParamsFromJson(json);

  static const toJsonFactory = _$BookmarkParamsToJson;
  Map<String, dynamic> toJson() => _$BookmarkParamsToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: bookmarkParamsContentTypeToJson,
    fromJson: bookmarkParamsContentTypeFromJson,
  )
  final enums.BookmarkParamsContentType contentType;
  @JsonKey(name: 'deletionDate', includeIfNull: false)
  final DateTime? deletionDate;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  @JsonKey(
    name: 'timingBasis',
    includeIfNull: false,
    toJson: timingBasisToJson,
    fromJson: timingBasisFromJson,
  )
  final enums.TimingBasis? timingBasis;
  static const fromJsonFactory = _$BookmarkParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkParams &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.deletionDate, deletionDate) ||
                const DeepCollectionEquality()
                    .equals(other.deletionDate, deletionDate)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)) &&
            (identical(other.timingBasis, timingBasis) ||
                const DeepCollectionEquality()
                    .equals(other.timingBasis, timingBasis)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(deletionDate) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      const DeepCollectionEquality().hash(timingBasis) ^
      runtimeType.hashCode;
}

extension $BookmarkParamsExtension on BookmarkParams {
  BookmarkParams copyWith(
      {String? customerId,
      String? titleId,
      int? position,
      int? duration,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      bool? isAdult,
      int? minimumAge,
      enums.BookmarkParamsContentType? contentType,
      DateTime? deletionDate,
      String? channelId,
      String? cpeId,
      DateTime? timestamp,
      String? partiallyWatchedBreakId,
      enums.TimingBasis? timingBasis}) {
    return BookmarkParams(
        customerId: customerId ?? this.customerId,
        titleId: titleId ?? this.titleId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        contentType: contentType ?? this.contentType,
        deletionDate: deletionDate ?? this.deletionDate,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId,
        timestamp: timestamp ?? this.timestamp,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId,
        timingBasis: timingBasis ?? this.timingBasis);
  }

  BookmarkParams copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<String>? titleId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? minimumAge,
      Wrapped<enums.BookmarkParamsContentType>? contentType,
      Wrapped<DateTime?>? deletionDate,
      Wrapped<String?>? channelId,
      Wrapped<String?>? cpeId,
      Wrapped<DateTime?>? timestamp,
      Wrapped<String?>? partiallyWatchedBreakId,
      Wrapped<enums.TimingBasis?>? timingBasis}) {
    return BookmarkParams(
        customerId: (customerId != null ? customerId.value : this.customerId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        deletionDate:
            (deletionDate != null ? deletionDate.value : this.deletionDate),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId),
        timingBasis:
            (timingBasis != null ? timingBasis.value : this.timingBasis));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkBookmarkParams {
  BulkBookmarkParams({
    required this.contentId,
    required this.titleId,
    required this.position,
    required this.duration,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.isAdult,
    this.minimumAge,
    required this.contentType,
    this.channelId,
    required this.timestamp,
    this.deletionDate,
  });

  factory BulkBookmarkParams.fromJson(Map<String, dynamic> json) =>
      _$BulkBookmarkParamsFromJson(json);

  static const toJsonFactory = _$BulkBookmarkParamsToJson;
  Map<String, dynamic> toJson() => _$BulkBookmarkParamsToJson(this);

  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: bulkBookmarkParamsContentTypeToJson,
    fromJson: bulkBookmarkParamsContentTypeFromJson,
  )
  final enums.BulkBookmarkParamsContentType contentType;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime timestamp;
  @JsonKey(name: 'deletionDate', includeIfNull: false)
  final DateTime? deletionDate;
  static const fromJsonFactory = _$BulkBookmarkParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkBookmarkParams &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.deletionDate, deletionDate) ||
                const DeepCollectionEquality()
                    .equals(other.deletionDate, deletionDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(deletionDate) ^
      runtimeType.hashCode;
}

extension $BulkBookmarkParamsExtension on BulkBookmarkParams {
  BulkBookmarkParams copyWith(
      {String? contentId,
      String? titleId,
      int? position,
      int? duration,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      bool? isAdult,
      int? minimumAge,
      enums.BulkBookmarkParamsContentType? contentType,
      String? channelId,
      DateTime? timestamp,
      DateTime? deletionDate}) {
    return BulkBookmarkParams(
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        contentType: contentType ?? this.contentType,
        channelId: channelId ?? this.channelId,
        timestamp: timestamp ?? this.timestamp,
        deletionDate: deletionDate ?? this.deletionDate);
  }

  BulkBookmarkParams copyWithWrapped(
      {Wrapped<String>? contentId,
      Wrapped<String>? titleId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? minimumAge,
      Wrapped<enums.BulkBookmarkParamsContentType>? contentType,
      Wrapped<String?>? channelId,
      Wrapped<DateTime>? timestamp,
      Wrapped<DateTime?>? deletionDate}) {
    return BulkBookmarkParams(
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        channelId: (channelId != null ? channelId.value : this.channelId),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        deletionDate:
            (deletionDate != null ? deletionDate.value : this.deletionDate));
  }
}

typedef BookmarkArray = List<Bookmark>;
typedef BulkBookmarkParamsArray = List<BulkBookmarkParams>;

@JsonSerializable(explicitToJson: true)
class Bookmark {
  Bookmark({
    required this.contentId,
    required this.position,
    required this.contentType,
    this.viewedState,
    this.viewState,
    this.timestamp,
    this.isAdult,
    this.cpeId,
    this.partiallyWatchedBreakId,
    this.timingBasis,
  });

  factory Bookmark.fromJson(Map<String, dynamic> json) =>
      _$BookmarkFromJson(json);

  static const toJsonFactory = _$BookmarkToJson;
  Map<String, dynamic> toJson() => _$BookmarkToJson(this);

  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateToJson,
    fromJson: viewedStateFromJson,
  )
  final enums.ViewedState? viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  @JsonKey(
    name: 'timingBasis',
    includeIfNull: false,
    toJson: timingBasisToJson,
    fromJson: timingBasisFromJson,
  )
  final enums.TimingBasis? timingBasis;
  static const fromJsonFactory = _$BookmarkFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Bookmark &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)) &&
            (identical(other.timingBasis, timingBasis) ||
                const DeepCollectionEquality()
                    .equals(other.timingBasis, timingBasis)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      const DeepCollectionEquality().hash(timingBasis) ^
      runtimeType.hashCode;
}

extension $BookmarkExtension on Bookmark {
  Bookmark copyWith(
      {String? contentId,
      int? position,
      enums.ContentType? contentType,
      enums.ViewedState? viewedState,
      enums.ViewState? viewState,
      DateTime? timestamp,
      bool? isAdult,
      String? cpeId,
      String? partiallyWatchedBreakId,
      enums.TimingBasis? timingBasis}) {
    return Bookmark(
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        contentType: contentType ?? this.contentType,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        timestamp: timestamp ?? this.timestamp,
        isAdult: isAdult ?? this.isAdult,
        cpeId: cpeId ?? this.cpeId,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId,
        timingBasis: timingBasis ?? this.timingBasis);
  }

  Bookmark copyWithWrapped(
      {Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<enums.ViewedState?>? viewedState,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? timestamp,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? partiallyWatchedBreakId,
      Wrapped<enums.TimingBasis?>? timingBasis}) {
    return Bookmark(
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId),
        timingBasis:
            (timingBasis != null ? timingBasis.value : this.timingBasis));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkAdvanced {
  BookmarkAdvanced({
    required this.profileId,
    required this.contentId,
    required this.position,
    required this.duration,
    required this.contentType,
    this.viewedState,
    this.viewState,
    this.timestamp,
    this.isAdult,
    this.titleId,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.minimumAge,
    this.channelId,
    this.cpeId,
    this.partiallyWatchedBreakId,
  });

  factory BookmarkAdvanced.fromJson(Map<String, dynamic> json) =>
      _$BookmarkAdvancedFromJson(json);

  static const toJsonFactory = _$BookmarkAdvancedToJson;
  Map<String, dynamic> toJson() => _$BookmarkAdvancedToJson(this);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateToJson,
    fromJson: viewedStateFromJson,
  )
  final enums.ViewedState? viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  static const fromJsonFactory = _$BookmarkAdvancedFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkAdvanced &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      runtimeType.hashCode;
}

extension $BookmarkAdvancedExtension on BookmarkAdvanced {
  BookmarkAdvanced copyWith(
      {String? profileId,
      String? contentId,
      int? position,
      int? duration,
      enums.ContentType? contentType,
      enums.ViewedState? viewedState,
      enums.ViewState? viewState,
      DateTime? timestamp,
      bool? isAdult,
      String? titleId,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      int? minimumAge,
      String? channelId,
      String? cpeId,
      String? partiallyWatchedBreakId}) {
    return BookmarkAdvanced(
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        contentType: contentType ?? this.contentType,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        timestamp: timestamp ?? this.timestamp,
        isAdult: isAdult ?? this.isAdult,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        minimumAge: minimumAge ?? this.minimumAge,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId);
  }

  BookmarkAdvanced copyWithWrapped(
      {Wrapped<String>? profileId,
      Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<enums.ViewedState?>? viewedState,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? timestamp,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? titleId,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? channelId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? partiallyWatchedBreakId}) {
    return BookmarkAdvanced(
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkAdvancedV2 {
  BookmarkAdvancedV2({
    required this.profileId,
    required this.contentId,
    required this.position,
    required this.duration,
    required this.contentType,
    this.viewState,
    this.timestamp,
    this.isAdult,
    this.titleId,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.minimumAge,
    this.channelId,
    this.cpeId,
    this.partiallyWatchedBreakId,
    this.timingBasis,
  });

  factory BookmarkAdvancedV2.fromJson(Map<String, dynamic> json) =>
      _$BookmarkAdvancedV2FromJson(json);

  static const toJsonFactory = _$BookmarkAdvancedV2ToJson;
  Map<String, dynamic> toJson() => _$BookmarkAdvancedV2ToJson(this);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  @JsonKey(
    name: 'timingBasis',
    includeIfNull: false,
    toJson: timingBasisToJson,
    fromJson: timingBasisFromJson,
  )
  final enums.TimingBasis? timingBasis;
  static const fromJsonFactory = _$BookmarkAdvancedV2FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkAdvancedV2 &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)) &&
            (identical(other.timingBasis, timingBasis) ||
                const DeepCollectionEquality()
                    .equals(other.timingBasis, timingBasis)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      const DeepCollectionEquality().hash(timingBasis) ^
      runtimeType.hashCode;
}

extension $BookmarkAdvancedV2Extension on BookmarkAdvancedV2 {
  BookmarkAdvancedV2 copyWith(
      {String? profileId,
      String? contentId,
      int? position,
      int? duration,
      enums.ContentType? contentType,
      enums.ViewState? viewState,
      DateTime? timestamp,
      bool? isAdult,
      String? titleId,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      int? minimumAge,
      String? channelId,
      String? cpeId,
      String? partiallyWatchedBreakId,
      enums.TimingBasis? timingBasis}) {
    return BookmarkAdvancedV2(
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        contentType: contentType ?? this.contentType,
        viewState: viewState ?? this.viewState,
        timestamp: timestamp ?? this.timestamp,
        isAdult: isAdult ?? this.isAdult,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        minimumAge: minimumAge ?? this.minimumAge,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId,
        timingBasis: timingBasis ?? this.timingBasis);
  }

  BookmarkAdvancedV2 copyWithWrapped(
      {Wrapped<String>? profileId,
      Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? timestamp,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? titleId,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? channelId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? partiallyWatchedBreakId,
      Wrapped<enums.TimingBasis?>? timingBasis}) {
    return BookmarkAdvancedV2(
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        viewState: (viewState != null ? viewState.value : this.viewState),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId),
        timingBasis:
            (timingBasis != null ? timingBasis.value : this.timingBasis));
  }
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingItem {
  ContinueWatchingItem({
    required this.contentId,
    required this.position,
    required this.contentType,
    required this.timestamp,
    required this.viewedState,
    required this.viewState,
    this.customerId,
    this.titleId,
    this.showId,
    this.minimumAge,
    this.cpeId,
    required this.duration,
    this.partiallyWatchedBreakId,
  });

  factory ContinueWatchingItem.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingItemFromJson(json);

  static const toJsonFactory = _$ContinueWatchingItemToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingItemToJson(this);

  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: continueWatchingItemContentTypeToJson,
    fromJson: continueWatchingItemContentTypeFromJson,
  )
  final enums.ContinueWatchingItemContentType contentType;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime timestamp;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateToJson,
    fromJson: viewedStateFromJson,
  )
  final enums.ViewedState viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState viewState;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  static const fromJsonFactory = _$ContinueWatchingItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingItem &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingItemExtension on ContinueWatchingItem {
  ContinueWatchingItem copyWith(
      {String? contentId,
      int? position,
      enums.ContinueWatchingItemContentType? contentType,
      DateTime? timestamp,
      enums.ViewedState? viewedState,
      enums.ViewState? viewState,
      String? customerId,
      String? titleId,
      String? showId,
      int? minimumAge,
      String? cpeId,
      int? duration,
      String? partiallyWatchedBreakId}) {
    return ContinueWatchingItem(
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        contentType: contentType ?? this.contentType,
        timestamp: timestamp ?? this.timestamp,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        customerId: customerId ?? this.customerId,
        titleId: titleId ?? this.titleId,
        showId: showId ?? this.showId,
        minimumAge: minimumAge ?? this.minimumAge,
        cpeId: cpeId ?? this.cpeId,
        duration: duration ?? this.duration,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId);
  }

  ContinueWatchingItem copyWithWrapped(
      {Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<enums.ContinueWatchingItemContentType>? contentType,
      Wrapped<DateTime>? timestamp,
      Wrapped<enums.ViewedState>? viewedState,
      Wrapped<enums.ViewState>? viewState,
      Wrapped<String?>? customerId,
      Wrapped<String?>? titleId,
      Wrapped<String?>? showId,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? cpeId,
      Wrapped<int>? duration,
      Wrapped<String?>? partiallyWatchedBreakId}) {
    return ContinueWatchingItem(
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        customerId: (customerId != null ? customerId.value : this.customerId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        showId: (showId != null ? showId.value : this.showId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        duration: (duration != null ? duration.value : this.duration),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkSearchFilter {
  BookmarkSearchFilter({
    this.customerId,
    this.profileId,
    this.contentId,
    this.titleId,
    this.seasonId,
    this.showId,
    this.viewedState,
    this.contentType,
    this.isAdult,
    this.creationDateFrom,
    this.creationDateTo,
    this.cpeId,
    this.limit,
    this.groupBookmarksBy,
  });

  factory BookmarkSearchFilter.fromJson(Map<String, dynamic> json) =>
      _$BookmarkSearchFilterFromJson(json);

  static const toJsonFactory = _$BookmarkSearchFilterToJson;
  Map<String, dynamic> toJson() => _$BookmarkSearchFilterToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showId;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateListToJson,
    fromJson: viewedStateListFromJson,
  )
  final List<enums.ViewedState>? viewedState;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeListToJson,
    fromJson: contentTypeListFromJson,
  )
  final List<enums.ContentType>? contentType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'creationDateFrom', includeIfNull: false)
  final DateTime? creationDateFrom;
  @JsonKey(name: 'creationDateTo', includeIfNull: false)
  final DateTime? creationDateTo;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(
    name: 'groupBookmarksBy',
    includeIfNull: false,
    toJson: bookmarkSearchFilterGroupBookmarksByToJson,
    fromJson: bookmarkSearchFilterGroupBookmarksByFromJson,
  )
  final enums.BookmarkSearchFilterGroupBookmarksBy? groupBookmarksBy;
  static const fromJsonFactory = _$BookmarkSearchFilterFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkSearchFilter &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.creationDateFrom, creationDateFrom) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateFrom, creationDateFrom)) &&
            (identical(other.creationDateTo, creationDateTo) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateTo, creationDateTo)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.groupBookmarksBy, groupBookmarksBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupBookmarksBy, groupBookmarksBy)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(creationDateFrom) ^
      const DeepCollectionEquality().hash(creationDateTo) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(groupBookmarksBy) ^
      runtimeType.hashCode;
}

extension $BookmarkSearchFilterExtension on BookmarkSearchFilter {
  BookmarkSearchFilter copyWith(
      {String? customerId,
      String? profileId,
      List<String>? contentId,
      List<String>? titleId,
      List<String>? seasonId,
      List<String>? showId,
      List<enums.ViewedState>? viewedState,
      List<enums.ContentType>? contentType,
      bool? isAdult,
      DateTime? creationDateFrom,
      DateTime? creationDateTo,
      String? cpeId,
      int? limit,
      enums.BookmarkSearchFilterGroupBookmarksBy? groupBookmarksBy}) {
    return BookmarkSearchFilter(
        customerId: customerId ?? this.customerId,
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        viewedState: viewedState ?? this.viewedState,
        contentType: contentType ?? this.contentType,
        isAdult: isAdult ?? this.isAdult,
        creationDateFrom: creationDateFrom ?? this.creationDateFrom,
        creationDateTo: creationDateTo ?? this.creationDateTo,
        cpeId: cpeId ?? this.cpeId,
        limit: limit ?? this.limit,
        groupBookmarksBy: groupBookmarksBy ?? this.groupBookmarksBy);
  }

  BookmarkSearchFilter copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<String?>? profileId,
      Wrapped<List<String>?>? contentId,
      Wrapped<List<String>?>? titleId,
      Wrapped<List<String>?>? seasonId,
      Wrapped<List<String>?>? showId,
      Wrapped<List<enums.ViewedState>?>? viewedState,
      Wrapped<List<enums.ContentType>?>? contentType,
      Wrapped<bool?>? isAdult,
      Wrapped<DateTime?>? creationDateFrom,
      Wrapped<DateTime?>? creationDateTo,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? limit,
      Wrapped<enums.BookmarkSearchFilterGroupBookmarksBy?>? groupBookmarksBy}) {
    return BookmarkSearchFilter(
        customerId: (customerId != null ? customerId.value : this.customerId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        creationDateFrom: (creationDateFrom != null
            ? creationDateFrom.value
            : this.creationDateFrom),
        creationDateTo: (creationDateTo != null
            ? creationDateTo.value
            : this.creationDateTo),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        limit: (limit != null ? limit.value : this.limit),
        groupBookmarksBy: (groupBookmarksBy != null
            ? groupBookmarksBy.value
            : this.groupBookmarksBy));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkSearchFilterV2 {
  BookmarkSearchFilterV2({
    this.customerId,
    this.profileId,
    this.contentId,
    this.titleId,
    this.seasonId,
    this.showId,
    this.viewState,
    this.contentType,
    this.isAdult,
    this.creationDateFrom,
    this.creationDateTo,
    this.cpeId,
    this.limit,
    this.groupBookmarksBy,
  });

  factory BookmarkSearchFilterV2.fromJson(Map<String, dynamic> json) =>
      _$BookmarkSearchFilterV2FromJson(json);

  static const toJsonFactory = _$BookmarkSearchFilterV2ToJson;
  Map<String, dynamic> toJson() => _$BookmarkSearchFilterV2ToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showId;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateListToJson,
    fromJson: viewStateListFromJson,
  )
  final List<enums.ViewState>? viewState;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeListToJson,
    fromJson: contentTypeListFromJson,
  )
  final List<enums.ContentType>? contentType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'creationDateFrom', includeIfNull: false)
  final DateTime? creationDateFrom;
  @JsonKey(name: 'creationDateTo', includeIfNull: false)
  final DateTime? creationDateTo;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(
    name: 'groupBookmarksBy',
    includeIfNull: false,
    toJson: bookmarkSearchFilterV2GroupBookmarksByToJson,
    fromJson: bookmarkSearchFilterV2GroupBookmarksByFromJson,
  )
  final enums.BookmarkSearchFilterV2GroupBookmarksBy? groupBookmarksBy;
  static const fromJsonFactory = _$BookmarkSearchFilterV2FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkSearchFilterV2 &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.creationDateFrom, creationDateFrom) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateFrom, creationDateFrom)) &&
            (identical(other.creationDateTo, creationDateTo) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateTo, creationDateTo)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.groupBookmarksBy, groupBookmarksBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupBookmarksBy, groupBookmarksBy)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(creationDateFrom) ^
      const DeepCollectionEquality().hash(creationDateTo) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(groupBookmarksBy) ^
      runtimeType.hashCode;
}

extension $BookmarkSearchFilterV2Extension on BookmarkSearchFilterV2 {
  BookmarkSearchFilterV2 copyWith(
      {String? customerId,
      String? profileId,
      List<String>? contentId,
      List<String>? titleId,
      List<String>? seasonId,
      List<String>? showId,
      List<enums.ViewState>? viewState,
      List<enums.ContentType>? contentType,
      bool? isAdult,
      DateTime? creationDateFrom,
      DateTime? creationDateTo,
      String? cpeId,
      int? limit,
      enums.BookmarkSearchFilterV2GroupBookmarksBy? groupBookmarksBy}) {
    return BookmarkSearchFilterV2(
        customerId: customerId ?? this.customerId,
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        viewState: viewState ?? this.viewState,
        contentType: contentType ?? this.contentType,
        isAdult: isAdult ?? this.isAdult,
        creationDateFrom: creationDateFrom ?? this.creationDateFrom,
        creationDateTo: creationDateTo ?? this.creationDateTo,
        cpeId: cpeId ?? this.cpeId,
        limit: limit ?? this.limit,
        groupBookmarksBy: groupBookmarksBy ?? this.groupBookmarksBy);
  }

  BookmarkSearchFilterV2 copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<String?>? profileId,
      Wrapped<List<String>?>? contentId,
      Wrapped<List<String>?>? titleId,
      Wrapped<List<String>?>? seasonId,
      Wrapped<List<String>?>? showId,
      Wrapped<List<enums.ViewState>?>? viewState,
      Wrapped<List<enums.ContentType>?>? contentType,
      Wrapped<bool?>? isAdult,
      Wrapped<DateTime?>? creationDateFrom,
      Wrapped<DateTime?>? creationDateTo,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? limit,
      Wrapped<enums.BookmarkSearchFilterV2GroupBookmarksBy?>?
          groupBookmarksBy}) {
    return BookmarkSearchFilterV2(
        customerId: (customerId != null ? customerId.value : this.customerId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        viewState: (viewState != null ? viewState.value : this.viewState),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        creationDateFrom: (creationDateFrom != null
            ? creationDateFrom.value
            : this.creationDateFrom),
        creationDateTo: (creationDateTo != null
            ? creationDateTo.value
            : this.creationDateTo),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        limit: (limit != null ? limit.value : this.limit),
        groupBookmarksBy: (groupBookmarksBy != null
            ? groupBookmarksBy.value
            : this.groupBookmarksBy));
  }
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams({
    this.titleIds,
    this.showIds,
  });

  factory ContinueWatchingDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingDeleteParamsFromJson(json);

  static const toJsonFactory = _$ContinueWatchingDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingDeleteParamsToJson(this);

  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(name: 'showIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showIds;
  static const fromJsonFactory = _$ContinueWatchingDeleteParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingDeleteParams &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.showIds, showIds) ||
                const DeepCollectionEquality().equals(other.showIds, showIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(showIds) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingDeleteParamsExtension
    on ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams copyWith(
      {List<String>? titleIds, List<String>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: titleIds ?? this.titleIds, showIds: showIds ?? this.showIds);
  }

  ContinueWatchingDeleteParams copyWithWrapped(
      {Wrapped<List<String>?>? titleIds, Wrapped<List<String>?>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        showIds: (showIds != null ? showIds.value : this.showIds));
  }
}

@JsonSerializable(explicitToJson: true)
class CheckBookmarksExist {
  CheckBookmarksExist({
    this.contentTypes,
    this.contentIds,
    this.titleIds,
    this.seasonIds,
    this.showIds,
  });

  factory CheckBookmarksExist.fromJson(Map<String, dynamic> json) =>
      _$CheckBookmarksExistFromJson(json);

  static const toJsonFactory = _$CheckBookmarksExistToJson;
  Map<String, dynamic> toJson() => _$CheckBookmarksExistToJson(this);

  @JsonKey(
    name: 'contentTypes',
    includeIfNull: false,
    toJson: contentTypeListToJson,
    fromJson: contentTypeListFromJson,
  )
  final List<enums.ContentType>? contentTypes;
  @JsonKey(name: 'contentIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? contentIds;
  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(name: 'seasonIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonIds;
  @JsonKey(name: 'showIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showIds;
  static const fromJsonFactory = _$CheckBookmarksExistFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CheckBookmarksExist &&
            (identical(other.contentTypes, contentTypes) ||
                const DeepCollectionEquality()
                    .equals(other.contentTypes, contentTypes)) &&
            (identical(other.contentIds, contentIds) ||
                const DeepCollectionEquality()
                    .equals(other.contentIds, contentIds)) &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.seasonIds, seasonIds) ||
                const DeepCollectionEquality()
                    .equals(other.seasonIds, seasonIds)) &&
            (identical(other.showIds, showIds) ||
                const DeepCollectionEquality().equals(other.showIds, showIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentTypes) ^
      const DeepCollectionEquality().hash(contentIds) ^
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(seasonIds) ^
      const DeepCollectionEquality().hash(showIds) ^
      runtimeType.hashCode;
}

extension $CheckBookmarksExistExtension on CheckBookmarksExist {
  CheckBookmarksExist copyWith(
      {List<enums.ContentType>? contentTypes,
      List<String>? contentIds,
      List<String>? titleIds,
      List<String>? seasonIds,
      List<String>? showIds}) {
    return CheckBookmarksExist(
        contentTypes: contentTypes ?? this.contentTypes,
        contentIds: contentIds ?? this.contentIds,
        titleIds: titleIds ?? this.titleIds,
        seasonIds: seasonIds ?? this.seasonIds,
        showIds: showIds ?? this.showIds);
  }

  CheckBookmarksExist copyWithWrapped(
      {Wrapped<List<enums.ContentType>?>? contentTypes,
      Wrapped<List<String>?>? contentIds,
      Wrapped<List<String>?>? titleIds,
      Wrapped<List<String>?>? seasonIds,
      Wrapped<List<String>?>? showIds}) {
    return CheckBookmarksExist(
        contentTypes:
            (contentTypes != null ? contentTypes.value : this.contentTypes),
        contentIds: (contentIds != null ? contentIds.value : this.contentIds),
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        seasonIds: (seasonIds != null ? seasonIds.value : this.seasonIds),
        showIds: (showIds != null ? showIds.value : this.showIds));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarksExist {
  BookmarksExist({
    required this.contents,
    required this.titles,
    required this.seasons,
    required this.shows,
  });

  factory BookmarksExist.fromJson(Map<String, dynamic> json) =>
      _$BookmarksExistFromJson(json);

  static const toJsonFactory = _$BookmarksExistToJson;
  Map<String, dynamic> toJson() => _$BookmarksExistToJson(this);

  @JsonKey(name: 'contents', includeIfNull: false)
  final ItemsExist contents;
  @JsonKey(name: 'titles', includeIfNull: false)
  final ItemsExist titles;
  @JsonKey(name: 'seasons', includeIfNull: false)
  final ItemsExist seasons;
  @JsonKey(name: 'shows', includeIfNull: false)
  final ItemsExist shows;
  static const fromJsonFactory = _$BookmarksExistFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarksExist &&
            (identical(other.contents, contents) ||
                const DeepCollectionEquality()
                    .equals(other.contents, contents)) &&
            (identical(other.titles, titles) ||
                const DeepCollectionEquality().equals(other.titles, titles)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.shows, shows) ||
                const DeepCollectionEquality().equals(other.shows, shows)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contents) ^
      const DeepCollectionEquality().hash(titles) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(shows) ^
      runtimeType.hashCode;
}

extension $BookmarksExistExtension on BookmarksExist {
  BookmarksExist copyWith(
      {ItemsExist? contents,
      ItemsExist? titles,
      ItemsExist? seasons,
      ItemsExist? shows}) {
    return BookmarksExist(
        contents: contents ?? this.contents,
        titles: titles ?? this.titles,
        seasons: seasons ?? this.seasons,
        shows: shows ?? this.shows);
  }

  BookmarksExist copyWithWrapped(
      {Wrapped<ItemsExist>? contents,
      Wrapped<ItemsExist>? titles,
      Wrapped<ItemsExist>? seasons,
      Wrapped<ItemsExist>? shows}) {
    return BookmarksExist(
        contents: (contents != null ? contents.value : this.contents),
        titles: (titles != null ? titles.value : this.titles),
        seasons: (seasons != null ? seasons.value : this.seasons),
        shows: (shows != null ? shows.value : this.shows));
  }
}

@JsonSerializable(explicitToJson: true)
class ItemsExist {
  ItemsExist({
    this.exist,
    this.notExist,
  });

  factory ItemsExist.fromJson(Map<String, dynamic> json) =>
      _$ItemsExistFromJson(json);

  static const toJsonFactory = _$ItemsExistToJson;
  Map<String, dynamic> toJson() => _$ItemsExistToJson(this);

  @JsonKey(name: 'exist', includeIfNull: false, defaultValue: <String>[])
  final List<String>? exist;
  @JsonKey(name: 'notExist', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notExist;
  static const fromJsonFactory = _$ItemsExistFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ItemsExist &&
            (identical(other.exist, exist) ||
                const DeepCollectionEquality().equals(other.exist, exist)) &&
            (identical(other.notExist, notExist) ||
                const DeepCollectionEquality()
                    .equals(other.notExist, notExist)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(exist) ^
      const DeepCollectionEquality().hash(notExist) ^
      runtimeType.hashCode;
}

extension $ItemsExistExtension on ItemsExist {
  ItemsExist copyWith({List<String>? exist, List<String>? notExist}) {
    return ItemsExist(
        exist: exist ?? this.exist, notExist: notExist ?? this.notExist);
  }

  ItemsExist copyWithWrapped(
      {Wrapped<List<String>?>? exist, Wrapped<List<String>?>? notExist}) {
    return ItemsExist(
        exist: (exist != null ? exist.value : this.exist),
        notExist: (notExist != null ? notExist.value : this.notExist));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerAccessError {
  CustomerAccessError({
    this.errorMessage,
  });

  factory CustomerAccessError.fromJson(Map<String, dynamic> json) =>
      _$CustomerAccessErrorFromJson(json);

  static const toJsonFactory = _$CustomerAccessErrorToJson;
  Map<String, dynamic> toJson() => _$CustomerAccessErrorToJson(this);

  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  static const fromJsonFactory = _$CustomerAccessErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerAccessError &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errorMessage) ^ runtimeType.hashCode;
}

extension $CustomerAccessErrorExtension on CustomerAccessError {
  CustomerAccessError copyWith({String? errorMessage}) {
    return CustomerAccessError(errorMessage: errorMessage ?? this.errorMessage);
  }

  CustomerAccessError copyWithWrapped({Wrapped<String?>? errorMessage}) {
    return CustomerAccessError(
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage));
  }
}

@JsonSerializable(explicitToJson: true)
class LatestBookmarkView {
  LatestBookmarkView({
    this.position,
    this.timestamp,
    this.partiallyWatchedBreakId,
    this.timingBasis,
  });

  factory LatestBookmarkView.fromJson(Map<String, dynamic> json) =>
      _$LatestBookmarkViewFromJson(json);

  static const toJsonFactory = _$LatestBookmarkViewToJson;
  Map<String, dynamic> toJson() => _$LatestBookmarkViewToJson(this);

  @JsonKey(name: 'position', includeIfNull: false)
  final int? position;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  @JsonKey(
    name: 'timingBasis',
    includeIfNull: false,
    toJson: timingBasisToJson,
    fromJson: timingBasisFromJson,
  )
  final enums.TimingBasis? timingBasis;
  static const fromJsonFactory = _$LatestBookmarkViewFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LatestBookmarkView &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)) &&
            (identical(other.timingBasis, timingBasis) ||
                const DeepCollectionEquality()
                    .equals(other.timingBasis, timingBasis)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      const DeepCollectionEquality().hash(timingBasis) ^
      runtimeType.hashCode;
}

extension $LatestBookmarkViewExtension on LatestBookmarkView {
  LatestBookmarkView copyWith(
      {int? position,
      DateTime? timestamp,
      String? partiallyWatchedBreakId,
      enums.TimingBasis? timingBasis}) {
    return LatestBookmarkView(
        position: position ?? this.position,
        timestamp: timestamp ?? this.timestamp,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId,
        timingBasis: timingBasis ?? this.timingBasis);
  }

  LatestBookmarkView copyWithWrapped(
      {Wrapped<int?>? position,
      Wrapped<DateTime?>? timestamp,
      Wrapped<String?>? partiallyWatchedBreakId,
      Wrapped<enums.TimingBasis?>? timingBasis}) {
    return LatestBookmarkView(
        position: (position != null ? position.value : this.position),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId),
        timingBasis:
            (timingBasis != null ? timingBasis.value : this.timingBasis));
  }
}

@JsonSerializable(explicitToJson: true)
class MigrateCustomerParam {
  MigrateCustomerParam({
    required this.currentCustomerId,
    required this.newCustomerId,
  });

  factory MigrateCustomerParam.fromJson(Map<String, dynamic> json) =>
      _$MigrateCustomerParamFromJson(json);

  static const toJsonFactory = _$MigrateCustomerParamToJson;
  Map<String, dynamic> toJson() => _$MigrateCustomerParamToJson(this);

  @JsonKey(name: 'currentCustomerId', includeIfNull: false, defaultValue: '')
  final String currentCustomerId;
  @JsonKey(name: 'newCustomerId', includeIfNull: false, defaultValue: '')
  final String newCustomerId;
  static const fromJsonFactory = _$MigrateCustomerParamFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MigrateCustomerParam &&
            (identical(other.currentCustomerId, currentCustomerId) ||
                const DeepCollectionEquality()
                    .equals(other.currentCustomerId, currentCustomerId)) &&
            (identical(other.newCustomerId, newCustomerId) ||
                const DeepCollectionEquality()
                    .equals(other.newCustomerId, newCustomerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(currentCustomerId) ^
      const DeepCollectionEquality().hash(newCustomerId) ^
      runtimeType.hashCode;
}

extension $MigrateCustomerParamExtension on MigrateCustomerParam {
  MigrateCustomerParam copyWith(
      {String? currentCustomerId, String? newCustomerId}) {
    return MigrateCustomerParam(
        currentCustomerId: currentCustomerId ?? this.currentCustomerId,
        newCustomerId: newCustomerId ?? this.newCustomerId);
  }

  MigrateCustomerParam copyWithWrapped(
      {Wrapped<String>? currentCustomerId, Wrapped<String>? newCustomerId}) {
    return MigrateCustomerParam(
        currentCustomerId: (currentCustomerId != null
            ? currentCustomerId.value
            : this.currentCustomerId),
        newCustomerId:
            (newCustomerId != null ? newCustomerId.value : this.newCustomerId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    required this.details,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String details;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality().equals(other.details, details)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String>? details}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details));
  }
}

String? bookmarkParamsContentTypeToJson(
    enums.BookmarkParamsContentType? bookmarkParamsContentType) {
  return bookmarkParamsContentType?.value;
}

enums.BookmarkParamsContentType bookmarkParamsContentTypeFromJson(
  Object? bookmarkParamsContentType, [
  enums.BookmarkParamsContentType? defaultValue,
]) {
  return enums.BookmarkParamsContentType.values
          .firstWhereOrNull((e) => e.value == bookmarkParamsContentType) ??
      defaultValue ??
      enums.BookmarkParamsContentType.swaggerGeneratedUnknown;
}

List<String> bookmarkParamsContentTypeListToJson(
    List<enums.BookmarkParamsContentType>? bookmarkParamsContentType) {
  if (bookmarkParamsContentType == null) {
    return [];
  }

  return bookmarkParamsContentType.map((e) => e.value!).toList();
}

List<enums.BookmarkParamsContentType> bookmarkParamsContentTypeListFromJson(
  List? bookmarkParamsContentType, [
  List<enums.BookmarkParamsContentType>? defaultValue,
]) {
  if (bookmarkParamsContentType == null) {
    return defaultValue ?? [];
  }

  return bookmarkParamsContentType
      .map((e) => bookmarkParamsContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.BookmarkParamsContentType>?
    bookmarkParamsContentTypeNullableListFromJson(
  List? bookmarkParamsContentType, [
  List<enums.BookmarkParamsContentType>? defaultValue,
]) {
  if (bookmarkParamsContentType == null) {
    return defaultValue;
  }

  return bookmarkParamsContentType
      .map((e) => bookmarkParamsContentTypeFromJson(e.toString()))
      .toList();
}

String? bulkBookmarkParamsContentTypeToJson(
    enums.BulkBookmarkParamsContentType? bulkBookmarkParamsContentType) {
  return bulkBookmarkParamsContentType?.value;
}

enums.BulkBookmarkParamsContentType bulkBookmarkParamsContentTypeFromJson(
  Object? bulkBookmarkParamsContentType, [
  enums.BulkBookmarkParamsContentType? defaultValue,
]) {
  return enums.BulkBookmarkParamsContentType.values
          .firstWhereOrNull((e) => e.value == bulkBookmarkParamsContentType) ??
      defaultValue ??
      enums.BulkBookmarkParamsContentType.swaggerGeneratedUnknown;
}

List<String> bulkBookmarkParamsContentTypeListToJson(
    List<enums.BulkBookmarkParamsContentType>? bulkBookmarkParamsContentType) {
  if (bulkBookmarkParamsContentType == null) {
    return [];
  }

  return bulkBookmarkParamsContentType.map((e) => e.value!).toList();
}

List<enums.BulkBookmarkParamsContentType>
    bulkBookmarkParamsContentTypeListFromJson(
  List? bulkBookmarkParamsContentType, [
  List<enums.BulkBookmarkParamsContentType>? defaultValue,
]) {
  if (bulkBookmarkParamsContentType == null) {
    return defaultValue ?? [];
  }

  return bulkBookmarkParamsContentType
      .map((e) => bulkBookmarkParamsContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.BulkBookmarkParamsContentType>?
    bulkBookmarkParamsContentTypeNullableListFromJson(
  List? bulkBookmarkParamsContentType, [
  List<enums.BulkBookmarkParamsContentType>? defaultValue,
]) {
  if (bulkBookmarkParamsContentType == null) {
    return defaultValue;
  }

  return bulkBookmarkParamsContentType
      .map((e) => bulkBookmarkParamsContentTypeFromJson(e.toString()))
      .toList();
}

String? continueWatchingItemContentTypeToJson(
    enums.ContinueWatchingItemContentType? continueWatchingItemContentType) {
  return continueWatchingItemContentType?.value;
}

enums.ContinueWatchingItemContentType continueWatchingItemContentTypeFromJson(
  Object? continueWatchingItemContentType, [
  enums.ContinueWatchingItemContentType? defaultValue,
]) {
  return enums.ContinueWatchingItemContentType.values.firstWhereOrNull(
          (e) => e.value == continueWatchingItemContentType) ??
      defaultValue ??
      enums.ContinueWatchingItemContentType.swaggerGeneratedUnknown;
}

List<String> continueWatchingItemContentTypeListToJson(
    List<enums.ContinueWatchingItemContentType>?
        continueWatchingItemContentType) {
  if (continueWatchingItemContentType == null) {
    return [];
  }

  return continueWatchingItemContentType.map((e) => e.value!).toList();
}

List<enums.ContinueWatchingItemContentType>
    continueWatchingItemContentTypeListFromJson(
  List? continueWatchingItemContentType, [
  List<enums.ContinueWatchingItemContentType>? defaultValue,
]) {
  if (continueWatchingItemContentType == null) {
    return defaultValue ?? [];
  }

  return continueWatchingItemContentType
      .map((e) => continueWatchingItemContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.ContinueWatchingItemContentType>?
    continueWatchingItemContentTypeNullableListFromJson(
  List? continueWatchingItemContentType, [
  List<enums.ContinueWatchingItemContentType>? defaultValue,
]) {
  if (continueWatchingItemContentType == null) {
    return defaultValue;
  }

  return continueWatchingItemContentType
      .map((e) => continueWatchingItemContentTypeFromJson(e.toString()))
      .toList();
}

String? bookmarkSearchFilterGroupBookmarksByToJson(
    enums.BookmarkSearchFilterGroupBookmarksBy?
        bookmarkSearchFilterGroupBookmarksBy) {
  return bookmarkSearchFilterGroupBookmarksBy?.value;
}

enums.BookmarkSearchFilterGroupBookmarksBy
    bookmarkSearchFilterGroupBookmarksByFromJson(
  Object? bookmarkSearchFilterGroupBookmarksBy, [
  enums.BookmarkSearchFilterGroupBookmarksBy? defaultValue,
]) {
  return enums.BookmarkSearchFilterGroupBookmarksBy.values.firstWhereOrNull(
          (e) => e.value == bookmarkSearchFilterGroupBookmarksBy) ??
      defaultValue ??
      enums.BookmarkSearchFilterGroupBookmarksBy.swaggerGeneratedUnknown;
}

List<String> bookmarkSearchFilterGroupBookmarksByListToJson(
    List<enums.BookmarkSearchFilterGroupBookmarksBy>?
        bookmarkSearchFilterGroupBookmarksBy) {
  if (bookmarkSearchFilterGroupBookmarksBy == null) {
    return [];
  }

  return bookmarkSearchFilterGroupBookmarksBy.map((e) => e.value!).toList();
}

List<enums.BookmarkSearchFilterGroupBookmarksBy>
    bookmarkSearchFilterGroupBookmarksByListFromJson(
  List? bookmarkSearchFilterGroupBookmarksBy, [
  List<enums.BookmarkSearchFilterGroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterGroupBookmarksBy == null) {
    return defaultValue ?? [];
  }

  return bookmarkSearchFilterGroupBookmarksBy
      .map((e) => bookmarkSearchFilterGroupBookmarksByFromJson(e.toString()))
      .toList();
}

List<enums.BookmarkSearchFilterGroupBookmarksBy>?
    bookmarkSearchFilterGroupBookmarksByNullableListFromJson(
  List? bookmarkSearchFilterGroupBookmarksBy, [
  List<enums.BookmarkSearchFilterGroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterGroupBookmarksBy == null) {
    return defaultValue;
  }

  return bookmarkSearchFilterGroupBookmarksBy
      .map((e) => bookmarkSearchFilterGroupBookmarksByFromJson(e.toString()))
      .toList();
}

String? bookmarkSearchFilterV2GroupBookmarksByToJson(
    enums.BookmarkSearchFilterV2GroupBookmarksBy?
        bookmarkSearchFilterV2GroupBookmarksBy) {
  return bookmarkSearchFilterV2GroupBookmarksBy?.value;
}

enums.BookmarkSearchFilterV2GroupBookmarksBy
    bookmarkSearchFilterV2GroupBookmarksByFromJson(
  Object? bookmarkSearchFilterV2GroupBookmarksBy, [
  enums.BookmarkSearchFilterV2GroupBookmarksBy? defaultValue,
]) {
  return enums.BookmarkSearchFilterV2GroupBookmarksBy.values.firstWhereOrNull(
          (e) => e.value == bookmarkSearchFilterV2GroupBookmarksBy) ??
      defaultValue ??
      enums.BookmarkSearchFilterV2GroupBookmarksBy.swaggerGeneratedUnknown;
}

List<String> bookmarkSearchFilterV2GroupBookmarksByListToJson(
    List<enums.BookmarkSearchFilterV2GroupBookmarksBy>?
        bookmarkSearchFilterV2GroupBookmarksBy) {
  if (bookmarkSearchFilterV2GroupBookmarksBy == null) {
    return [];
  }

  return bookmarkSearchFilterV2GroupBookmarksBy.map((e) => e.value!).toList();
}

List<enums.BookmarkSearchFilterV2GroupBookmarksBy>
    bookmarkSearchFilterV2GroupBookmarksByListFromJson(
  List? bookmarkSearchFilterV2GroupBookmarksBy, [
  List<enums.BookmarkSearchFilterV2GroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterV2GroupBookmarksBy == null) {
    return defaultValue ?? [];
  }

  return bookmarkSearchFilterV2GroupBookmarksBy
      .map((e) => bookmarkSearchFilterV2GroupBookmarksByFromJson(e.toString()))
      .toList();
}

List<enums.BookmarkSearchFilterV2GroupBookmarksBy>?
    bookmarkSearchFilterV2GroupBookmarksByNullableListFromJson(
  List? bookmarkSearchFilterV2GroupBookmarksBy, [
  List<enums.BookmarkSearchFilterV2GroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterV2GroupBookmarksBy == null) {
    return defaultValue;
  }

  return bookmarkSearchFilterV2GroupBookmarksBy
      .map((e) => bookmarkSearchFilterV2GroupBookmarksByFromJson(e.toString()))
      .toList();
}

String? contentTypeToJson(enums.ContentType? contentType) {
  return contentType?.value;
}

enums.ContentType contentTypeFromJson(
  Object? contentType, [
  enums.ContentType? defaultValue,
]) {
  return enums.ContentType.values
          .firstWhereOrNull((e) => e.value == contentType) ??
      defaultValue ??
      enums.ContentType.swaggerGeneratedUnknown;
}

List<String> contentTypeListToJson(List<enums.ContentType>? contentType) {
  if (contentType == null) {
    return [];
  }

  return contentType.map((e) => e.value!).toList();
}

List<enums.ContentType> contentTypeListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue ?? [];
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

List<enums.ContentType>? contentTypeNullableListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue;
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

String? viewedStateToJson(enums.ViewedState? viewedState) {
  return viewedState?.value;
}

enums.ViewedState viewedStateFromJson(
  Object? viewedState, [
  enums.ViewedState? defaultValue,
]) {
  return enums.ViewedState.values
          .firstWhereOrNull((e) => e.value == viewedState) ??
      defaultValue ??
      enums.ViewedState.swaggerGeneratedUnknown;
}

List<String> viewedStateListToJson(List<enums.ViewedState>? viewedState) {
  if (viewedState == null) {
    return [];
  }

  return viewedState.map((e) => e.value!).toList();
}

List<enums.ViewedState> viewedStateListFromJson(
  List? viewedState, [
  List<enums.ViewedState>? defaultValue,
]) {
  if (viewedState == null) {
    return defaultValue ?? [];
  }

  return viewedState.map((e) => viewedStateFromJson(e.toString())).toList();
}

List<enums.ViewedState>? viewedStateNullableListFromJson(
  List? viewedState, [
  List<enums.ViewedState>? defaultValue,
]) {
  if (viewedState == null) {
    return defaultValue;
  }

  return viewedState.map((e) => viewedStateFromJson(e.toString())).toList();
}

String? viewStateToJson(enums.ViewState? viewState) {
  return viewState?.value;
}

enums.ViewState viewStateFromJson(
  Object? viewState, [
  enums.ViewState? defaultValue,
]) {
  return enums.ViewState.values.firstWhereOrNull((e) => e.value == viewState) ??
      defaultValue ??
      enums.ViewState.swaggerGeneratedUnknown;
}

List<String> viewStateListToJson(List<enums.ViewState>? viewState) {
  if (viewState == null) {
    return [];
  }

  return viewState.map((e) => e.value!).toList();
}

List<enums.ViewState> viewStateListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue ?? [];
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

List<enums.ViewState>? viewStateNullableListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue;
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

String? timingBasisToJson(enums.TimingBasis? timingBasis) {
  return timingBasis?.value;
}

enums.TimingBasis timingBasisFromJson(
  Object? timingBasis, [
  enums.TimingBasis? defaultValue,
]) {
  return enums.TimingBasis.values
          .firstWhereOrNull((e) => e.value == timingBasis) ??
      defaultValue ??
      enums.TimingBasis.swaggerGeneratedUnknown;
}

List<String> timingBasisListToJson(List<enums.TimingBasis>? timingBasis) {
  if (timingBasis == null) {
    return [];
  }

  return timingBasis.map((e) => e.value!).toList();
}

List<enums.TimingBasis> timingBasisListFromJson(
  List? timingBasis, [
  List<enums.TimingBasis>? defaultValue,
]) {
  if (timingBasis == null) {
    return defaultValue ?? [];
  }

  return timingBasis.map((e) => timingBasisFromJson(e.toString())).toList();
}

List<enums.TimingBasis>? timingBasisNullableListFromJson(
  List? timingBasis, [
  List<enums.TimingBasis>? defaultValue,
]) {
  if (timingBasis == null) {
    return defaultValue;
  }

  return timingBasis.map((e) => timingBasisFromJson(e.toString())).toList();
}

String? latestProfileIdContentIdGetContentTypeToJson(
    enums.LatestProfileIdContentIdGetContentType?
        latestProfileIdContentIdGetContentType) {
  return latestProfileIdContentIdGetContentType?.value;
}

enums.LatestProfileIdContentIdGetContentType
    latestProfileIdContentIdGetContentTypeFromJson(
  Object? latestProfileIdContentIdGetContentType, [
  enums.LatestProfileIdContentIdGetContentType? defaultValue,
]) {
  return enums.LatestProfileIdContentIdGetContentType.values.firstWhereOrNull(
          (e) => e.value == latestProfileIdContentIdGetContentType) ??
      defaultValue ??
      enums.LatestProfileIdContentIdGetContentType.swaggerGeneratedUnknown;
}

List<String> latestProfileIdContentIdGetContentTypeListToJson(
    List<enums.LatestProfileIdContentIdGetContentType>?
        latestProfileIdContentIdGetContentType) {
  if (latestProfileIdContentIdGetContentType == null) {
    return [];
  }

  return latestProfileIdContentIdGetContentType.map((e) => e.value!).toList();
}

List<enums.LatestProfileIdContentIdGetContentType>
    latestProfileIdContentIdGetContentTypeListFromJson(
  List? latestProfileIdContentIdGetContentType, [
  List<enums.LatestProfileIdContentIdGetContentType>? defaultValue,
]) {
  if (latestProfileIdContentIdGetContentType == null) {
    return defaultValue ?? [];
  }

  return latestProfileIdContentIdGetContentType
      .map((e) => latestProfileIdContentIdGetContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.LatestProfileIdContentIdGetContentType>?
    latestProfileIdContentIdGetContentTypeNullableListFromJson(
  List? latestProfileIdContentIdGetContentType, [
  List<enums.LatestProfileIdContentIdGetContentType>? defaultValue,
]) {
  if (latestProfileIdContentIdGetContentType == null) {
    return defaultValue;
  }

  return latestProfileIdContentIdGetContentType
      .map((e) => latestProfileIdContentIdGetContentTypeFromJson(e.toString()))
      .toList();
}

String? profilesProfileIdBookmarksGetContentTypeToJson(
    enums.ProfilesProfileIdBookmarksGetContentType?
        profilesProfileIdBookmarksGetContentType) {
  return profilesProfileIdBookmarksGetContentType?.value;
}

enums.ProfilesProfileIdBookmarksGetContentType
    profilesProfileIdBookmarksGetContentTypeFromJson(
  Object? profilesProfileIdBookmarksGetContentType, [
  enums.ProfilesProfileIdBookmarksGetContentType? defaultValue,
]) {
  return enums.ProfilesProfileIdBookmarksGetContentType.values.firstWhereOrNull(
          (e) => e.value == profilesProfileIdBookmarksGetContentType) ??
      defaultValue ??
      enums.ProfilesProfileIdBookmarksGetContentType.swaggerGeneratedUnknown;
}

List<String> profilesProfileIdBookmarksGetContentTypeListToJson(
    List<enums.ProfilesProfileIdBookmarksGetContentType>?
        profilesProfileIdBookmarksGetContentType) {
  if (profilesProfileIdBookmarksGetContentType == null) {
    return [];
  }

  return profilesProfileIdBookmarksGetContentType.map((e) => e.value!).toList();
}

List<enums.ProfilesProfileIdBookmarksGetContentType>
    profilesProfileIdBookmarksGetContentTypeListFromJson(
  List? profilesProfileIdBookmarksGetContentType, [
  List<enums.ProfilesProfileIdBookmarksGetContentType>? defaultValue,
]) {
  if (profilesProfileIdBookmarksGetContentType == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdBookmarksGetContentType
      .map(
          (e) => profilesProfileIdBookmarksGetContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdBookmarksGetContentType>?
    profilesProfileIdBookmarksGetContentTypeNullableListFromJson(
  List? profilesProfileIdBookmarksGetContentType, [
  List<enums.ProfilesProfileIdBookmarksGetContentType>? defaultValue,
]) {
  if (profilesProfileIdBookmarksGetContentType == null) {
    return defaultValue;
  }

  return profilesProfileIdBookmarksGetContentType
      .map(
          (e) => profilesProfileIdBookmarksGetContentTypeFromJson(e.toString()))
      .toList();
}

String? bookmarksContentTypeContentIdDeleteContentTypeToJson(
    enums.BookmarksContentTypeContentIdDeleteContentType?
        bookmarksContentTypeContentIdDeleteContentType) {
  return bookmarksContentTypeContentIdDeleteContentType?.value;
}

enums.BookmarksContentTypeContentIdDeleteContentType
    bookmarksContentTypeContentIdDeleteContentTypeFromJson(
  Object? bookmarksContentTypeContentIdDeleteContentType, [
  enums.BookmarksContentTypeContentIdDeleteContentType? defaultValue,
]) {
  return enums.BookmarksContentTypeContentIdDeleteContentType.values
          .firstWhereOrNull((e) =>
              e.value == bookmarksContentTypeContentIdDeleteContentType) ??
      defaultValue ??
      enums.BookmarksContentTypeContentIdDeleteContentType
          .swaggerGeneratedUnknown;
}

List<String> bookmarksContentTypeContentIdDeleteContentTypeListToJson(
    List<enums.BookmarksContentTypeContentIdDeleteContentType>?
        bookmarksContentTypeContentIdDeleteContentType) {
  if (bookmarksContentTypeContentIdDeleteContentType == null) {
    return [];
  }

  return bookmarksContentTypeContentIdDeleteContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.BookmarksContentTypeContentIdDeleteContentType>
    bookmarksContentTypeContentIdDeleteContentTypeListFromJson(
  List? bookmarksContentTypeContentIdDeleteContentType, [
  List<enums.BookmarksContentTypeContentIdDeleteContentType>? defaultValue,
]) {
  if (bookmarksContentTypeContentIdDeleteContentType == null) {
    return defaultValue ?? [];
  }

  return bookmarksContentTypeContentIdDeleteContentType
      .map((e) =>
          bookmarksContentTypeContentIdDeleteContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.BookmarksContentTypeContentIdDeleteContentType>?
    bookmarksContentTypeContentIdDeleteContentTypeNullableListFromJson(
  List? bookmarksContentTypeContentIdDeleteContentType, [
  List<enums.BookmarksContentTypeContentIdDeleteContentType>? defaultValue,
]) {
  if (bookmarksContentTypeContentIdDeleteContentType == null) {
    return defaultValue;
  }

  return bookmarksContentTypeContentIdDeleteContentType
      .map((e) =>
          bookmarksContentTypeContentIdDeleteContentTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
