// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'channels_application_service.enums.swagger.dart' as enums;
export 'channels_application_service.enums.swagger.dart';

part 'channels_application_service.swagger.chopper.dart';
part 'channels_application_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ChannelsApplicationService extends ChopperService {
  static ChannelsApplicationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ChannelsApplicationService(client);
    }

    final newClient = ChopperClient(
        services: [_$ChannelsApplicationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://localhost:10014/channels'));
    return _$ChannelsApplicationService(newClient);
  }

  ///Get channels given the channel ids passed.
  ///@param channelIds Channel ids
  Future<chopper.Response<List<Channel>>> getChannelsPut({
    List<String>? channelIds,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Channel, () => Channel.fromJsonFactory);

    return _getChannelsPut(channelIds: channelIds, cacheControl: cacheControl);
  }

  ///Get channels given the channel ids passed.
  ///@param channelIds Channel ids
  @Put(path: '/getChannels')
  Future<chopper.Response<List<Channel>>> _getChannelsPut({
    @Body() List<String>? channelIds,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the currently tuned channel ID.
  Future<chopper.Response<String>> getCurrentChannelPut(
      {String? cacheControl}) {
    return _getCurrentChannelPut(cacheControl: cacheControl);
  }

  ///Returns the currently tuned channel ID.
  @Put(
    path: '/getCurrentChannel',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _getCurrentChannelPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Returns the array of IDs of channels that were recently set as current.
  Future<chopper.Response<List<String>>> getRecentChannelsPut(
      {String? cacheControl}) {
    return _getRecentChannelsPut(cacheControl: cacheControl);
  }

  ///Returns the array of IDs of channels that were recently set as current.
  @Put(
    path: '/getRecentChannels',
    optionalBody: true,
  )
  Future<chopper.Response<List<String>>> _getRecentChannelsPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Returns most watched channels list.
  Future<chopper.Response<List<String>>> getMostWatchedChannelsPut(
      {String? cacheControl}) {
    return _getMostWatchedChannelsPut(cacheControl: cacheControl);
  }

  ///Returns most watched channels list.
  @Put(
    path: '/getMostWatchedChannels',
    optionalBody: true,
  )
  Future<chopper.Response<List<String>>> _getMostWatchedChannelsPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Resets most watched channels list.
  Future<chopper.Response> resetMostWatchedChannelsPut({String? cacheControl}) {
    return _resetMostWatchedChannelsPut(cacheControl: cacheControl);
  }

  ///Resets most watched channels list.
  @Put(
    path: '/resetMostWatchedChannels',
    optionalBody: true,
  )
  Future<chopper.Response> _resetMostWatchedChannelsPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Sets the currently tuned channel ID.
  ///@param channelId The ID of the current channel.
  Future<chopper.Response> setCurrentChannelPut({
    required String? channelId,
    String? cacheControl,
  }) {
    return _setCurrentChannelPut(
        channelId: channelId, cacheControl: cacheControl);
  }

  ///Sets the currently tuned channel ID.
  ///@param channelId The ID of the current channel.
  @Put(path: '/setCurrentChannel')
  Future<chopper.Response> _setCurrentChannelPut({
    @Body() required String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns channel lists of current user.
  Future<chopper.Response<List<ChannelList>>> getChannelListsPut(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ChannelList, () => ChannelList.fromJsonFactory);

    return _getChannelListsPut(cacheControl: cacheControl);
  }

  ///Returns channel lists of current user.
  @Put(
    path: '/getChannelLists',
    optionalBody: true,
  )
  Future<chopper.Response<List<ChannelList>>> _getChannelListsPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Sets channel lists of current user.
  ///@param channelLists Channel lists
  Future<chopper.Response> setChannelListsPut({
    required List<ChannelList>? channelLists,
    String? cacheControl,
  }) {
    return _setChannelListsPut(
        channelLists: channelLists, cacheControl: cacheControl);
  }

  ///Sets channel lists of current user.
  ///@param channelLists Channel lists
  @Put(path: '/setChannelLists')
  Future<chopper.Response> _setChannelListsPut({
    @Body() required List<ChannelList>? channelLists,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Current channel change event.
  Future<chopper.Response> currentChannelChangeGet({String? cacheControl}) {
    return _currentChannelChangeGet(cacheControl: cacheControl);
  }

  ///Current channel change event.
  @Get(path: '/currentChannelChange')
  Future<chopper.Response> _currentChannelChangeGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Channels updated event.
  Future<chopper.Response> channelsUpdatedGet({String? cacheControl}) {
    return _channelsUpdatedGet(cacheControl: cacheControl);
  }

  ///Channels updated event.
  @Get(path: '/channelsUpdated')
  Future<chopper.Response> _channelsUpdatedGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Channel list change event.
  Future<chopper.Response> channelListChangeGet({String? cacheControl}) {
    return _channelListChangeGet(cacheControl: cacheControl);
  }

  ///Channel list change event.
  @Get(path: '/channelListChange')
  Future<chopper.Response> _channelListChangeGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Current channel list change event.
  Future<chopper.Response> currentChannelListChangeGet({String? cacheControl}) {
    return _currentChannelListChangeGet(cacheControl: cacheControl);
  }

  ///Current channel list change event.
  @Get(path: '/currentChannelListChange')
  Future<chopper.Response> _currentChannelListChangeGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.message,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({String? message}) {
    return ErrorResponse(message: message ?? this.message);
  }

  ErrorResponse copyWithWrapped({Wrapped<String>? message}) {
    return ErrorResponse(
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel {
  Channel({
    required this.channelId,
    required this.name,
    required this.channelNumber,
    this.logoFocused,
    this.logoUnfocused,
    this.isEntitled,
    this.isRadio,
    this.isAdult,
    this.is3D,
    this.isWatershed,
    this.isHidden,
    this.isPPV,
    this.hasIpTeletext,
    this.resolution,
    this.locator,
    this.blackoutSchedule,
    this.blackoutDuration,
    this.allowStartOver,
    this.isStartOverEntitled,
    this.allowReplayTV,
    this.replayMode,
    this.replayDuration,
    this.replayEntitledDuration,
    this.allowedOverlayApps,
    this.boundApps,
    this.entitlementEnd,
    this.genres,
    this.trickPlayControl,
    this.replaySources,
    this.replayAppId,
    this.replayAppChannelId,
    this.prePadding,
    this.postPadding,
    this.hasLDVRChannelBasedAuthorization,
    this.hasLDVRRestrictCPEStreaming,
    this.ndvrBlackout,
    this.saveReplayToNdvr,
    this.replacement,
    this.providerLogo,
    this.appIdForDayPass,
    this.promotionalImage,
    this.contextMenuActions,
    this.providerId,
    this.dlarEnabled,
    this.isDayPassEnabled,
    this.uidPlacement,
    this.adChannelType,
    this.adSupport,
  });

  factory Channel.fromJson(Map<String, dynamic> json) =>
      _$ChannelFromJson(json);

  static const toJsonFactory = _$ChannelToJson;
  Map<String, dynamic> toJson() => _$ChannelToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'channelNumber', includeIfNull: false)
  final int channelNumber;
  @JsonKey(name: 'logoFocused', includeIfNull: false, defaultValue: '')
  final String? logoFocused;
  @JsonKey(name: 'logoUnfocused', includeIfNull: false, defaultValue: '')
  final String? logoUnfocused;
  @JsonKey(name: 'isEntitled', includeIfNull: false)
  final bool? isEntitled;
  @JsonKey(name: 'isRadio', includeIfNull: false)
  final bool? isRadio;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'is3D', includeIfNull: false)
  final bool? is3D;
  @JsonKey(name: 'isWatershed', includeIfNull: false)
  final bool? isWatershed;
  @JsonKey(name: 'isHidden', includeIfNull: false)
  final bool? isHidden;
  @JsonKey(name: 'isPPV', includeIfNull: false)
  final bool? isPPV;
  @JsonKey(name: 'hasIpTeletext', includeIfNull: false)
  final bool? hasIpTeletext;
  @JsonKey(
    name: 'resolution',
    includeIfNull: false,
    toJson: channelResolutionToJson,
    fromJson: channelResolutionFromJson,
  )
  final enums.ChannelResolution? resolution;
  @JsonKey(name: 'locator', includeIfNull: false, defaultValue: '')
  final String? locator;
  @JsonKey(name: 'blackoutSchedule', includeIfNull: false, defaultValue: '')
  final String? blackoutSchedule;
  @JsonKey(name: 'blackoutDuration', includeIfNull: false, defaultValue: '')
  final String? blackoutDuration;
  @JsonKey(name: 'allowStartOver', includeIfNull: false)
  final bool? allowStartOver;
  @JsonKey(name: 'isStartOverEntitled', includeIfNull: false)
  final bool? isStartOverEntitled;
  @JsonKey(name: 'allowReplayTV', includeIfNull: false)
  final bool? allowReplayTV;
  @JsonKey(
    name: 'replayMode',
    includeIfNull: false,
    toJson: channelReplayModeToJson,
    fromJson: channelReplayModeReplayModeFromJson,
  )
  final enums.ChannelReplayMode? replayMode;
  static enums.ChannelReplayMode channelReplayModeReplayModeFromJson(
          Object? value) =>
      channelReplayModeFromJson(value, enums.ChannelReplayMode.exact);

  @JsonKey(name: 'replayDuration', includeIfNull: false)
  final int? replayDuration;
  @JsonKey(name: 'replayEntitledDuration', includeIfNull: false)
  final int? replayEntitledDuration;
  @JsonKey(
      name: 'allowedOverlayApps',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? allowedOverlayApps;
  @JsonKey(name: 'boundApps', includeIfNull: false, defaultValue: <BoundApp>[])
  final List<BoundApp>? boundApps;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final int? entitlementEnd;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: channelTrickPlayControlListToJson,
    fromJson: channelTrickPlayControlListFromJson,
  )
  final List<enums.ChannelTrickPlayControl>? trickPlayControl;
  @JsonKey(
    name: 'replaySources',
    includeIfNull: false,
    toJson: channelReplaySourcesListToJson,
    fromJson: channelReplaySourcesListFromJson,
  )
  final List<enums.ChannelReplaySources>? replaySources;
  @JsonKey(name: 'replayAppId', includeIfNull: false, defaultValue: '')
  final String? replayAppId;
  @JsonKey(name: 'replayAppChannelId', includeIfNull: false, defaultValue: '')
  final String? replayAppChannelId;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(name: 'hasLDVRChannelBasedAuthorization', includeIfNull: false)
  final bool? hasLDVRChannelBasedAuthorization;
  @JsonKey(name: 'hasLDVRRestrictCPEStreaming', includeIfNull: false)
  final bool? hasLDVRRestrictCPEStreaming;
  @JsonKey(name: 'ndvrBlackout', includeIfNull: false)
  final bool? ndvrBlackout;
  @JsonKey(name: 'saveReplayToNdvr', includeIfNull: false, defaultValue: false)
  final bool? saveReplayToNdvr;
  @JsonKey(name: 'replacement', includeIfNull: false)
  final Channel$Replacement? replacement;
  @JsonKey(name: 'providerLogo', includeIfNull: false, defaultValue: '')
  final String? providerLogo;
  @JsonKey(name: 'appIdForDayPass', includeIfNull: false, defaultValue: '')
  final String? appIdForDayPass;
  @JsonKey(name: 'promotionalImage', includeIfNull: false, defaultValue: '')
  final String? promotionalImage;
  @JsonKey(
    name: 'contextMenuActions',
    includeIfNull: false,
    toJson: channelContextMenuActionsToJson,
    fromJson: channelContextMenuActionsFromJson,
  )
  final enums.ChannelContextMenuActions? contextMenuActions;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'dlarEnabled', includeIfNull: false, defaultValue: false)
  final bool? dlarEnabled;
  @JsonKey(name: 'isDayPassEnabled', includeIfNull: false)
  final bool? isDayPassEnabled;
  @JsonKey(name: 'uidPlacement', includeIfNull: false)
  final bool? uidPlacement;
  @JsonKey(name: 'adChannelType', includeIfNull: false, defaultValue: '')
  final String? adChannelType;
  @JsonKey(name: 'adSupport', includeIfNull: false, defaultValue: <String>[])
  final List<String>? adSupport;
  static const fromJsonFactory = _$ChannelFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelNumber, channelNumber) ||
                const DeepCollectionEquality()
                    .equals(other.channelNumber, channelNumber)) &&
            (identical(other.logoFocused, logoFocused) ||
                const DeepCollectionEquality()
                    .equals(other.logoFocused, logoFocused)) &&
            (identical(other.logoUnfocused, logoUnfocused) ||
                const DeepCollectionEquality()
                    .equals(other.logoUnfocused, logoUnfocused)) &&
            (identical(other.isEntitled, isEntitled) ||
                const DeepCollectionEquality()
                    .equals(other.isEntitled, isEntitled)) &&
            (identical(other.isRadio, isRadio) ||
                const DeepCollectionEquality()
                    .equals(other.isRadio, isRadio)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.is3D, is3D) ||
                const DeepCollectionEquality().equals(other.is3D, is3D)) &&
            (identical(other.isWatershed, isWatershed) ||
                const DeepCollectionEquality()
                    .equals(other.isWatershed, isWatershed)) &&
            (identical(other.isHidden, isHidden) ||
                const DeepCollectionEquality()
                    .equals(other.isHidden, isHidden)) &&
            (identical(other.isPPV, isPPV) ||
                const DeepCollectionEquality().equals(other.isPPV, isPPV)) &&
            (identical(other.hasIpTeletext, hasIpTeletext) ||
                const DeepCollectionEquality()
                    .equals(other.hasIpTeletext, hasIpTeletext)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.locator, locator) ||
                const DeepCollectionEquality()
                    .equals(other.locator, locator)) &&
            (identical(other.blackoutSchedule, blackoutSchedule) ||
                const DeepCollectionEquality()
                    .equals(other.blackoutSchedule, blackoutSchedule)) &&
            (identical(other.blackoutDuration, blackoutDuration) ||
                const DeepCollectionEquality()
                    .equals(other.blackoutDuration, blackoutDuration)) &&
            (identical(other.allowStartOver, allowStartOver) ||
                const DeepCollectionEquality()
                    .equals(other.allowStartOver, allowStartOver)) &&
            (identical(other.isStartOverEntitled, isStartOverEntitled) ||
                const DeepCollectionEquality()
                    .equals(other.isStartOverEntitled, isStartOverEntitled)) &&
            (identical(other.allowReplayTV, allowReplayTV) ||
                const DeepCollectionEquality()
                    .equals(other.allowReplayTV, allowReplayTV)) &&
            (identical(other.replayMode, replayMode) ||
                const DeepCollectionEquality()
                    .equals(other.replayMode, replayMode)) &&
            (identical(other.replayDuration, replayDuration) ||
                const DeepCollectionEquality()
                    .equals(other.replayDuration, replayDuration)) &&
            (identical(other.replayEntitledDuration, replayEntitledDuration) ||
                const DeepCollectionEquality().equals(
                    other.replayEntitledDuration, replayEntitledDuration)) &&
            (identical(other.allowedOverlayApps, allowedOverlayApps) || const DeepCollectionEquality().equals(other.allowedOverlayApps, allowedOverlayApps)) &&
            (identical(other.boundApps, boundApps) || const DeepCollectionEquality().equals(other.boundApps, boundApps)) &&
            (identical(other.entitlementEnd, entitlementEnd) || const DeepCollectionEquality().equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.genres, genres) || const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.replaySources, replaySources) || const DeepCollectionEquality().equals(other.replaySources, replaySources)) &&
            (identical(other.replayAppId, replayAppId) || const DeepCollectionEquality().equals(other.replayAppId, replayAppId)) &&
            (identical(other.replayAppChannelId, replayAppChannelId) || const DeepCollectionEquality().equals(other.replayAppChannelId, replayAppChannelId)) &&
            (identical(other.prePadding, prePadding) || const DeepCollectionEquality().equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) || const DeepCollectionEquality().equals(other.postPadding, postPadding)) &&
            (identical(other.hasLDVRChannelBasedAuthorization, hasLDVRChannelBasedAuthorization) || const DeepCollectionEquality().equals(other.hasLDVRChannelBasedAuthorization, hasLDVRChannelBasedAuthorization)) &&
            (identical(other.hasLDVRRestrictCPEStreaming, hasLDVRRestrictCPEStreaming) || const DeepCollectionEquality().equals(other.hasLDVRRestrictCPEStreaming, hasLDVRRestrictCPEStreaming)) &&
            (identical(other.ndvrBlackout, ndvrBlackout) || const DeepCollectionEquality().equals(other.ndvrBlackout, ndvrBlackout)) &&
            (identical(other.saveReplayToNdvr, saveReplayToNdvr) || const DeepCollectionEquality().equals(other.saveReplayToNdvr, saveReplayToNdvr)) &&
            (identical(other.replacement, replacement) || const DeepCollectionEquality().equals(other.replacement, replacement)) &&
            (identical(other.providerLogo, providerLogo) || const DeepCollectionEquality().equals(other.providerLogo, providerLogo)) &&
            (identical(other.appIdForDayPass, appIdForDayPass) || const DeepCollectionEquality().equals(other.appIdForDayPass, appIdForDayPass)) &&
            (identical(other.promotionalImage, promotionalImage) || const DeepCollectionEquality().equals(other.promotionalImage, promotionalImage)) &&
            (identical(other.contextMenuActions, contextMenuActions) || const DeepCollectionEquality().equals(other.contextMenuActions, contextMenuActions)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)) &&
            (identical(other.dlarEnabled, dlarEnabled) || const DeepCollectionEquality().equals(other.dlarEnabled, dlarEnabled)) &&
            (identical(other.isDayPassEnabled, isDayPassEnabled) || const DeepCollectionEquality().equals(other.isDayPassEnabled, isDayPassEnabled)) &&
            (identical(other.uidPlacement, uidPlacement) || const DeepCollectionEquality().equals(other.uidPlacement, uidPlacement)) &&
            (identical(other.adChannelType, adChannelType) || const DeepCollectionEquality().equals(other.adChannelType, adChannelType)) &&
            (identical(other.adSupport, adSupport) || const DeepCollectionEquality().equals(other.adSupport, adSupport)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelNumber) ^
      const DeepCollectionEquality().hash(logoFocused) ^
      const DeepCollectionEquality().hash(logoUnfocused) ^
      const DeepCollectionEquality().hash(isEntitled) ^
      const DeepCollectionEquality().hash(isRadio) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(is3D) ^
      const DeepCollectionEquality().hash(isWatershed) ^
      const DeepCollectionEquality().hash(isHidden) ^
      const DeepCollectionEquality().hash(isPPV) ^
      const DeepCollectionEquality().hash(hasIpTeletext) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(locator) ^
      const DeepCollectionEquality().hash(blackoutSchedule) ^
      const DeepCollectionEquality().hash(blackoutDuration) ^
      const DeepCollectionEquality().hash(allowStartOver) ^
      const DeepCollectionEquality().hash(isStartOverEntitled) ^
      const DeepCollectionEquality().hash(allowReplayTV) ^
      const DeepCollectionEquality().hash(replayMode) ^
      const DeepCollectionEquality().hash(replayDuration) ^
      const DeepCollectionEquality().hash(replayEntitledDuration) ^
      const DeepCollectionEquality().hash(allowedOverlayApps) ^
      const DeepCollectionEquality().hash(boundApps) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(replaySources) ^
      const DeepCollectionEquality().hash(replayAppId) ^
      const DeepCollectionEquality().hash(replayAppChannelId) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(hasLDVRChannelBasedAuthorization) ^
      const DeepCollectionEquality().hash(hasLDVRRestrictCPEStreaming) ^
      const DeepCollectionEquality().hash(ndvrBlackout) ^
      const DeepCollectionEquality().hash(saveReplayToNdvr) ^
      const DeepCollectionEquality().hash(replacement) ^
      const DeepCollectionEquality().hash(providerLogo) ^
      const DeepCollectionEquality().hash(appIdForDayPass) ^
      const DeepCollectionEquality().hash(promotionalImage) ^
      const DeepCollectionEquality().hash(contextMenuActions) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(dlarEnabled) ^
      const DeepCollectionEquality().hash(isDayPassEnabled) ^
      const DeepCollectionEquality().hash(uidPlacement) ^
      const DeepCollectionEquality().hash(adChannelType) ^
      const DeepCollectionEquality().hash(adSupport) ^
      runtimeType.hashCode;
}

extension $ChannelExtension on Channel {
  Channel copyWith(
      {String? channelId,
      String? name,
      int? channelNumber,
      String? logoFocused,
      String? logoUnfocused,
      bool? isEntitled,
      bool? isRadio,
      bool? isAdult,
      bool? is3D,
      bool? isWatershed,
      bool? isHidden,
      bool? isPPV,
      bool? hasIpTeletext,
      enums.ChannelResolution? resolution,
      String? locator,
      String? blackoutSchedule,
      String? blackoutDuration,
      bool? allowStartOver,
      bool? isStartOverEntitled,
      bool? allowReplayTV,
      enums.ChannelReplayMode? replayMode,
      int? replayDuration,
      int? replayEntitledDuration,
      List<String>? allowedOverlayApps,
      List<BoundApp>? boundApps,
      int? entitlementEnd,
      List<String>? genres,
      List<enums.ChannelTrickPlayControl>? trickPlayControl,
      List<enums.ChannelReplaySources>? replaySources,
      String? replayAppId,
      String? replayAppChannelId,
      int? prePadding,
      int? postPadding,
      bool? hasLDVRChannelBasedAuthorization,
      bool? hasLDVRRestrictCPEStreaming,
      bool? ndvrBlackout,
      bool? saveReplayToNdvr,
      Channel$Replacement? replacement,
      String? providerLogo,
      String? appIdForDayPass,
      String? promotionalImage,
      enums.ChannelContextMenuActions? contextMenuActions,
      String? providerId,
      bool? dlarEnabled,
      bool? isDayPassEnabled,
      bool? uidPlacement,
      String? adChannelType,
      List<String>? adSupport}) {
    return Channel(
        channelId: channelId ?? this.channelId,
        name: name ?? this.name,
        channelNumber: channelNumber ?? this.channelNumber,
        logoFocused: logoFocused ?? this.logoFocused,
        logoUnfocused: logoUnfocused ?? this.logoUnfocused,
        isEntitled: isEntitled ?? this.isEntitled,
        isRadio: isRadio ?? this.isRadio,
        isAdult: isAdult ?? this.isAdult,
        is3D: is3D ?? this.is3D,
        isWatershed: isWatershed ?? this.isWatershed,
        isHidden: isHidden ?? this.isHidden,
        isPPV: isPPV ?? this.isPPV,
        hasIpTeletext: hasIpTeletext ?? this.hasIpTeletext,
        resolution: resolution ?? this.resolution,
        locator: locator ?? this.locator,
        blackoutSchedule: blackoutSchedule ?? this.blackoutSchedule,
        blackoutDuration: blackoutDuration ?? this.blackoutDuration,
        allowStartOver: allowStartOver ?? this.allowStartOver,
        isStartOverEntitled: isStartOverEntitled ?? this.isStartOverEntitled,
        allowReplayTV: allowReplayTV ?? this.allowReplayTV,
        replayMode: replayMode ?? this.replayMode,
        replayDuration: replayDuration ?? this.replayDuration,
        replayEntitledDuration:
            replayEntitledDuration ?? this.replayEntitledDuration,
        allowedOverlayApps: allowedOverlayApps ?? this.allowedOverlayApps,
        boundApps: boundApps ?? this.boundApps,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        genres: genres ?? this.genres,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        replaySources: replaySources ?? this.replaySources,
        replayAppId: replayAppId ?? this.replayAppId,
        replayAppChannelId: replayAppChannelId ?? this.replayAppChannelId,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        hasLDVRChannelBasedAuthorization: hasLDVRChannelBasedAuthorization ??
            this.hasLDVRChannelBasedAuthorization,
        hasLDVRRestrictCPEStreaming:
            hasLDVRRestrictCPEStreaming ?? this.hasLDVRRestrictCPEStreaming,
        ndvrBlackout: ndvrBlackout ?? this.ndvrBlackout,
        saveReplayToNdvr: saveReplayToNdvr ?? this.saveReplayToNdvr,
        replacement: replacement ?? this.replacement,
        providerLogo: providerLogo ?? this.providerLogo,
        appIdForDayPass: appIdForDayPass ?? this.appIdForDayPass,
        promotionalImage: promotionalImage ?? this.promotionalImage,
        contextMenuActions: contextMenuActions ?? this.contextMenuActions,
        providerId: providerId ?? this.providerId,
        dlarEnabled: dlarEnabled ?? this.dlarEnabled,
        isDayPassEnabled: isDayPassEnabled ?? this.isDayPassEnabled,
        uidPlacement: uidPlacement ?? this.uidPlacement,
        adChannelType: adChannelType ?? this.adChannelType,
        adSupport: adSupport ?? this.adSupport);
  }

  Channel copyWithWrapped(
      {Wrapped<String>? channelId,
      Wrapped<String>? name,
      Wrapped<int>? channelNumber,
      Wrapped<String?>? logoFocused,
      Wrapped<String?>? logoUnfocused,
      Wrapped<bool?>? isEntitled,
      Wrapped<bool?>? isRadio,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? is3D,
      Wrapped<bool?>? isWatershed,
      Wrapped<bool?>? isHidden,
      Wrapped<bool?>? isPPV,
      Wrapped<bool?>? hasIpTeletext,
      Wrapped<enums.ChannelResolution?>? resolution,
      Wrapped<String?>? locator,
      Wrapped<String?>? blackoutSchedule,
      Wrapped<String?>? blackoutDuration,
      Wrapped<bool?>? allowStartOver,
      Wrapped<bool?>? isStartOverEntitled,
      Wrapped<bool?>? allowReplayTV,
      Wrapped<enums.ChannelReplayMode?>? replayMode,
      Wrapped<int?>? replayDuration,
      Wrapped<int?>? replayEntitledDuration,
      Wrapped<List<String>?>? allowedOverlayApps,
      Wrapped<List<BoundApp>?>? boundApps,
      Wrapped<int?>? entitlementEnd,
      Wrapped<List<String>?>? genres,
      Wrapped<List<enums.ChannelTrickPlayControl>?>? trickPlayControl,
      Wrapped<List<enums.ChannelReplaySources>?>? replaySources,
      Wrapped<String?>? replayAppId,
      Wrapped<String?>? replayAppChannelId,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<bool?>? hasLDVRChannelBasedAuthorization,
      Wrapped<bool?>? hasLDVRRestrictCPEStreaming,
      Wrapped<bool?>? ndvrBlackout,
      Wrapped<bool?>? saveReplayToNdvr,
      Wrapped<Channel$Replacement?>? replacement,
      Wrapped<String?>? providerLogo,
      Wrapped<String?>? appIdForDayPass,
      Wrapped<String?>? promotionalImage,
      Wrapped<enums.ChannelContextMenuActions?>? contextMenuActions,
      Wrapped<String?>? providerId,
      Wrapped<bool?>? dlarEnabled,
      Wrapped<bool?>? isDayPassEnabled,
      Wrapped<bool?>? uidPlacement,
      Wrapped<String?>? adChannelType,
      Wrapped<List<String>?>? adSupport}) {
    return Channel(
        channelId: (channelId != null ? channelId.value : this.channelId),
        name: (name != null ? name.value : this.name),
        channelNumber:
            (channelNumber != null ? channelNumber.value : this.channelNumber),
        logoFocused:
            (logoFocused != null ? logoFocused.value : this.logoFocused),
        logoUnfocused:
            (logoUnfocused != null ? logoUnfocused.value : this.logoUnfocused),
        isEntitled: (isEntitled != null ? isEntitled.value : this.isEntitled),
        isRadio: (isRadio != null ? isRadio.value : this.isRadio),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        is3D: (is3D != null ? is3D.value : this.is3D),
        isWatershed:
            (isWatershed != null ? isWatershed.value : this.isWatershed),
        isHidden: (isHidden != null ? isHidden.value : this.isHidden),
        isPPV: (isPPV != null ? isPPV.value : this.isPPV),
        hasIpTeletext:
            (hasIpTeletext != null ? hasIpTeletext.value : this.hasIpTeletext),
        resolution: (resolution != null ? resolution.value : this.resolution),
        locator: (locator != null ? locator.value : this.locator),
        blackoutSchedule: (blackoutSchedule != null
            ? blackoutSchedule.value
            : this.blackoutSchedule),
        blackoutDuration: (blackoutDuration != null
            ? blackoutDuration.value
            : this.blackoutDuration),
        allowStartOver: (allowStartOver != null
            ? allowStartOver.value
            : this.allowStartOver),
        isStartOverEntitled: (isStartOverEntitled != null
            ? isStartOverEntitled.value
            : this.isStartOverEntitled),
        allowReplayTV:
            (allowReplayTV != null ? allowReplayTV.value : this.allowReplayTV),
        replayMode: (replayMode != null ? replayMode.value : this.replayMode),
        replayDuration: (replayDuration != null
            ? replayDuration.value
            : this.replayDuration),
        replayEntitledDuration: (replayEntitledDuration != null
            ? replayEntitledDuration.value
            : this.replayEntitledDuration),
        allowedOverlayApps: (allowedOverlayApps != null
            ? allowedOverlayApps.value
            : this.allowedOverlayApps),
        boundApps: (boundApps != null ? boundApps.value : this.boundApps),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        genres: (genres != null ? genres.value : this.genres),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        replaySources:
            (replaySources != null ? replaySources.value : this.replaySources),
        replayAppId:
            (replayAppId != null ? replayAppId.value : this.replayAppId),
        replayAppChannelId: (replayAppChannelId != null
            ? replayAppChannelId.value
            : this.replayAppChannelId),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        hasLDVRChannelBasedAuthorization:
            (hasLDVRChannelBasedAuthorization != null
                ? hasLDVRChannelBasedAuthorization.value
                : this.hasLDVRChannelBasedAuthorization),
        hasLDVRRestrictCPEStreaming: (hasLDVRRestrictCPEStreaming != null
            ? hasLDVRRestrictCPEStreaming.value
            : this.hasLDVRRestrictCPEStreaming),
        ndvrBlackout:
            (ndvrBlackout != null ? ndvrBlackout.value : this.ndvrBlackout),
        saveReplayToNdvr: (saveReplayToNdvr != null
            ? saveReplayToNdvr.value
            : this.saveReplayToNdvr),
        replacement:
            (replacement != null ? replacement.value : this.replacement),
        providerLogo:
            (providerLogo != null ? providerLogo.value : this.providerLogo),
        appIdForDayPass: (appIdForDayPass != null
            ? appIdForDayPass.value
            : this.appIdForDayPass),
        promotionalImage: (promotionalImage != null
            ? promotionalImage.value
            : this.promotionalImage),
        contextMenuActions: (contextMenuActions != null
            ? contextMenuActions.value
            : this.contextMenuActions),
        providerId: (providerId != null ? providerId.value : this.providerId),
        dlarEnabled:
            (dlarEnabled != null ? dlarEnabled.value : this.dlarEnabled),
        isDayPassEnabled: (isDayPassEnabled != null
            ? isDayPassEnabled.value
            : this.isDayPassEnabled),
        uidPlacement:
            (uidPlacement != null ? uidPlacement.value : this.uidPlacement),
        adChannelType:
            (adChannelType != null ? adChannelType.value : this.adChannelType),
        adSupport: (adSupport != null ? adSupport.value : this.adSupport));
  }
}

@JsonSerializable(explicitToJson: true)
class BoundApp {
  BoundApp({
    required this.deeplink,
    this.trigger,
    this.delay,
    this.applogo,
    this.posterlogo,
    this.toastMessage,
    this.toastImage,
    this.displayTime,
    this.repeat,
    this.interval,
    this.deeplinkfordaypass,
    this.promotionalimage,
    this.synopsis,
    this.channelBound,
  });

  factory BoundApp.fromJson(Map<String, dynamic> json) =>
      _$BoundAppFromJson(json);

  static const toJsonFactory = _$BoundAppToJson;
  Map<String, dynamic> toJson() => _$BoundAppToJson(this);

  @JsonKey(name: 'deeplink', includeIfNull: false, defaultValue: '')
  final String deeplink;
  @JsonKey(
    name: 'trigger',
    includeIfNull: false,
    toJson: boundAppTriggerToJson,
    fromJson: boundAppTriggerFromJson,
  )
  final enums.BoundAppTrigger? trigger;
  @JsonKey(name: 'delay', includeIfNull: false)
  final int? delay;
  @JsonKey(name: 'applogo', includeIfNull: false, defaultValue: '')
  final String? applogo;
  @JsonKey(name: 'posterlogo', includeIfNull: false, defaultValue: '')
  final String? posterlogo;
  @JsonKey(name: 'toastMessage', includeIfNull: false)
  final Map<String, dynamic>? toastMessage;
  @JsonKey(name: 'toastImage', includeIfNull: false, defaultValue: '')
  final String? toastImage;
  @JsonKey(name: 'displayTime', includeIfNull: false)
  final int? displayTime;
  @JsonKey(name: 'repeat', includeIfNull: false)
  final int? repeat;
  @JsonKey(name: 'interval', includeIfNull: false)
  final int? interval;
  @JsonKey(name: 'deeplinkfordaypass', includeIfNull: false, defaultValue: '')
  final String? deeplinkfordaypass;
  @JsonKey(name: 'promotionalimage', includeIfNull: false, defaultValue: '')
  final String? promotionalimage;
  @JsonKey(name: 'synopsis', includeIfNull: false)
  final Map<String, dynamic>? synopsis;
  @JsonKey(name: 'channelBound', includeIfNull: false, defaultValue: <String>[])
  final List<String>? channelBound;
  static const fromJsonFactory = _$BoundAppFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BoundApp &&
            (identical(other.deeplink, deeplink) ||
                const DeepCollectionEquality()
                    .equals(other.deeplink, deeplink)) &&
            (identical(other.trigger, trigger) ||
                const DeepCollectionEquality()
                    .equals(other.trigger, trigger)) &&
            (identical(other.delay, delay) ||
                const DeepCollectionEquality().equals(other.delay, delay)) &&
            (identical(other.applogo, applogo) ||
                const DeepCollectionEquality()
                    .equals(other.applogo, applogo)) &&
            (identical(other.posterlogo, posterlogo) ||
                const DeepCollectionEquality()
                    .equals(other.posterlogo, posterlogo)) &&
            (identical(other.toastMessage, toastMessage) ||
                const DeepCollectionEquality()
                    .equals(other.toastMessage, toastMessage)) &&
            (identical(other.toastImage, toastImage) ||
                const DeepCollectionEquality()
                    .equals(other.toastImage, toastImage)) &&
            (identical(other.displayTime, displayTime) ||
                const DeepCollectionEquality()
                    .equals(other.displayTime, displayTime)) &&
            (identical(other.repeat, repeat) ||
                const DeepCollectionEquality().equals(other.repeat, repeat)) &&
            (identical(other.interval, interval) ||
                const DeepCollectionEquality()
                    .equals(other.interval, interval)) &&
            (identical(other.deeplinkfordaypass, deeplinkfordaypass) ||
                const DeepCollectionEquality()
                    .equals(other.deeplinkfordaypass, deeplinkfordaypass)) &&
            (identical(other.promotionalimage, promotionalimage) ||
                const DeepCollectionEquality()
                    .equals(other.promotionalimage, promotionalimage)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.channelBound, channelBound) ||
                const DeepCollectionEquality()
                    .equals(other.channelBound, channelBound)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deeplink) ^
      const DeepCollectionEquality().hash(trigger) ^
      const DeepCollectionEquality().hash(delay) ^
      const DeepCollectionEquality().hash(applogo) ^
      const DeepCollectionEquality().hash(posterlogo) ^
      const DeepCollectionEquality().hash(toastMessage) ^
      const DeepCollectionEquality().hash(toastImage) ^
      const DeepCollectionEquality().hash(displayTime) ^
      const DeepCollectionEquality().hash(repeat) ^
      const DeepCollectionEquality().hash(interval) ^
      const DeepCollectionEquality().hash(deeplinkfordaypass) ^
      const DeepCollectionEquality().hash(promotionalimage) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(channelBound) ^
      runtimeType.hashCode;
}

extension $BoundAppExtension on BoundApp {
  BoundApp copyWith(
      {String? deeplink,
      enums.BoundAppTrigger? trigger,
      int? delay,
      String? applogo,
      String? posterlogo,
      Map<String, dynamic>? toastMessage,
      String? toastImage,
      int? displayTime,
      int? repeat,
      int? interval,
      String? deeplinkfordaypass,
      String? promotionalimage,
      Map<String, dynamic>? synopsis,
      List<String>? channelBound}) {
    return BoundApp(
        deeplink: deeplink ?? this.deeplink,
        trigger: trigger ?? this.trigger,
        delay: delay ?? this.delay,
        applogo: applogo ?? this.applogo,
        posterlogo: posterlogo ?? this.posterlogo,
        toastMessage: toastMessage ?? this.toastMessage,
        toastImage: toastImage ?? this.toastImage,
        displayTime: displayTime ?? this.displayTime,
        repeat: repeat ?? this.repeat,
        interval: interval ?? this.interval,
        deeplinkfordaypass: deeplinkfordaypass ?? this.deeplinkfordaypass,
        promotionalimage: promotionalimage ?? this.promotionalimage,
        synopsis: synopsis ?? this.synopsis,
        channelBound: channelBound ?? this.channelBound);
  }

  BoundApp copyWithWrapped(
      {Wrapped<String>? deeplink,
      Wrapped<enums.BoundAppTrigger?>? trigger,
      Wrapped<int?>? delay,
      Wrapped<String?>? applogo,
      Wrapped<String?>? posterlogo,
      Wrapped<Map<String, dynamic>?>? toastMessage,
      Wrapped<String?>? toastImage,
      Wrapped<int?>? displayTime,
      Wrapped<int?>? repeat,
      Wrapped<int?>? interval,
      Wrapped<String?>? deeplinkfordaypass,
      Wrapped<String?>? promotionalimage,
      Wrapped<Map<String, dynamic>?>? synopsis,
      Wrapped<List<String>?>? channelBound}) {
    return BoundApp(
        deeplink: (deeplink != null ? deeplink.value : this.deeplink),
        trigger: (trigger != null ? trigger.value : this.trigger),
        delay: (delay != null ? delay.value : this.delay),
        applogo: (applogo != null ? applogo.value : this.applogo),
        posterlogo: (posterlogo != null ? posterlogo.value : this.posterlogo),
        toastMessage:
            (toastMessage != null ? toastMessage.value : this.toastMessage),
        toastImage: (toastImage != null ? toastImage.value : this.toastImage),
        displayTime:
            (displayTime != null ? displayTime.value : this.displayTime),
        repeat: (repeat != null ? repeat.value : this.repeat),
        interval: (interval != null ? interval.value : this.interval),
        deeplinkfordaypass: (deeplinkfordaypass != null
            ? deeplinkfordaypass.value
            : this.deeplinkfordaypass),
        promotionalimage: (promotionalimage != null
            ? promotionalimage.value
            : this.promotionalimage),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        channelBound:
            (channelBound != null ? channelBound.value : this.channelBound));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelList {
  ChannelList({
    required this.type,
    this.name,
    required this.channels,
    this.profileId,
  });

  factory ChannelList.fromJson(Map<String, dynamic> json) =>
      _$ChannelListFromJson(json);

  static const toJsonFactory = _$ChannelListToJson;
  Map<String, dynamic> toJson() => _$ChannelListToJson(this);

  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: channelListTypeToJson,
    fromJson: channelListTypeFromJson,
  )
  final enums.ChannelListType type;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <ChannelRef>[])
  final List<ChannelRef> channels;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  static const fromJsonFactory = _$ChannelListFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelList &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(profileId) ^
      runtimeType.hashCode;
}

extension $ChannelListExtension on ChannelList {
  ChannelList copyWith(
      {enums.ChannelListType? type,
      String? name,
      List<ChannelRef>? channels,
      String? profileId}) {
    return ChannelList(
        type: type ?? this.type,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        profileId: profileId ?? this.profileId);
  }

  ChannelList copyWithWrapped(
      {Wrapped<enums.ChannelListType>? type,
      Wrapped<String?>? name,
      Wrapped<List<ChannelRef>>? channels,
      Wrapped<String?>? profileId}) {
    return ChannelList(
        type: (type != null ? type.value : this.type),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        profileId: (profileId != null ? profileId.value : this.profileId));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelRef {
  ChannelRef({
    required this.channelId,
    this.name,
    this.channelNumber,
  });

  factory ChannelRef.fromJson(Map<String, dynamic> json) =>
      _$ChannelRefFromJson(json);

  static const toJsonFactory = _$ChannelRefToJson;
  Map<String, dynamic> toJson() => _$ChannelRefToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelNumber', includeIfNull: false)
  final int? channelNumber;
  static const fromJsonFactory = _$ChannelRefFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelRef &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelNumber, channelNumber) ||
                const DeepCollectionEquality()
                    .equals(other.channelNumber, channelNumber)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelNumber) ^
      runtimeType.hashCode;
}

extension $ChannelRefExtension on ChannelRef {
  ChannelRef copyWith({String? channelId, String? name, int? channelNumber}) {
    return ChannelRef(
        channelId: channelId ?? this.channelId,
        name: name ?? this.name,
        channelNumber: channelNumber ?? this.channelNumber);
  }

  ChannelRef copyWithWrapped(
      {Wrapped<String>? channelId,
      Wrapped<String?>? name,
      Wrapped<int?>? channelNumber}) {
    return ChannelRef(
        channelId: (channelId != null ? channelId.value : this.channelId),
        name: (name != null ? name.value : this.name),
        channelNumber:
            (channelNumber != null ? channelNumber.value : this.channelNumber));
  }
}

@JsonSerializable(explicitToJson: true)
class CurrentChannelChangeEvent {
  CurrentChannelChangeEvent({
    this.currentId,
    this.previousId,
  });

  factory CurrentChannelChangeEvent.fromJson(Map<String, dynamic> json) =>
      _$CurrentChannelChangeEventFromJson(json);

  static const toJsonFactory = _$CurrentChannelChangeEventToJson;
  Map<String, dynamic> toJson() => _$CurrentChannelChangeEventToJson(this);

  @JsonKey(name: 'currentId', includeIfNull: false, defaultValue: '')
  final String? currentId;
  @JsonKey(name: 'previousId', includeIfNull: false, defaultValue: '')
  final String? previousId;
  static const fromJsonFactory = _$CurrentChannelChangeEventFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CurrentChannelChangeEvent &&
            (identical(other.currentId, currentId) ||
                const DeepCollectionEquality()
                    .equals(other.currentId, currentId)) &&
            (identical(other.previousId, previousId) ||
                const DeepCollectionEquality()
                    .equals(other.previousId, previousId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(currentId) ^
      const DeepCollectionEquality().hash(previousId) ^
      runtimeType.hashCode;
}

extension $CurrentChannelChangeEventExtension on CurrentChannelChangeEvent {
  CurrentChannelChangeEvent copyWith({String? currentId, String? previousId}) {
    return CurrentChannelChangeEvent(
        currentId: currentId ?? this.currentId,
        previousId: previousId ?? this.previousId);
  }

  CurrentChannelChangeEvent copyWithWrapped(
      {Wrapped<String?>? currentId, Wrapped<String?>? previousId}) {
    return CurrentChannelChangeEvent(
        currentId: (currentId != null ? currentId.value : this.currentId),
        previousId: (previousId != null ? previousId.value : this.previousId));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelListChangeEvent {
  ChannelListChangeEvent({
    this.oldList,
    this.newList,
    this.type,
  });

  factory ChannelListChangeEvent.fromJson(Map<String, dynamic> json) =>
      _$ChannelListChangeEventFromJson(json);

  static const toJsonFactory = _$ChannelListChangeEventToJson;
  Map<String, dynamic> toJson() => _$ChannelListChangeEventToJson(this);

  @JsonKey(name: 'oldList', includeIfNull: false)
  final ChannelList? oldList;
  @JsonKey(name: 'newList', includeIfNull: false)
  final ChannelList? newList;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: currentChannelListTypeToJson,
    fromJson: currentChannelListTypeFromJson,
  )
  final enums.CurrentChannelListType? type;
  static const fromJsonFactory = _$ChannelListChangeEventFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelListChangeEvent &&
            (identical(other.oldList, oldList) ||
                const DeepCollectionEquality()
                    .equals(other.oldList, oldList)) &&
            (identical(other.newList, newList) ||
                const DeepCollectionEquality()
                    .equals(other.newList, newList)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(oldList) ^
      const DeepCollectionEquality().hash(newList) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ChannelListChangeEventExtension on ChannelListChangeEvent {
  ChannelListChangeEvent copyWith(
      {ChannelList? oldList,
      ChannelList? newList,
      enums.CurrentChannelListType? type}) {
    return ChannelListChangeEvent(
        oldList: oldList ?? this.oldList,
        newList: newList ?? this.newList,
        type: type ?? this.type);
  }

  ChannelListChangeEvent copyWithWrapped(
      {Wrapped<ChannelList?>? oldList,
      Wrapped<ChannelList?>? newList,
      Wrapped<enums.CurrentChannelListType?>? type}) {
    return ChannelListChangeEvent(
        oldList: (oldList != null ? oldList.value : this.oldList),
        newList: (newList != null ? newList.value : this.newList),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelsUpdatedEvent {
  ChannelsUpdatedEvent({
    this.addedIds,
    this.modifiedIds,
    this.removedIds,
  });

  factory ChannelsUpdatedEvent.fromJson(Map<String, dynamic> json) =>
      _$ChannelsUpdatedEventFromJson(json);

  static const toJsonFactory = _$ChannelsUpdatedEventToJson;
  Map<String, dynamic> toJson() => _$ChannelsUpdatedEventToJson(this);

  @JsonKey(name: 'addedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? addedIds;
  @JsonKey(name: 'modifiedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? modifiedIds;
  @JsonKey(name: 'removedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? removedIds;
  static const fromJsonFactory = _$ChannelsUpdatedEventFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelsUpdatedEvent &&
            (identical(other.addedIds, addedIds) ||
                const DeepCollectionEquality()
                    .equals(other.addedIds, addedIds)) &&
            (identical(other.modifiedIds, modifiedIds) ||
                const DeepCollectionEquality()
                    .equals(other.modifiedIds, modifiedIds)) &&
            (identical(other.removedIds, removedIds) ||
                const DeepCollectionEquality()
                    .equals(other.removedIds, removedIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(addedIds) ^
      const DeepCollectionEquality().hash(modifiedIds) ^
      const DeepCollectionEquality().hash(removedIds) ^
      runtimeType.hashCode;
}

extension $ChannelsUpdatedEventExtension on ChannelsUpdatedEvent {
  ChannelsUpdatedEvent copyWith(
      {List<String>? addedIds,
      List<String>? modifiedIds,
      List<String>? removedIds}) {
    return ChannelsUpdatedEvent(
        addedIds: addedIds ?? this.addedIds,
        modifiedIds: modifiedIds ?? this.modifiedIds,
        removedIds: removedIds ?? this.removedIds);
  }

  ChannelsUpdatedEvent copyWithWrapped(
      {Wrapped<List<String>?>? addedIds,
      Wrapped<List<String>?>? modifiedIds,
      Wrapped<List<String>?>? removedIds}) {
    return ChannelsUpdatedEvent(
        addedIds: (addedIds != null ? addedIds.value : this.addedIds),
        modifiedIds:
            (modifiedIds != null ? modifiedIds.value : this.modifiedIds),
        removedIds: (removedIds != null ? removedIds.value : this.removedIds));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel$Replacement {
  Channel$Replacement({
    required this.startTimeLocal,
    required this.endTimeLocal,
    required this.replacementURI,
    this.replacementChannel,
  });

  factory Channel$Replacement.fromJson(Map<String, dynamic> json) =>
      _$Channel$ReplacementFromJson(json);

  static const toJsonFactory = _$Channel$ReplacementToJson;
  Map<String, dynamic> toJson() => _$Channel$ReplacementToJson(this);

  @JsonKey(name: 'startTimeLocal', includeIfNull: false, defaultValue: '')
  final String startTimeLocal;
  @JsonKey(name: 'endTimeLocal', includeIfNull: false, defaultValue: '')
  final String endTimeLocal;
  @JsonKey(name: 'replacementURI', includeIfNull: false, defaultValue: '')
  final String replacementURI;
  @JsonKey(name: 'replacementChannel', includeIfNull: false, defaultValue: '')
  final String? replacementChannel;
  static const fromJsonFactory = _$Channel$ReplacementFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel$Replacement &&
            (identical(other.startTimeLocal, startTimeLocal) ||
                const DeepCollectionEquality()
                    .equals(other.startTimeLocal, startTimeLocal)) &&
            (identical(other.endTimeLocal, endTimeLocal) ||
                const DeepCollectionEquality()
                    .equals(other.endTimeLocal, endTimeLocal)) &&
            (identical(other.replacementURI, replacementURI) ||
                const DeepCollectionEquality()
                    .equals(other.replacementURI, replacementURI)) &&
            (identical(other.replacementChannel, replacementChannel) ||
                const DeepCollectionEquality()
                    .equals(other.replacementChannel, replacementChannel)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTimeLocal) ^
      const DeepCollectionEquality().hash(endTimeLocal) ^
      const DeepCollectionEquality().hash(replacementURI) ^
      const DeepCollectionEquality().hash(replacementChannel) ^
      runtimeType.hashCode;
}

extension $Channel$ReplacementExtension on Channel$Replacement {
  Channel$Replacement copyWith(
      {String? startTimeLocal,
      String? endTimeLocal,
      String? replacementURI,
      String? replacementChannel}) {
    return Channel$Replacement(
        startTimeLocal: startTimeLocal ?? this.startTimeLocal,
        endTimeLocal: endTimeLocal ?? this.endTimeLocal,
        replacementURI: replacementURI ?? this.replacementURI,
        replacementChannel: replacementChannel ?? this.replacementChannel);
  }

  Channel$Replacement copyWithWrapped(
      {Wrapped<String>? startTimeLocal,
      Wrapped<String>? endTimeLocal,
      Wrapped<String>? replacementURI,
      Wrapped<String?>? replacementChannel}) {
    return Channel$Replacement(
        startTimeLocal: (startTimeLocal != null
            ? startTimeLocal.value
            : this.startTimeLocal),
        endTimeLocal:
            (endTimeLocal != null ? endTimeLocal.value : this.endTimeLocal),
        replacementURI: (replacementURI != null
            ? replacementURI.value
            : this.replacementURI),
        replacementChannel: (replacementChannel != null
            ? replacementChannel.value
            : this.replacementChannel));
  }
}

String? channelResolutionToJson(enums.ChannelResolution? channelResolution) {
  return channelResolution?.value;
}

enums.ChannelResolution channelResolutionFromJson(
  Object? channelResolution, [
  enums.ChannelResolution? defaultValue,
]) {
  return enums.ChannelResolution.values
          .firstWhereOrNull((e) => e.value == channelResolution) ??
      defaultValue ??
      enums.ChannelResolution.swaggerGeneratedUnknown;
}

List<String> channelResolutionListToJson(
    List<enums.ChannelResolution>? channelResolution) {
  if (channelResolution == null) {
    return [];
  }

  return channelResolution.map((e) => e.value!).toList();
}

List<enums.ChannelResolution> channelResolutionListFromJson(
  List? channelResolution, [
  List<enums.ChannelResolution>? defaultValue,
]) {
  if (channelResolution == null) {
    return defaultValue ?? [];
  }

  return channelResolution
      .map((e) => channelResolutionFromJson(e.toString()))
      .toList();
}

List<enums.ChannelResolution>? channelResolutionNullableListFromJson(
  List? channelResolution, [
  List<enums.ChannelResolution>? defaultValue,
]) {
  if (channelResolution == null) {
    return defaultValue;
  }

  return channelResolution
      .map((e) => channelResolutionFromJson(e.toString()))
      .toList();
}

String? channelReplayModeToJson(enums.ChannelReplayMode? channelReplayMode) {
  return channelReplayMode?.value;
}

enums.ChannelReplayMode channelReplayModeFromJson(
  Object? channelReplayMode, [
  enums.ChannelReplayMode? defaultValue,
]) {
  return enums.ChannelReplayMode.values
          .firstWhereOrNull((e) => e.value == channelReplayMode) ??
      defaultValue ??
      enums.ChannelReplayMode.swaggerGeneratedUnknown;
}

List<String> channelReplayModeListToJson(
    List<enums.ChannelReplayMode>? channelReplayMode) {
  if (channelReplayMode == null) {
    return [];
  }

  return channelReplayMode.map((e) => e.value!).toList();
}

List<enums.ChannelReplayMode> channelReplayModeListFromJson(
  List? channelReplayMode, [
  List<enums.ChannelReplayMode>? defaultValue,
]) {
  if (channelReplayMode == null) {
    return defaultValue ?? [];
  }

  return channelReplayMode
      .map((e) => channelReplayModeFromJson(e.toString()))
      .toList();
}

List<enums.ChannelReplayMode>? channelReplayModeNullableListFromJson(
  List? channelReplayMode, [
  List<enums.ChannelReplayMode>? defaultValue,
]) {
  if (channelReplayMode == null) {
    return defaultValue;
  }

  return channelReplayMode
      .map((e) => channelReplayModeFromJson(e.toString()))
      .toList();
}

String? channelTrickPlayControlToJson(
    enums.ChannelTrickPlayControl? channelTrickPlayControl) {
  return channelTrickPlayControl?.value;
}

enums.ChannelTrickPlayControl channelTrickPlayControlFromJson(
  Object? channelTrickPlayControl, [
  enums.ChannelTrickPlayControl? defaultValue,
]) {
  return enums.ChannelTrickPlayControl.values
          .firstWhereOrNull((e) => e.value == channelTrickPlayControl) ??
      defaultValue ??
      enums.ChannelTrickPlayControl.swaggerGeneratedUnknown;
}

List<String> channelTrickPlayControlListToJson(
    List<enums.ChannelTrickPlayControl>? channelTrickPlayControl) {
  if (channelTrickPlayControl == null) {
    return [];
  }

  return channelTrickPlayControl.map((e) => e.value!).toList();
}

List<enums.ChannelTrickPlayControl> channelTrickPlayControlListFromJson(
  List? channelTrickPlayControl, [
  List<enums.ChannelTrickPlayControl>? defaultValue,
]) {
  if (channelTrickPlayControl == null) {
    return defaultValue ?? [];
  }

  return channelTrickPlayControl
      .map((e) => channelTrickPlayControlFromJson(e.toString()))
      .toList();
}

List<enums.ChannelTrickPlayControl>?
    channelTrickPlayControlNullableListFromJson(
  List? channelTrickPlayControl, [
  List<enums.ChannelTrickPlayControl>? defaultValue,
]) {
  if (channelTrickPlayControl == null) {
    return defaultValue;
  }

  return channelTrickPlayControl
      .map((e) => channelTrickPlayControlFromJson(e.toString()))
      .toList();
}

String? channelReplaySourcesToJson(
    enums.ChannelReplaySources? channelReplaySources) {
  return channelReplaySources?.value;
}

enums.ChannelReplaySources channelReplaySourcesFromJson(
  Object? channelReplaySources, [
  enums.ChannelReplaySources? defaultValue,
]) {
  return enums.ChannelReplaySources.values
          .firstWhereOrNull((e) => e.value == channelReplaySources) ??
      defaultValue ??
      enums.ChannelReplaySources.swaggerGeneratedUnknown;
}

List<String> channelReplaySourcesListToJson(
    List<enums.ChannelReplaySources>? channelReplaySources) {
  if (channelReplaySources == null) {
    return [];
  }

  return channelReplaySources.map((e) => e.value!).toList();
}

List<enums.ChannelReplaySources> channelReplaySourcesListFromJson(
  List? channelReplaySources, [
  List<enums.ChannelReplaySources>? defaultValue,
]) {
  if (channelReplaySources == null) {
    return defaultValue ?? [];
  }

  return channelReplaySources
      .map((e) => channelReplaySourcesFromJson(e.toString()))
      .toList();
}

List<enums.ChannelReplaySources>? channelReplaySourcesNullableListFromJson(
  List? channelReplaySources, [
  List<enums.ChannelReplaySources>? defaultValue,
]) {
  if (channelReplaySources == null) {
    return defaultValue;
  }

  return channelReplaySources
      .map((e) => channelReplaySourcesFromJson(e.toString()))
      .toList();
}

String? channelContextMenuActionsToJson(
    enums.ChannelContextMenuActions? channelContextMenuActions) {
  return channelContextMenuActions?.value;
}

enums.ChannelContextMenuActions channelContextMenuActionsFromJson(
  Object? channelContextMenuActions, [
  enums.ChannelContextMenuActions? defaultValue,
]) {
  return enums.ChannelContextMenuActions.values
          .firstWhereOrNull((e) => e.value == channelContextMenuActions) ??
      defaultValue ??
      enums.ChannelContextMenuActions.swaggerGeneratedUnknown;
}

List<String> channelContextMenuActionsListToJson(
    List<enums.ChannelContextMenuActions>? channelContextMenuActions) {
  if (channelContextMenuActions == null) {
    return [];
  }

  return channelContextMenuActions.map((e) => e.value!).toList();
}

List<enums.ChannelContextMenuActions> channelContextMenuActionsListFromJson(
  List? channelContextMenuActions, [
  List<enums.ChannelContextMenuActions>? defaultValue,
]) {
  if (channelContextMenuActions == null) {
    return defaultValue ?? [];
  }

  return channelContextMenuActions
      .map((e) => channelContextMenuActionsFromJson(e.toString()))
      .toList();
}

List<enums.ChannelContextMenuActions>?
    channelContextMenuActionsNullableListFromJson(
  List? channelContextMenuActions, [
  List<enums.ChannelContextMenuActions>? defaultValue,
]) {
  if (channelContextMenuActions == null) {
    return defaultValue;
  }

  return channelContextMenuActions
      .map((e) => channelContextMenuActionsFromJson(e.toString()))
      .toList();
}

String? boundAppTriggerToJson(enums.BoundAppTrigger? boundAppTrigger) {
  return boundAppTrigger?.value;
}

enums.BoundAppTrigger boundAppTriggerFromJson(
  Object? boundAppTrigger, [
  enums.BoundAppTrigger? defaultValue,
]) {
  return enums.BoundAppTrigger.values
          .firstWhereOrNull((e) => e.value == boundAppTrigger) ??
      defaultValue ??
      enums.BoundAppTrigger.swaggerGeneratedUnknown;
}

List<String> boundAppTriggerListToJson(
    List<enums.BoundAppTrigger>? boundAppTrigger) {
  if (boundAppTrigger == null) {
    return [];
  }

  return boundAppTrigger.map((e) => e.value!).toList();
}

List<enums.BoundAppTrigger> boundAppTriggerListFromJson(
  List? boundAppTrigger, [
  List<enums.BoundAppTrigger>? defaultValue,
]) {
  if (boundAppTrigger == null) {
    return defaultValue ?? [];
  }

  return boundAppTrigger
      .map((e) => boundAppTriggerFromJson(e.toString()))
      .toList();
}

List<enums.BoundAppTrigger>? boundAppTriggerNullableListFromJson(
  List? boundAppTrigger, [
  List<enums.BoundAppTrigger>? defaultValue,
]) {
  if (boundAppTrigger == null) {
    return defaultValue;
  }

  return boundAppTrigger
      .map((e) => boundAppTriggerFromJson(e.toString()))
      .toList();
}

String? channelListTypeToJson(enums.ChannelListType? channelListType) {
  return channelListType?.value;
}

enums.ChannelListType channelListTypeFromJson(
  Object? channelListType, [
  enums.ChannelListType? defaultValue,
]) {
  return enums.ChannelListType.values
          .firstWhereOrNull((e) => e.value == channelListType) ??
      defaultValue ??
      enums.ChannelListType.swaggerGeneratedUnknown;
}

List<String> channelListTypeListToJson(
    List<enums.ChannelListType>? channelListType) {
  if (channelListType == null) {
    return [];
  }

  return channelListType.map((e) => e.value!).toList();
}

List<enums.ChannelListType> channelListTypeListFromJson(
  List? channelListType, [
  List<enums.ChannelListType>? defaultValue,
]) {
  if (channelListType == null) {
    return defaultValue ?? [];
  }

  return channelListType
      .map((e) => channelListTypeFromJson(e.toString()))
      .toList();
}

List<enums.ChannelListType>? channelListTypeNullableListFromJson(
  List? channelListType, [
  List<enums.ChannelListType>? defaultValue,
]) {
  if (channelListType == null) {
    return defaultValue;
  }

  return channelListType
      .map((e) => channelListTypeFromJson(e.toString()))
      .toList();
}

String? currentChannelListTypeToJson(
    enums.CurrentChannelListType? currentChannelListType) {
  return currentChannelListType?.value;
}

enums.CurrentChannelListType currentChannelListTypeFromJson(
  Object? currentChannelListType, [
  enums.CurrentChannelListType? defaultValue,
]) {
  return enums.CurrentChannelListType.values
          .firstWhereOrNull((e) => e.value == currentChannelListType) ??
      defaultValue ??
      enums.CurrentChannelListType.swaggerGeneratedUnknown;
}

List<String> currentChannelListTypeListToJson(
    List<enums.CurrentChannelListType>? currentChannelListType) {
  if (currentChannelListType == null) {
    return [];
  }

  return currentChannelListType.map((e) => e.value!).toList();
}

List<enums.CurrentChannelListType> currentChannelListTypeListFromJson(
  List? currentChannelListType, [
  List<enums.CurrentChannelListType>? defaultValue,
]) {
  if (currentChannelListType == null) {
    return defaultValue ?? [];
  }

  return currentChannelListType
      .map((e) => currentChannelListTypeFromJson(e.toString()))
      .toList();
}

List<enums.CurrentChannelListType>? currentChannelListTypeNullableListFromJson(
  List? currentChannelListType, [
  List<enums.CurrentChannelListType>? defaultValue,
]) {
  if (currentChannelListType == null) {
    return defaultValue;
  }

  return currentChannelListType
      .map((e) => currentChannelListTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
