// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'continue_watching_service.enums.swagger.dart' as enums;
export 'continue_watching_service.enums.swagger.dart';

part 'continue_watching_service.swagger.chopper.dart';
part 'continue_watching_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ContinueWatchingService extends ChopperService {
  static ContinueWatchingService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ContinueWatchingService(client);
    }

    final newClient = ChopperClient(
        services: [_$ContinueWatchingService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$ContinueWatchingService(newClient);
  }

  ///Returns a continue watching list enriched with metadata
  ///@param profileId profile identifier
  ///@param customerId Customer identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param clientType
  ///@param maxRes
  ///@param cityId
  ///@param limit Determines how many continue watching items should be returned at once
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Household ID
  ///@param X-Entitlements-Token Entitlements token header
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<List<ContinueWatchingItem>>>
      profilesProfileIdContinueWatchingGet({
    required String? profileId,
    String? customerId,
    String? language,
    enums.ProfilesProfileIdContinueWatchingGetContentType? contentType,
    enums.ProfilesProfileIdContinueWatchingGetClientType? clientType,
    enums.ProfilesProfileIdContinueWatchingGetMaxRes? maxRes,
    int? cityId,
    int? limit,
    String? replayOptInDate,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xCWSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContinueWatchingItem, () => ContinueWatchingItem.fromJsonFactory);

    return _profilesProfileIdContinueWatchingGet(
        profileId: profileId,
        customerId: customerId,
        language: language,
        contentType: contentType?.value?.toString(),
        clientType: clientType?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        limit: limit,
        replayOptInDate: replayOptInDate,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xCWSExplicitLogging: xCWSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Returns a continue watching list enriched with metadata
  ///@param profileId profile identifier
  ///@param customerId Customer identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param clientType
  ///@param maxRes
  ///@param cityId
  ///@param limit Determines how many continue watching items should be returned at once
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Household ID
  ///@param X-Entitlements-Token Entitlements token header
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/profiles/{profileId}/continue-watching')
  Future<chopper.Response<List<ContinueWatchingItem>>>
      _profilesProfileIdContinueWatchingGet({
    @Path('profileId')
        required String? profileId,
    @Query('customerId')
        String? customerId,
    @Query('language')
        String? language,
    @Query('contentType')
        String? contentType,
    @Query('clientType')
        String? clientType,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('limit')
        int? limit,
    @Query('replayOptInDate')
        String? replayOptInDate,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-CWS-Explicit-Logging')
        String? xCWSExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Delete items from continue watching list for given profile
  ///@param profileId profile identifier
  ///@param X-Cus Household ID
  Future<chopper.Response> profilesProfileIdContinueWatchingDeletePost({
    required String? profileId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required ContinueWatchingDeleteParams? body,
  }) {
    return _profilesProfileIdContinueWatchingDeletePost(
        profileId: profileId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Delete items from continue watching list for given profile
  ///@param profileId profile identifier
  ///@param X-Cus Household ID
  @Post(
    path: '/profiles/{profileId}/continue-watching/delete',
    optionalBody: true,
  )
  Future<chopper.Response> _profilesProfileIdContinueWatchingDeletePost({
    @Path('profileId') required String? profileId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required ContinueWatchingDeleteParams? body,
  });

  ///Returns a next episode enriched with metadata
  ///@param customerId customer id identifier
  ///@param contentId content id identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param cityId
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Household ID
  ///@param X-Entitlements-Token Entitlements token header
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<NextEpisode>>
      customersCustomerIdNextEpisodeContentIdGet({
    required String? customerId,
    required String? contentId,
    String? language,
    required enums.CustomersCustomerIdNextEpisodeContentIdGetContentType?
        contentType,
    int? cityId,
    String? replayOptInDate,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xCWSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NextEpisode, () => NextEpisode.fromJsonFactory);

    return _customersCustomerIdNextEpisodeContentIdGet(
        customerId: customerId,
        contentId: contentId,
        language: language,
        contentType: contentType?.value?.toString(),
        cityId: cityId,
        replayOptInDate: replayOptInDate,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xCWSExplicitLogging: xCWSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Returns a next episode enriched with metadata
  ///@param customerId customer id identifier
  ///@param contentId content id identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param cityId
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Household ID
  ///@param X-Entitlements-Token Entitlements token header
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/customers/{customerId}/nextEpisode/{contentId}')
  Future<chopper.Response<NextEpisode>>
      _customersCustomerIdNextEpisodeContentIdGet({
    @Path('customerId')
        required String? customerId,
    @Path('contentId')
        required String? contentId,
    @Query('language')
        String? language,
    @Query('contentType')
        required String? contentType,
    @Query('cityId')
        int? cityId,
    @Query('replayOptInDate')
        String? replayOptInDate,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-CWS-Explicit-Logging')
        String? xCWSExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Returns a next event enriched with metadata
  ///@param eventId customer id identifier
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Household ID
  ///@param X-Entitlements-Token Entitlements token header
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<NextEvent>> nextEventEventIdGet({
    required String? eventId,
    String? replayOptInDate,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xCWSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(NextEvent, () => NextEvent.fromJsonFactory);

    return _nextEventEventIdGet(
        eventId: eventId,
        replayOptInDate: replayOptInDate,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xCWSExplicitLogging: xCWSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Returns a next event enriched with metadata
  ///@param eventId customer id identifier
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Household ID
  ///@param X-Entitlements-Token Entitlements token header
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/nextEvent/{eventId}')
  Future<chopper.Response<NextEvent>> _nextEventEventIdGet({
    @Path('eventId')
        required String? eventId,
    @Query('replayOptInDate')
        String? replayOptInDate,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-CWS-Explicit-Logging')
        String? xCWSExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingItem {
  ContinueWatchingItem({
    required this.id,
    required this.contentType,
    required this.name,
    this.minimumAge,
    required this.duration,
    this.pictureUrl,
    this.posterUrl,
    required this.bookmark,
    this.channelId,
    required this.startTime,
    required this.endTime,
    this.episodeNumber,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.showId,
    this.showName,
    this.currency,
    this.entitlementState,
    this.entitlementEnd,
    this.price,
    this.priceDisplay,
    this.rentalPeriod,
    this.listingId,
    this.containsAdult,
    this.trickPlayRestrictions,
    this.cpeId,
    this.viewState,
    this.hasMultipleProducts,
    required this.titleId,
    this.recordingState,
    this.restricted,
    this.channelBasedAuthorization,
    this.resolution,
    this.brandingProviderId,
    this.imageVersion,
    this.isGoPlayable,
    this.isGoPlayableViaExternalApp,
    this.externalAppUrls,
  });

  factory ContinueWatchingItem.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingItemFromJson(json);

  static const toJsonFactory = _$ContinueWatchingItemToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingItemToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'pictureUrl', includeIfNull: false, defaultValue: '')
  final String? pictureUrl;
  @JsonKey(name: 'posterUrl', includeIfNull: false, defaultValue: '')
  final String? posterUrl;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'listingId', includeIfNull: false, defaultValue: '')
  final String? listingId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(
      name: 'trickPlayRestrictions', includeIfNull: false, defaultValue: '')
  final String? trickPlayRestrictions;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'isGoPlayableViaExternalApp', includeIfNull: false)
  final bool? isGoPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrl>[])
  final List<ExternalAppUrl>? externalAppUrls;
  static const fromJsonFactory = _$ContinueWatchingItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.pictureUrl, pictureUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pictureUrl, pictureUrl)) &&
            (identical(other.posterUrl, posterUrl) ||
                const DeepCollectionEquality()
                    .equals(other.posterUrl, posterUrl)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.listingId, listingId) ||
                const DeepCollectionEquality().equals(other.listingId, listingId)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.trickPlayRestrictions, trickPlayRestrictions) || const DeepCollectionEquality().equals(other.trickPlayRestrictions, trickPlayRestrictions)) &&
            (identical(other.cpeId, cpeId) || const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.viewState, viewState) || const DeepCollectionEquality().equals(other.viewState, viewState)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) || const DeepCollectionEquality().equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.titleId, titleId) || const DeepCollectionEquality().equals(other.titleId, titleId)) &&
            (identical(other.recordingState, recordingState) || const DeepCollectionEquality().equals(other.recordingState, recordingState)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.brandingProviderId, brandingProviderId) || const DeepCollectionEquality().equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isGoPlayable, isGoPlayable) || const DeepCollectionEquality().equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.isGoPlayableViaExternalApp, isGoPlayableViaExternalApp) || const DeepCollectionEquality().equals(other.isGoPlayableViaExternalApp, isGoPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) || const DeepCollectionEquality().equals(other.externalAppUrls, externalAppUrls)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(pictureUrl) ^
      const DeepCollectionEquality().hash(posterUrl) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(listingId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(trickPlayRestrictions) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(isGoPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingItemExtension on ContinueWatchingItem {
  ContinueWatchingItem copyWith(
      {String? id,
      enums.ContentType? contentType,
      String? name,
      int? minimumAge,
      int? duration,
      String? pictureUrl,
      String? posterUrl,
      int? bookmark,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      int? episodeNumber,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      String? showId,
      String? showName,
      String? currency,
      String? entitlementState,
      DateTime? entitlementEnd,
      String? price,
      String? priceDisplay,
      String? rentalPeriod,
      String? listingId,
      bool? containsAdult,
      String? trickPlayRestrictions,
      String? cpeId,
      enums.ViewState? viewState,
      bool? hasMultipleProducts,
      String? titleId,
      enums.RecordingState? recordingState,
      bool? restricted,
      bool? channelBasedAuthorization,
      String? resolution,
      String? brandingProviderId,
      String? imageVersion,
      bool? isGoPlayable,
      bool? isGoPlayableViaExternalApp,
      List<ExternalAppUrl>? externalAppUrls}) {
    return ContinueWatchingItem(
        id: id ?? this.id,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        minimumAge: minimumAge ?? this.minimumAge,
        duration: duration ?? this.duration,
        pictureUrl: pictureUrl ?? this.pictureUrl,
        posterUrl: posterUrl ?? this.posterUrl,
        bookmark: bookmark ?? this.bookmark,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        showId: showId ?? this.showId,
        showName: showName ?? this.showName,
        currency: currency ?? this.currency,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        listingId: listingId ?? this.listingId,
        containsAdult: containsAdult ?? this.containsAdult,
        trickPlayRestrictions:
            trickPlayRestrictions ?? this.trickPlayRestrictions,
        cpeId: cpeId ?? this.cpeId,
        viewState: viewState ?? this.viewState,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        titleId: titleId ?? this.titleId,
        recordingState: recordingState ?? this.recordingState,
        restricted: restricted ?? this.restricted,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        resolution: resolution ?? this.resolution,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        imageVersion: imageVersion ?? this.imageVersion,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        isGoPlayableViaExternalApp:
            isGoPlayableViaExternalApp ?? this.isGoPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls);
  }

  ContinueWatchingItem copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<String>? name,
      Wrapped<int?>? minimumAge,
      Wrapped<int>? duration,
      Wrapped<String?>? pictureUrl,
      Wrapped<String?>? posterUrl,
      Wrapped<int>? bookmark,
      Wrapped<String?>? channelId,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? showName,
      Wrapped<String?>? currency,
      Wrapped<String?>? entitlementState,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<String?>? price,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? rentalPeriod,
      Wrapped<String?>? listingId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? trickPlayRestrictions,
      Wrapped<String?>? cpeId,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<String>? titleId,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<String?>? resolution,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<bool?>? isGoPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrl>?>? externalAppUrls}) {
    return ContinueWatchingItem(
        id: (id != null ? id.value : this.id),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        duration: (duration != null ? duration.value : this.duration),
        pictureUrl: (pictureUrl != null ? pictureUrl.value : this.pictureUrl),
        posterUrl: (posterUrl != null ? posterUrl.value : this.posterUrl),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        showId: (showId != null ? showId.value : this.showId),
        showName: (showName != null ? showName.value : this.showName),
        currency: (currency != null ? currency.value : this.currency),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        listingId: (listingId != null ? listingId.value : this.listingId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        trickPlayRestrictions: (trickPlayRestrictions != null
            ? trickPlayRestrictions.value
            : this.trickPlayRestrictions),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        viewState: (viewState != null ? viewState.value : this.viewState),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        titleId: (titleId != null ? titleId.value : this.titleId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        restricted: (restricted != null ? restricted.value : this.restricted),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        resolution: (resolution != null ? resolution.value : this.resolution),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        isGoPlayableViaExternalApp: (isGoPlayableViaExternalApp != null
            ? isGoPlayableViaExternalApp.value
            : this.isGoPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls));
  }
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams({
    this.titleIds,
    this.showIds,
  });

  factory ContinueWatchingDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingDeleteParamsFromJson(json);

  static const toJsonFactory = _$ContinueWatchingDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingDeleteParamsToJson(this);

  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(name: 'showIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showIds;
  static const fromJsonFactory = _$ContinueWatchingDeleteParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingDeleteParams &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.showIds, showIds) ||
                const DeepCollectionEquality().equals(other.showIds, showIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(showIds) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingDeleteParamsExtension
    on ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams copyWith(
      {List<String>? titleIds, List<String>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: titleIds ?? this.titleIds, showIds: showIds ?? this.showIds);
  }

  ContinueWatchingDeleteParams copyWithWrapped(
      {Wrapped<List<String>?>? titleIds, Wrapped<List<String>?>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        showIds: (showIds != null ? showIds.value : this.showIds));
  }
}

@JsonSerializable(explicitToJson: true)
class NextEpisode {
  NextEpisode({
    required this.nextEpisodeId,
    required this.contentType,
    required this.name,
    this.minimumAge,
    required this.duration,
    this.pictureUrl,
    this.posterUrl,
    this.channelId,
    required this.startTime,
    required this.endTime,
    this.episodeNumber,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.showId,
    this.showName,
    this.entitlementState,
    this.entitlementEnd,
    this.rentalPeriod,
    this.listingId,
    this.containsAdult,
    this.trickPlayRestrictions,
    this.cpeId,
    required this.titleId,
    this.restricted,
    this.channelBasedAuthorization,
    this.resolution,
  });

  factory NextEpisode.fromJson(Map<String, dynamic> json) =>
      _$NextEpisodeFromJson(json);

  static const toJsonFactory = _$NextEpisodeToJson;
  Map<String, dynamic> toJson() => _$NextEpisodeToJson(this);

  @JsonKey(name: 'nextEpisodeId', includeIfNull: false, defaultValue: '')
  final String nextEpisodeId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'pictureUrl', includeIfNull: false, defaultValue: '')
  final String? pictureUrl;
  @JsonKey(name: 'posterUrl', includeIfNull: false, defaultValue: '')
  final String? posterUrl;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'listingId', includeIfNull: false, defaultValue: '')
  final String? listingId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(
      name: 'trickPlayRestrictions', includeIfNull: false, defaultValue: '')
  final String? trickPlayRestrictions;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  static const fromJsonFactory = _$NextEpisodeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NextEpisode &&
            (identical(other.nextEpisodeId, nextEpisodeId) ||
                const DeepCollectionEquality()
                    .equals(other.nextEpisodeId, nextEpisodeId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.pictureUrl, pictureUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pictureUrl, pictureUrl)) &&
            (identical(other.posterUrl, posterUrl) ||
                const DeepCollectionEquality()
                    .equals(other.posterUrl, posterUrl)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.listingId, listingId) ||
                const DeepCollectionEquality()
                    .equals(other.listingId, listingId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.trickPlayRestrictions, trickPlayRestrictions) ||
                const DeepCollectionEquality().equals(
                    other.trickPlayRestrictions, trickPlayRestrictions)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.titleId, titleId) || const DeepCollectionEquality().equals(other.titleId, titleId)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nextEpisodeId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(pictureUrl) ^
      const DeepCollectionEquality().hash(posterUrl) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(listingId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(trickPlayRestrictions) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(resolution) ^
      runtimeType.hashCode;
}

extension $NextEpisodeExtension on NextEpisode {
  NextEpisode copyWith(
      {String? nextEpisodeId,
      enums.ContentType? contentType,
      String? name,
      int? minimumAge,
      int? duration,
      String? pictureUrl,
      String? posterUrl,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      int? episodeNumber,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      String? showId,
      String? showName,
      String? entitlementState,
      DateTime? entitlementEnd,
      String? rentalPeriod,
      String? listingId,
      bool? containsAdult,
      String? trickPlayRestrictions,
      String? cpeId,
      String? titleId,
      bool? restricted,
      bool? channelBasedAuthorization,
      String? resolution}) {
    return NextEpisode(
        nextEpisodeId: nextEpisodeId ?? this.nextEpisodeId,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        minimumAge: minimumAge ?? this.minimumAge,
        duration: duration ?? this.duration,
        pictureUrl: pictureUrl ?? this.pictureUrl,
        posterUrl: posterUrl ?? this.posterUrl,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        showId: showId ?? this.showId,
        showName: showName ?? this.showName,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        listingId: listingId ?? this.listingId,
        containsAdult: containsAdult ?? this.containsAdult,
        trickPlayRestrictions:
            trickPlayRestrictions ?? this.trickPlayRestrictions,
        cpeId: cpeId ?? this.cpeId,
        titleId: titleId ?? this.titleId,
        restricted: restricted ?? this.restricted,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        resolution: resolution ?? this.resolution);
  }

  NextEpisode copyWithWrapped(
      {Wrapped<String>? nextEpisodeId,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<String>? name,
      Wrapped<int?>? minimumAge,
      Wrapped<int>? duration,
      Wrapped<String?>? pictureUrl,
      Wrapped<String?>? posterUrl,
      Wrapped<String?>? channelId,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? showName,
      Wrapped<String?>? entitlementState,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<String?>? rentalPeriod,
      Wrapped<String?>? listingId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? trickPlayRestrictions,
      Wrapped<String?>? cpeId,
      Wrapped<String>? titleId,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<String?>? resolution}) {
    return NextEpisode(
        nextEpisodeId:
            (nextEpisodeId != null ? nextEpisodeId.value : this.nextEpisodeId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        duration: (duration != null ? duration.value : this.duration),
        pictureUrl: (pictureUrl != null ? pictureUrl.value : this.pictureUrl),
        posterUrl: (posterUrl != null ? posterUrl.value : this.posterUrl),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        showId: (showId != null ? showId.value : this.showId),
        showName: (showName != null ? showName.value : this.showName),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        listingId: (listingId != null ? listingId.value : this.listingId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        trickPlayRestrictions: (trickPlayRestrictions != null
            ? trickPlayRestrictions.value
            : this.trickPlayRestrictions),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        restricted: (restricted != null ? restricted.value : this.restricted),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        resolution: (resolution != null ? resolution.value : this.resolution));
  }
}

@JsonSerializable(explicitToJson: true)
class NextEvent {
  NextEvent({
    required this.nextEventId,
    required this.duration,
    required this.channelId,
    required this.startTime,
  });

  factory NextEvent.fromJson(Map<String, dynamic> json) =>
      _$NextEventFromJson(json);

  static const toJsonFactory = _$NextEventToJson;
  Map<String, dynamic> toJson() => _$NextEventToJson(this);

  @JsonKey(name: 'nextEventId', includeIfNull: false, defaultValue: '')
  final String nextEventId;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  static const fromJsonFactory = _$NextEventFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NextEvent &&
            (identical(other.nextEventId, nextEventId) ||
                const DeepCollectionEquality()
                    .equals(other.nextEventId, nextEventId)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nextEventId) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      runtimeType.hashCode;
}

extension $NextEventExtension on NextEvent {
  NextEvent copyWith(
      {String? nextEventId,
      int? duration,
      String? channelId,
      DateTime? startTime}) {
    return NextEvent(
        nextEventId: nextEventId ?? this.nextEventId,
        duration: duration ?? this.duration,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime);
  }

  NextEvent copyWithWrapped(
      {Wrapped<String>? nextEventId,
      Wrapped<int>? duration,
      Wrapped<String>? channelId,
      Wrapped<DateTime>? startTime}) {
    return NextEvent(
        nextEventId:
            (nextEventId != null ? nextEventId.value : this.nextEventId),
        duration: (duration != null ? duration.value : this.duration),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ExternalAppUrl {
  ExternalAppUrl({
    this.deviceCode,
    this.url,
  });

  factory ExternalAppUrl.fromJson(Map<String, dynamic> json) =>
      _$ExternalAppUrlFromJson(json);

  static const toJsonFactory = _$ExternalAppUrlToJson;
  Map<String, dynamic> toJson() => _$ExternalAppUrlToJson(this);

  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String? deviceCode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$ExternalAppUrlFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ExternalAppUrl &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ExternalAppUrlExtension on ExternalAppUrl {
  ExternalAppUrl copyWith({String? deviceCode, String? url}) {
    return ExternalAppUrl(
        deviceCode: deviceCode ?? this.deviceCode, url: url ?? this.url);
  }

  ExternalAppUrl copyWithWrapped(
      {Wrapped<String?>? deviceCode, Wrapped<String?>? url}) {
    return ExternalAppUrl(
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    required this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<String>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? contentTypeToJson(enums.ContentType? contentType) {
  return contentType?.value;
}

enums.ContentType contentTypeFromJson(
  Object? contentType, [
  enums.ContentType? defaultValue,
]) {
  return enums.ContentType.values
          .firstWhereOrNull((e) => e.value == contentType) ??
      defaultValue ??
      enums.ContentType.swaggerGeneratedUnknown;
}

List<String> contentTypeListToJson(List<enums.ContentType>? contentType) {
  if (contentType == null) {
    return [];
  }

  return contentType.map((e) => e.value!).toList();
}

List<enums.ContentType> contentTypeListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue ?? [];
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

List<enums.ContentType>? contentTypeNullableListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue;
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

String? viewStateToJson(enums.ViewState? viewState) {
  return viewState?.value;
}

enums.ViewState viewStateFromJson(
  Object? viewState, [
  enums.ViewState? defaultValue,
]) {
  return enums.ViewState.values.firstWhereOrNull((e) => e.value == viewState) ??
      defaultValue ??
      enums.ViewState.swaggerGeneratedUnknown;
}

List<String> viewStateListToJson(List<enums.ViewState>? viewState) {
  if (viewState == null) {
    return [];
  }

  return viewState.map((e) => e.value!).toList();
}

List<enums.ViewState> viewStateListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue ?? [];
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

List<enums.ViewState>? viewStateNullableListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue;
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

String? recordingStateToJson(enums.RecordingState? recordingState) {
  return recordingState?.value;
}

enums.RecordingState recordingStateFromJson(
  Object? recordingState, [
  enums.RecordingState? defaultValue,
]) {
  return enums.RecordingState.values
          .firstWhereOrNull((e) => e.value == recordingState) ??
      defaultValue ??
      enums.RecordingState.swaggerGeneratedUnknown;
}

List<String> recordingStateListToJson(
    List<enums.RecordingState>? recordingState) {
  if (recordingState == null) {
    return [];
  }

  return recordingState.map((e) => e.value!).toList();
}

List<enums.RecordingState> recordingStateListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue ?? [];
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

List<enums.RecordingState>? recordingStateNullableListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue;
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

String? profilesProfileIdContinueWatchingGetContentTypeToJson(
    enums.ProfilesProfileIdContinueWatchingGetContentType?
        profilesProfileIdContinueWatchingGetContentType) {
  return profilesProfileIdContinueWatchingGetContentType?.value;
}

enums.ProfilesProfileIdContinueWatchingGetContentType
    profilesProfileIdContinueWatchingGetContentTypeFromJson(
  Object? profilesProfileIdContinueWatchingGetContentType, [
  enums.ProfilesProfileIdContinueWatchingGetContentType? defaultValue,
]) {
  return enums.ProfilesProfileIdContinueWatchingGetContentType.values
          .firstWhereOrNull((e) =>
              e.value == profilesProfileIdContinueWatchingGetContentType) ??
      defaultValue ??
      enums.ProfilesProfileIdContinueWatchingGetContentType
          .swaggerGeneratedUnknown;
}

List<String> profilesProfileIdContinueWatchingGetContentTypeListToJson(
    List<enums.ProfilesProfileIdContinueWatchingGetContentType>?
        profilesProfileIdContinueWatchingGetContentType) {
  if (profilesProfileIdContinueWatchingGetContentType == null) {
    return [];
  }

  return profilesProfileIdContinueWatchingGetContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetContentType>
    profilesProfileIdContinueWatchingGetContentTypeListFromJson(
  List? profilesProfileIdContinueWatchingGetContentType, [
  List<enums.ProfilesProfileIdContinueWatchingGetContentType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetContentType == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdContinueWatchingGetContentType
      .map((e) =>
          profilesProfileIdContinueWatchingGetContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetContentType>?
    profilesProfileIdContinueWatchingGetContentTypeNullableListFromJson(
  List? profilesProfileIdContinueWatchingGetContentType, [
  List<enums.ProfilesProfileIdContinueWatchingGetContentType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetContentType == null) {
    return defaultValue;
  }

  return profilesProfileIdContinueWatchingGetContentType
      .map((e) =>
          profilesProfileIdContinueWatchingGetContentTypeFromJson(e.toString()))
      .toList();
}

String? profilesProfileIdContinueWatchingGetClientTypeToJson(
    enums.ProfilesProfileIdContinueWatchingGetClientType?
        profilesProfileIdContinueWatchingGetClientType) {
  return profilesProfileIdContinueWatchingGetClientType?.value;
}

enums.ProfilesProfileIdContinueWatchingGetClientType
    profilesProfileIdContinueWatchingGetClientTypeFromJson(
  Object? profilesProfileIdContinueWatchingGetClientType, [
  enums.ProfilesProfileIdContinueWatchingGetClientType? defaultValue,
]) {
  return enums.ProfilesProfileIdContinueWatchingGetClientType.values
          .firstWhereOrNull((e) =>
              e.value == profilesProfileIdContinueWatchingGetClientType) ??
      defaultValue ??
      enums.ProfilesProfileIdContinueWatchingGetClientType
          .swaggerGeneratedUnknown;
}

List<String> profilesProfileIdContinueWatchingGetClientTypeListToJson(
    List<enums.ProfilesProfileIdContinueWatchingGetClientType>?
        profilesProfileIdContinueWatchingGetClientType) {
  if (profilesProfileIdContinueWatchingGetClientType == null) {
    return [];
  }

  return profilesProfileIdContinueWatchingGetClientType
      .map((e) => e.value!)
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetClientType>
    profilesProfileIdContinueWatchingGetClientTypeListFromJson(
  List? profilesProfileIdContinueWatchingGetClientType, [
  List<enums.ProfilesProfileIdContinueWatchingGetClientType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetClientType == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdContinueWatchingGetClientType
      .map((e) =>
          profilesProfileIdContinueWatchingGetClientTypeFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetClientType>?
    profilesProfileIdContinueWatchingGetClientTypeNullableListFromJson(
  List? profilesProfileIdContinueWatchingGetClientType, [
  List<enums.ProfilesProfileIdContinueWatchingGetClientType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetClientType == null) {
    return defaultValue;
  }

  return profilesProfileIdContinueWatchingGetClientType
      .map((e) =>
          profilesProfileIdContinueWatchingGetClientTypeFromJson(e.toString()))
      .toList();
}

String? profilesProfileIdContinueWatchingGetMaxResToJson(
    enums.ProfilesProfileIdContinueWatchingGetMaxRes?
        profilesProfileIdContinueWatchingGetMaxRes) {
  return profilesProfileIdContinueWatchingGetMaxRes?.value;
}

enums.ProfilesProfileIdContinueWatchingGetMaxRes
    profilesProfileIdContinueWatchingGetMaxResFromJson(
  Object? profilesProfileIdContinueWatchingGetMaxRes, [
  enums.ProfilesProfileIdContinueWatchingGetMaxRes? defaultValue,
]) {
  return enums.ProfilesProfileIdContinueWatchingGetMaxRes.values
          .firstWhereOrNull(
              (e) => e.value == profilesProfileIdContinueWatchingGetMaxRes) ??
      defaultValue ??
      enums.ProfilesProfileIdContinueWatchingGetMaxRes.swaggerGeneratedUnknown;
}

List<String> profilesProfileIdContinueWatchingGetMaxResListToJson(
    List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>?
        profilesProfileIdContinueWatchingGetMaxRes) {
  if (profilesProfileIdContinueWatchingGetMaxRes == null) {
    return [];
  }

  return profilesProfileIdContinueWatchingGetMaxRes
      .map((e) => e.value!)
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>
    profilesProfileIdContinueWatchingGetMaxResListFromJson(
  List? profilesProfileIdContinueWatchingGetMaxRes, [
  List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdContinueWatchingGetMaxRes
      .map((e) =>
          profilesProfileIdContinueWatchingGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>?
    profilesProfileIdContinueWatchingGetMaxResNullableListFromJson(
  List? profilesProfileIdContinueWatchingGetMaxRes, [
  List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetMaxRes == null) {
    return defaultValue;
  }

  return profilesProfileIdContinueWatchingGetMaxRes
      .map((e) =>
          profilesProfileIdContinueWatchingGetMaxResFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdNextEpisodeContentIdGetContentTypeToJson(
    enums.CustomersCustomerIdNextEpisodeContentIdGetContentType?
        customersCustomerIdNextEpisodeContentIdGetContentType) {
  return customersCustomerIdNextEpisodeContentIdGetContentType?.value;
}

enums.CustomersCustomerIdNextEpisodeContentIdGetContentType
    customersCustomerIdNextEpisodeContentIdGetContentTypeFromJson(
  Object? customersCustomerIdNextEpisodeContentIdGetContentType, [
  enums.CustomersCustomerIdNextEpisodeContentIdGetContentType? defaultValue,
]) {
  return enums.CustomersCustomerIdNextEpisodeContentIdGetContentType.values
          .firstWhereOrNull((e) =>
              e.value ==
              customersCustomerIdNextEpisodeContentIdGetContentType) ??
      defaultValue ??
      enums.CustomersCustomerIdNextEpisodeContentIdGetContentType
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdNextEpisodeContentIdGetContentTypeListToJson(
    List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
        customersCustomerIdNextEpisodeContentIdGetContentType) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType == null) {
    return [];
  }

  return customersCustomerIdNextEpisodeContentIdGetContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>
    customersCustomerIdNextEpisodeContentIdGetContentTypeListFromJson(
  List? customersCustomerIdNextEpisodeContentIdGetContentType, [
  List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
      defaultValue,
]) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdNextEpisodeContentIdGetContentType
      .map((e) => customersCustomerIdNextEpisodeContentIdGetContentTypeFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
    customersCustomerIdNextEpisodeContentIdGetContentTypeNullableListFromJson(
  List? customersCustomerIdNextEpisodeContentIdGetContentType, [
  List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
      defaultValue,
]) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType == null) {
    return defaultValue;
  }

  return customersCustomerIdNextEpisodeContentIdGetContentType
      .map((e) => customersCustomerIdNextEpisodeContentIdGetContentTypeFromJson(
          e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
