// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'epg_packager_lite.swagger.chopper.dart';
part 'epg_packager_lite.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class EpgPackagerLite extends ChopperService {
  static EpgPackagerLite create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$EpgPackagerLite(client);
    }

    final newClient = ChopperClient(
        services: [_$EpgPackagerLite()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$EpgPackagerLite(newClient);
  }

  ///Get Index of Event Metadata Segments
  ///@param country ISO ALPHA-2 country code. Example 'nl'.
  ///@param lang ISO 639-1 (2-letter) language in which data needs to be returned. Depends on the availability in a particular country.
  ///@param If-None-Match Optional 'ETag' header field value of previously retrieved content. If present, and equal to the 'ETag' of most recent content, then 304 response code will be responded instead of the content.
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  Future<chopper.Response<EventSegmentIndex>>
      countryLangEventsSegmentsIndexGet({
    required String? country,
    required String? lang,
    String? ifNoneMatch,
    String? ifModifiedSince,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EventSegmentIndex, () => EventSegmentIndex.fromJsonFactory);

    return _countryLangEventsSegmentsIndexGet(
        country: country,
        lang: lang,
        ifNoneMatch: ifNoneMatch,
        ifModifiedSince: ifModifiedSince,
        cacheControl: cacheControl);
  }

  ///Get Index of Event Metadata Segments
  ///@param country ISO ALPHA-2 country code. Example 'nl'.
  ///@param lang ISO 639-1 (2-letter) language in which data needs to be returned. Depends on the availability in a particular country.
  ///@param If-None-Match Optional 'ETag' header field value of previously retrieved content. If present, and equal to the 'ETag' of most recent content, then 304 response code will be responded instead of the content.
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  @Get(path: '/{country}/{lang}/events/segments/index')
  Future<chopper.Response<EventSegmentIndex>>
      _countryLangEventsSegmentsIndexGet({
    @Path('country') required String? country,
    @Path('lang') required String? lang,
    @Header('If-None-Match') String? ifNoneMatch,
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get Event Metadata for a particular Segment.
  ///@param country ISO ALPHA-2 country code. Example 'nl'.
  ///@param lang ISO 639-1 (2-letter) language in which data needs to be returned. Depends on the availability in a particular country.
  ///@param segmentName Name of the Event Metadata Segment.
  ///@param If-None-Match Optional 'ETag' header field value of previously retrieved content. If present, and equal to the 'ETag' of most recent content, then 304 response code will be responded instead of the content.
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  Future<chopper.Response<Map>> countryLangEventsSegmentsSegmentNameGet({
    required String? country,
    required String? lang,
    required String? segmentName,
    String? ifNoneMatch,
    String? ifModifiedSince,
    String? cacheControl,
  }) {
    return _countryLangEventsSegmentsSegmentNameGet(
        country: country,
        lang: lang,
        segmentName: segmentName,
        ifNoneMatch: ifNoneMatch,
        ifModifiedSince: ifModifiedSince,
        cacheControl: cacheControl);
  }

  ///Get Event Metadata for a particular Segment.
  ///@param country ISO ALPHA-2 country code. Example 'nl'.
  ///@param lang ISO 639-1 (2-letter) language in which data needs to be returned. Depends on the availability in a particular country.
  ///@param segmentName Name of the Event Metadata Segment.
  ///@param If-None-Match Optional 'ETag' header field value of previously retrieved content. If present, and equal to the 'ETag' of most recent content, then 304 response code will be responded instead of the content.
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  @Get(path: '/{country}/{lang}/events/segments/{segmentName}')
  Future<chopper.Response<Map>> _countryLangEventsSegmentsSegmentNameGet({
    @Path('country') required String? country,
    @Path('lang') required String? lang,
    @Path('segmentName') required String? segmentName,
    @Header('If-None-Match') String? ifNoneMatch,
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Event {
  Event({
    required this.id,
    required this.title,
    required this.startTime,
    required this.endTime,
    this.mergedId,
    this.minimumAge,
    this.seriesId,
    this.parentSeriesId,
    this.seriesName,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    this.shortDescription,
    this.longDescription,
    this.actors,
    this.directors,
    this.producers,
    this.audioType,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.productionDate,
    this.countryOfOrigin,
    this.genres,
    this.isLive,
    this.isAdult,
    this.allowLDVR,
    this.allowNDVR,
    this.hasReplayTV,
    this.hasStartOver,
    this.isOpen,
    this.replayTVMinAge,
    this.replayTVAdult,
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.strictAvailabilityEnd,
    this.actualStartOffset,
    this.actualEndOffset,
    this.isPurchasable,
    this.isPlaceHolder,
    this.replayTVDisplayAge,
    this.imageVersion,
    this.hasReplayTVOTT,
    this.isSplitProgram,
    this.groupedStartTime,
    this.groupedEndTime,
    this.groupedEventIdFirstPart,
    this.groupedActualEndOffset,
    this.hasLiveTVOTT,
    this.seriesMepSeriesFinale,
    this.seriesPremiereAirings,
    this.premiere,
  });

  factory Event.fromJson(Map<String, dynamic> json) => _$EventFromJson(json);

  static const toJsonFactory = _$EventToJson;
  Map<String, dynamic> toJson() => _$EventToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final int startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final int endTime;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'actors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? actors;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'producers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? producers;
  @JsonKey(name: 'audioType', includeIfNull: false)
  final int? audioType;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'productionDate', includeIfNull: false, defaultValue: '')
  final String? productionDate;
  @JsonKey(name: 'countryOfOrigin', includeIfNull: false, defaultValue: '')
  final String? countryOfOrigin;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'isLive', includeIfNull: false, defaultValue: false)
  final bool? isLive;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'allowLDVR', includeIfNull: false, defaultValue: true)
  final bool? allowLDVR;
  @JsonKey(name: 'allowNDVR', includeIfNull: false, defaultValue: true)
  final bool? allowNDVR;
  @JsonKey(name: 'hasReplayTV', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTV;
  @JsonKey(name: 'hasStartOver', includeIfNull: false, defaultValue: true)
  final bool? hasStartOver;
  @JsonKey(name: 'isOpen', includeIfNull: false, defaultValue: false)
  final bool? isOpen;
  @JsonKey(name: 'replayTVMinAge', includeIfNull: false)
  final int? replayTVMinAge;
  @JsonKey(name: 'replayTVAdult', includeIfNull: false)
  final bool? replayTVAdult;
  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final int? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final int? replayAvailabilityEnd;
  @JsonKey(name: 'strictAvailabilityEnd', includeIfNull: false)
  final int? strictAvailabilityEnd;
  @JsonKey(name: 'actualStartOffset', includeIfNull: false)
  final int? actualStartOffset;
  @JsonKey(name: 'actualEndOffset', includeIfNull: false)
  final int? actualEndOffset;
  @JsonKey(name: 'isPurchasable', includeIfNull: false, defaultValue: false)
  final bool? isPurchasable;
  @JsonKey(name: 'isPlaceHolder', includeIfNull: false)
  final bool? isPlaceHolder;
  @JsonKey(
      name: 'replayTVDisplayAge', includeIfNull: false, defaultValue: false)
  final bool? replayTVDisplayAge;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'hasReplayTVOTT', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTVOTT;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false, defaultValue: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'groupedStartTime', includeIfNull: false)
  final int? groupedStartTime;
  @JsonKey(name: 'groupedEndTime', includeIfNull: false)
  final int? groupedEndTime;
  @JsonKey(
      name: 'groupedEventIdFirstPart', includeIfNull: false, defaultValue: '')
  final String? groupedEventIdFirstPart;
  @JsonKey(name: 'groupedActualEndOffset', includeIfNull: false)
  final int? groupedActualEndOffset;
  @JsonKey(name: 'hasLiveTVOTT', includeIfNull: false)
  final bool? hasLiveTVOTT;
  @JsonKey(name: 'seriesMepSeriesFinale', includeIfNull: false)
  final int? seriesMepSeriesFinale;
  @JsonKey(name: 'seriesPremiereAirings', includeIfNull: false)
  final bool? seriesPremiereAirings;
  @JsonKey(name: 'premiere', includeIfNull: false)
  final bool? premiere;
  static const fromJsonFactory = _$EventFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Event &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.longDescription, longDescription) ||
                const DeepCollectionEquality()
                    .equals(other.longDescription, longDescription)) &&
            (identical(other.actors, actors) ||
                const DeepCollectionEquality().equals(other.actors, actors)) &&
            (identical(other.directors, directors) ||
                const DeepCollectionEquality()
                    .equals(other.directors, directors)) &&
            (identical(other.producers, producers) ||
                const DeepCollectionEquality()
                    .equals(other.producers, producers)) &&
            (identical(other.audioType, audioType) ||
                const DeepCollectionEquality()
                    .equals(other.audioType, audioType)) &&
            (identical(other.audioLanguages, audioLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.signLanguages, signLanguages)) &&
            (identical(other.productionDate, productionDate) ||
                const DeepCollectionEquality()
                    .equals(other.productionDate, productionDate)) &&
            (identical(other.countryOfOrigin, countryOfOrigin) ||
                const DeepCollectionEquality()
                    .equals(other.countryOfOrigin, countryOfOrigin)) &&
            (identical(other.genres, genres) || const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.isLive, isLive) || const DeepCollectionEquality().equals(other.isLive, isLive)) &&
            (identical(other.isAdult, isAdult) || const DeepCollectionEquality().equals(other.isAdult, isAdult)) &&
            (identical(other.allowLDVR, allowLDVR) || const DeepCollectionEquality().equals(other.allowLDVR, allowLDVR)) &&
            (identical(other.allowNDVR, allowNDVR) || const DeepCollectionEquality().equals(other.allowNDVR, allowNDVR)) &&
            (identical(other.hasReplayTV, hasReplayTV) || const DeepCollectionEquality().equals(other.hasReplayTV, hasReplayTV)) &&
            (identical(other.hasStartOver, hasStartOver) || const DeepCollectionEquality().equals(other.hasStartOver, hasStartOver)) &&
            (identical(other.isOpen, isOpen) || const DeepCollectionEquality().equals(other.isOpen, isOpen)) &&
            (identical(other.replayTVMinAge, replayTVMinAge) || const DeepCollectionEquality().equals(other.replayTVMinAge, replayTVMinAge)) &&
            (identical(other.replayTVAdult, replayTVAdult) || const DeepCollectionEquality().equals(other.replayTVAdult, replayTVAdult)) &&
            (identical(other.replayAvailabilityStart, replayAvailabilityStart) || const DeepCollectionEquality().equals(other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) || const DeepCollectionEquality().equals(other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.strictAvailabilityEnd, strictAvailabilityEnd) || const DeepCollectionEquality().equals(other.strictAvailabilityEnd, strictAvailabilityEnd)) &&
            (identical(other.actualStartOffset, actualStartOffset) || const DeepCollectionEquality().equals(other.actualStartOffset, actualStartOffset)) &&
            (identical(other.actualEndOffset, actualEndOffset) || const DeepCollectionEquality().equals(other.actualEndOffset, actualEndOffset)) &&
            (identical(other.isPurchasable, isPurchasable) || const DeepCollectionEquality().equals(other.isPurchasable, isPurchasable)) &&
            (identical(other.isPlaceHolder, isPlaceHolder) || const DeepCollectionEquality().equals(other.isPlaceHolder, isPlaceHolder)) &&
            (identical(other.replayTVDisplayAge, replayTVDisplayAge) || const DeepCollectionEquality().equals(other.replayTVDisplayAge, replayTVDisplayAge)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.hasReplayTVOTT, hasReplayTVOTT) || const DeepCollectionEquality().equals(other.hasReplayTVOTT, hasReplayTVOTT)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.groupedStartTime, groupedStartTime) || const DeepCollectionEquality().equals(other.groupedStartTime, groupedStartTime)) &&
            (identical(other.groupedEndTime, groupedEndTime) || const DeepCollectionEquality().equals(other.groupedEndTime, groupedEndTime)) &&
            (identical(other.groupedEventIdFirstPart, groupedEventIdFirstPart) || const DeepCollectionEquality().equals(other.groupedEventIdFirstPart, groupedEventIdFirstPart)) &&
            (identical(other.groupedActualEndOffset, groupedActualEndOffset) || const DeepCollectionEquality().equals(other.groupedActualEndOffset, groupedActualEndOffset)) &&
            (identical(other.hasLiveTVOTT, hasLiveTVOTT) || const DeepCollectionEquality().equals(other.hasLiveTVOTT, hasLiveTVOTT)) &&
            (identical(other.seriesMepSeriesFinale, seriesMepSeriesFinale) || const DeepCollectionEquality().equals(other.seriesMepSeriesFinale, seriesMepSeriesFinale)) &&
            (identical(other.seriesPremiereAirings, seriesPremiereAirings) || const DeepCollectionEquality().equals(other.seriesPremiereAirings, seriesPremiereAirings)) &&
            (identical(other.premiere, premiere) || const DeepCollectionEquality().equals(other.premiere, premiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(actors) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(producers) ^
      const DeepCollectionEquality().hash(audioType) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(productionDate) ^
      const DeepCollectionEquality().hash(countryOfOrigin) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(isLive) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(allowLDVR) ^
      const DeepCollectionEquality().hash(allowNDVR) ^
      const DeepCollectionEquality().hash(hasReplayTV) ^
      const DeepCollectionEquality().hash(hasStartOver) ^
      const DeepCollectionEquality().hash(isOpen) ^
      const DeepCollectionEquality().hash(replayTVMinAge) ^
      const DeepCollectionEquality().hash(replayTVAdult) ^
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(strictAvailabilityEnd) ^
      const DeepCollectionEquality().hash(actualStartOffset) ^
      const DeepCollectionEquality().hash(actualEndOffset) ^
      const DeepCollectionEquality().hash(isPurchasable) ^
      const DeepCollectionEquality().hash(isPlaceHolder) ^
      const DeepCollectionEquality().hash(replayTVDisplayAge) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(hasReplayTVOTT) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(groupedStartTime) ^
      const DeepCollectionEquality().hash(groupedEndTime) ^
      const DeepCollectionEquality().hash(groupedEventIdFirstPart) ^
      const DeepCollectionEquality().hash(groupedActualEndOffset) ^
      const DeepCollectionEquality().hash(hasLiveTVOTT) ^
      const DeepCollectionEquality().hash(seriesMepSeriesFinale) ^
      const DeepCollectionEquality().hash(seriesPremiereAirings) ^
      const DeepCollectionEquality().hash(premiere) ^
      runtimeType.hashCode;
}

extension $EventExtension on Event {
  Event copyWith(
      {String? id,
      String? title,
      int? startTime,
      int? endTime,
      String? mergedId,
      int? minimumAge,
      String? seriesId,
      String? parentSeriesId,
      String? seriesName,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      String? shortDescription,
      String? longDescription,
      List<String>? actors,
      List<String>? directors,
      List<String>? producers,
      int? audioType,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      String? productionDate,
      String? countryOfOrigin,
      List<String>? genres,
      bool? isLive,
      bool? isAdult,
      bool? allowLDVR,
      bool? allowNDVR,
      bool? hasReplayTV,
      bool? hasStartOver,
      bool? isOpen,
      int? replayTVMinAge,
      bool? replayTVAdult,
      int? replayAvailabilityStart,
      int? replayAvailabilityEnd,
      int? strictAvailabilityEnd,
      int? actualStartOffset,
      int? actualEndOffset,
      bool? isPurchasable,
      bool? isPlaceHolder,
      bool? replayTVDisplayAge,
      String? imageVersion,
      bool? hasReplayTVOTT,
      bool? isSplitProgram,
      int? groupedStartTime,
      int? groupedEndTime,
      String? groupedEventIdFirstPart,
      int? groupedActualEndOffset,
      bool? hasLiveTVOTT,
      int? seriesMepSeriesFinale,
      bool? seriesPremiereAirings,
      bool? premiere}) {
    return Event(
        id: id ?? this.id,
        title: title ?? this.title,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        mergedId: mergedId ?? this.mergedId,
        minimumAge: minimumAge ?? this.minimumAge,
        seriesId: seriesId ?? this.seriesId,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        shortDescription: shortDescription ?? this.shortDescription,
        longDescription: longDescription ?? this.longDescription,
        actors: actors ?? this.actors,
        directors: directors ?? this.directors,
        producers: producers ?? this.producers,
        audioType: audioType ?? this.audioType,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        productionDate: productionDate ?? this.productionDate,
        countryOfOrigin: countryOfOrigin ?? this.countryOfOrigin,
        genres: genres ?? this.genres,
        isLive: isLive ?? this.isLive,
        isAdult: isAdult ?? this.isAdult,
        allowLDVR: allowLDVR ?? this.allowLDVR,
        allowNDVR: allowNDVR ?? this.allowNDVR,
        hasReplayTV: hasReplayTV ?? this.hasReplayTV,
        hasStartOver: hasStartOver ?? this.hasStartOver,
        isOpen: isOpen ?? this.isOpen,
        replayTVMinAge: replayTVMinAge ?? this.replayTVMinAge,
        replayTVAdult: replayTVAdult ?? this.replayTVAdult,
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        strictAvailabilityEnd:
            strictAvailabilityEnd ?? this.strictAvailabilityEnd,
        actualStartOffset: actualStartOffset ?? this.actualStartOffset,
        actualEndOffset: actualEndOffset ?? this.actualEndOffset,
        isPurchasable: isPurchasable ?? this.isPurchasable,
        isPlaceHolder: isPlaceHolder ?? this.isPlaceHolder,
        replayTVDisplayAge: replayTVDisplayAge ?? this.replayTVDisplayAge,
        imageVersion: imageVersion ?? this.imageVersion,
        hasReplayTVOTT: hasReplayTVOTT ?? this.hasReplayTVOTT,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        groupedStartTime: groupedStartTime ?? this.groupedStartTime,
        groupedEndTime: groupedEndTime ?? this.groupedEndTime,
        groupedEventIdFirstPart:
            groupedEventIdFirstPart ?? this.groupedEventIdFirstPart,
        groupedActualEndOffset:
            groupedActualEndOffset ?? this.groupedActualEndOffset,
        hasLiveTVOTT: hasLiveTVOTT ?? this.hasLiveTVOTT,
        seriesMepSeriesFinale:
            seriesMepSeriesFinale ?? this.seriesMepSeriesFinale,
        seriesPremiereAirings:
            seriesPremiereAirings ?? this.seriesPremiereAirings,
        premiere: premiere ?? this.premiere);
  }

  Event copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<int>? startTime,
      Wrapped<int>? endTime,
      Wrapped<String?>? mergedId,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? longDescription,
      Wrapped<List<String>?>? actors,
      Wrapped<List<String>?>? directors,
      Wrapped<List<String>?>? producers,
      Wrapped<int?>? audioType,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<String?>? productionDate,
      Wrapped<String?>? countryOfOrigin,
      Wrapped<List<String>?>? genres,
      Wrapped<bool?>? isLive,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? allowLDVR,
      Wrapped<bool?>? allowNDVR,
      Wrapped<bool?>? hasReplayTV,
      Wrapped<bool?>? hasStartOver,
      Wrapped<bool?>? isOpen,
      Wrapped<int?>? replayTVMinAge,
      Wrapped<bool?>? replayTVAdult,
      Wrapped<int?>? replayAvailabilityStart,
      Wrapped<int?>? replayAvailabilityEnd,
      Wrapped<int?>? strictAvailabilityEnd,
      Wrapped<int?>? actualStartOffset,
      Wrapped<int?>? actualEndOffset,
      Wrapped<bool?>? isPurchasable,
      Wrapped<bool?>? isPlaceHolder,
      Wrapped<bool?>? replayTVDisplayAge,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? hasReplayTVOTT,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? groupedStartTime,
      Wrapped<int?>? groupedEndTime,
      Wrapped<String?>? groupedEventIdFirstPart,
      Wrapped<int?>? groupedActualEndOffset,
      Wrapped<bool?>? hasLiveTVOTT,
      Wrapped<int?>? seriesMepSeriesFinale,
      Wrapped<bool?>? seriesPremiereAirings,
      Wrapped<bool?>? premiere}) {
    return Event(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        actors: (actors != null ? actors.value : this.actors),
        directors: (directors != null ? directors.value : this.directors),
        producers: (producers != null ? producers.value : this.producers),
        audioType: (audioType != null ? audioType.value : this.audioType),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        productionDate: (productionDate != null
            ? productionDate.value
            : this.productionDate),
        countryOfOrigin: (countryOfOrigin != null
            ? countryOfOrigin.value
            : this.countryOfOrigin),
        genres: (genres != null ? genres.value : this.genres),
        isLive: (isLive != null ? isLive.value : this.isLive),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        allowLDVR: (allowLDVR != null ? allowLDVR.value : this.allowLDVR),
        allowNDVR: (allowNDVR != null ? allowNDVR.value : this.allowNDVR),
        hasReplayTV:
            (hasReplayTV != null ? hasReplayTV.value : this.hasReplayTV),
        hasStartOver:
            (hasStartOver != null ? hasStartOver.value : this.hasStartOver),
        isOpen: (isOpen != null ? isOpen.value : this.isOpen),
        replayTVMinAge: (replayTVMinAge != null
            ? replayTVMinAge.value
            : this.replayTVMinAge),
        replayTVAdult:
            (replayTVAdult != null ? replayTVAdult.value : this.replayTVAdult),
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        strictAvailabilityEnd: (strictAvailabilityEnd != null
            ? strictAvailabilityEnd.value
            : this.strictAvailabilityEnd),
        actualStartOffset: (actualStartOffset != null
            ? actualStartOffset.value
            : this.actualStartOffset),
        actualEndOffset: (actualEndOffset != null
            ? actualEndOffset.value
            : this.actualEndOffset),
        isPurchasable:
            (isPurchasable != null ? isPurchasable.value : this.isPurchasable),
        isPlaceHolder:
            (isPlaceHolder != null ? isPlaceHolder.value : this.isPlaceHolder),
        replayTVDisplayAge: (replayTVDisplayAge != null
            ? replayTVDisplayAge.value
            : this.replayTVDisplayAge),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        hasReplayTVOTT: (hasReplayTVOTT != null
            ? hasReplayTVOTT.value
            : this.hasReplayTVOTT),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        groupedStartTime: (groupedStartTime != null
            ? groupedStartTime.value
            : this.groupedStartTime),
        groupedEndTime: (groupedEndTime != null
            ? groupedEndTime.value
            : this.groupedEndTime),
        groupedEventIdFirstPart: (groupedEventIdFirstPart != null
            ? groupedEventIdFirstPart.value
            : this.groupedEventIdFirstPart),
        groupedActualEndOffset: (groupedActualEndOffset != null
            ? groupedActualEndOffset.value
            : this.groupedActualEndOffset),
        hasLiveTVOTT:
            (hasLiveTVOTT != null ? hasLiveTVOTT.value : this.hasLiveTVOTT),
        seriesMepSeriesFinale: (seriesMepSeriesFinale != null
            ? seriesMepSeriesFinale.value
            : this.seriesMepSeriesFinale),
        seriesPremiereAirings: (seriesPremiereAirings != null
            ? seriesPremiereAirings.value
            : this.seriesPremiereAirings),
        premiere: (premiere != null ? premiere.value : this.premiere));
  }
}

@JsonSerializable(explicitToJson: true)
class AudioLanguage {
  AudioLanguage({
    required this.lang,
    this.purpose,
  });

  factory AudioLanguage.fromJson(Map<String, dynamic> json) =>
      _$AudioLanguageFromJson(json);

  static const toJsonFactory = _$AudioLanguageToJson;
  Map<String, dynamic> toJson() => _$AudioLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$AudioLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AudioLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $AudioLanguageExtension on AudioLanguage {
  AudioLanguage copyWith({String? lang, int? purpose}) {
    return AudioLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  AudioLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return AudioLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class CaptionLanguage {
  CaptionLanguage({
    required this.lang,
    this.purpose,
  });

  factory CaptionLanguage.fromJson(Map<String, dynamic> json) =>
      _$CaptionLanguageFromJson(json);

  static const toJsonFactory = _$CaptionLanguageToJson;
  Map<String, dynamic> toJson() => _$CaptionLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$CaptionLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CaptionLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $CaptionLanguageExtension on CaptionLanguage {
  CaptionLanguage copyWith({String? lang, int? purpose}) {
    return CaptionLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  CaptionLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return CaptionLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class SignLanguage {
  SignLanguage({
    required this.lang,
  });

  factory SignLanguage.fromJson(Map<String, dynamic> json) =>
      _$SignLanguageFromJson(json);

  static const toJsonFactory = _$SignLanguageToJson;
  Map<String, dynamic> toJson() => _$SignLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  static const fromJsonFactory = _$SignLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SignLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^ runtimeType.hashCode;
}

extension $SignLanguageExtension on SignLanguage {
  SignLanguage copyWith({String? lang}) {
    return SignLanguage(lang: lang ?? this.lang);
  }

  SignLanguage copyWithWrapped({Wrapped<String>? lang}) {
    return SignLanguage(lang: (lang != null ? lang.value : this.lang));
  }
}

@JsonSerializable(explicitToJson: true)
class EventSegment {
  EventSegment({
    required this.time,
    required this.duration,
    required this.entries,
  });

  factory EventSegment.fromJson(Map<String, dynamic> json) =>
      _$EventSegmentFromJson(json);

  static const toJsonFactory = _$EventSegmentToJson;
  Map<String, dynamic> toJson() => _$EventSegmentToJson(this);

  @JsonKey(name: 'time', includeIfNull: false)
  final int time;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <EventSegment$Entries$Item>[])
  final List<EventSegment$Entries$Item> entries;
  static const fromJsonFactory = _$EventSegmentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventSegment &&
            (identical(other.time, time) ||
                const DeepCollectionEquality().equals(other.time, time)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality().equals(other.entries, entries)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(time) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(entries) ^
      runtimeType.hashCode;
}

extension $EventSegmentExtension on EventSegment {
  EventSegment copyWith(
      {int? time, int? duration, List<EventSegment$Entries$Item>? entries}) {
    return EventSegment(
        time: time ?? this.time,
        duration: duration ?? this.duration,
        entries: entries ?? this.entries);
  }

  EventSegment copyWithWrapped(
      {Wrapped<int>? time,
      Wrapped<int>? duration,
      Wrapped<List<EventSegment$Entries$Item>>? entries}) {
    return EventSegment(
        time: (time != null ? time.value : this.time),
        duration: (duration != null ? duration.value : this.duration),
        entries: (entries != null ? entries.value : this.entries));
  }
}

@JsonSerializable(explicitToJson: true)
class EventSegmentIndexEntry {
  EventSegmentIndexEntry({
    required this.channelIds,
    required this.segments,
    this.durations,
  });

  factory EventSegmentIndexEntry.fromJson(Map<String, dynamic> json) =>
      _$EventSegmentIndexEntryFromJson(json);

  static const toJsonFactory = _$EventSegmentIndexEntryToJson;
  Map<String, dynamic> toJson() => _$EventSegmentIndexEntryToJson(this);

  @JsonKey(name: 'channelIds', includeIfNull: false, defaultValue: <String>[])
  final List<String> channelIds;
  @JsonKey(name: 'segments', includeIfNull: false, defaultValue: <String>[])
  final List<String> segments;
  @JsonKey(name: 'durations', includeIfNull: false, defaultValue: <int>[])
  final List<int>? durations;
  static const fromJsonFactory = _$EventSegmentIndexEntryFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventSegmentIndexEntry &&
            (identical(other.channelIds, channelIds) ||
                const DeepCollectionEquality()
                    .equals(other.channelIds, channelIds)) &&
            (identical(other.segments, segments) ||
                const DeepCollectionEquality()
                    .equals(other.segments, segments)) &&
            (identical(other.durations, durations) ||
                const DeepCollectionEquality()
                    .equals(other.durations, durations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelIds) ^
      const DeepCollectionEquality().hash(segments) ^
      const DeepCollectionEquality().hash(durations) ^
      runtimeType.hashCode;
}

extension $EventSegmentIndexEntryExtension on EventSegmentIndexEntry {
  EventSegmentIndexEntry copyWith(
      {List<String>? channelIds,
      List<String>? segments,
      List<int>? durations}) {
    return EventSegmentIndexEntry(
        channelIds: channelIds ?? this.channelIds,
        segments: segments ?? this.segments,
        durations: durations ?? this.durations);
  }

  EventSegmentIndexEntry copyWithWrapped(
      {Wrapped<List<String>>? channelIds,
      Wrapped<List<String>>? segments,
      Wrapped<List<int>?>? durations}) {
    return EventSegmentIndexEntry(
        channelIds: (channelIds != null ? channelIds.value : this.channelIds),
        segments: (segments != null ? segments.value : this.segments),
        durations: (durations != null ? durations.value : this.durations));
  }
}

@JsonSerializable(explicitToJson: true)
class EventSegmentIndex {
  EventSegmentIndex({
    required this.time,
    required this.durationSeconds,
    this.defaultSegmentDurationSeconds,
    this.entries,
  });

  factory EventSegmentIndex.fromJson(Map<String, dynamic> json) =>
      _$EventSegmentIndexFromJson(json);

  static const toJsonFactory = _$EventSegmentIndexToJson;
  Map<String, dynamic> toJson() => _$EventSegmentIndexToJson(this);

  @JsonKey(name: 'time', includeIfNull: false)
  final int time;
  @JsonKey(name: 'durationSeconds', includeIfNull: false)
  final int durationSeconds;
  @JsonKey(name: 'defaultSegmentDurationSeconds', includeIfNull: false)
  final int? defaultSegmentDurationSeconds;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <EventSegmentIndexEntry>[])
  final List<EventSegmentIndexEntry>? entries;
  static const fromJsonFactory = _$EventSegmentIndexFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventSegmentIndex &&
            (identical(other.time, time) ||
                const DeepCollectionEquality().equals(other.time, time)) &&
            (identical(other.durationSeconds, durationSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationSeconds, durationSeconds)) &&
            (identical(other.defaultSegmentDurationSeconds,
                    defaultSegmentDurationSeconds) ||
                const DeepCollectionEquality().equals(
                    other.defaultSegmentDurationSeconds,
                    defaultSegmentDurationSeconds)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality().equals(other.entries, entries)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(time) ^
      const DeepCollectionEquality().hash(durationSeconds) ^
      const DeepCollectionEquality().hash(defaultSegmentDurationSeconds) ^
      const DeepCollectionEquality().hash(entries) ^
      runtimeType.hashCode;
}

extension $EventSegmentIndexExtension on EventSegmentIndex {
  EventSegmentIndex copyWith(
      {int? time,
      int? durationSeconds,
      int? defaultSegmentDurationSeconds,
      List<EventSegmentIndexEntry>? entries}) {
    return EventSegmentIndex(
        time: time ?? this.time,
        durationSeconds: durationSeconds ?? this.durationSeconds,
        defaultSegmentDurationSeconds:
            defaultSegmentDurationSeconds ?? this.defaultSegmentDurationSeconds,
        entries: entries ?? this.entries);
  }

  EventSegmentIndex copyWithWrapped(
      {Wrapped<int>? time,
      Wrapped<int>? durationSeconds,
      Wrapped<int?>? defaultSegmentDurationSeconds,
      Wrapped<List<EventSegmentIndexEntry>?>? entries}) {
    return EventSegmentIndex(
        time: (time != null ? time.value : this.time),
        durationSeconds: (durationSeconds != null
            ? durationSeconds.value
            : this.durationSeconds),
        defaultSegmentDurationSeconds: (defaultSegmentDurationSeconds != null
            ? defaultSegmentDurationSeconds.value
            : this.defaultSegmentDurationSeconds),
        entries: (entries != null ? entries.value : this.entries));
  }
}

typedef EventSegment$Entries = List<EventSegment$Entries$Item>;

@JsonSerializable(explicitToJson: true)
class EventSegment$Entries$Item {
  EventSegment$Entries$Item({
    required this.channelId,
    this.events,
  });

  factory EventSegment$Entries$Item.fromJson(Map<String, dynamic> json) =>
      _$EventSegment$Entries$ItemFromJson(json);

  static const toJsonFactory = _$EventSegment$Entries$ItemToJson;
  Map<String, dynamic> toJson() => _$EventSegment$Entries$ItemToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'events', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? events;
  static const fromJsonFactory = _$EventSegment$Entries$ItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventSegment$Entries$Item &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(events) ^
      runtimeType.hashCode;
}

extension $EventSegment$Entries$ItemExtension on EventSegment$Entries$Item {
  EventSegment$Entries$Item copyWith(
      {String? channelId, List<Object>? events}) {
    return EventSegment$Entries$Item(
        channelId: channelId ?? this.channelId, events: events ?? this.events);
  }

  EventSegment$Entries$Item copyWithWrapped(
      {Wrapped<String>? channelId, Wrapped<List<Object>?>? events}) {
    return EventSegment$Entries$Item(
        channelId: (channelId != null ? channelId.value : this.channelId),
        events: (events != null ? events.value : this.events));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
