// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'image_service.enums.swagger.dart' as enums;
export 'image_service.enums.swagger.dart';

part 'image_service.swagger.chopper.dart';
part 'image_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ImageService extends ChopperService {
  static ImageService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ImageService(client);
    }

    final newClient = ChopperClient(
        services: [_$ImageService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$ImageService(newClient);
  }

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  ///@param jsonBody JSON body
  Future<chopper.Response<List<ContentResponse>>> intentGet({
    required String? jsonBody,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContentResponse, () => ContentResponse.fromJsonFactory);

    return _intentGet(jsonBody: jsonBody, cacheControl: cacheControl);
  }

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  ///@param jsonBody JSON body
  @Get(path: '/intent')
  Future<chopper.Response<List<ContentResponse>>> _intentGet({
    @Query('jsonBody') required String? jsonBody,
    @Header('Cache-Control') String? cacheControl,
  });

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  Future<chopper.Response<List<ContentResponse>>> intentPost({
    String? cacheControl,
    required List<ContentRequest>? body,
  }) {
    generatedMapping.putIfAbsent(
        ContentResponse, () => ContentResponse.fromJsonFactory);

    return _intentPost(cacheControl: cacheControl, body: body);
  }

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  @Post(
    path: '/intent',
    optionalBody: true,
  )
  Future<chopper.Response<List<ContentResponse>>> _intentPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required List<ContentRequest>? body,
  });

  ///API for retrieving the actual location of the image matching the resource id + imageType
  ///@param width The width the picture should be resized to
  ///@param height The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorSpace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param resourceId Resource id
  ///@param type The type the resource id represents
  ///@param imageType The requested imageType
  ///@param If-None-Match If-None-Match
  Future<chopper.Response> intentResourceIdImageTypeGet({
    int? width,
    int? height,
    enums.IntentResourceIdImageTypeGetMode? mode,
    num? blur,
    int? brightness,
    enums.IntentResourceIdImageTypeGetFormat? format,
    String? style,
    enums.IntentResourceIdImageTypeGetChannel? channel,
    enums.IntentResourceIdImageTypeGetColorSpace? colorSpace,
    List<String>? overlay,
    bool? metadata,
    num? quality,
    String? stylePlaceholders,
    String? cornerRadius,
    required String? resourceId,
    enums.IntentResourceIdImageTypeGetType? type,
    required String? imageType,
    String? ifNoneMatch,
    String? cacheControl,
  }) {
    return _intentResourceIdImageTypeGet(
        width: width,
        height: height,
        mode: mode?.value?.toString(),
        blur: blur,
        brightness: brightness,
        format: format?.value?.toString(),
        style: style,
        channel: channel?.value?.toString(),
        colorSpace: colorSpace?.value?.toString(),
        overlay: overlay,
        metadata: metadata,
        quality: quality,
        stylePlaceholders: stylePlaceholders,
        cornerRadius: cornerRadius,
        resourceId: resourceId,
        type: type?.value?.toString(),
        imageType: imageType,
        ifNoneMatch: ifNoneMatch,
        cacheControl: cacheControl);
  }

  ///API for retrieving the actual location of the image matching the resource id + imageType
  ///@param width The width the picture should be resized to
  ///@param height The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorSpace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param resourceId Resource id
  ///@param type The type the resource id represents
  ///@param imageType The requested imageType
  ///@param If-None-Match If-None-Match
  @Get(path: '/intent/{resourceId}/{imageType}')
  Future<chopper.Response> _intentResourceIdImageTypeGet({
    @Query('width') int? width,
    @Query('height') int? height,
    @Query('mode') String? mode,
    @Query('blur') num? blur,
    @Query('brightness') int? brightness,
    @Query('format') String? format,
    @Query('style') String? style,
    @Query('channel') String? channel,
    @Query('colorSpace') String? colorSpace,
    @Query('overlay') List<String>? overlay,
    @Query('metadata') bool? metadata,
    @Query('quality') num? quality,
    @Query('stylePlaceholders') String? stylePlaceholders,
    @Query('cornerRadius') String? cornerRadius,
    @Path('resourceId') required String? resourceId,
    @Query('type') String? type,
    @Path('imageType') required String? imageType,
    @Header('If-None-Match') String? ifNoneMatch,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns json with dominant colours from the image after optional processing given as query parameters.
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given  Note2: when resize mode is set to stretch or box and either height or width is missng → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightnening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param quality The image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidthPercentage The percentage of the width used for Wedge shape resize
  ///@param wedgeHeightPercentage The percentage of the height used for wedge shape resize
  Future<chopper.Response<ImageMetadata>> metadataPathGet({
    required String? path,
    String? ifNoneMatch,
    int? w,
    int? h,
    enums.MetadataPathGetMode? mode,
    num? blur,
    int? brightness,
    enums.MetadataPathGetFormat? format,
    String? style,
    enums.MetadataPathGetChannel? channel,
    enums.MetadataPathGetColorspace? colorspace,
    num? quality,
    String? cornerRadius,
    bool? trim,
    num? wedgeWidthPercentage,
    num? wedgeHeightPercentage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ImageMetadata, () => ImageMetadata.fromJsonFactory);

    return _metadataPathGet(
        path: path,
        ifNoneMatch: ifNoneMatch,
        w: w,
        h: h,
        mode: mode?.value?.toString(),
        blur: blur,
        brightness: brightness,
        format: format?.value?.toString(),
        style: style,
        channel: channel?.value?.toString(),
        colorspace: colorspace?.value?.toString(),
        quality: quality,
        cornerRadius: cornerRadius,
        trim: trim,
        wedgeWidthPercentage: wedgeWidthPercentage,
        wedgeHeightPercentage: wedgeHeightPercentage,
        cacheControl: cacheControl);
  }

  ///Returns json with dominant colours from the image after optional processing given as query parameters.
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given  Note2: when resize mode is set to stretch or box and either height or width is missng → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightnening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param quality The image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidthPercentage The percentage of the width used for Wedge shape resize
  ///@param wedgeHeightPercentage The percentage of the height used for wedge shape resize
  @Get(path: '/metadata/{path}')
  Future<chopper.Response<ImageMetadata>> _metadataPathGet({
    @Path('path') required String? path,
    @Header('If-None-Match') String? ifNoneMatch,
    @Query('w') int? w,
    @Query('h') int? h,
    @Query('mode') String? mode,
    @Query('blur') num? blur,
    @Query('brightness') int? brightness,
    @Query('format') String? format,
    @Query('style') String? style,
    @Query('channel') String? channel,
    @Query('colorspace') String? colorspace,
    @Query('quality') num? quality,
    @Query('cornerRadius') String? cornerRadius,
    @Query('trim') bool? trim,
    @Query('wedgeWidthPercentage') num? wedgeWidthPercentage,
    @Query('wedgeHeightPercentage') num? wedgeHeightPercentage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///API for moving images
  Future<chopper.Response<MovePaths>> movePost({
    String? cacheControl,
    required MovePaths? body,
  }) {
    generatedMapping.putIfAbsent(MovePaths, () => MovePaths.fromJsonFactory);

    return _movePost(cacheControl: cacheControl, body: body);
  }

  ///API for moving images
  @Post(
    path: '/move',
    optionalBody: true,
  )
  Future<chopper.Response<MovePaths>> _movePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required MovePaths? body,
  });

  ///API for uploading images
  ///@param folder The folder the files (located in the body) should be stored
  Future<chopper.Response<List<String>>> folderPost({
    required String? folder,
    String? cacheControl,
    required MultiRequest body,
  }) {
    return _folderPost(folder: folder, cacheControl: cacheControl, body: body);
  }

  ///API for uploading images
  ///@param folder The folder the files (located in the body) should be stored
  @Post(
    path: '/{folder}',
    optionalBody: true,
  )
  @Multipart()
  Future<chopper.Response<List<String>>> _folderPost({
    @Path('folder') required String? folder,
    @Header('Cache-Control') String? cacheControl,
    @Part() required MultiRequest body,
  });

  ///API for requesting images with filters and mutation capabilities. When request contains a style and additional manipulations (width, height, resize_mode, blur), those parameters will override the style manipulation value. Modifications are applied in order:  1. Resize image	 2. Blur 	 3. Brighten	 4. Image quality 	 5. Channel 	 6. Color space	 7. Overlays 	 8. CornerRadius
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidthPercentage The minimum width used for Wedge shape resize
  ///@param wedgeHeightPercentage The minimum height used for wedge shape resize
  Future<chopper.Response<List<String>>> pathGet({
    required String? path,
    String? ifNoneMatch,
    int? w,
    int? h,
    enums.PathGetMode? mode,
    num? blur,
    int? brightness,
    enums.PathGetFormat? format,
    String? style,
    enums.PathGetChannel? channel,
    enums.PathGetColorspace? colorspace,
    List<String>? overlay,
    bool? metadata,
    num? quality,
    String? stylePlaceholders,
    String? cornerRadius,
    bool? trim,
    num? wedgeWidthPercentage,
    num? wedgeHeightPercentage,
    String? cacheControl,
  }) {
    return _pathGet(
        path: path,
        ifNoneMatch: ifNoneMatch,
        w: w,
        h: h,
        mode: mode?.value?.toString(),
        blur: blur,
        brightness: brightness,
        format: format?.value?.toString(),
        style: style,
        channel: channel?.value?.toString(),
        colorspace: colorspace?.value?.toString(),
        overlay: overlay,
        metadata: metadata,
        quality: quality,
        stylePlaceholders: stylePlaceholders,
        cornerRadius: cornerRadius,
        trim: trim,
        wedgeWidthPercentage: wedgeWidthPercentage,
        wedgeHeightPercentage: wedgeHeightPercentage,
        cacheControl: cacheControl);
  }

  ///API for requesting images with filters and mutation capabilities. When request contains a style and additional manipulations (width, height, resize_mode, blur), those parameters will override the style manipulation value. Modifications are applied in order:  1. Resize image	 2. Blur 	 3. Brighten	 4. Image quality 	 5. Channel 	 6. Color space	 7. Overlays 	 8. CornerRadius
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidthPercentage The minimum width used for Wedge shape resize
  ///@param wedgeHeightPercentage The minimum height used for wedge shape resize
  @Get(path: '/{path}')
  Future<chopper.Response<List<String>>> _pathGet({
    @Path('path') required String? path,
    @Header('If-None-Match') String? ifNoneMatch,
    @Query('w') int? w,
    @Query('h') int? h,
    @Query('mode') String? mode,
    @Query('blur') num? blur,
    @Query('brightness') int? brightness,
    @Query('format') String? format,
    @Query('style') String? style,
    @Query('channel') String? channel,
    @Query('colorspace') String? colorspace,
    @Query('overlay') List<String>? overlay,
    @Query('metadata') bool? metadata,
    @Query('quality') num? quality,
    @Query('stylePlaceholders') String? stylePlaceholders,
    @Query('cornerRadius') String? cornerRadius,
    @Query('trim') bool? trim,
    @Query('wedgeWidthPercentage') num? wedgeWidthPercentage,
    @Query('wedgeHeightPercentage') num? wedgeHeightPercentage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///API for deleting images
  ///@param resourceLocation The image resource location
  Future<chopper.Response<List<String>>> resourceLocationDelete({
    required String? resourceLocation,
    String? cacheControl,
  }) {
    return _resourceLocationDelete(
        resourceLocation: resourceLocation, cacheControl: cacheControl);
  }

  ///API for deleting images
  ///@param resourceLocation The image resource location
  @Delete(path: '/{resourceLocation}')
  Future<chopper.Response<List<String>>> _resourceLocationDelete({
    @Path('resourceLocation') required String? resourceLocation,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class ContentRequest {
  ContentRequest({
    this.allowMultipleImages,
    required this.id,
    required this.intents,
    this.type,
  });

  factory ContentRequest.fromJson(Map<String, dynamic> json) =>
      _$ContentRequestFromJson(json);

  static const toJsonFactory = _$ContentRequestToJson;
  Map<String, dynamic> toJson() => _$ContentRequestToJson(this);

  @JsonKey(name: 'allowMultipleImages', includeIfNull: false)
  final bool? allowMultipleImages;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'intents', includeIfNull: false, defaultValue: <String>[])
  final List<String> intents;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: contentRequestTypeToJson,
    fromJson: contentRequestTypeFromJson,
  )
  final enums.ContentRequestType? type;
  static const fromJsonFactory = _$ContentRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContentRequest &&
            (identical(other.allowMultipleImages, allowMultipleImages) ||
                const DeepCollectionEquality()
                    .equals(other.allowMultipleImages, allowMultipleImages)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.intents, intents) ||
                const DeepCollectionEquality()
                    .equals(other.intents, intents)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(allowMultipleImages) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(intents) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ContentRequestExtension on ContentRequest {
  ContentRequest copyWith(
      {bool? allowMultipleImages,
      String? id,
      List<String>? intents,
      enums.ContentRequestType? type}) {
    return ContentRequest(
        allowMultipleImages: allowMultipleImages ?? this.allowMultipleImages,
        id: id ?? this.id,
        intents: intents ?? this.intents,
        type: type ?? this.type);
  }

  ContentRequest copyWithWrapped(
      {Wrapped<bool?>? allowMultipleImages,
      Wrapped<String>? id,
      Wrapped<List<String>>? intents,
      Wrapped<enums.ContentRequestType?>? type}) {
    return ContentRequest(
        allowMultipleImages: (allowMultipleImages != null
            ? allowMultipleImages.value
            : this.allowMultipleImages),
        id: (id != null ? id.value : this.id),
        intents: (intents != null ? intents.value : this.intents),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class ContentResponse {
  ContentResponse({
    this.id,
    this.intents,
  });

  factory ContentResponse.fromJson(Map<String, dynamic> json) =>
      _$ContentResponseFromJson(json);

  static const toJsonFactory = _$ContentResponseToJson;
  Map<String, dynamic> toJson() => _$ContentResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
      name: 'intents',
      includeIfNull: false,
      defaultValue: <IntentResultResponse>[])
  final List<IntentResultResponse>? intents;
  static const fromJsonFactory = _$ContentResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContentResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.intents, intents) ||
                const DeepCollectionEquality().equals(other.intents, intents)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(intents) ^
      runtimeType.hashCode;
}

extension $ContentResponseExtension on ContentResponse {
  ContentResponse copyWith({String? id, List<IntentResultResponse>? intents}) {
    return ContentResponse(id: id ?? this.id, intents: intents ?? this.intents);
  }

  ContentResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<List<IntentResultResponse>?>? intents}) {
    return ContentResponse(
        id: (id != null ? id.value : this.id),
        intents: (intents != null ? intents.value : this.intents));
  }
}

@JsonSerializable(explicitToJson: true)
class ImageMetadata {
  ImageMetadata({
    this.dominantColorCodes,
    this.ratio,
    this.resolution,
  });

  factory ImageMetadata.fromJson(Map<String, dynamic> json) =>
      _$ImageMetadataFromJson(json);

  static const toJsonFactory = _$ImageMetadataToJson;
  Map<String, dynamic> toJson() => _$ImageMetadataToJson(this);

  @JsonKey(
      name: 'dominantColorCodes',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? dominantColorCodes;
  @JsonKey(name: 'ratio', includeIfNull: false, defaultValue: '')
  final String? ratio;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  static const fromJsonFactory = _$ImageMetadataFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ImageMetadata &&
            (identical(other.dominantColorCodes, dominantColorCodes) ||
                const DeepCollectionEquality()
                    .equals(other.dominantColorCodes, dominantColorCodes)) &&
            (identical(other.ratio, ratio) ||
                const DeepCollectionEquality().equals(other.ratio, ratio)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(dominantColorCodes) ^
      const DeepCollectionEquality().hash(ratio) ^
      const DeepCollectionEquality().hash(resolution) ^
      runtimeType.hashCode;
}

extension $ImageMetadataExtension on ImageMetadata {
  ImageMetadata copyWith(
      {List<String>? dominantColorCodes, String? ratio, String? resolution}) {
    return ImageMetadata(
        dominantColorCodes: dominantColorCodes ?? this.dominantColorCodes,
        ratio: ratio ?? this.ratio,
        resolution: resolution ?? this.resolution);
  }

  ImageMetadata copyWithWrapped(
      {Wrapped<List<String>?>? dominantColorCodes,
      Wrapped<String?>? ratio,
      Wrapped<String?>? resolution}) {
    return ImageMetadata(
        dominantColorCodes: (dominantColorCodes != null
            ? dominantColorCodes.value
            : this.dominantColorCodes),
        ratio: (ratio != null ? ratio.value : this.ratio),
        resolution: (resolution != null ? resolution.value : this.resolution));
  }
}

@JsonSerializable(explicitToJson: true)
class IntentResultResponse {
  IntentResultResponse({
    this.intent,
    this.url,
  });

  factory IntentResultResponse.fromJson(Map<String, dynamic> json) =>
      _$IntentResultResponseFromJson(json);

  static const toJsonFactory = _$IntentResultResponseToJson;
  Map<String, dynamic> toJson() => _$IntentResultResponseToJson(this);

  @JsonKey(name: 'intent', includeIfNull: false, defaultValue: '')
  final String? intent;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$IntentResultResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IntentResultResponse &&
            (identical(other.intent, intent) ||
                const DeepCollectionEquality().equals(other.intent, intent)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intent) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $IntentResultResponseExtension on IntentResultResponse {
  IntentResultResponse copyWith({String? intent, String? url}) {
    return IntentResultResponse(
        intent: intent ?? this.intent, url: url ?? this.url);
  }

  IntentResultResponse copyWithWrapped(
      {Wrapped<String?>? intent, Wrapped<String?>? url}) {
    return IntentResultResponse(
        intent: (intent != null ? intent.value : this.intent),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    this.allErrors,
    this.correlationId,
    this.details,
    required this.httpStatusCode,
    required this.message,
    this.statusCode,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(statusCode) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {List<String>? allErrors,
      String? correlationId,
      String? details,
      int? httpStatusCode,
      String? message,
      int? statusCode}) {
    return KrakenError(
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId,
        details: details ?? this.details,
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        message: message ?? this.message,
        statusCode: statusCode ?? this.statusCode);
  }

  KrakenError copyWithWrapped(
      {Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId,
      Wrapped<String?>? details,
      Wrapped<int>? httpStatusCode,
      Wrapped<String>? message,
      Wrapped<int?>? statusCode}) {
    return KrakenError(
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId),
        details: (details != null ? details.value : this.details),
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        message: (message != null ? message.value : this.message),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode));
  }
}

@JsonSerializable(explicitToJson: true)
class MovePaths {
  MovePaths({
    this.destination,
    this.source,
  });

  factory MovePaths.fromJson(Map<String, dynamic> json) =>
      _$MovePathsFromJson(json);

  static const toJsonFactory = _$MovePathsToJson;
  Map<String, dynamic> toJson() => _$MovePathsToJson(this);

  @JsonKey(name: 'destination', includeIfNull: false, defaultValue: '')
  final String? destination;
  @JsonKey(name: 'source', includeIfNull: false, defaultValue: '')
  final String? source;
  static const fromJsonFactory = _$MovePathsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MovePaths &&
            (identical(other.destination, destination) ||
                const DeepCollectionEquality()
                    .equals(other.destination, destination)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(destination) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $MovePathsExtension on MovePaths {
  MovePaths copyWith({String? destination, String? source}) {
    return MovePaths(
        destination: destination ?? this.destination,
        source: source ?? this.source);
  }

  MovePaths copyWithWrapped(
      {Wrapped<String?>? destination, Wrapped<String?>? source}) {
    return MovePaths(
        destination:
            (destination != null ? destination.value : this.destination),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class MultiRequest {
  MultiRequest({
    required this.files,
  });

  factory MultiRequest.fromJson(Map<String, dynamic> json) =>
      _$MultiRequestFromJson(json);

  static const toJsonFactory = _$MultiRequestToJson;
  Map<String, dynamic> toJson() => _$MultiRequestToJson(this);

  @JsonKey(name: 'files', includeIfNull: false, defaultValue: '')
  final String files;
  static const fromJsonFactory = _$MultiRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MultiRequest &&
            (identical(other.files, files) ||
                const DeepCollectionEquality().equals(other.files, files)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(files) ^ runtimeType.hashCode;
}

extension $MultiRequestExtension on MultiRequest {
  MultiRequest copyWith({String? files}) {
    return MultiRequest(files: files ?? this.files);
  }

  MultiRequest copyWithWrapped({Wrapped<String>? files}) {
    return MultiRequest(files: (files != null ? files.value : this.files));
  }
}

String? contentRequestTypeToJson(enums.ContentRequestType? contentRequestType) {
  return contentRequestType?.value;
}

enums.ContentRequestType contentRequestTypeFromJson(
  Object? contentRequestType, [
  enums.ContentRequestType? defaultValue,
]) {
  return enums.ContentRequestType.values
          .firstWhereOrNull((e) => e.value == contentRequestType) ??
      defaultValue ??
      enums.ContentRequestType.swaggerGeneratedUnknown;
}

List<String> contentRequestTypeListToJson(
    List<enums.ContentRequestType>? contentRequestType) {
  if (contentRequestType == null) {
    return [];
  }

  return contentRequestType.map((e) => e.value!).toList();
}

List<enums.ContentRequestType> contentRequestTypeListFromJson(
  List? contentRequestType, [
  List<enums.ContentRequestType>? defaultValue,
]) {
  if (contentRequestType == null) {
    return defaultValue ?? [];
  }

  return contentRequestType
      .map((e) => contentRequestTypeFromJson(e.toString()))
      .toList();
}

List<enums.ContentRequestType>? contentRequestTypeNullableListFromJson(
  List? contentRequestType, [
  List<enums.ContentRequestType>? defaultValue,
]) {
  if (contentRequestType == null) {
    return defaultValue;
  }

  return contentRequestType
      .map((e) => contentRequestTypeFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetModeToJson(
    enums.IntentResourceIdImageTypeGetMode? intentResourceIdImageTypeGetMode) {
  return intentResourceIdImageTypeGetMode?.value;
}

enums.IntentResourceIdImageTypeGetMode intentResourceIdImageTypeGetModeFromJson(
  Object? intentResourceIdImageTypeGetMode, [
  enums.IntentResourceIdImageTypeGetMode? defaultValue,
]) {
  return enums.IntentResourceIdImageTypeGetMode.values.firstWhereOrNull(
          (e) => e.value == intentResourceIdImageTypeGetMode) ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetMode.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetModeListToJson(
    List<enums.IntentResourceIdImageTypeGetMode>?
        intentResourceIdImageTypeGetMode) {
  if (intentResourceIdImageTypeGetMode == null) {
    return [];
  }

  return intentResourceIdImageTypeGetMode.map((e) => e.value!).toList();
}

List<enums.IntentResourceIdImageTypeGetMode>
    intentResourceIdImageTypeGetModeListFromJson(
  List? intentResourceIdImageTypeGetMode, [
  List<enums.IntentResourceIdImageTypeGetMode>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetMode == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetMode
      .map((e) => intentResourceIdImageTypeGetModeFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetMode>?
    intentResourceIdImageTypeGetModeNullableListFromJson(
  List? intentResourceIdImageTypeGetMode, [
  List<enums.IntentResourceIdImageTypeGetMode>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetMode == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetMode
      .map((e) => intentResourceIdImageTypeGetModeFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetFormatToJson(
    enums.IntentResourceIdImageTypeGetFormat?
        intentResourceIdImageTypeGetFormat) {
  return intentResourceIdImageTypeGetFormat?.value;
}

enums.IntentResourceIdImageTypeGetFormat
    intentResourceIdImageTypeGetFormatFromJson(
  Object? intentResourceIdImageTypeGetFormat, [
  enums.IntentResourceIdImageTypeGetFormat? defaultValue,
]) {
  return enums.IntentResourceIdImageTypeGetFormat.values.firstWhereOrNull(
          (e) => e.value == intentResourceIdImageTypeGetFormat) ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetFormat.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetFormatListToJson(
    List<enums.IntentResourceIdImageTypeGetFormat>?
        intentResourceIdImageTypeGetFormat) {
  if (intentResourceIdImageTypeGetFormat == null) {
    return [];
  }

  return intentResourceIdImageTypeGetFormat.map((e) => e.value!).toList();
}

List<enums.IntentResourceIdImageTypeGetFormat>
    intentResourceIdImageTypeGetFormatListFromJson(
  List? intentResourceIdImageTypeGetFormat, [
  List<enums.IntentResourceIdImageTypeGetFormat>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetFormat == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetFormat
      .map((e) => intentResourceIdImageTypeGetFormatFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetFormat>?
    intentResourceIdImageTypeGetFormatNullableListFromJson(
  List? intentResourceIdImageTypeGetFormat, [
  List<enums.IntentResourceIdImageTypeGetFormat>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetFormat == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetFormat
      .map((e) => intentResourceIdImageTypeGetFormatFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetChannelToJson(
    enums.IntentResourceIdImageTypeGetChannel?
        intentResourceIdImageTypeGetChannel) {
  return intentResourceIdImageTypeGetChannel?.value;
}

enums.IntentResourceIdImageTypeGetChannel
    intentResourceIdImageTypeGetChannelFromJson(
  Object? intentResourceIdImageTypeGetChannel, [
  enums.IntentResourceIdImageTypeGetChannel? defaultValue,
]) {
  return enums.IntentResourceIdImageTypeGetChannel.values.firstWhereOrNull(
          (e) => e.value == intentResourceIdImageTypeGetChannel) ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetChannel.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetChannelListToJson(
    List<enums.IntentResourceIdImageTypeGetChannel>?
        intentResourceIdImageTypeGetChannel) {
  if (intentResourceIdImageTypeGetChannel == null) {
    return [];
  }

  return intentResourceIdImageTypeGetChannel.map((e) => e.value!).toList();
}

List<enums.IntentResourceIdImageTypeGetChannel>
    intentResourceIdImageTypeGetChannelListFromJson(
  List? intentResourceIdImageTypeGetChannel, [
  List<enums.IntentResourceIdImageTypeGetChannel>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetChannel == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetChannel
      .map((e) => intentResourceIdImageTypeGetChannelFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetChannel>?
    intentResourceIdImageTypeGetChannelNullableListFromJson(
  List? intentResourceIdImageTypeGetChannel, [
  List<enums.IntentResourceIdImageTypeGetChannel>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetChannel == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetChannel
      .map((e) => intentResourceIdImageTypeGetChannelFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetColorSpaceToJson(
    enums.IntentResourceIdImageTypeGetColorSpace?
        intentResourceIdImageTypeGetColorSpace) {
  return intentResourceIdImageTypeGetColorSpace?.value;
}

enums.IntentResourceIdImageTypeGetColorSpace
    intentResourceIdImageTypeGetColorSpaceFromJson(
  Object? intentResourceIdImageTypeGetColorSpace, [
  enums.IntentResourceIdImageTypeGetColorSpace? defaultValue,
]) {
  return enums.IntentResourceIdImageTypeGetColorSpace.values.firstWhereOrNull(
          (e) => e.value == intentResourceIdImageTypeGetColorSpace) ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetColorSpace.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetColorSpaceListToJson(
    List<enums.IntentResourceIdImageTypeGetColorSpace>?
        intentResourceIdImageTypeGetColorSpace) {
  if (intentResourceIdImageTypeGetColorSpace == null) {
    return [];
  }

  return intentResourceIdImageTypeGetColorSpace.map((e) => e.value!).toList();
}

List<enums.IntentResourceIdImageTypeGetColorSpace>
    intentResourceIdImageTypeGetColorSpaceListFromJson(
  List? intentResourceIdImageTypeGetColorSpace, [
  List<enums.IntentResourceIdImageTypeGetColorSpace>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetColorSpace == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetColorSpace
      .map((e) => intentResourceIdImageTypeGetColorSpaceFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetColorSpace>?
    intentResourceIdImageTypeGetColorSpaceNullableListFromJson(
  List? intentResourceIdImageTypeGetColorSpace, [
  List<enums.IntentResourceIdImageTypeGetColorSpace>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetColorSpace == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetColorSpace
      .map((e) => intentResourceIdImageTypeGetColorSpaceFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetTypeToJson(
    enums.IntentResourceIdImageTypeGetType? intentResourceIdImageTypeGetType) {
  return intentResourceIdImageTypeGetType?.value;
}

enums.IntentResourceIdImageTypeGetType intentResourceIdImageTypeGetTypeFromJson(
  Object? intentResourceIdImageTypeGetType, [
  enums.IntentResourceIdImageTypeGetType? defaultValue,
]) {
  return enums.IntentResourceIdImageTypeGetType.values.firstWhereOrNull(
          (e) => e.value == intentResourceIdImageTypeGetType) ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetType.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetTypeListToJson(
    List<enums.IntentResourceIdImageTypeGetType>?
        intentResourceIdImageTypeGetType) {
  if (intentResourceIdImageTypeGetType == null) {
    return [];
  }

  return intentResourceIdImageTypeGetType.map((e) => e.value!).toList();
}

List<enums.IntentResourceIdImageTypeGetType>
    intentResourceIdImageTypeGetTypeListFromJson(
  List? intentResourceIdImageTypeGetType, [
  List<enums.IntentResourceIdImageTypeGetType>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetType == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetType
      .map((e) => intentResourceIdImageTypeGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetType>?
    intentResourceIdImageTypeGetTypeNullableListFromJson(
  List? intentResourceIdImageTypeGetType, [
  List<enums.IntentResourceIdImageTypeGetType>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetType == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetType
      .map((e) => intentResourceIdImageTypeGetTypeFromJson(e.toString()))
      .toList();
}

String? metadataPathGetModeToJson(
    enums.MetadataPathGetMode? metadataPathGetMode) {
  return metadataPathGetMode?.value;
}

enums.MetadataPathGetMode metadataPathGetModeFromJson(
  Object? metadataPathGetMode, [
  enums.MetadataPathGetMode? defaultValue,
]) {
  return enums.MetadataPathGetMode.values
          .firstWhereOrNull((e) => e.value == metadataPathGetMode) ??
      defaultValue ??
      enums.MetadataPathGetMode.swaggerGeneratedUnknown;
}

List<String> metadataPathGetModeListToJson(
    List<enums.MetadataPathGetMode>? metadataPathGetMode) {
  if (metadataPathGetMode == null) {
    return [];
  }

  return metadataPathGetMode.map((e) => e.value!).toList();
}

List<enums.MetadataPathGetMode> metadataPathGetModeListFromJson(
  List? metadataPathGetMode, [
  List<enums.MetadataPathGetMode>? defaultValue,
]) {
  if (metadataPathGetMode == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetMode
      .map((e) => metadataPathGetModeFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetMode>? metadataPathGetModeNullableListFromJson(
  List? metadataPathGetMode, [
  List<enums.MetadataPathGetMode>? defaultValue,
]) {
  if (metadataPathGetMode == null) {
    return defaultValue;
  }

  return metadataPathGetMode
      .map((e) => metadataPathGetModeFromJson(e.toString()))
      .toList();
}

String? metadataPathGetFormatToJson(
    enums.MetadataPathGetFormat? metadataPathGetFormat) {
  return metadataPathGetFormat?.value;
}

enums.MetadataPathGetFormat metadataPathGetFormatFromJson(
  Object? metadataPathGetFormat, [
  enums.MetadataPathGetFormat? defaultValue,
]) {
  return enums.MetadataPathGetFormat.values
          .firstWhereOrNull((e) => e.value == metadataPathGetFormat) ??
      defaultValue ??
      enums.MetadataPathGetFormat.swaggerGeneratedUnknown;
}

List<String> metadataPathGetFormatListToJson(
    List<enums.MetadataPathGetFormat>? metadataPathGetFormat) {
  if (metadataPathGetFormat == null) {
    return [];
  }

  return metadataPathGetFormat.map((e) => e.value!).toList();
}

List<enums.MetadataPathGetFormat> metadataPathGetFormatListFromJson(
  List? metadataPathGetFormat, [
  List<enums.MetadataPathGetFormat>? defaultValue,
]) {
  if (metadataPathGetFormat == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetFormat
      .map((e) => metadataPathGetFormatFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetFormat>? metadataPathGetFormatNullableListFromJson(
  List? metadataPathGetFormat, [
  List<enums.MetadataPathGetFormat>? defaultValue,
]) {
  if (metadataPathGetFormat == null) {
    return defaultValue;
  }

  return metadataPathGetFormat
      .map((e) => metadataPathGetFormatFromJson(e.toString()))
      .toList();
}

String? metadataPathGetChannelToJson(
    enums.MetadataPathGetChannel? metadataPathGetChannel) {
  return metadataPathGetChannel?.value;
}

enums.MetadataPathGetChannel metadataPathGetChannelFromJson(
  Object? metadataPathGetChannel, [
  enums.MetadataPathGetChannel? defaultValue,
]) {
  return enums.MetadataPathGetChannel.values
          .firstWhereOrNull((e) => e.value == metadataPathGetChannel) ??
      defaultValue ??
      enums.MetadataPathGetChannel.swaggerGeneratedUnknown;
}

List<String> metadataPathGetChannelListToJson(
    List<enums.MetadataPathGetChannel>? metadataPathGetChannel) {
  if (metadataPathGetChannel == null) {
    return [];
  }

  return metadataPathGetChannel.map((e) => e.value!).toList();
}

List<enums.MetadataPathGetChannel> metadataPathGetChannelListFromJson(
  List? metadataPathGetChannel, [
  List<enums.MetadataPathGetChannel>? defaultValue,
]) {
  if (metadataPathGetChannel == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetChannel
      .map((e) => metadataPathGetChannelFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetChannel>? metadataPathGetChannelNullableListFromJson(
  List? metadataPathGetChannel, [
  List<enums.MetadataPathGetChannel>? defaultValue,
]) {
  if (metadataPathGetChannel == null) {
    return defaultValue;
  }

  return metadataPathGetChannel
      .map((e) => metadataPathGetChannelFromJson(e.toString()))
      .toList();
}

String? metadataPathGetColorspaceToJson(
    enums.MetadataPathGetColorspace? metadataPathGetColorspace) {
  return metadataPathGetColorspace?.value;
}

enums.MetadataPathGetColorspace metadataPathGetColorspaceFromJson(
  Object? metadataPathGetColorspace, [
  enums.MetadataPathGetColorspace? defaultValue,
]) {
  return enums.MetadataPathGetColorspace.values
          .firstWhereOrNull((e) => e.value == metadataPathGetColorspace) ??
      defaultValue ??
      enums.MetadataPathGetColorspace.swaggerGeneratedUnknown;
}

List<String> metadataPathGetColorspaceListToJson(
    List<enums.MetadataPathGetColorspace>? metadataPathGetColorspace) {
  if (metadataPathGetColorspace == null) {
    return [];
  }

  return metadataPathGetColorspace.map((e) => e.value!).toList();
}

List<enums.MetadataPathGetColorspace> metadataPathGetColorspaceListFromJson(
  List? metadataPathGetColorspace, [
  List<enums.MetadataPathGetColorspace>? defaultValue,
]) {
  if (metadataPathGetColorspace == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetColorspace
      .map((e) => metadataPathGetColorspaceFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetColorspace>?
    metadataPathGetColorspaceNullableListFromJson(
  List? metadataPathGetColorspace, [
  List<enums.MetadataPathGetColorspace>? defaultValue,
]) {
  if (metadataPathGetColorspace == null) {
    return defaultValue;
  }

  return metadataPathGetColorspace
      .map((e) => metadataPathGetColorspaceFromJson(e.toString()))
      .toList();
}

String? pathGetModeToJson(enums.PathGetMode? pathGetMode) {
  return pathGetMode?.value;
}

enums.PathGetMode pathGetModeFromJson(
  Object? pathGetMode, [
  enums.PathGetMode? defaultValue,
]) {
  return enums.PathGetMode.values
          .firstWhereOrNull((e) => e.value == pathGetMode) ??
      defaultValue ??
      enums.PathGetMode.swaggerGeneratedUnknown;
}

List<String> pathGetModeListToJson(List<enums.PathGetMode>? pathGetMode) {
  if (pathGetMode == null) {
    return [];
  }

  return pathGetMode.map((e) => e.value!).toList();
}

List<enums.PathGetMode> pathGetModeListFromJson(
  List? pathGetMode, [
  List<enums.PathGetMode>? defaultValue,
]) {
  if (pathGetMode == null) {
    return defaultValue ?? [];
  }

  return pathGetMode.map((e) => pathGetModeFromJson(e.toString())).toList();
}

List<enums.PathGetMode>? pathGetModeNullableListFromJson(
  List? pathGetMode, [
  List<enums.PathGetMode>? defaultValue,
]) {
  if (pathGetMode == null) {
    return defaultValue;
  }

  return pathGetMode.map((e) => pathGetModeFromJson(e.toString())).toList();
}

String? pathGetFormatToJson(enums.PathGetFormat? pathGetFormat) {
  return pathGetFormat?.value;
}

enums.PathGetFormat pathGetFormatFromJson(
  Object? pathGetFormat, [
  enums.PathGetFormat? defaultValue,
]) {
  return enums.PathGetFormat.values
          .firstWhereOrNull((e) => e.value == pathGetFormat) ??
      defaultValue ??
      enums.PathGetFormat.swaggerGeneratedUnknown;
}

List<String> pathGetFormatListToJson(List<enums.PathGetFormat>? pathGetFormat) {
  if (pathGetFormat == null) {
    return [];
  }

  return pathGetFormat.map((e) => e.value!).toList();
}

List<enums.PathGetFormat> pathGetFormatListFromJson(
  List? pathGetFormat, [
  List<enums.PathGetFormat>? defaultValue,
]) {
  if (pathGetFormat == null) {
    return defaultValue ?? [];
  }

  return pathGetFormat.map((e) => pathGetFormatFromJson(e.toString())).toList();
}

List<enums.PathGetFormat>? pathGetFormatNullableListFromJson(
  List? pathGetFormat, [
  List<enums.PathGetFormat>? defaultValue,
]) {
  if (pathGetFormat == null) {
    return defaultValue;
  }

  return pathGetFormat.map((e) => pathGetFormatFromJson(e.toString())).toList();
}

String? pathGetChannelToJson(enums.PathGetChannel? pathGetChannel) {
  return pathGetChannel?.value;
}

enums.PathGetChannel pathGetChannelFromJson(
  Object? pathGetChannel, [
  enums.PathGetChannel? defaultValue,
]) {
  return enums.PathGetChannel.values
          .firstWhereOrNull((e) => e.value == pathGetChannel) ??
      defaultValue ??
      enums.PathGetChannel.swaggerGeneratedUnknown;
}

List<String> pathGetChannelListToJson(
    List<enums.PathGetChannel>? pathGetChannel) {
  if (pathGetChannel == null) {
    return [];
  }

  return pathGetChannel.map((e) => e.value!).toList();
}

List<enums.PathGetChannel> pathGetChannelListFromJson(
  List? pathGetChannel, [
  List<enums.PathGetChannel>? defaultValue,
]) {
  if (pathGetChannel == null) {
    return defaultValue ?? [];
  }

  return pathGetChannel
      .map((e) => pathGetChannelFromJson(e.toString()))
      .toList();
}

List<enums.PathGetChannel>? pathGetChannelNullableListFromJson(
  List? pathGetChannel, [
  List<enums.PathGetChannel>? defaultValue,
]) {
  if (pathGetChannel == null) {
    return defaultValue;
  }

  return pathGetChannel
      .map((e) => pathGetChannelFromJson(e.toString()))
      .toList();
}

String? pathGetColorspaceToJson(enums.PathGetColorspace? pathGetColorspace) {
  return pathGetColorspace?.value;
}

enums.PathGetColorspace pathGetColorspaceFromJson(
  Object? pathGetColorspace, [
  enums.PathGetColorspace? defaultValue,
]) {
  return enums.PathGetColorspace.values
          .firstWhereOrNull((e) => e.value == pathGetColorspace) ??
      defaultValue ??
      enums.PathGetColorspace.swaggerGeneratedUnknown;
}

List<String> pathGetColorspaceListToJson(
    List<enums.PathGetColorspace>? pathGetColorspace) {
  if (pathGetColorspace == null) {
    return [];
  }

  return pathGetColorspace.map((e) => e.value!).toList();
}

List<enums.PathGetColorspace> pathGetColorspaceListFromJson(
  List? pathGetColorspace, [
  List<enums.PathGetColorspace>? defaultValue,
]) {
  if (pathGetColorspace == null) {
    return defaultValue ?? [];
  }

  return pathGetColorspace
      .map((e) => pathGetColorspaceFromJson(e.toString()))
      .toList();
}

List<enums.PathGetColorspace>? pathGetColorspaceNullableListFromJson(
  List? pathGetColorspace, [
  List<enums.PathGetColorspace>? defaultValue,
]) {
  if (pathGetColorspace == null) {
    return defaultValue;
  }

  return pathGetColorspace
      .map((e) => pathGetColorspaceFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
