// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'legacy_booking_service.enums.swagger.dart' as enums;
export 'legacy_booking_service.enums.swagger.dart';

part 'legacy_booking_service.swagger.chopper.dart';
part 'legacy_booking_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LegacyBookingService extends ChopperService {
  static LegacyBookingService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LegacyBookingService(client);
    }

    final newClient = ChopperClient(
        services: [_$LegacyBookingService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$LegacyBookingService(newClient);
  }

  ///List Customer Set Top Boxes
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<CustomerData>> customersCustomerIdBoxesGet({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CustomerData, () => CustomerData.fromJsonFactory);

    return _customersCustomerIdBoxesGet(
        customerId: customerId, xCus: xCus, cacheControl: cacheControl);
  }

  ///List Customer Set Top Boxes
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}/boxes')
  Future<chopper.Response<CustomerData>> _customersCustomerIdBoxesGet({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Books a single event to recording
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRemoteBookingSinglePost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required EventToBook? body,
  }) {
    return _customersCustomerIdRemoteBookingSinglePost(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Books a single event to recording
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param X-Cus Contains customer identifier
  @Post(
    path: '/customers/{customerId}/remote-booking/single',
    optionalBody: true,
  )
  Future<chopper.Response> _customersCustomerIdRemoteBookingSinglePost({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required EventToBook? body,
  });

  ///Receive all customer bookings
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<CustomerBookings>>
      customersCustomerIdRemoteBookingsGet({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CustomerBookings, () => CustomerBookings.fromJsonFactory);

    return _customersCustomerIdRemoteBookingsGet(
        customerId: customerId, xCus: xCus, cacheControl: cacheControl);
  }

  ///Receive all customer bookings
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}/remote-bookings')
  Future<chopper.Response<CustomerBookings>>
      _customersCustomerIdRemoteBookingsGet({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Find a Customer Recording by eventId
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param eventId Event Id to be searched
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<Booking>>
      customersCustomerIdRemoteBookingsEventIdGet({
    required String? customerId,
    required String? eventId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Booking, () => Booking.fromJsonFactory);

    return _customersCustomerIdRemoteBookingsEventIdGet(
        customerId: customerId,
        eventId: eventId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Find a Customer Recording by eventId
  ///@param customerId Contains customer identifier (HouseholdId)
  ///@param eventId Event Id to be searched
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}/remote-bookings/{eventId}')
  Future<chopper.Response<Booking>>
      _customersCustomerIdRemoteBookingsEventIdGet({
    @Path('customerId') required String? customerId,
    @Path('eventId') required String? eventId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class CustomerData {
  CustomerData({
    this.boxes,
  });

  factory CustomerData.fromJson(Map<String, dynamic> json) =>
      _$CustomerDataFromJson(json);

  static const toJsonFactory = _$CustomerDataToJson;
  Map<String, dynamic> toJson() => _$CustomerDataToJson(this);

  @JsonKey(name: 'boxes', includeIfNull: false, defaultValue: <SetTopBox>[])
  final List<SetTopBox>? boxes;
  static const fromJsonFactory = _$CustomerDataFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerData &&
            (identical(other.boxes, boxes) ||
                const DeepCollectionEquality().equals(other.boxes, boxes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(boxes) ^ runtimeType.hashCode;
}

extension $CustomerDataExtension on CustomerData {
  CustomerData copyWith({List<SetTopBox>? boxes}) {
    return CustomerData(boxes: boxes ?? this.boxes);
  }

  CustomerData copyWithWrapped({Wrapped<List<SetTopBox>?>? boxes}) {
    return CustomerData(boxes: (boxes != null ? boxes.value : this.boxes));
  }
}

@JsonSerializable(explicitToJson: true)
class SetTopBox {
  SetTopBox({
    this.smartCardId,
    this.boxType,
    this.isBookingCapable,
  });

  factory SetTopBox.fromJson(Map<String, dynamic> json) =>
      _$SetTopBoxFromJson(json);

  static const toJsonFactory = _$SetTopBoxToJson;
  Map<String, dynamic> toJson() => _$SetTopBoxToJson(this);

  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(
    name: 'boxType',
    includeIfNull: false,
    toJson: setTopBoxBoxTypeToJson,
    fromJson: setTopBoxBoxTypeFromJson,
  )
  final enums.SetTopBoxBoxType? boxType;
  @JsonKey(name: 'isBookingCapable', includeIfNull: false)
  final bool? isBookingCapable;
  static const fromJsonFactory = _$SetTopBoxFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SetTopBox &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.boxType, boxType) ||
                const DeepCollectionEquality()
                    .equals(other.boxType, boxType)) &&
            (identical(other.isBookingCapable, isBookingCapable) ||
                const DeepCollectionEquality()
                    .equals(other.isBookingCapable, isBookingCapable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(boxType) ^
      const DeepCollectionEquality().hash(isBookingCapable) ^
      runtimeType.hashCode;
}

extension $SetTopBoxExtension on SetTopBox {
  SetTopBox copyWith(
      {String? smartCardId,
      enums.SetTopBoxBoxType? boxType,
      bool? isBookingCapable}) {
    return SetTopBox(
        smartCardId: smartCardId ?? this.smartCardId,
        boxType: boxType ?? this.boxType,
        isBookingCapable: isBookingCapable ?? this.isBookingCapable);
  }

  SetTopBox copyWithWrapped(
      {Wrapped<String?>? smartCardId,
      Wrapped<enums.SetTopBoxBoxType?>? boxType,
      Wrapped<bool?>? isBookingCapable}) {
    return SetTopBox(
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        boxType: (boxType != null ? boxType.value : this.boxType),
        isBookingCapable: (isBookingCapable != null
            ? isBookingCapable.value
            : this.isBookingCapable));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerBookings {
  CustomerBookings({
    this.recordings,
  });

  factory CustomerBookings.fromJson(Map<String, dynamic> json) =>
      _$CustomerBookingsFromJson(json);

  static const toJsonFactory = _$CustomerBookingsToJson;
  Map<String, dynamic> toJson() => _$CustomerBookingsToJson(this);

  @JsonKey(name: 'recordings', includeIfNull: false, defaultValue: <Booking>[])
  final List<Booking>? recordings;
  static const fromJsonFactory = _$CustomerBookingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerBookings &&
            (identical(other.recordings, recordings) ||
                const DeepCollectionEquality()
                    .equals(other.recordings, recordings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordings) ^ runtimeType.hashCode;
}

extension $CustomerBookingsExtension on CustomerBookings {
  CustomerBookings copyWith({List<Booking>? recordings}) {
    return CustomerBookings(recordings: recordings ?? this.recordings);
  }

  CustomerBookings copyWithWrapped({Wrapped<List<Booking>?>? recordings}) {
    return CustomerBookings(
        recordings: (recordings != null ? recordings.value : this.recordings));
  }
}

@JsonSerializable(explicitToJson: true)
class Booking {
  Booking({
    this.eventId,
    this.status,
    this.smartCardId,
    this.statusCode,
    this.reason,
  });

  factory Booking.fromJson(Map<String, dynamic> json) =>
      _$BookingFromJson(json);

  static const toJsonFactory = _$BookingToJson;
  Map<String, dynamic> toJson() => _$BookingToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'reason', includeIfNull: false, defaultValue: '')
  final String? reason;
  static const fromJsonFactory = _$BookingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Booking &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.reason, reason) ||
                const DeepCollectionEquality().equals(other.reason, reason)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(reason) ^
      runtimeType.hashCode;
}

extension $BookingExtension on Booking {
  Booking copyWith(
      {String? eventId,
      String? status,
      String? smartCardId,
      int? statusCode,
      String? reason}) {
    return Booking(
        eventId: eventId ?? this.eventId,
        status: status ?? this.status,
        smartCardId: smartCardId ?? this.smartCardId,
        statusCode: statusCode ?? this.statusCode,
        reason: reason ?? this.reason);
  }

  Booking copyWithWrapped(
      {Wrapped<String?>? eventId,
      Wrapped<String?>? status,
      Wrapped<String?>? smartCardId,
      Wrapped<int?>? statusCode,
      Wrapped<String?>? reason}) {
    return Booking(
        eventId: (eventId != null ? eventId.value : this.eventId),
        status: (status != null ? status.value : this.status),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        reason: (reason != null ? reason.value : this.reason));
  }
}

@JsonSerializable(explicitToJson: true)
class EventToBook {
  EventToBook({
    this.smartCardId,
    this.eventId,
    this.shouldOverride,
  });

  factory EventToBook.fromJson(Map<String, dynamic> json) =>
      _$EventToBookFromJson(json);

  static const toJsonFactory = _$EventToBookToJson;
  Map<String, dynamic> toJson() => _$EventToBookToJson(this);

  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'shouldOverride', includeIfNull: false)
  final bool? shouldOverride;
  static const fromJsonFactory = _$EventToBookFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventToBook &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.shouldOverride, shouldOverride) ||
                const DeepCollectionEquality()
                    .equals(other.shouldOverride, shouldOverride)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(shouldOverride) ^
      runtimeType.hashCode;
}

extension $EventToBookExtension on EventToBook {
  EventToBook copyWith(
      {String? smartCardId, String? eventId, bool? shouldOverride}) {
    return EventToBook(
        smartCardId: smartCardId ?? this.smartCardId,
        eventId: eventId ?? this.eventId,
        shouldOverride: shouldOverride ?? this.shouldOverride);
  }

  EventToBook copyWithWrapped(
      {Wrapped<String?>? smartCardId,
      Wrapped<String?>? eventId,
      Wrapped<bool?>? shouldOverride}) {
    return EventToBook(
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        shouldOverride: (shouldOverride != null
            ? shouldOverride.value
            : this.shouldOverride));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error?>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? setTopBoxBoxTypeToJson(enums.SetTopBoxBoxType? setTopBoxBoxType) {
  return setTopBoxBoxType?.value;
}

enums.SetTopBoxBoxType setTopBoxBoxTypeFromJson(
  Object? setTopBoxBoxType, [
  enums.SetTopBoxBoxType? defaultValue,
]) {
  return enums.SetTopBoxBoxType.values
          .firstWhereOrNull((e) => e.value == setTopBoxBoxType) ??
      defaultValue ??
      enums.SetTopBoxBoxType.swaggerGeneratedUnknown;
}

List<String> setTopBoxBoxTypeListToJson(
    List<enums.SetTopBoxBoxType>? setTopBoxBoxType) {
  if (setTopBoxBoxType == null) {
    return [];
  }

  return setTopBoxBoxType.map((e) => e.value!).toList();
}

List<enums.SetTopBoxBoxType> setTopBoxBoxTypeListFromJson(
  List? setTopBoxBoxType, [
  List<enums.SetTopBoxBoxType>? defaultValue,
]) {
  if (setTopBoxBoxType == null) {
    return defaultValue ?? [];
  }

  return setTopBoxBoxType
      .map((e) => setTopBoxBoxTypeFromJson(e.toString()))
      .toList();
}

List<enums.SetTopBoxBoxType>? setTopBoxBoxTypeNullableListFromJson(
  List? setTopBoxBoxType, [
  List<enums.SetTopBoxBoxType>? defaultValue,
]) {
  if (setTopBoxBoxType == null) {
    return defaultValue;
  }

  return setTopBoxBoxType
      .map((e) => setTopBoxBoxTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
