// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'pay_per_view_service.swagger.chopper.dart';
part 'pay_per_view_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PayPerViewService extends ChopperService {
  static PayPerViewService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PayPerViewService(client);
    }

    final newClient = ChopperClient(
        services: [_$PayPerViewService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$PayPerViewService(newClient);
  }

  ///Get list of PPV events
  ///@param language
  ///@param limit
  ///@param customerId
  ///@param purchased
  ///@param x-cus Household ID
  ///@param x-dev Device ID
  ///@param x-entitlements-token Entitlements token header
  Future<chopper.Response<List<PPVEvent>>> eventsGet({
    required String? language,
    int? limit,
    String? customerId,
    bool? purchased,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PPVEvent, () => PPVEvent.fromJsonFactory);

    return _eventsGet(
        language: language,
        limit: limit,
        customerId: customerId,
        purchased: purchased,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of PPV events
  ///@param language
  ///@param limit
  ///@param customerId
  ///@param purchased
  ///@param x-cus Household ID
  ///@param x-dev Device ID
  ///@param x-entitlements-token Entitlements token header
  @Get(path: '/events')
  Future<chopper.Response<List<PPVEvent>>> _eventsGet({
    @Query('language')
        required String? language,
    @Query('limit')
        int? limit,
    @Query('customerId')
        String? customerId,
    @Query('purchased')
        bool? purchased,
    @Header('x-cus')
        String? xCus = 'X-Cus',
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get PPV event details
  ///@param eventId
  ///@param language
  ///@param customerId
  ///@param x-cus Household ID
  ///@param x-dev Device ID
  ///@param x-entitlements-token Entitlements token header
  Future<chopper.Response<PPVEventDetail>> eventsEventIdGet({
    required String? eventId,
    required String? language,
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PPVEventDetail, () => PPVEventDetail.fromJsonFactory);

    return _eventsEventIdGet(
        eventId: eventId,
        language: language,
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get PPV event details
  ///@param eventId
  ///@param language
  ///@param customerId
  ///@param x-cus Household ID
  ///@param x-dev Device ID
  ///@param x-entitlements-token Entitlements token header
  @Get(path: '/events/{eventId}')
  Future<chopper.Response<PPVEventDetail>> _eventsEventIdGet({
    @Path('eventId')
        required String? eventId,
    @Query('language')
        required String? language,
    @Query('customerId')
        required String? customerId,
    @Header('x-cus')
        String? xCus = 'X-Cus',
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of DayPass Products
  ///@param channelId
  ///@param x-cus Household ID
  Future<chopper.Response<DayPass>> daypassChannelIdGet({
    required String? channelId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(DayPass, () => DayPass.fromJsonFactory);

    return _daypassChannelIdGet(
        channelId: channelId, xCus: xCus, cacheControl: cacheControl);
  }

  ///Get list of DayPass Products
  ///@param channelId
  ///@param x-cus Household ID
  @Get(path: '/daypass/{channelId}')
  Future<chopper.Response<DayPass>> _daypassChannelIdGet({
    @Path('channelId') required String? channelId,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class DayPass {
  DayPass({
    this.dayPassProducts,
  });

  factory DayPass.fromJson(Map<String, dynamic> json) =>
      _$DayPassFromJson(json);

  static const toJsonFactory = _$DayPassToJson;
  Map<String, dynamic> toJson() => _$DayPassToJson(this);

  @JsonKey(
      name: 'dayPassProducts', includeIfNull: false, defaultValue: <Product>[])
  final List<Product>? dayPassProducts;
  static const fromJsonFactory = _$DayPassFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DayPass &&
            (identical(other.dayPassProducts, dayPassProducts) ||
                const DeepCollectionEquality()
                    .equals(other.dayPassProducts, dayPassProducts)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(dayPassProducts) ^
      runtimeType.hashCode;
}

extension $DayPassExtension on DayPass {
  DayPass copyWith({List<Product>? dayPassProducts}) {
    return DayPass(dayPassProducts: dayPassProducts ?? this.dayPassProducts);
  }

  DayPass copyWithWrapped({Wrapped<List<Product>?>? dayPassProducts}) {
    return DayPass(
        dayPassProducts: (dayPassProducts != null
            ? dayPassProducts.value
            : this.dayPassProducts));
  }
}

@JsonSerializable(explicitToJson: true)
class Product {
  Product({
    required this.productId,
    required this.duration,
    required this.price,
    required this.priceDisplay,
    required this.currency,
    required this.title,
    required this.isAdult,
  });

  factory Product.fromJson(Map<String, dynamic> json) =>
      _$ProductFromJson(json);

  static const toJsonFactory = _$ProductToJson;
  Map<String, dynamic> toJson() => _$ProductToJson(this);

  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String productId;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'price', includeIfNull: false)
  final double price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String priceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  static const fromJsonFactory = _$ProductFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Product &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality().equals(other.isAdult, isAdult)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(isAdult) ^
      runtimeType.hashCode;
}

extension $ProductExtension on Product {
  Product copyWith(
      {String? productId,
      int? duration,
      double? price,
      String? priceDisplay,
      String? currency,
      String? title,
      bool? isAdult}) {
    return Product(
        productId: productId ?? this.productId,
        duration: duration ?? this.duration,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        currency: currency ?? this.currency,
        title: title ?? this.title,
        isAdult: isAdult ?? this.isAdult);
  }

  Product copyWithWrapped(
      {Wrapped<String>? productId,
      Wrapped<int>? duration,
      Wrapped<double>? price,
      Wrapped<String>? priceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? title,
      Wrapped<bool>? isAdult}) {
    return Product(
        productId: (productId != null ? productId.value : this.productId),
        duration: (duration != null ? duration.value : this.duration),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        title: (title != null ? title.value : this.title),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult));
  }
}

@JsonSerializable(explicitToJson: true)
class PPVEvent {
  PPVEvent({
    required this.eventId,
    required this.channelId,
    required this.nagraELKProductID,
    required this.name,
    required this.shortSynopsis,
    required this.isAdult,
    required this.minAge,
    required this.eventStartTime,
    required this.eventEndTime,
    required this.purchaseAvailableStartTime,
    required this.purchaseAvailableEndTime,
    this.isPurchased,
    required this.images,
  });

  factory PPVEvent.fromJson(Map<String, dynamic> json) =>
      _$PPVEventFromJson(json);

  static const toJsonFactory = _$PPVEventToJson;
  Map<String, dynamic> toJson() => _$PPVEventToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'nagraELKProductID', includeIfNull: false, defaultValue: '')
  final String nagraELKProductID;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'shortSynopsis', includeIfNull: false, defaultValue: '')
  final String shortSynopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'minAge', includeIfNull: false)
  final int minAge;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime eventStartTime;
  @JsonKey(name: 'eventEndTime', includeIfNull: false)
  final DateTime eventEndTime;
  @JsonKey(name: 'purchaseAvailableStartTime', includeIfNull: false)
  final DateTime purchaseAvailableStartTime;
  @JsonKey(name: 'purchaseAvailableEndTime', includeIfNull: false)
  final DateTime purchaseAvailableEndTime;
  @JsonKey(name: 'isPurchased', includeIfNull: false)
  final bool? isPurchased;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image> images;
  static const fromJsonFactory = _$PPVEventFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PPVEvent &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.nagraELKProductID, nagraELKProductID) ||
                const DeepCollectionEquality()
                    .equals(other.nagraELKProductID, nagraELKProductID)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.shortSynopsis, shortSynopsis) ||
                const DeepCollectionEquality()
                    .equals(other.shortSynopsis, shortSynopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minAge, minAge) ||
                const DeepCollectionEquality().equals(other.minAge, minAge)) &&
            (identical(other.eventStartTime, eventStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.eventEndTime, eventEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventEndTime, eventEndTime)) &&
            (identical(other.purchaseAvailableStartTime,
                    purchaseAvailableStartTime) ||
                const DeepCollectionEquality().equals(
                    other.purchaseAvailableStartTime,
                    purchaseAvailableStartTime)) &&
            (identical(
                    other.purchaseAvailableEndTime, purchaseAvailableEndTime) ||
                const DeepCollectionEquality().equals(
                    other.purchaseAvailableEndTime,
                    purchaseAvailableEndTime)) &&
            (identical(other.isPurchased, isPurchased) ||
                const DeepCollectionEquality()
                    .equals(other.isPurchased, isPurchased)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(nagraELKProductID) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(shortSynopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minAge) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(eventEndTime) ^
      const DeepCollectionEquality().hash(purchaseAvailableStartTime) ^
      const DeepCollectionEquality().hash(purchaseAvailableEndTime) ^
      const DeepCollectionEquality().hash(isPurchased) ^
      const DeepCollectionEquality().hash(images) ^
      runtimeType.hashCode;
}

extension $PPVEventExtension on PPVEvent {
  PPVEvent copyWith(
      {String? eventId,
      String? channelId,
      String? nagraELKProductID,
      String? name,
      String? shortSynopsis,
      bool? isAdult,
      int? minAge,
      DateTime? eventStartTime,
      DateTime? eventEndTime,
      DateTime? purchaseAvailableStartTime,
      DateTime? purchaseAvailableEndTime,
      bool? isPurchased,
      List<Image>? images}) {
    return PPVEvent(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        nagraELKProductID: nagraELKProductID ?? this.nagraELKProductID,
        name: name ?? this.name,
        shortSynopsis: shortSynopsis ?? this.shortSynopsis,
        isAdult: isAdult ?? this.isAdult,
        minAge: minAge ?? this.minAge,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        eventEndTime: eventEndTime ?? this.eventEndTime,
        purchaseAvailableStartTime:
            purchaseAvailableStartTime ?? this.purchaseAvailableStartTime,
        purchaseAvailableEndTime:
            purchaseAvailableEndTime ?? this.purchaseAvailableEndTime,
        isPurchased: isPurchased ?? this.isPurchased,
        images: images ?? this.images);
  }

  PPVEvent copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<String>? nagraELKProductID,
      Wrapped<String>? name,
      Wrapped<String>? shortSynopsis,
      Wrapped<bool>? isAdult,
      Wrapped<int>? minAge,
      Wrapped<DateTime>? eventStartTime,
      Wrapped<DateTime>? eventEndTime,
      Wrapped<DateTime>? purchaseAvailableStartTime,
      Wrapped<DateTime>? purchaseAvailableEndTime,
      Wrapped<bool?>? isPurchased,
      Wrapped<List<Image>>? images}) {
    return PPVEvent(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        nagraELKProductID: (nagraELKProductID != null
            ? nagraELKProductID.value
            : this.nagraELKProductID),
        name: (name != null ? name.value : this.name),
        shortSynopsis:
            (shortSynopsis != null ? shortSynopsis.value : this.shortSynopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minAge: (minAge != null ? minAge.value : this.minAge),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        eventEndTime:
            (eventEndTime != null ? eventEndTime.value : this.eventEndTime),
        purchaseAvailableStartTime: (purchaseAvailableStartTime != null
            ? purchaseAvailableStartTime.value
            : this.purchaseAvailableStartTime),
        purchaseAvailableEndTime: (purchaseAvailableEndTime != null
            ? purchaseAvailableEndTime.value
            : this.purchaseAvailableEndTime),
        isPurchased:
            (isPurchased != null ? isPurchased.value : this.isPurchased),
        images: (images != null ? images.value : this.images));
  }
}

@JsonSerializable(explicitToJson: true)
class PPVEventDetail {
  PPVEventDetail({
    required this.eventId,
    required this.channelId,
    required this.productId,
    required this.edsProductId,
    required this.nagraELKProductID,
    required this.name,
    required this.shortSynopsis,
    this.longSynopsis,
    required this.isAdult,
    required this.minAge,
    required this.price,
    this.priceDisplay,
    required this.eventStartTime,
    required this.eventEndTime,
    required this.purchaseAvailableStartTime,
    required this.purchaseAvailableEndTime,
    this.isPurchased,
    this.entitlementEnd,
    required this.images,
    this.videoQuality,
    this.audioMixType,
    this.captionLanguages,
    this.supplementalAudioDescription,
    this.supplementalCaptionLanguage,
    this.originalLanguages,
    this.signLanguages,
  });

  factory PPVEventDetail.fromJson(Map<String, dynamic> json) =>
      _$PPVEventDetailFromJson(json);

  static const toJsonFactory = _$PPVEventDetailToJson;
  Map<String, dynamic> toJson() => _$PPVEventDetailToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String productId;
  @JsonKey(name: 'edsProductId', includeIfNull: false, defaultValue: '')
  final String edsProductId;
  @JsonKey(name: 'nagraELKProductID', includeIfNull: false, defaultValue: '')
  final String nagraELKProductID;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'shortSynopsis', includeIfNull: false, defaultValue: '')
  final String shortSynopsis;
  @JsonKey(name: 'longSynopsis', includeIfNull: false, defaultValue: '')
  final String? longSynopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'minAge', includeIfNull: false)
  final int minAge;
  @JsonKey(name: 'price', includeIfNull: false)
  final double price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime eventStartTime;
  @JsonKey(name: 'eventEndTime', includeIfNull: false)
  final DateTime eventEndTime;
  @JsonKey(name: 'purchaseAvailableStartTime', includeIfNull: false)
  final DateTime purchaseAvailableStartTime;
  @JsonKey(name: 'purchaseAvailableEndTime', includeIfNull: false)
  final DateTime purchaseAvailableEndTime;
  @JsonKey(name: 'isPurchased', includeIfNull: false)
  final bool? isPurchased;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image> images;
  @JsonKey(name: 'videoQuality', includeIfNull: false, defaultValue: '')
  final String? videoQuality;
  @JsonKey(name: 'audioMixType', includeIfNull: false, defaultValue: '')
  final String? audioMixType;
  @JsonKey(
      name: 'captionLanguages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? captionLanguages;
  @JsonKey(
      name: 'supplementalAudioDescription',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? supplementalAudioDescription;
  @JsonKey(
      name: 'supplementalCaptionLanguage',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? supplementalCaptionLanguage;
  @JsonKey(
      name: 'originalLanguages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? originalLanguages;
  @JsonKey(
      name: 'signLanguages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? signLanguages;
  static const fromJsonFactory = _$PPVEventDetailFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PPVEventDetail &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.edsProductId, edsProductId) ||
                const DeepCollectionEquality()
                    .equals(other.edsProductId, edsProductId)) &&
            (identical(other.nagraELKProductID, nagraELKProductID) ||
                const DeepCollectionEquality()
                    .equals(other.nagraELKProductID, nagraELKProductID)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.shortSynopsis, shortSynopsis) ||
                const DeepCollectionEquality()
                    .equals(other.shortSynopsis, shortSynopsis)) &&
            (identical(other.longSynopsis, longSynopsis) ||
                const DeepCollectionEquality()
                    .equals(other.longSynopsis, longSynopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minAge, minAge) ||
                const DeepCollectionEquality().equals(other.minAge, minAge)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.eventStartTime, eventStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.eventEndTime, eventEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventEndTime, eventEndTime)) &&
            (identical(other.purchaseAvailableStartTime, purchaseAvailableStartTime) ||
                const DeepCollectionEquality().equals(
                    other.purchaseAvailableStartTime,
                    purchaseAvailableStartTime)) &&
            (identical(other.purchaseAvailableEndTime, purchaseAvailableEndTime) ||
                const DeepCollectionEquality().equals(
                    other.purchaseAvailableEndTime,
                    purchaseAvailableEndTime)) &&
            (identical(other.isPurchased, isPurchased) ||
                const DeepCollectionEquality()
                    .equals(other.isPurchased, isPurchased)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.videoQuality, videoQuality) ||
                const DeepCollectionEquality()
                    .equals(other.videoQuality, videoQuality)) &&
            (identical(other.audioMixType, audioMixType) ||
                const DeepCollectionEquality()
                    .equals(other.audioMixType, audioMixType)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.supplementalAudioDescription, supplementalAudioDescription) || const DeepCollectionEquality().equals(other.supplementalAudioDescription, supplementalAudioDescription)) &&
            (identical(other.supplementalCaptionLanguage, supplementalCaptionLanguage) || const DeepCollectionEquality().equals(other.supplementalCaptionLanguage, supplementalCaptionLanguage)) &&
            (identical(other.originalLanguages, originalLanguages) || const DeepCollectionEquality().equals(other.originalLanguages, originalLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(edsProductId) ^
      const DeepCollectionEquality().hash(nagraELKProductID) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(shortSynopsis) ^
      const DeepCollectionEquality().hash(longSynopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minAge) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(eventEndTime) ^
      const DeepCollectionEquality().hash(purchaseAvailableStartTime) ^
      const DeepCollectionEquality().hash(purchaseAvailableEndTime) ^
      const DeepCollectionEquality().hash(isPurchased) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(videoQuality) ^
      const DeepCollectionEquality().hash(audioMixType) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(supplementalAudioDescription) ^
      const DeepCollectionEquality().hash(supplementalCaptionLanguage) ^
      const DeepCollectionEquality().hash(originalLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      runtimeType.hashCode;
}

extension $PPVEventDetailExtension on PPVEventDetail {
  PPVEventDetail copyWith(
      {String? eventId,
      String? channelId,
      String? productId,
      String? edsProductId,
      String? nagraELKProductID,
      String? name,
      String? shortSynopsis,
      String? longSynopsis,
      bool? isAdult,
      int? minAge,
      double? price,
      String? priceDisplay,
      DateTime? eventStartTime,
      DateTime? eventEndTime,
      DateTime? purchaseAvailableStartTime,
      DateTime? purchaseAvailableEndTime,
      bool? isPurchased,
      DateTime? entitlementEnd,
      List<Image>? images,
      String? videoQuality,
      String? audioMixType,
      List<String>? captionLanguages,
      List<String>? supplementalAudioDescription,
      List<String>? supplementalCaptionLanguage,
      List<String>? originalLanguages,
      List<String>? signLanguages}) {
    return PPVEventDetail(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        productId: productId ?? this.productId,
        edsProductId: edsProductId ?? this.edsProductId,
        nagraELKProductID: nagraELKProductID ?? this.nagraELKProductID,
        name: name ?? this.name,
        shortSynopsis: shortSynopsis ?? this.shortSynopsis,
        longSynopsis: longSynopsis ?? this.longSynopsis,
        isAdult: isAdult ?? this.isAdult,
        minAge: minAge ?? this.minAge,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        eventEndTime: eventEndTime ?? this.eventEndTime,
        purchaseAvailableStartTime:
            purchaseAvailableStartTime ?? this.purchaseAvailableStartTime,
        purchaseAvailableEndTime:
            purchaseAvailableEndTime ?? this.purchaseAvailableEndTime,
        isPurchased: isPurchased ?? this.isPurchased,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        images: images ?? this.images,
        videoQuality: videoQuality ?? this.videoQuality,
        audioMixType: audioMixType ?? this.audioMixType,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        supplementalAudioDescription:
            supplementalAudioDescription ?? this.supplementalAudioDescription,
        supplementalCaptionLanguage:
            supplementalCaptionLanguage ?? this.supplementalCaptionLanguage,
        originalLanguages: originalLanguages ?? this.originalLanguages,
        signLanguages: signLanguages ?? this.signLanguages);
  }

  PPVEventDetail copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<String>? productId,
      Wrapped<String>? edsProductId,
      Wrapped<String>? nagraELKProductID,
      Wrapped<String>? name,
      Wrapped<String>? shortSynopsis,
      Wrapped<String?>? longSynopsis,
      Wrapped<bool>? isAdult,
      Wrapped<int>? minAge,
      Wrapped<double>? price,
      Wrapped<String?>? priceDisplay,
      Wrapped<DateTime>? eventStartTime,
      Wrapped<DateTime>? eventEndTime,
      Wrapped<DateTime>? purchaseAvailableStartTime,
      Wrapped<DateTime>? purchaseAvailableEndTime,
      Wrapped<bool?>? isPurchased,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<List<Image>>? images,
      Wrapped<String?>? videoQuality,
      Wrapped<String?>? audioMixType,
      Wrapped<List<String>?>? captionLanguages,
      Wrapped<List<String>?>? supplementalAudioDescription,
      Wrapped<List<String>?>? supplementalCaptionLanguage,
      Wrapped<List<String>?>? originalLanguages,
      Wrapped<List<String>?>? signLanguages}) {
    return PPVEventDetail(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        productId: (productId != null ? productId.value : this.productId),
        edsProductId:
            (edsProductId != null ? edsProductId.value : this.edsProductId),
        nagraELKProductID: (nagraELKProductID != null
            ? nagraELKProductID.value
            : this.nagraELKProductID),
        name: (name != null ? name.value : this.name),
        shortSynopsis:
            (shortSynopsis != null ? shortSynopsis.value : this.shortSynopsis),
        longSynopsis:
            (longSynopsis != null ? longSynopsis.value : this.longSynopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minAge: (minAge != null ? minAge.value : this.minAge),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        eventEndTime:
            (eventEndTime != null ? eventEndTime.value : this.eventEndTime),
        purchaseAvailableStartTime: (purchaseAvailableStartTime != null
            ? purchaseAvailableStartTime.value
            : this.purchaseAvailableStartTime),
        purchaseAvailableEndTime: (purchaseAvailableEndTime != null
            ? purchaseAvailableEndTime.value
            : this.purchaseAvailableEndTime),
        isPurchased:
            (isPurchased != null ? isPurchased.value : this.isPurchased),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        images: (images != null ? images.value : this.images),
        videoQuality:
            (videoQuality != null ? videoQuality.value : this.videoQuality),
        audioMixType:
            (audioMixType != null ? audioMixType.value : this.audioMixType),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        supplementalAudioDescription: (supplementalAudioDescription != null
            ? supplementalAudioDescription.value
            : this.supplementalAudioDescription),
        supplementalCaptionLanguage: (supplementalCaptionLanguage != null
            ? supplementalCaptionLanguage.value
            : this.supplementalCaptionLanguage),
        originalLanguages: (originalLanguages != null
            ? originalLanguages.value
            : this.originalLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages));
  }
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    required this.image,
    required this.type,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String image;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  static const fromJsonFactory = _$ImageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({String? image, String? type}) {
    return Image(image: image ?? this.image, type: type ?? this.type);
  }

  Image copyWithWrapped({Wrapped<String>? image, Wrapped<String>? type}) {
    return Image(
        image: (image != null ? image.value : this.image),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class ValidationErrorMessage {
  ValidationErrorMessage({
    required this.errors,
  });

  factory ValidationErrorMessage.fromJson(Map<String, dynamic> json) =>
      _$ValidationErrorMessageFromJson(json);

  static const toJsonFactory = _$ValidationErrorMessageToJson;
  Map<String, dynamic> toJson() => _$ValidationErrorMessageToJson(this);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ValidationErrorMessageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidationErrorMessage &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ValidationErrorMessageExtension on ValidationErrorMessage {
  ValidationErrorMessage copyWith({List<String>? errors}) {
    return ValidationErrorMessage(errors: errors ?? this.errors);
  }

  ValidationErrorMessage copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ValidationErrorMessage(
        errors: (errors != null ? errors.value : this.errors));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerAccessError {
  CustomerAccessError({
    this.errorMessage,
  });

  factory CustomerAccessError.fromJson(Map<String, dynamic> json) =>
      _$CustomerAccessErrorFromJson(json);

  static const toJsonFactory = _$CustomerAccessErrorToJson;
  Map<String, dynamic> toJson() => _$CustomerAccessErrorToJson(this);

  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  static const fromJsonFactory = _$CustomerAccessErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerAccessError &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errorMessage) ^ runtimeType.hashCode;
}

extension $CustomerAccessErrorExtension on CustomerAccessError {
  CustomerAccessError copyWith({String? errorMessage}) {
    return CustomerAccessError(errorMessage: errorMessage ?? this.errorMessage);
  }

  CustomerAccessError copyWithWrapped({Wrapped<String?>? errorMessage}) {
    return CustomerAccessError(
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    required this.details,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String details;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality().equals(other.details, details)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String>? details}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
