// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'qr_code_service.enums.swagger.dart' as enums;
export 'qr_code_service.enums.swagger.dart';

part 'qr_code_service.swagger.chopper.dart';
part 'qr_code_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class QrCodeService extends ChopperService {
  static QrCodeService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$QrCodeService(client);
    }

    final newClient = ChopperClient(
        services: [_$QrCodeService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$QrCodeService(newClient);
  }

  ///Generate QR code
  Future<chopper.Response<QrCodesResponse>> qrcodesPost({
    String? cacheControl,
    required QrCodesRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        QrCodesResponse, () => QrCodesResponse.fromJsonFactory);

    return _qrcodesPost(cacheControl: cacheControl, body: body);
  }

  ///Generate QR code
  @Post(
    path: '/qrcodes',
    optionalBody: true,
  )
  Future<chopper.Response<QrCodesResponse>> _qrcodesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodesRequest? body,
  });

  ///Generate QR code
  Future<chopper.Response<QrCodesResponse>> v2QrcodesPost({
    String? cacheControl,
    required QrCodesRequestV2? body,
  }) {
    generatedMapping.putIfAbsent(
        QrCodesResponse, () => QrCodesResponse.fromJsonFactory);

    return _v2QrcodesPost(cacheControl: cacheControl, body: body);
  }

  ///Generate QR code
  @Post(
    path: '/v2/qrcodes',
    optionalBody: true,
  )
  Future<chopper.Response<QrCodesResponse>> _v2QrcodesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodesRequestV2? body,
  });

  ///Generate QR code
  Future<chopper.Response<QrCodesResponse>> v3QrcodesPost({
    String? cacheControl,
    required QrCodesRequestV3? body,
  }) {
    generatedMapping.putIfAbsent(
        QrCodesResponse, () => QrCodesResponse.fromJsonFactory);

    return _v3QrcodesPost(cacheControl: cacheControl, body: body);
  }

  ///Generate QR code
  @Post(
    path: '/v3/qrcodes',
    optionalBody: true,
  )
  Future<chopper.Response<QrCodesResponse>> _v3QrcodesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodesRequestV3? body,
  });

  ///Short url to login page redirection
  ///@param tinyUrlCode
  Future<chopper.Response> qrcodesTinyurlTinyUrlCodeGet({
    required String? tinyUrlCode,
    String? cacheControl,
  }) {
    return _qrcodesTinyurlTinyUrlCodeGet(
        tinyUrlCode: tinyUrlCode, cacheControl: cacheControl);
  }

  ///Short url to login page redirection
  ///@param tinyUrlCode
  @Get(path: '/qrcodes/tinyurl/{tinyUrlCode}')
  Future<chopper.Response> _qrcodesTinyurlTinyUrlCodeGet({
    @Path('tinyUrlCode') required String? tinyUrlCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Short url to login page redirection
  ///@param tinyUrlCode
  Future<chopper.Response> v3QrcodesTinyurlTinyUrlCodeGet({
    required String? tinyUrlCode,
    String? cacheControl,
  }) {
    return _v3QrcodesTinyurlTinyUrlCodeGet(
        tinyUrlCode: tinyUrlCode, cacheControl: cacheControl);
  }

  ///Short url to login page redirection
  ///@param tinyUrlCode
  @Get(path: '/v3/qrcodes/tinyurl/{tinyUrlCode}')
  Future<chopper.Response> _v3QrcodesTinyurlTinyUrlCodeGet({
    @Path('tinyUrlCode') required String? tinyUrlCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get QR code state, subscribing for status change
  ///@param state
  ///@param status Status of qrcode
  Future<chopper.Response> qrcodesStateGet({
    required String? state,
    required enums.CheckStatus? status,
    String? cacheControl,
  }) {
    return _qrcodesStateGet(
        state: state,
        status: status?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Get QR code state, subscribing for status change
  ///@param state
  ///@param status Status of qrcode
  @Get(path: '/qrcodes/{state}')
  Future<chopper.Response> _qrcodesStateGet({
    @Path('state') required String? state,
    @Query('status') required String? status,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get QR code state
  ///@param state
  Future<chopper.Response> v2QrcodesStateGet({
    required String? state,
    String? cacheControl,
  }) {
    return _v2QrcodesStateGet(state: state, cacheControl: cacheControl);
  }

  ///Get QR code state
  ///@param state
  @Get(path: '/v2/qrcodes/{state}')
  Future<chopper.Response> _v2QrcodesStateGet({
    @Path('state') required String? state,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get QR code state
  ///@param state
  Future<chopper.Response> v3QrcodesStateGet({
    required String? state,
    String? cacheControl,
  }) {
    return _v3QrcodesStateGet(state: state, cacheControl: cacheControl);
  }

  ///Get QR code state
  ///@param state
  @Get(path: '/v3/qrcodes/{state}')
  Future<chopper.Response> _v3QrcodesStateGet({
    @Path('state') required String? state,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Authorize state with confirmation and authorization code provided
  Future<chopper.Response<String>> qrcodesConfirmationPost({
    String? cacheControl,
    required QrCodeConfirmationRequest? body,
  }) {
    return _qrcodesConfirmationPost(cacheControl: cacheControl, body: body);
  }

  ///Authorize state with confirmation and authorization code provided
  @Post(
    path: '/qrcodes/confirmation',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _qrcodesConfirmationPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodeConfirmationRequest? body,
  });

  ///Callback used after successfully authorize qrcode
  ///@param state
  ///@param code
  Future<chopper.Response> qrcodesConfirmationGet({
    required String? state,
    required String? code,
    String? cacheControl,
  }) {
    return _qrcodesConfirmationGet(
        state: state, code: code, cacheControl: cacheControl);
  }

  ///Callback used after successfully authorize qrcode
  ///@param state
  ///@param code
  @Get(path: '/qrcodes/confirmation')
  Future<chopper.Response> _qrcodesConfirmationGet({
    @Query('state') required String? state,
    @Query('code') required String? code,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Authorize state with confirmation and authorization code provided
  Future<chopper.Response<String>> v3QrcodesConfirmationPost({
    String? cacheControl,
    required QrCodeConfirmationRequest? body,
  }) {
    return _v3QrcodesConfirmationPost(cacheControl: cacheControl, body: body);
  }

  ///Authorize state with confirmation and authorization code provided
  @Post(
    path: '/v3/qrcodes/confirmation',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _v3QrcodesConfirmationPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodeConfirmationRequest? body,
  });

  ///Callback used after successfully authorize qrcode
  ///@param state
  ///@param authNToken
  Future<chopper.Response> v3QrcodesConfirmationGet({
    required String? state,
    required String? authNToken,
    String? cacheControl,
  }) {
    return _v3QrcodesConfirmationGet(
        state: state, authNToken: authNToken, cacheControl: cacheControl);
  }

  ///Callback used after successfully authorize qrcode
  ///@param state
  ///@param authNToken
  @Get(path: '/v3/qrcodes/confirmation')
  Future<chopper.Response> _v3QrcodesConfirmationGet({
    @Query('state') required String? state,
    @Query('authNToken') required String? authNToken,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set qrCode state to CANCELED
  ///@param state
  Future<chopper.Response<String>> v3QrcodesStateCancelPut({
    required String? state,
    String? cacheControl,
  }) {
    return _v3QrcodesStateCancelPut(state: state, cacheControl: cacheControl);
  }

  ///Set qrCode state to CANCELED
  ///@param state
  @Put(
    path: '/v3/qrcodes/{state}/cancel',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _v3QrcodesStateCancelPut({
    @Path('state') required String? state,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class QrCodesRequest {
  QrCodesRequest({
    required this.screenSize,
    required this.language,
    required this.deviceCode,
  });

  factory QrCodesRequest.fromJson(Map<String, dynamic> json) =>
      _$QrCodesRequestFromJson(json);

  static const toJsonFactory = _$QrCodesRequestToJson;
  Map<String, dynamic> toJson() => _$QrCodesRequestToJson(this);

  @JsonKey(name: 'screenSize', includeIfNull: false, defaultValue: '')
  final String screenSize;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String language;
  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String deviceCode;
  static const fromJsonFactory = _$QrCodesRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesRequest &&
            (identical(other.screenSize, screenSize) ||
                const DeepCollectionEquality()
                    .equals(other.screenSize, screenSize)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(screenSize) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(deviceCode) ^
      runtimeType.hashCode;
}

extension $QrCodesRequestExtension on QrCodesRequest {
  QrCodesRequest copyWith(
      {String? screenSize, String? language, String? deviceCode}) {
    return QrCodesRequest(
        screenSize: screenSize ?? this.screenSize,
        language: language ?? this.language,
        deviceCode: deviceCode ?? this.deviceCode);
  }

  QrCodesRequest copyWithWrapped(
      {Wrapped<String>? screenSize,
      Wrapped<String>? language,
      Wrapped<String>? deviceCode}) {
    return QrCodesRequest(
        screenSize: (screenSize != null ? screenSize.value : this.screenSize),
        language: (language != null ? language.value : this.language),
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesRequestV2 {
  QrCodesRequestV2({
    required this.screenSize,
    required this.language,
    required this.deviceCode,
    this.codeChallenge,
  });

  factory QrCodesRequestV2.fromJson(Map<String, dynamic> json) =>
      _$QrCodesRequestV2FromJson(json);

  static const toJsonFactory = _$QrCodesRequestV2ToJson;
  Map<String, dynamic> toJson() => _$QrCodesRequestV2ToJson(this);

  @JsonKey(name: 'screenSize', includeIfNull: false, defaultValue: '')
  final String screenSize;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String language;
  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String deviceCode;
  @JsonKey(name: 'codeChallenge', includeIfNull: false, defaultValue: '')
  final String? codeChallenge;
  static const fromJsonFactory = _$QrCodesRequestV2FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesRequestV2 &&
            (identical(other.screenSize, screenSize) ||
                const DeepCollectionEquality()
                    .equals(other.screenSize, screenSize)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.codeChallenge, codeChallenge) ||
                const DeepCollectionEquality()
                    .equals(other.codeChallenge, codeChallenge)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(screenSize) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(codeChallenge) ^
      runtimeType.hashCode;
}

extension $QrCodesRequestV2Extension on QrCodesRequestV2 {
  QrCodesRequestV2 copyWith(
      {String? screenSize,
      String? language,
      String? deviceCode,
      String? codeChallenge}) {
    return QrCodesRequestV2(
        screenSize: screenSize ?? this.screenSize,
        language: language ?? this.language,
        deviceCode: deviceCode ?? this.deviceCode,
        codeChallenge: codeChallenge ?? this.codeChallenge);
  }

  QrCodesRequestV2 copyWithWrapped(
      {Wrapped<String>? screenSize,
      Wrapped<String>? language,
      Wrapped<String>? deviceCode,
      Wrapped<String?>? codeChallenge}) {
    return QrCodesRequestV2(
        screenSize: (screenSize != null ? screenSize.value : this.screenSize),
        language: (language != null ? language.value : this.language),
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        codeChallenge:
            (codeChallenge != null ? codeChallenge.value : this.codeChallenge));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesRequestV3 {
  QrCodesRequestV3({
    required this.screenSize,
    required this.deviceId,
    required this.deviceName,
    this.language,
  });

  factory QrCodesRequestV3.fromJson(Map<String, dynamic> json) =>
      _$QrCodesRequestV3FromJson(json);

  static const toJsonFactory = _$QrCodesRequestV3ToJson;
  Map<String, dynamic> toJson() => _$QrCodesRequestV3ToJson(this);

  @JsonKey(name: 'screenSize', includeIfNull: false, defaultValue: '')
  final String screenSize;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String deviceName;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  static const fromJsonFactory = _$QrCodesRequestV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesRequestV3 &&
            (identical(other.screenSize, screenSize) ||
                const DeepCollectionEquality()
                    .equals(other.screenSize, screenSize)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(screenSize) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(language) ^
      runtimeType.hashCode;
}

extension $QrCodesRequestV3Extension on QrCodesRequestV3 {
  QrCodesRequestV3 copyWith(
      {String? screenSize,
      String? deviceId,
      String? deviceName,
      String? language}) {
    return QrCodesRequestV3(
        screenSize: screenSize ?? this.screenSize,
        deviceId: deviceId ?? this.deviceId,
        deviceName: deviceName ?? this.deviceName,
        language: language ?? this.language);
  }

  QrCodesRequestV3 copyWithWrapped(
      {Wrapped<String>? screenSize,
      Wrapped<String>? deviceId,
      Wrapped<String>? deviceName,
      Wrapped<String?>? language}) {
    return QrCodesRequestV3(
        screenSize: (screenSize != null ? screenSize.value : this.screenSize),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        language: (language != null ? language.value : this.language));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesAuthorizedResponse {
  QrCodesAuthorizedResponse({
    required this.state,
    required this.validityToken,
    required this.status,
    required this.authorizationCode,
  });

  factory QrCodesAuthorizedResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesAuthorizedResponseFromJson(json);

  static const toJsonFactory = _$QrCodesAuthorizedResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesAuthorizedResponseToJson(this);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String validityToken;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status status;
  @JsonKey(name: 'authorizationCode', includeIfNull: false, defaultValue: '')
  final String authorizationCode;
  static const fromJsonFactory = _$QrCodesAuthorizedResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesAuthorizedResponse &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.authorizationCode, authorizationCode) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationCode, authorizationCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(validityToken) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(authorizationCode) ^
      runtimeType.hashCode;
}

extension $QrCodesAuthorizedResponseExtension on QrCodesAuthorizedResponse {
  QrCodesAuthorizedResponse copyWith(
      {String? state,
      String? validityToken,
      enums.Status? status,
      String? authorizationCode}) {
    return QrCodesAuthorizedResponse(
        state: state ?? this.state,
        validityToken: validityToken ?? this.validityToken,
        status: status ?? this.status,
        authorizationCode: authorizationCode ?? this.authorizationCode);
  }

  QrCodesAuthorizedResponse copyWithWrapped(
      {Wrapped<String>? state,
      Wrapped<String>? validityToken,
      Wrapped<enums.Status>? status,
      Wrapped<String>? authorizationCode}) {
    return QrCodesAuthorizedResponse(
        state: (state != null ? state.value : this.state),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken),
        status: (status != null ? status.value : this.status),
        authorizationCode: (authorizationCode != null
            ? authorizationCode.value
            : this.authorizationCode));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesAuthorizedResponseV3 {
  QrCodesAuthorizedResponseV3({
    required this.state,
    required this.status,
    required this.authNToken,
  });

  factory QrCodesAuthorizedResponseV3.fromJson(Map<String, dynamic> json) =>
      _$QrCodesAuthorizedResponseV3FromJson(json);

  static const toJsonFactory = _$QrCodesAuthorizedResponseV3ToJson;
  Map<String, dynamic> toJson() => _$QrCodesAuthorizedResponseV3ToJson(this);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status status;
  @JsonKey(name: 'authNToken', includeIfNull: false, defaultValue: '')
  final String authNToken;
  static const fromJsonFactory = _$QrCodesAuthorizedResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesAuthorizedResponseV3 &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.authNToken, authNToken) ||
                const DeepCollectionEquality()
                    .equals(other.authNToken, authNToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(authNToken) ^
      runtimeType.hashCode;
}

extension $QrCodesAuthorizedResponseV3Extension on QrCodesAuthorizedResponseV3 {
  QrCodesAuthorizedResponseV3 copyWith(
      {String? state, enums.Status? status, String? authNToken}) {
    return QrCodesAuthorizedResponseV3(
        state: state ?? this.state,
        status: status ?? this.status,
        authNToken: authNToken ?? this.authNToken);
  }

  QrCodesAuthorizedResponseV3 copyWithWrapped(
      {Wrapped<String>? state,
      Wrapped<enums.Status>? status,
      Wrapped<String>? authNToken}) {
    return QrCodesAuthorizedResponseV3(
        state: (state != null ? state.value : this.state),
        status: (status != null ? status.value : this.status),
        authNToken: (authNToken != null ? authNToken.value : this.authNToken));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesConfirmationResponse {
  QrCodesConfirmationResponse({
    required this.state,
    required this.status,
    required this.confirmationCode,
  });

  factory QrCodesConfirmationResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesConfirmationResponseFromJson(json);

  static const toJsonFactory = _$QrCodesConfirmationResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesConfirmationResponseToJson(this);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status status;
  @JsonKey(name: 'confirmationCode', includeIfNull: false, defaultValue: '')
  final String confirmationCode;
  static const fromJsonFactory = _$QrCodesConfirmationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesConfirmationResponse &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.confirmationCode, confirmationCode) ||
                const DeepCollectionEquality()
                    .equals(other.confirmationCode, confirmationCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(confirmationCode) ^
      runtimeType.hashCode;
}

extension $QrCodesConfirmationResponseExtension on QrCodesConfirmationResponse {
  QrCodesConfirmationResponse copyWith(
      {String? state, enums.Status? status, String? confirmationCode}) {
    return QrCodesConfirmationResponse(
        state: state ?? this.state,
        status: status ?? this.status,
        confirmationCode: confirmationCode ?? this.confirmationCode);
  }

  QrCodesConfirmationResponse copyWithWrapped(
      {Wrapped<String>? state,
      Wrapped<enums.Status>? status,
      Wrapped<String>? confirmationCode}) {
    return QrCodesConfirmationResponse(
        state: (state != null ? state.value : this.state),
        status: (status != null ? status.value : this.status),
        confirmationCode: (confirmationCode != null
            ? confirmationCode.value
            : this.confirmationCode));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesValidResponse {
  QrCodesValidResponse({
    required this.state,
    required this.status,
  });

  factory QrCodesValidResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesValidResponseFromJson(json);

  static const toJsonFactory = _$QrCodesValidResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesValidResponseToJson(this);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status status;
  static const fromJsonFactory = _$QrCodesValidResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesValidResponse &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(status) ^
      runtimeType.hashCode;
}

extension $QrCodesValidResponseExtension on QrCodesValidResponse {
  QrCodesValidResponse copyWith({String? state, enums.Status? status}) {
    return QrCodesValidResponse(
        state: state ?? this.state, status: status ?? this.status);
  }

  QrCodesValidResponse copyWithWrapped(
      {Wrapped<String>? state, Wrapped<enums.Status>? status}) {
    return QrCodesValidResponse(
        state: (state != null ? state.value : this.state),
        status: (status != null ? status.value : this.status));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesStatusResponse {
  QrCodesStatusResponse({
    required this.status,
  });

  factory QrCodesStatusResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesStatusResponseFromJson(json);

  static const toJsonFactory = _$QrCodesStatusResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesStatusResponseToJson(this);

  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status status;
  static const fromJsonFactory = _$QrCodesStatusResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesStatusResponse &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^ runtimeType.hashCode;
}

extension $QrCodesStatusResponseExtension on QrCodesStatusResponse {
  QrCodesStatusResponse copyWith({enums.Status? status}) {
    return QrCodesStatusResponse(status: status ?? this.status);
  }

  QrCodesStatusResponse copyWithWrapped({Wrapped<enums.Status>? status}) {
    return QrCodesStatusResponse(
        status: (status != null ? status.value : this.status));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesResponse {
  QrCodesResponse({
    this.state,
    this.expiry,
    this.counterExpiresInSeconds,
    this.qrCode,
    this.tinyUrl,
  });

  factory QrCodesResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesResponseFromJson(json);

  static const toJsonFactory = _$QrCodesResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesResponseToJson(this);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'expiry', includeIfNull: false)
  final DateTime? expiry;
  @JsonKey(name: 'counterExpiresInSeconds', includeIfNull: false)
  final double? counterExpiresInSeconds;
  @JsonKey(name: 'qrCode', includeIfNull: false, defaultValue: '')
  final String? qrCode;
  @JsonKey(name: 'tinyUrl', includeIfNull: false, defaultValue: '')
  final String? tinyUrl;
  static const fromJsonFactory = _$QrCodesResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesResponse &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.expiry, expiry) ||
                const DeepCollectionEquality().equals(other.expiry, expiry)) &&
            (identical(
                    other.counterExpiresInSeconds, counterExpiresInSeconds) ||
                const DeepCollectionEquality().equals(
                    other.counterExpiresInSeconds, counterExpiresInSeconds)) &&
            (identical(other.qrCode, qrCode) ||
                const DeepCollectionEquality().equals(other.qrCode, qrCode)) &&
            (identical(other.tinyUrl, tinyUrl) ||
                const DeepCollectionEquality().equals(other.tinyUrl, tinyUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(expiry) ^
      const DeepCollectionEquality().hash(counterExpiresInSeconds) ^
      const DeepCollectionEquality().hash(qrCode) ^
      const DeepCollectionEquality().hash(tinyUrl) ^
      runtimeType.hashCode;
}

extension $QrCodesResponseExtension on QrCodesResponse {
  QrCodesResponse copyWith(
      {String? state,
      DateTime? expiry,
      double? counterExpiresInSeconds,
      String? qrCode,
      String? tinyUrl}) {
    return QrCodesResponse(
        state: state ?? this.state,
        expiry: expiry ?? this.expiry,
        counterExpiresInSeconds:
            counterExpiresInSeconds ?? this.counterExpiresInSeconds,
        qrCode: qrCode ?? this.qrCode,
        tinyUrl: tinyUrl ?? this.tinyUrl);
  }

  QrCodesResponse copyWithWrapped(
      {Wrapped<String?>? state,
      Wrapped<DateTime?>? expiry,
      Wrapped<double?>? counterExpiresInSeconds,
      Wrapped<String?>? qrCode,
      Wrapped<String?>? tinyUrl}) {
    return QrCodesResponse(
        state: (state != null ? state.value : this.state),
        expiry: (expiry != null ? expiry.value : this.expiry),
        counterExpiresInSeconds: (counterExpiresInSeconds != null
            ? counterExpiresInSeconds.value
            : this.counterExpiresInSeconds),
        qrCode: (qrCode != null ? qrCode.value : this.qrCode),
        tinyUrl: (tinyUrl != null ? tinyUrl.value : this.tinyUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodeConfirmationRequest {
  QrCodeConfirmationRequest({
    required this.state,
    required this.confirmationCode,
  });

  factory QrCodeConfirmationRequest.fromJson(Map<String, dynamic> json) =>
      _$QrCodeConfirmationRequestFromJson(json);

  static const toJsonFactory = _$QrCodeConfirmationRequestToJson;
  Map<String, dynamic> toJson() => _$QrCodeConfirmationRequestToJson(this);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(name: 'confirmationCode', includeIfNull: false, defaultValue: '')
  final String confirmationCode;
  static const fromJsonFactory = _$QrCodeConfirmationRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodeConfirmationRequest &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.confirmationCode, confirmationCode) ||
                const DeepCollectionEquality()
                    .equals(other.confirmationCode, confirmationCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(confirmationCode) ^
      runtimeType.hashCode;
}

extension $QrCodeConfirmationRequestExtension on QrCodeConfirmationRequest {
  QrCodeConfirmationRequest copyWith(
      {String? state, String? confirmationCode}) {
    return QrCodeConfirmationRequest(
        state: state ?? this.state,
        confirmationCode: confirmationCode ?? this.confirmationCode);
  }

  QrCodeConfirmationRequest copyWithWrapped(
      {Wrapped<String>? state, Wrapped<String>? confirmationCode}) {
    return QrCodeConfirmationRequest(
        state: (state != null ? state.value : this.state),
        confirmationCode: (confirmationCode != null
            ? confirmationCode.value
            : this.confirmationCode));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({KrakenError? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    this.allErrors,
    this.correlationId,
    this.details,
    required this.httpStatusCode,
    required this.message,
    this.statusCode,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(statusCode) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {List<String>? allErrors,
      String? correlationId,
      String? details,
      int? httpStatusCode,
      String? message,
      int? statusCode}) {
    return KrakenError(
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId,
        details: details ?? this.details,
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        message: message ?? this.message,
        statusCode: statusCode ?? this.statusCode);
  }

  KrakenError copyWithWrapped(
      {Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId,
      Wrapped<String?>? details,
      Wrapped<int>? httpStatusCode,
      Wrapped<String>? message,
      Wrapped<int?>? statusCode}) {
    return KrakenError(
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId),
        details: (details != null ? details.value : this.details),
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        message: (message != null ? message.value : this.message),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorMessage {
  ErrorMessage({
    this.details,
    required this.code,
    required this.message,
  });

  factory ErrorMessage.fromJson(Map<String, dynamic> json) =>
      _$ErrorMessageFromJson(json);

  static const toJsonFactory = _$ErrorMessageToJson;
  Map<String, dynamic> toJson() => _$ErrorMessageToJson(this);

  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'code', includeIfNull: false)
  final int code;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  static const fromJsonFactory = _$ErrorMessageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorMessage &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(message) ^
      runtimeType.hashCode;
}

extension $ErrorMessageExtension on ErrorMessage {
  ErrorMessage copyWith({String? details, int? code, String? message}) {
    return ErrorMessage(
        details: details ?? this.details,
        code: code ?? this.code,
        message: message ?? this.message);
  }

  ErrorMessage copyWithWrapped(
      {Wrapped<String?>? details,
      Wrapped<int>? code,
      Wrapped<String>? message}) {
    return ErrorMessage(
        details: (details != null ? details.value : this.details),
        code: (code != null ? code.value : this.code),
        message: (message != null ? message.value : this.message));
  }
}

String? statusToJson(enums.Status? status) {
  return status?.value;
}

enums.Status statusFromJson(
  Object? status, [
  enums.Status? defaultValue,
]) {
  return enums.Status.values.firstWhereOrNull((e) => e.value == status) ??
      defaultValue ??
      enums.Status.swaggerGeneratedUnknown;
}

List<String> statusListToJson(List<enums.Status>? status) {
  if (status == null) {
    return [];
  }

  return status.map((e) => e.value!).toList();
}

List<enums.Status> statusListFromJson(
  List? status, [
  List<enums.Status>? defaultValue,
]) {
  if (status == null) {
    return defaultValue ?? [];
  }

  return status.map((e) => statusFromJson(e.toString())).toList();
}

List<enums.Status>? statusNullableListFromJson(
  List? status, [
  List<enums.Status>? defaultValue,
]) {
  if (status == null) {
    return defaultValue;
  }

  return status.map((e) => statusFromJson(e.toString())).toList();
}

String? checkStatusToJson(enums.CheckStatus? checkStatus) {
  return checkStatus?.value;
}

enums.CheckStatus checkStatusFromJson(
  Object? checkStatus, [
  enums.CheckStatus? defaultValue,
]) {
  return enums.CheckStatus.values
          .firstWhereOrNull((e) => e.value == checkStatus) ??
      defaultValue ??
      enums.CheckStatus.swaggerGeneratedUnknown;
}

List<String> checkStatusListToJson(List<enums.CheckStatus>? checkStatus) {
  if (checkStatus == null) {
    return [];
  }

  return checkStatus.map((e) => e.value!).toList();
}

List<enums.CheckStatus> checkStatusListFromJson(
  List? checkStatus, [
  List<enums.CheckStatus>? defaultValue,
]) {
  if (checkStatus == null) {
    return defaultValue ?? [];
  }

  return checkStatus.map((e) => checkStatusFromJson(e.toString())).toList();
}

List<enums.CheckStatus>? checkStatusNullableListFromJson(
  List? checkStatus, [
  List<enums.CheckStatus>? defaultValue,
]) {
  if (checkStatus == null) {
    return defaultValue;
  }

  return checkStatus.map((e) => checkStatusFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
