// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'replay_catalog_service.enums.swagger.dart' as enums;
export 'replay_catalog_service.enums.swagger.dart';

part 'replay_catalog_service.swagger.chopper.dart';
part 'replay_catalog_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ReplayCatalogService extends ChopperService {
  static ReplayCatalogService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ReplayCatalogService(client);
    }

    final newClient = ChopperClient(
        services: [_$ReplayCatalogService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$ReplayCatalogService(newClient);
  }

  ///
  ///@param programId
  ///@param type
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param channelId Filters results by **channel**. Use **/networks** API to get valid values. Can't be used together with **providerId** parameter.
  ///@param providerId Filters results by **provider (network)**. Use **/networks** API to get valid values. Can't be used together with **channelId** parameter.
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param genreId Filters results by genre. Use **/genres** API to list available ones.
  ///@param onlyGoPlayable Set to true to **only** get the most relevant instances available for Go devices
  ///@param includeExternalAppReplay Set to false to exclude the most relevant instances replayable via the 3rd party Apps
  ///@param sort Results sorting criteria. When the value of is 'startTime' the same event is proposed as was used to sort on programs api
  ///@param CLAIMSTOKEN Customer Claims token
  Future<chopper.Response<MostRelevantInstanceResponse>>
      mostrelevantinstanceGet({
    required String? programId,
    required enums.MostrelevantinstanceGetType? type,
    required String? language,
    String? cityId,
    String? channelId,
    String? providerId,
    String? dayStart,
    enums.MostrelevantinstanceGetMaxRes? maxRes,
    String? profileId,
    String? genreId,
    bool? onlyGoPlayable,
    bool? includeExternalAppReplay,
    enums.MostrelevantinstanceGetSort? sort,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(MostRelevantInstanceResponse,
        () => MostRelevantInstanceResponse.fromJsonFactory);

    return _mostrelevantinstanceGet(
        programId: programId,
        type: type?.value?.toString(),
        language: language,
        cityId: cityId,
        channelId: channelId,
        providerId: providerId,
        dayStart: dayStart,
        maxRes: maxRes?.value?.toString(),
        profileId: profileId,
        genreId: genreId,
        onlyGoPlayable: onlyGoPlayable,
        includeExternalAppReplay: includeExternalAppReplay,
        sort: sort?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///
  ///@param programId
  ///@param type
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param channelId Filters results by **channel**. Use **/networks** API to get valid values. Can't be used together with **providerId** parameter.
  ///@param providerId Filters results by **provider (network)**. Use **/networks** API to get valid values. Can't be used together with **channelId** parameter.
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param genreId Filters results by genre. Use **/genres** API to list available ones.
  ///@param onlyGoPlayable Set to true to **only** get the most relevant instances available for Go devices
  ///@param includeExternalAppReplay Set to false to exclude the most relevant instances replayable via the 3rd party Apps
  ///@param sort Results sorting criteria. When the value of is 'startTime' the same event is proposed as was used to sort on programs api
  ///@param CLAIMSTOKEN Customer Claims token
  @Get(path: '/mostrelevantinstance')
  Future<chopper.Response<MostRelevantInstanceResponse>>
      _mostrelevantinstanceGet({
    @Query('programId') required String? programId,
    @Query('type') required String? type,
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('channelId') String? channelId,
    @Query('providerId') String? providerId,
    @Query('dayStart') String? dayStart,
    @Query('maxRes') String? maxRes,
    @Query('profileId') String? profileId,
    @Query('genreId') String? genreId,
    @Query('onlyGoPlayable') bool? onlyGoPlayable,
    @Query('includeExternalAppReplay') bool? includeExternalAppReplay,
    @Query('sort') String? sort,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  Future<chopper.Response<ReplayChannelResponse>> channelsGet({
    required String? language,
    String? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayChannelResponse, () => ReplayChannelResponse.fromJsonFactory);

    return _channelsGet(
        language: language, cityId: cityId, cacheControl: cacheControl);
  }

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  @Get(path: '/channels')
  Future<chopper.Response<ReplayChannelResponse>> _channelsGet({
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param customerId
  ///@param entitled Set to true to **only** get the networks customer is entitled to
  ///@param onlyGoPlayable Set to true to **only** get the networks available for Go devices
  ///@param X-Cus Household ID
  ///@param X-Dev Device ID
  ///@param X-Entitlements-Token Token that contains encrypted customer's entitlement data
  Future<chopper.Response<ReplayNetworksResponse>> networksGet({
    required String? language,
    String? cityId,
    enums.NetworksGetMaxRes? maxRes,
    String? customerId,
    bool? entitled,
    bool? onlyGoPlayable,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayNetworksResponse, () => ReplayNetworksResponse.fromJsonFactory);

    return _networksGet(
        language: language,
        cityId: cityId,
        maxRes: maxRes?.value?.toString(),
        customerId: customerId,
        entitled: entitled,
        onlyGoPlayable: onlyGoPlayable,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param customerId
  ///@param entitled Set to true to **only** get the networks customer is entitled to
  ///@param onlyGoPlayable Set to true to **only** get the networks available for Go devices
  ///@param X-Cus Household ID
  ///@param X-Dev Device ID
  ///@param X-Entitlements-Token Token that contains encrypted customer's entitlement data
  @Get(path: '/networks')
  Future<chopper.Response<ReplayNetworksResponse>> _networksGet({
    @Query('language')
        required String? language,
    @Query('cityId')
        String? cityId,
    @Query('maxRes')
        String? maxRes,
    @Query('customerId')
        String? customerId,
    @Query('entitled')
        bool? entitled,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param channelId Filters programs by channel
  ///@param providerId Filters programs by network (provider)
  ///@param page
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight. Can not be used together with **start** parameter.    **NOTE**: This parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param start Filters results by date/time: starting from provided value until now. Can not be used together with **dayStart** parameter.
  ///@param sort Results sorting criteria. **NOTE**: **dayStart** parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param genreId Filters programs by genre. Use **/genres** API to list available ones.
  ///@param onlyGoPlayable Set to true to **only** get the programs available for Go devices
  ///@param includeExternalAppReplay Set to false to exclude the programs replayable via the 3rd party Apps
  ///@param CLAIMSTOKEN Customer Claims token
  Future<chopper.Response<ReplayProgramsResponse>> programsGet({
    String? channelId,
    String? providerId,
    int? page,
    String? dayStart,
    String? start,
    enums.ProgramsGetSort? sort,
    String? profileId,
    required String? language,
    String? cityId,
    enums.ProgramsGetMaxRes? maxRes,
    String? genreId,
    bool? onlyGoPlayable,
    bool? includeExternalAppReplay,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayProgramsResponse, () => ReplayProgramsResponse.fromJsonFactory);

    return _programsGet(
        channelId: channelId,
        providerId: providerId,
        page: page,
        dayStart: dayStart,
        start: start,
        sort: sort?.value?.toString(),
        profileId: profileId,
        language: language,
        cityId: cityId,
        maxRes: maxRes?.value?.toString(),
        genreId: genreId,
        onlyGoPlayable: onlyGoPlayable,
        includeExternalAppReplay: includeExternalAppReplay,
        cacheControl: cacheControl);
  }

  ///
  ///@param channelId Filters programs by channel
  ///@param providerId Filters programs by network (provider)
  ///@param page
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight. Can not be used together with **start** parameter.    **NOTE**: This parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param start Filters results by date/time: starting from provided value until now. Can not be used together with **dayStart** parameter.
  ///@param sort Results sorting criteria. **NOTE**: **dayStart** parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param genreId Filters programs by genre. Use **/genres** API to list available ones.
  ///@param onlyGoPlayable Set to true to **only** get the programs available for Go devices
  ///@param includeExternalAppReplay Set to false to exclude the programs replayable via the 3rd party Apps
  ///@param CLAIMSTOKEN Customer Claims token
  @Get(path: '/programs')
  Future<chopper.Response<ReplayProgramsResponse>> _programsGet({
    @Query('channelId') String? channelId,
    @Query('providerId') String? providerId,
    @Query('page') int? page,
    @Query('dayStart') String? dayStart,
    @Query('start') String? start,
    @Query('sort') String? sort,
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('maxRes') String? maxRes,
    @Query('genreId') String? genreId,
    @Query('onlyGoPlayable') bool? onlyGoPlayable,
    @Query('includeExternalAppReplay') bool? includeExternalAppReplay,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param onlyGoPlayable Set to true to **only** get programs available for Go devices
  Future<chopper.Response<ReplayProgramsResponse>> programsContextualMenuGet({
    String? profileId,
    required String? language,
    String? cityId,
    enums.ProgramsContextualMenuGetMaxRes? maxRes,
    bool? onlyGoPlayable,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayProgramsResponse, () => ReplayProgramsResponse.fromJsonFactory);

    return _programsContextualMenuGet(
        profileId: profileId,
        language: language,
        cityId: cityId,
        maxRes: maxRes?.value?.toString(),
        onlyGoPlayable: onlyGoPlayable,
        cacheControl: cacheControl);
  }

  ///
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param onlyGoPlayable Set to true to **only** get programs available for Go devices
  @Get(path: '/programs/contextualMenu')
  Future<chopper.Response<ReplayProgramsResponse>> _programsContextualMenuGet({
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('maxRes') String? maxRes,
    @Query('onlyGoPlayable') bool? onlyGoPlayable,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  Future<chopper.Response<GenresResponse>> genresGet({
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GenresResponse, () => GenresResponse.fromJsonFactory);

    return _genresGet(language: language, cacheControl: cacheControl);
  }

  ///
  ///@param language
  @Get(path: '/genres')
  Future<chopper.Response<GenresResponse>> _genresGet({
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  Future<chopper.Response<GenresV2Response>> v2GenresGet({
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GenresV2Response, () => GenresV2Response.fromJsonFactory);

    return _v2GenresGet(language: language, cacheControl: cacheControl);
  }

  ///
  ///@param language
  @Get(path: '/v2/genres')
  Future<chopper.Response<GenresV2Response>> _v2GenresGet({
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class MostRelevantInstanceResponse {
  MostRelevantInstanceResponse({
    required this.mostRelevantInstances,
    this.bookmarkedInstance,
  });

  factory MostRelevantInstanceResponse.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantInstanceResponseFromJson(json);

  static const toJsonFactory = _$MostRelevantInstanceResponseToJson;
  Map<String, dynamic> toJson() => _$MostRelevantInstanceResponseToJson(this);

  @JsonKey(
      name: 'mostRelevantInstances',
      includeIfNull: false,
      defaultValue: <InstanceOfProgram>[])
  final List<InstanceOfProgram> mostRelevantInstances;
  @JsonKey(name: 'bookmarkedInstance', includeIfNull: false)
  final Bookmark? bookmarkedInstance;
  static const fromJsonFactory = _$MostRelevantInstanceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantInstanceResponse &&
            (identical(other.mostRelevantInstances, mostRelevantInstances) ||
                const DeepCollectionEquality().equals(
                    other.mostRelevantInstances, mostRelevantInstances)) &&
            (identical(other.bookmarkedInstance, bookmarkedInstance) ||
                const DeepCollectionEquality()
                    .equals(other.bookmarkedInstance, bookmarkedInstance)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mostRelevantInstances) ^
      const DeepCollectionEquality().hash(bookmarkedInstance) ^
      runtimeType.hashCode;
}

extension $MostRelevantInstanceResponseExtension
    on MostRelevantInstanceResponse {
  MostRelevantInstanceResponse copyWith(
      {List<InstanceOfProgram>? mostRelevantInstances,
      Bookmark? bookmarkedInstance}) {
    return MostRelevantInstanceResponse(
        mostRelevantInstances:
            mostRelevantInstances ?? this.mostRelevantInstances,
        bookmarkedInstance: bookmarkedInstance ?? this.bookmarkedInstance);
  }

  MostRelevantInstanceResponse copyWithWrapped(
      {Wrapped<List<InstanceOfProgram>>? mostRelevantInstances,
      Wrapped<Bookmark?>? bookmarkedInstance}) {
    return MostRelevantInstanceResponse(
        mostRelevantInstances: (mostRelevantInstances != null
            ? mostRelevantInstances.value
            : this.mostRelevantInstances),
        bookmarkedInstance: (bookmarkedInstance != null
            ? bookmarkedInstance.value
            : this.bookmarkedInstance));
  }
}

@JsonSerializable(explicitToJson: true)
class GenresResponse {
  GenresResponse({
    required this.genres,
  });

  factory GenresResponse.fromJson(Map<String, dynamic> json) =>
      _$GenresResponseFromJson(json);

  static const toJsonFactory = _$GenresResponseToJson;
  Map<String, dynamic> toJson() => _$GenresResponseToJson(this);

  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <Genre>[])
  final List<Genre> genres;
  static const fromJsonFactory = _$GenresResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenresResponse &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(genres) ^ runtimeType.hashCode;
}

extension $GenresResponseExtension on GenresResponse {
  GenresResponse copyWith({List<Genre>? genres}) {
    return GenresResponse(genres: genres ?? this.genres);
  }

  GenresResponse copyWithWrapped({Wrapped<List<Genre>>? genres}) {
    return GenresResponse(
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    required this.genreId,
    required this.name,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @JsonKey(name: 'genreId', includeIfNull: false, defaultValue: '')
  final String genreId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$GenreFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.genreId, genreId) ||
                const DeepCollectionEquality()
                    .equals(other.genreId, genreId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(genreId) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith({String? genreId, String? name}) {
    return Genre(genreId: genreId ?? this.genreId, name: name ?? this.name);
  }

  Genre copyWithWrapped({Wrapped<String>? genreId, Wrapped<String>? name}) {
    return Genre(
        genreId: (genreId != null ? genreId.value : this.genreId),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class GenresV2Response {
  GenresV2Response({
    required this.genres,
  });

  factory GenresV2Response.fromJson(Map<String, dynamic> json) =>
      _$GenresV2ResponseFromJson(json);

  static const toJsonFactory = _$GenresV2ResponseToJson;
  Map<String, dynamic> toJson() => _$GenresV2ResponseToJson(this);

  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <GenreV2>[])
  final List<GenreV2> genres;
  static const fromJsonFactory = _$GenresV2ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenresV2Response &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(genres) ^ runtimeType.hashCode;
}

extension $GenresV2ResponseExtension on GenresV2Response {
  GenresV2Response copyWith({List<GenreV2>? genres}) {
    return GenresV2Response(genres: genres ?? this.genres);
  }

  GenresV2Response copyWithWrapped({Wrapped<List<GenreV2>>? genres}) {
    return GenresV2Response(
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class GenreV2 {
  GenreV2({
    required this.genreId,
    required this.name,
    this.subgenres,
  });

  factory GenreV2.fromJson(Map<String, dynamic> json) =>
      _$GenreV2FromJson(json);

  static const toJsonFactory = _$GenreV2ToJson;
  Map<String, dynamic> toJson() => _$GenreV2ToJson(this);

  @JsonKey(name: 'genreId', includeIfNull: false, defaultValue: '')
  final String genreId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'subgenres', includeIfNull: false, defaultValue: <Genre>[])
  final List<Genre>? subgenres;
  static const fromJsonFactory = _$GenreV2FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenreV2 &&
            (identical(other.genreId, genreId) ||
                const DeepCollectionEquality()
                    .equals(other.genreId, genreId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.subgenres, subgenres) ||
                const DeepCollectionEquality()
                    .equals(other.subgenres, subgenres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(genreId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(subgenres) ^
      runtimeType.hashCode;
}

extension $GenreV2Extension on GenreV2 {
  GenreV2 copyWith({String? genreId, String? name, List<Genre>? subgenres}) {
    return GenreV2(
        genreId: genreId ?? this.genreId,
        name: name ?? this.name,
        subgenres: subgenres ?? this.subgenres);
  }

  GenreV2 copyWithWrapped(
      {Wrapped<String>? genreId,
      Wrapped<String>? name,
      Wrapped<List<Genre>?>? subgenres}) {
    return GenreV2(
        genreId: (genreId != null ? genreId.value : this.genreId),
        name: (name != null ? name.value : this.name),
        subgenres: (subgenres != null ? subgenres.value : this.subgenres));
  }
}

@JsonSerializable(explicitToJson: true)
class InstanceOfProgram {
  InstanceOfProgram({
    required this.eventId,
    required this.channelId,
    required this.eventStartTime,
    required this.isAdult,
    required this.replayContainsAdult,
    required this.replayMinAge,
    required this.isGoPlayable,
    required this.goPlayableViaExternalApp,
    required this.externalAppUrls,
    this.imageVersion,
  });

  factory InstanceOfProgram.fromJson(Map<String, dynamic> json) =>
      _$InstanceOfProgramFromJson(json);

  static const toJsonFactory = _$InstanceOfProgramToJson;
  Map<String, dynamic> toJson() => _$InstanceOfProgramToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime eventStartTime;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int replayMinAge;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool goPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrl>[])
  final List<ExternalAppUrl> externalAppUrls;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$InstanceOfProgramFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InstanceOfProgram &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventStartTime, eventStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) ||
                const DeepCollectionEquality()
                    .equals(other.externalAppUrls, externalAppUrls)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $InstanceOfProgramExtension on InstanceOfProgram {
  InstanceOfProgram copyWith(
      {String? eventId,
      String? channelId,
      DateTime? eventStartTime,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge,
      bool? isGoPlayable,
      bool? goPlayableViaExternalApp,
      List<ExternalAppUrl>? externalAppUrls,
      String? imageVersion}) {
    return InstanceOfProgram(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  InstanceOfProgram copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<DateTime>? eventStartTime,
      Wrapped<bool>? isAdult,
      Wrapped<bool>? replayContainsAdult,
      Wrapped<int>? replayMinAge,
      Wrapped<bool>? isGoPlayable,
      Wrapped<bool>? goPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrl>>? externalAppUrls,
      Wrapped<String?>? imageVersion}) {
    return InstanceOfProgram(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class ExternalAppUrl {
  ExternalAppUrl({
    required this.deviceCode,
    required this.url,
  });

  factory ExternalAppUrl.fromJson(Map<String, dynamic> json) =>
      _$ExternalAppUrlFromJson(json);

  static const toJsonFactory = _$ExternalAppUrlToJson;
  Map<String, dynamic> toJson() => _$ExternalAppUrlToJson(this);

  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String deviceCode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$ExternalAppUrlFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ExternalAppUrl &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ExternalAppUrlExtension on ExternalAppUrl {
  ExternalAppUrl copyWith({String? deviceCode, String? url}) {
    return ExternalAppUrl(
        deviceCode: deviceCode ?? this.deviceCode, url: url ?? this.url);
  }

  ExternalAppUrl copyWithWrapped(
      {Wrapped<String>? deviceCode, Wrapped<String>? url}) {
    return ExternalAppUrl(
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class Bookmark {
  Bookmark({
    required this.position,
    required this.duration,
    this.eventId,
    required this.isGoPlayable,
  });

  factory Bookmark.fromJson(Map<String, dynamic> json) =>
      _$BookmarkFromJson(json);

  static const toJsonFactory = _$BookmarkToJson;
  Map<String, dynamic> toJson() => _$BookmarkToJson(this);

  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  static const fromJsonFactory = _$BookmarkFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Bookmark &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      runtimeType.hashCode;
}

extension $BookmarkExtension on Bookmark {
  Bookmark copyWith(
      {int? position, int? duration, String? eventId, bool? isGoPlayable}) {
    return Bookmark(
        position: position ?? this.position,
        duration: duration ?? this.duration,
        eventId: eventId ?? this.eventId,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable);
  }

  Bookmark copyWithWrapped(
      {Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<String?>? eventId,
      Wrapped<bool>? isGoPlayable}) {
    return Bookmark(
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        eventId: (eventId != null ? eventId.value : this.eventId),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayChannelResponse {
  ReplayChannelResponse({
    required this.replayChannels,
  });

  factory ReplayChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayChannelResponseFromJson(json);

  static const toJsonFactory = _$ReplayChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayChannelResponseToJson(this);

  @JsonKey(
      name: 'replayChannels',
      includeIfNull: false,
      defaultValue: <ReplayChannel>[])
  final List<ReplayChannel> replayChannels;
  static const fromJsonFactory = _$ReplayChannelResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayChannelResponse &&
            (identical(other.replayChannels, replayChannels) ||
                const DeepCollectionEquality()
                    .equals(other.replayChannels, replayChannels)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayChannels) ^
      runtimeType.hashCode;
}

extension $ReplayChannelResponseExtension on ReplayChannelResponse {
  ReplayChannelResponse copyWith({List<ReplayChannel>? replayChannels}) {
    return ReplayChannelResponse(
        replayChannels: replayChannels ?? this.replayChannels);
  }

  ReplayChannelResponse copyWithWrapped(
      {Wrapped<List<ReplayChannel>>? replayChannels}) {
    return ReplayChannelResponse(
        replayChannels: (replayChannels != null
            ? replayChannels.value
            : this.replayChannels));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayChannel {
  ReplayChannel({
    required this.id,
    required this.name,
    this.logo,
  });

  factory ReplayChannel.fromJson(Map<String, dynamic> json) =>
      _$ReplayChannelFromJson(json);

  static const toJsonFactory = _$ReplayChannelToJson;
  Map<String, dynamic> toJson() => _$ReplayChannelToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'logo', includeIfNull: false, defaultValue: '')
  final String? logo;
  static const fromJsonFactory = _$ReplayChannelFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayChannel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(logo) ^
      runtimeType.hashCode;
}

extension $ReplayChannelExtension on ReplayChannel {
  ReplayChannel copyWith({String? id, String? name, String? logo}) {
    return ReplayChannel(
        id: id ?? this.id, name: name ?? this.name, logo: logo ?? this.logo);
  }

  ReplayChannel copyWithWrapped(
      {Wrapped<String>? id, Wrapped<String>? name, Wrapped<String?>? logo}) {
    return ReplayChannel(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        logo: (logo != null ? logo.value : this.logo));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayNetworksResponse {
  ReplayNetworksResponse({
    required this.replayNetworks,
  });

  factory ReplayNetworksResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayNetworksResponseFromJson(json);

  static const toJsonFactory = _$ReplayNetworksResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayNetworksResponseToJson(this);

  @JsonKey(
      name: 'replayNetworks',
      includeIfNull: false,
      defaultValue: <ReplayNetwork>[])
  final List<ReplayNetwork> replayNetworks;
  static const fromJsonFactory = _$ReplayNetworksResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayNetworksResponse &&
            (identical(other.replayNetworks, replayNetworks) ||
                const DeepCollectionEquality()
                    .equals(other.replayNetworks, replayNetworks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayNetworks) ^
      runtimeType.hashCode;
}

extension $ReplayNetworksResponseExtension on ReplayNetworksResponse {
  ReplayNetworksResponse copyWith({List<ReplayNetwork>? replayNetworks}) {
    return ReplayNetworksResponse(
        replayNetworks: replayNetworks ?? this.replayNetworks);
  }

  ReplayNetworksResponse copyWithWrapped(
      {Wrapped<List<ReplayNetwork>>? replayNetworks}) {
    return ReplayNetworksResponse(
        replayNetworks: (replayNetworks != null
            ? replayNetworks.value
            : this.replayNetworks));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayNetwork {
  ReplayNetwork({
    required this.id,
    required this.name,
    required this.replayDays,
    this.backgroundImage,
    this.logo,
    this.dualBrandingLogo,
    required this.type,
    this.entitlement,
    required this.isGoPlayable,
  });

  factory ReplayNetwork.fromJson(Map<String, dynamic> json) =>
      _$ReplayNetworkFromJson(json);

  static const toJsonFactory = _$ReplayNetworkToJson;
  Map<String, dynamic> toJson() => _$ReplayNetworkToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'replayDays', includeIfNull: false)
  final int replayDays;
  @JsonKey(name: 'backgroundImage', includeIfNull: false, defaultValue: '')
  final String? backgroundImage;
  @JsonKey(name: 'logo', includeIfNull: false, defaultValue: '')
  final String? logo;
  @JsonKey(name: 'dualBrandingLogo', includeIfNull: false, defaultValue: '')
  final String? dualBrandingLogo;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: replayNetworkTypeToJson,
    fromJson: replayNetworkTypeFromJson,
  )
  final enums.ReplayNetworkType type;
  @JsonKey(
    name: 'entitlement',
    includeIfNull: false,
    toJson: replayNetworkEntitlementToJson,
    fromJson: replayNetworkEntitlementFromJson,
  )
  final enums.ReplayNetworkEntitlement? entitlement;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  static const fromJsonFactory = _$ReplayNetworkFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayNetwork &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.replayDays, replayDays) ||
                const DeepCollectionEquality()
                    .equals(other.replayDays, replayDays)) &&
            (identical(other.backgroundImage, backgroundImage) ||
                const DeepCollectionEquality()
                    .equals(other.backgroundImage, backgroundImage)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)) &&
            (identical(other.dualBrandingLogo, dualBrandingLogo) ||
                const DeepCollectionEquality()
                    .equals(other.dualBrandingLogo, dualBrandingLogo)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlement, entitlement) ||
                const DeepCollectionEquality()
                    .equals(other.entitlement, entitlement)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(replayDays) ^
      const DeepCollectionEquality().hash(backgroundImage) ^
      const DeepCollectionEquality().hash(logo) ^
      const DeepCollectionEquality().hash(dualBrandingLogo) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlement) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      runtimeType.hashCode;
}

extension $ReplayNetworkExtension on ReplayNetwork {
  ReplayNetwork copyWith(
      {String? id,
      String? name,
      int? replayDays,
      String? backgroundImage,
      String? logo,
      String? dualBrandingLogo,
      enums.ReplayNetworkType? type,
      enums.ReplayNetworkEntitlement? entitlement,
      bool? isGoPlayable}) {
    return ReplayNetwork(
        id: id ?? this.id,
        name: name ?? this.name,
        replayDays: replayDays ?? this.replayDays,
        backgroundImage: backgroundImage ?? this.backgroundImage,
        logo: logo ?? this.logo,
        dualBrandingLogo: dualBrandingLogo ?? this.dualBrandingLogo,
        type: type ?? this.type,
        entitlement: entitlement ?? this.entitlement,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable);
  }

  ReplayNetwork copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<int>? replayDays,
      Wrapped<String?>? backgroundImage,
      Wrapped<String?>? logo,
      Wrapped<String?>? dualBrandingLogo,
      Wrapped<enums.ReplayNetworkType>? type,
      Wrapped<enums.ReplayNetworkEntitlement?>? entitlement,
      Wrapped<bool>? isGoPlayable}) {
    return ReplayNetwork(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        replayDays: (replayDays != null ? replayDays.value : this.replayDays),
        backgroundImage: (backgroundImage != null
            ? backgroundImage.value
            : this.backgroundImage),
        logo: (logo != null ? logo.value : this.logo),
        dualBrandingLogo: (dualBrandingLogo != null
            ? dualBrandingLogo.value
            : this.dualBrandingLogo),
        type: (type != null ? type.value : this.type),
        entitlement:
            (entitlement != null ? entitlement.value : this.entitlement),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgramsResponse {
  ReplayProgramsResponse({
    this.promotion,
    this.aspots,
    required this.replayPrograms,
    required this.page,
    required this.isLastPage,
  });

  factory ReplayProgramsResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayProgramsResponseFromJson(json);

  static const toJsonFactory = _$ReplayProgramsResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayProgramsResponseToJson(this);

  @JsonKey(name: 'promotion', includeIfNull: false)
  final ReplayProgramsResponse$Promotion? promotion;
  @JsonKey(name: 'aspots', includeIfNull: false, defaultValue: <ReplayAspot>[])
  final List<ReplayAspot>? aspots;
  @JsonKey(
      name: 'replayPrograms',
      includeIfNull: false,
      defaultValue: <ReplayProgram>[])
  final List<ReplayProgram> replayPrograms;
  @JsonKey(name: 'page', includeIfNull: false)
  final int page;
  @JsonKey(name: 'isLastPage', includeIfNull: false)
  final bool isLastPage;
  static const fromJsonFactory = _$ReplayProgramsResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgramsResponse &&
            (identical(other.promotion, promotion) ||
                const DeepCollectionEquality()
                    .equals(other.promotion, promotion)) &&
            (identical(other.aspots, aspots) ||
                const DeepCollectionEquality().equals(other.aspots, aspots)) &&
            (identical(other.replayPrograms, replayPrograms) ||
                const DeepCollectionEquality()
                    .equals(other.replayPrograms, replayPrograms)) &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)) &&
            (identical(other.isLastPage, isLastPage) ||
                const DeepCollectionEquality()
                    .equals(other.isLastPage, isLastPage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(promotion) ^
      const DeepCollectionEquality().hash(aspots) ^
      const DeepCollectionEquality().hash(replayPrograms) ^
      const DeepCollectionEquality().hash(page) ^
      const DeepCollectionEquality().hash(isLastPage) ^
      runtimeType.hashCode;
}

extension $ReplayProgramsResponseExtension on ReplayProgramsResponse {
  ReplayProgramsResponse copyWith(
      {ReplayProgramsResponse$Promotion? promotion,
      List<ReplayAspot>? aspots,
      List<ReplayProgram>? replayPrograms,
      int? page,
      bool? isLastPage}) {
    return ReplayProgramsResponse(
        promotion: promotion ?? this.promotion,
        aspots: aspots ?? this.aspots,
        replayPrograms: replayPrograms ?? this.replayPrograms,
        page: page ?? this.page,
        isLastPage: isLastPage ?? this.isLastPage);
  }

  ReplayProgramsResponse copyWithWrapped(
      {Wrapped<ReplayProgramsResponse$Promotion?>? promotion,
      Wrapped<List<ReplayAspot>?>? aspots,
      Wrapped<List<ReplayProgram>>? replayPrograms,
      Wrapped<int>? page,
      Wrapped<bool>? isLastPage}) {
    return ReplayProgramsResponse(
        promotion: (promotion != null ? promotion.value : this.promotion),
        aspots: (aspots != null ? aspots.value : this.aspots),
        replayPrograms: (replayPrograms != null
            ? replayPrograms.value
            : this.replayPrograms),
        page: (page != null ? page.value : this.page),
        isLastPage: (isLastPage != null ? isLastPage.value : this.isLastPage));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgram {
  ReplayProgram({
    required this.id,
    required this.name,
    required this.type,
    required this.channelId,
    this.providerId,
    this.mergedId,
    required this.isAdult,
    this.image,
    this.imageVersion,
    this.bookmark,
    required this.isGoPlayable,
    required this.goPlayableViaExternalApp,
    this.episodeNumber,
    this.seasonNumber,
    this.mepSeriesFinale,
    this.isPremiereAirings,
  });

  factory ReplayProgram.fromJson(Map<String, dynamic> json) =>
      _$ReplayProgramFromJson(json);

  static const toJsonFactory = _$ReplayProgramToJson;
  Map<String, dynamic> toJson() => _$ReplayProgramToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: replayProgramTypeToJson,
    fromJson: replayProgramTypeFromJson,
  )
  final enums.ReplayProgramType type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final Bookmark? bookmark;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool goPlayableViaExternalApp;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final DateTime? mepSeriesFinale;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  static const fromJsonFactory = _$ReplayProgramFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgram &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.providerId, providerId) ||
                const DeepCollectionEquality()
                    .equals(other.providerId, providerId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.isPremiereAirings, isPremiereAirings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      runtimeType.hashCode;
}

extension $ReplayProgramExtension on ReplayProgram {
  ReplayProgram copyWith(
      {String? id,
      String? name,
      enums.ReplayProgramType? type,
      String? channelId,
      String? providerId,
      String? mergedId,
      bool? isAdult,
      String? image,
      String? imageVersion,
      Bookmark? bookmark,
      bool? isGoPlayable,
      bool? goPlayableViaExternalApp,
      int? episodeNumber,
      int? seasonNumber,
      DateTime? mepSeriesFinale,
      bool? isPremiereAirings}) {
    return ReplayProgram(
        id: id ?? this.id,
        name: name ?? this.name,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        providerId: providerId ?? this.providerId,
        mergedId: mergedId ?? this.mergedId,
        isAdult: isAdult ?? this.isAdult,
        image: image ?? this.image,
        imageVersion: imageVersion ?? this.imageVersion,
        bookmark: bookmark ?? this.bookmark,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings);
  }

  ReplayProgram copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<enums.ReplayProgramType>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? providerId,
      Wrapped<String?>? mergedId,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? image,
      Wrapped<String?>? imageVersion,
      Wrapped<Bookmark?>? bookmark,
      Wrapped<bool>? isGoPlayable,
      Wrapped<bool>? goPlayableViaExternalApp,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<DateTime?>? mepSeriesFinale,
      Wrapped<bool?>? isPremiereAirings}) {
    return ReplayProgram(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        providerId: (providerId != null ? providerId.value : this.providerId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        image: (image != null ? image.value : this.image),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayAspot {
  ReplayAspot({
    required this.synopsis,
    required this.background,
    required this.treatment,
    required this.program,
  });

  factory ReplayAspot.fromJson(Map<String, dynamic> json) =>
      _$ReplayAspotFromJson(json);

  static const toJsonFactory = _$ReplayAspotToJson;
  Map<String, dynamic> toJson() => _$ReplayAspotToJson(this);

  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String synopsis;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String background;
  @JsonKey(name: 'treatment', includeIfNull: false, defaultValue: '')
  final String treatment;
  @JsonKey(name: 'program', includeIfNull: false)
  final ReplayProgramWithInstances program;
  static const fromJsonFactory = _$ReplayAspotFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayAspot &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.treatment, treatment) ||
                const DeepCollectionEquality()
                    .equals(other.treatment, treatment)) &&
            (identical(other.program, program) ||
                const DeepCollectionEquality().equals(other.program, program)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(treatment) ^
      const DeepCollectionEquality().hash(program) ^
      runtimeType.hashCode;
}

extension $ReplayAspotExtension on ReplayAspot {
  ReplayAspot copyWith(
      {String? synopsis,
      String? background,
      String? treatment,
      ReplayProgramWithInstances? program}) {
    return ReplayAspot(
        synopsis: synopsis ?? this.synopsis,
        background: background ?? this.background,
        treatment: treatment ?? this.treatment,
        program: program ?? this.program);
  }

  ReplayAspot copyWithWrapped(
      {Wrapped<String>? synopsis,
      Wrapped<String>? background,
      Wrapped<String>? treatment,
      Wrapped<ReplayProgramWithInstances>? program}) {
    return ReplayAspot(
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        background: (background != null ? background.value : this.background),
        treatment: (treatment != null ? treatment.value : this.treatment),
        program: (program != null ? program.value : this.program));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgramWithInstances {
  ReplayProgramWithInstances({
    required this.mostRelevantInstances,
    this.bookmarkedInstance,
    required this.id,
    required this.name,
    required this.type,
    required this.channelId,
    this.providerId,
    this.mergedId,
    required this.isAdult,
    this.image,
    this.imageVersion,
    this.bookmark,
    required this.isGoPlayable,
    required this.goPlayableViaExternalApp,
    this.episodeNumber,
    this.seasonNumber,
    this.mepSeriesFinale,
    this.isPremiereAirings,
  });

  factory ReplayProgramWithInstances.fromJson(Map<String, dynamic> json) =>
      _$ReplayProgramWithInstancesFromJson(json);

  static const toJsonFactory = _$ReplayProgramWithInstancesToJson;
  Map<String, dynamic> toJson() => _$ReplayProgramWithInstancesToJson(this);

  @JsonKey(
      name: 'mostRelevantInstances',
      includeIfNull: false,
      defaultValue: <InstanceOfProgram>[])
  final List<InstanceOfProgram> mostRelevantInstances;
  @JsonKey(name: 'bookmarkedInstance', includeIfNull: false)
  final Bookmark? bookmarkedInstance;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: replayProgramWithInstancesTypeToJson,
    fromJson: replayProgramWithInstancesTypeFromJson,
  )
  final enums.ReplayProgramWithInstancesType type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final Bookmark? bookmark;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool goPlayableViaExternalApp;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final DateTime? mepSeriesFinale;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  static const fromJsonFactory = _$ReplayProgramWithInstancesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgramWithInstances &&
            (identical(other.mostRelevantInstances, mostRelevantInstances) ||
                const DeepCollectionEquality().equals(
                    other.mostRelevantInstances, mostRelevantInstances)) &&
            (identical(other.bookmarkedInstance, bookmarkedInstance) ||
                const DeepCollectionEquality()
                    .equals(other.bookmarkedInstance, bookmarkedInstance)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.providerId, providerId) ||
                const DeepCollectionEquality()
                    .equals(other.providerId, providerId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.isPremiereAirings, isPremiereAirings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mostRelevantInstances) ^
      const DeepCollectionEquality().hash(bookmarkedInstance) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      runtimeType.hashCode;
}

extension $ReplayProgramWithInstancesExtension on ReplayProgramWithInstances {
  ReplayProgramWithInstances copyWith(
      {List<InstanceOfProgram>? mostRelevantInstances,
      Bookmark? bookmarkedInstance,
      String? id,
      String? name,
      enums.ReplayProgramWithInstancesType? type,
      String? channelId,
      String? providerId,
      String? mergedId,
      bool? isAdult,
      String? image,
      String? imageVersion,
      Bookmark? bookmark,
      bool? isGoPlayable,
      bool? goPlayableViaExternalApp,
      int? episodeNumber,
      int? seasonNumber,
      DateTime? mepSeriesFinale,
      bool? isPremiereAirings}) {
    return ReplayProgramWithInstances(
        mostRelevantInstances:
            mostRelevantInstances ?? this.mostRelevantInstances,
        bookmarkedInstance: bookmarkedInstance ?? this.bookmarkedInstance,
        id: id ?? this.id,
        name: name ?? this.name,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        providerId: providerId ?? this.providerId,
        mergedId: mergedId ?? this.mergedId,
        isAdult: isAdult ?? this.isAdult,
        image: image ?? this.image,
        imageVersion: imageVersion ?? this.imageVersion,
        bookmark: bookmark ?? this.bookmark,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings);
  }

  ReplayProgramWithInstances copyWithWrapped(
      {Wrapped<List<InstanceOfProgram>>? mostRelevantInstances,
      Wrapped<Bookmark?>? bookmarkedInstance,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<enums.ReplayProgramWithInstancesType>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? providerId,
      Wrapped<String?>? mergedId,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? image,
      Wrapped<String?>? imageVersion,
      Wrapped<Bookmark?>? bookmark,
      Wrapped<bool>? isGoPlayable,
      Wrapped<bool>? goPlayableViaExternalApp,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<DateTime?>? mepSeriesFinale,
      Wrapped<bool?>? isPremiereAirings}) {
    return ReplayProgramWithInstances(
        mostRelevantInstances: (mostRelevantInstances != null
            ? mostRelevantInstances.value
            : this.mostRelevantInstances),
        bookmarkedInstance: (bookmarkedInstance != null
            ? bookmarkedInstance.value
            : this.bookmarkedInstance),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        providerId: (providerId != null ? providerId.value : this.providerId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        image: (image != null ? image.value : this.image),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.errors,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({List<String>? errors}) {
    return ErrorResponse(errors: errors ?? this.errors);
  }

  ErrorResponse copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ErrorResponse(errors: (errors != null ? errors.value : this.errors));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgramsResponse$Promotion {
  ReplayProgramsResponse$Promotion({
    required this.replayPrograms,
    required this.name,
  });

  factory ReplayProgramsResponse$Promotion.fromJson(
          Map<String, dynamic> json) =>
      _$ReplayProgramsResponse$PromotionFromJson(json);

  static const toJsonFactory = _$ReplayProgramsResponse$PromotionToJson;
  Map<String, dynamic> toJson() =>
      _$ReplayProgramsResponse$PromotionToJson(this);

  @JsonKey(
      name: 'replayPrograms',
      includeIfNull: false,
      defaultValue: <ReplayProgram>[])
  final List<ReplayProgram> replayPrograms;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$ReplayProgramsResponse$PromotionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgramsResponse$Promotion &&
            (identical(other.replayPrograms, replayPrograms) ||
                const DeepCollectionEquality()
                    .equals(other.replayPrograms, replayPrograms)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayPrograms) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $ReplayProgramsResponse$PromotionExtension
    on ReplayProgramsResponse$Promotion {
  ReplayProgramsResponse$Promotion copyWith(
      {List<ReplayProgram>? replayPrograms, String? name}) {
    return ReplayProgramsResponse$Promotion(
        replayPrograms: replayPrograms ?? this.replayPrograms,
        name: name ?? this.name);
  }

  ReplayProgramsResponse$Promotion copyWithWrapped(
      {Wrapped<List<ReplayProgram>>? replayPrograms, Wrapped<String>? name}) {
    return ReplayProgramsResponse$Promotion(
        replayPrograms: (replayPrograms != null
            ? replayPrograms.value
            : this.replayPrograms),
        name: (name != null ? name.value : this.name));
  }
}

String? replayNetworkTypeToJson(enums.ReplayNetworkType? replayNetworkType) {
  return replayNetworkType?.value;
}

enums.ReplayNetworkType replayNetworkTypeFromJson(
  Object? replayNetworkType, [
  enums.ReplayNetworkType? defaultValue,
]) {
  return enums.ReplayNetworkType.values
          .firstWhereOrNull((e) => e.value == replayNetworkType) ??
      defaultValue ??
      enums.ReplayNetworkType.swaggerGeneratedUnknown;
}

List<String> replayNetworkTypeListToJson(
    List<enums.ReplayNetworkType>? replayNetworkType) {
  if (replayNetworkType == null) {
    return [];
  }

  return replayNetworkType.map((e) => e.value!).toList();
}

List<enums.ReplayNetworkType> replayNetworkTypeListFromJson(
  List? replayNetworkType, [
  List<enums.ReplayNetworkType>? defaultValue,
]) {
  if (replayNetworkType == null) {
    return defaultValue ?? [];
  }

  return replayNetworkType
      .map((e) => replayNetworkTypeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayNetworkType>? replayNetworkTypeNullableListFromJson(
  List? replayNetworkType, [
  List<enums.ReplayNetworkType>? defaultValue,
]) {
  if (replayNetworkType == null) {
    return defaultValue;
  }

  return replayNetworkType
      .map((e) => replayNetworkTypeFromJson(e.toString()))
      .toList();
}

String? replayNetworkEntitlementToJson(
    enums.ReplayNetworkEntitlement? replayNetworkEntitlement) {
  return replayNetworkEntitlement?.value;
}

enums.ReplayNetworkEntitlement replayNetworkEntitlementFromJson(
  Object? replayNetworkEntitlement, [
  enums.ReplayNetworkEntitlement? defaultValue,
]) {
  return enums.ReplayNetworkEntitlement.values
          .firstWhereOrNull((e) => e.value == replayNetworkEntitlement) ??
      defaultValue ??
      enums.ReplayNetworkEntitlement.swaggerGeneratedUnknown;
}

List<String> replayNetworkEntitlementListToJson(
    List<enums.ReplayNetworkEntitlement>? replayNetworkEntitlement) {
  if (replayNetworkEntitlement == null) {
    return [];
  }

  return replayNetworkEntitlement.map((e) => e.value!).toList();
}

List<enums.ReplayNetworkEntitlement> replayNetworkEntitlementListFromJson(
  List? replayNetworkEntitlement, [
  List<enums.ReplayNetworkEntitlement>? defaultValue,
]) {
  if (replayNetworkEntitlement == null) {
    return defaultValue ?? [];
  }

  return replayNetworkEntitlement
      .map((e) => replayNetworkEntitlementFromJson(e.toString()))
      .toList();
}

List<enums.ReplayNetworkEntitlement>?
    replayNetworkEntitlementNullableListFromJson(
  List? replayNetworkEntitlement, [
  List<enums.ReplayNetworkEntitlement>? defaultValue,
]) {
  if (replayNetworkEntitlement == null) {
    return defaultValue;
  }

  return replayNetworkEntitlement
      .map((e) => replayNetworkEntitlementFromJson(e.toString()))
      .toList();
}

String? replayProgramTypeToJson(enums.ReplayProgramType? replayProgramType) {
  return replayProgramType?.value;
}

enums.ReplayProgramType replayProgramTypeFromJson(
  Object? replayProgramType, [
  enums.ReplayProgramType? defaultValue,
]) {
  return enums.ReplayProgramType.values
          .firstWhereOrNull((e) => e.value == replayProgramType) ??
      defaultValue ??
      enums.ReplayProgramType.swaggerGeneratedUnknown;
}

List<String> replayProgramTypeListToJson(
    List<enums.ReplayProgramType>? replayProgramType) {
  if (replayProgramType == null) {
    return [];
  }

  return replayProgramType.map((e) => e.value!).toList();
}

List<enums.ReplayProgramType> replayProgramTypeListFromJson(
  List? replayProgramType, [
  List<enums.ReplayProgramType>? defaultValue,
]) {
  if (replayProgramType == null) {
    return defaultValue ?? [];
  }

  return replayProgramType
      .map((e) => replayProgramTypeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayProgramType>? replayProgramTypeNullableListFromJson(
  List? replayProgramType, [
  List<enums.ReplayProgramType>? defaultValue,
]) {
  if (replayProgramType == null) {
    return defaultValue;
  }

  return replayProgramType
      .map((e) => replayProgramTypeFromJson(e.toString()))
      .toList();
}

String? replayProgramWithInstancesTypeToJson(
    enums.ReplayProgramWithInstancesType? replayProgramWithInstancesType) {
  return replayProgramWithInstancesType?.value;
}

enums.ReplayProgramWithInstancesType replayProgramWithInstancesTypeFromJson(
  Object? replayProgramWithInstancesType, [
  enums.ReplayProgramWithInstancesType? defaultValue,
]) {
  return enums.ReplayProgramWithInstancesType.values
          .firstWhereOrNull((e) => e.value == replayProgramWithInstancesType) ??
      defaultValue ??
      enums.ReplayProgramWithInstancesType.swaggerGeneratedUnknown;
}

List<String> replayProgramWithInstancesTypeListToJson(
    List<enums.ReplayProgramWithInstancesType>?
        replayProgramWithInstancesType) {
  if (replayProgramWithInstancesType == null) {
    return [];
  }

  return replayProgramWithInstancesType.map((e) => e.value!).toList();
}

List<enums.ReplayProgramWithInstancesType>
    replayProgramWithInstancesTypeListFromJson(
  List? replayProgramWithInstancesType, [
  List<enums.ReplayProgramWithInstancesType>? defaultValue,
]) {
  if (replayProgramWithInstancesType == null) {
    return defaultValue ?? [];
  }

  return replayProgramWithInstancesType
      .map((e) => replayProgramWithInstancesTypeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayProgramWithInstancesType>?
    replayProgramWithInstancesTypeNullableListFromJson(
  List? replayProgramWithInstancesType, [
  List<enums.ReplayProgramWithInstancesType>? defaultValue,
]) {
  if (replayProgramWithInstancesType == null) {
    return defaultValue;
  }

  return replayProgramWithInstancesType
      .map((e) => replayProgramWithInstancesTypeFromJson(e.toString()))
      .toList();
}

String? mostrelevantinstanceGetTypeToJson(
    enums.MostrelevantinstanceGetType? mostrelevantinstanceGetType) {
  return mostrelevantinstanceGetType?.value;
}

enums.MostrelevantinstanceGetType mostrelevantinstanceGetTypeFromJson(
  Object? mostrelevantinstanceGetType, [
  enums.MostrelevantinstanceGetType? defaultValue,
]) {
  return enums.MostrelevantinstanceGetType.values
          .firstWhereOrNull((e) => e.value == mostrelevantinstanceGetType) ??
      defaultValue ??
      enums.MostrelevantinstanceGetType.swaggerGeneratedUnknown;
}

List<String> mostrelevantinstanceGetTypeListToJson(
    List<enums.MostrelevantinstanceGetType>? mostrelevantinstanceGetType) {
  if (mostrelevantinstanceGetType == null) {
    return [];
  }

  return mostrelevantinstanceGetType.map((e) => e.value!).toList();
}

List<enums.MostrelevantinstanceGetType> mostrelevantinstanceGetTypeListFromJson(
  List? mostrelevantinstanceGetType, [
  List<enums.MostrelevantinstanceGetType>? defaultValue,
]) {
  if (mostrelevantinstanceGetType == null) {
    return defaultValue ?? [];
  }

  return mostrelevantinstanceGetType
      .map((e) => mostrelevantinstanceGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.MostrelevantinstanceGetType>?
    mostrelevantinstanceGetTypeNullableListFromJson(
  List? mostrelevantinstanceGetType, [
  List<enums.MostrelevantinstanceGetType>? defaultValue,
]) {
  if (mostrelevantinstanceGetType == null) {
    return defaultValue;
  }

  return mostrelevantinstanceGetType
      .map((e) => mostrelevantinstanceGetTypeFromJson(e.toString()))
      .toList();
}

String? mostrelevantinstanceGetMaxResToJson(
    enums.MostrelevantinstanceGetMaxRes? mostrelevantinstanceGetMaxRes) {
  return mostrelevantinstanceGetMaxRes?.value;
}

enums.MostrelevantinstanceGetMaxRes mostrelevantinstanceGetMaxResFromJson(
  Object? mostrelevantinstanceGetMaxRes, [
  enums.MostrelevantinstanceGetMaxRes? defaultValue,
]) {
  return enums.MostrelevantinstanceGetMaxRes.values
          .firstWhereOrNull((e) => e.value == mostrelevantinstanceGetMaxRes) ??
      defaultValue ??
      enums.MostrelevantinstanceGetMaxRes.swaggerGeneratedUnknown;
}

List<String> mostrelevantinstanceGetMaxResListToJson(
    List<enums.MostrelevantinstanceGetMaxRes>? mostrelevantinstanceGetMaxRes) {
  if (mostrelevantinstanceGetMaxRes == null) {
    return [];
  }

  return mostrelevantinstanceGetMaxRes.map((e) => e.value!).toList();
}

List<enums.MostrelevantinstanceGetMaxRes>
    mostrelevantinstanceGetMaxResListFromJson(
  List? mostrelevantinstanceGetMaxRes, [
  List<enums.MostrelevantinstanceGetMaxRes>? defaultValue,
]) {
  if (mostrelevantinstanceGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return mostrelevantinstanceGetMaxRes
      .map((e) => mostrelevantinstanceGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.MostrelevantinstanceGetMaxRes>?
    mostrelevantinstanceGetMaxResNullableListFromJson(
  List? mostrelevantinstanceGetMaxRes, [
  List<enums.MostrelevantinstanceGetMaxRes>? defaultValue,
]) {
  if (mostrelevantinstanceGetMaxRes == null) {
    return defaultValue;
  }

  return mostrelevantinstanceGetMaxRes
      .map((e) => mostrelevantinstanceGetMaxResFromJson(e.toString()))
      .toList();
}

String? mostrelevantinstanceGetSortToJson(
    enums.MostrelevantinstanceGetSort? mostrelevantinstanceGetSort) {
  return mostrelevantinstanceGetSort?.value;
}

enums.MostrelevantinstanceGetSort mostrelevantinstanceGetSortFromJson(
  Object? mostrelevantinstanceGetSort, [
  enums.MostrelevantinstanceGetSort? defaultValue,
]) {
  return enums.MostrelevantinstanceGetSort.values
          .firstWhereOrNull((e) => e.value == mostrelevantinstanceGetSort) ??
      defaultValue ??
      enums.MostrelevantinstanceGetSort.swaggerGeneratedUnknown;
}

List<String> mostrelevantinstanceGetSortListToJson(
    List<enums.MostrelevantinstanceGetSort>? mostrelevantinstanceGetSort) {
  if (mostrelevantinstanceGetSort == null) {
    return [];
  }

  return mostrelevantinstanceGetSort.map((e) => e.value!).toList();
}

List<enums.MostrelevantinstanceGetSort> mostrelevantinstanceGetSortListFromJson(
  List? mostrelevantinstanceGetSort, [
  List<enums.MostrelevantinstanceGetSort>? defaultValue,
]) {
  if (mostrelevantinstanceGetSort == null) {
    return defaultValue ?? [];
  }

  return mostrelevantinstanceGetSort
      .map((e) => mostrelevantinstanceGetSortFromJson(e.toString()))
      .toList();
}

List<enums.MostrelevantinstanceGetSort>?
    mostrelevantinstanceGetSortNullableListFromJson(
  List? mostrelevantinstanceGetSort, [
  List<enums.MostrelevantinstanceGetSort>? defaultValue,
]) {
  if (mostrelevantinstanceGetSort == null) {
    return defaultValue;
  }

  return mostrelevantinstanceGetSort
      .map((e) => mostrelevantinstanceGetSortFromJson(e.toString()))
      .toList();
}

String? networksGetMaxResToJson(enums.NetworksGetMaxRes? networksGetMaxRes) {
  return networksGetMaxRes?.value;
}

enums.NetworksGetMaxRes networksGetMaxResFromJson(
  Object? networksGetMaxRes, [
  enums.NetworksGetMaxRes? defaultValue,
]) {
  return enums.NetworksGetMaxRes.values
          .firstWhereOrNull((e) => e.value == networksGetMaxRes) ??
      defaultValue ??
      enums.NetworksGetMaxRes.swaggerGeneratedUnknown;
}

List<String> networksGetMaxResListToJson(
    List<enums.NetworksGetMaxRes>? networksGetMaxRes) {
  if (networksGetMaxRes == null) {
    return [];
  }

  return networksGetMaxRes.map((e) => e.value!).toList();
}

List<enums.NetworksGetMaxRes> networksGetMaxResListFromJson(
  List? networksGetMaxRes, [
  List<enums.NetworksGetMaxRes>? defaultValue,
]) {
  if (networksGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return networksGetMaxRes
      .map((e) => networksGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.NetworksGetMaxRes>? networksGetMaxResNullableListFromJson(
  List? networksGetMaxRes, [
  List<enums.NetworksGetMaxRes>? defaultValue,
]) {
  if (networksGetMaxRes == null) {
    return defaultValue;
  }

  return networksGetMaxRes
      .map((e) => networksGetMaxResFromJson(e.toString()))
      .toList();
}

String? programsGetSortToJson(enums.ProgramsGetSort? programsGetSort) {
  return programsGetSort?.value;
}

enums.ProgramsGetSort programsGetSortFromJson(
  Object? programsGetSort, [
  enums.ProgramsGetSort? defaultValue,
]) {
  return enums.ProgramsGetSort.values
          .firstWhereOrNull((e) => e.value == programsGetSort) ??
      defaultValue ??
      enums.ProgramsGetSort.swaggerGeneratedUnknown;
}

List<String> programsGetSortListToJson(
    List<enums.ProgramsGetSort>? programsGetSort) {
  if (programsGetSort == null) {
    return [];
  }

  return programsGetSort.map((e) => e.value!).toList();
}

List<enums.ProgramsGetSort> programsGetSortListFromJson(
  List? programsGetSort, [
  List<enums.ProgramsGetSort>? defaultValue,
]) {
  if (programsGetSort == null) {
    return defaultValue ?? [];
  }

  return programsGetSort
      .map((e) => programsGetSortFromJson(e.toString()))
      .toList();
}

List<enums.ProgramsGetSort>? programsGetSortNullableListFromJson(
  List? programsGetSort, [
  List<enums.ProgramsGetSort>? defaultValue,
]) {
  if (programsGetSort == null) {
    return defaultValue;
  }

  return programsGetSort
      .map((e) => programsGetSortFromJson(e.toString()))
      .toList();
}

String? programsGetMaxResToJson(enums.ProgramsGetMaxRes? programsGetMaxRes) {
  return programsGetMaxRes?.value;
}

enums.ProgramsGetMaxRes programsGetMaxResFromJson(
  Object? programsGetMaxRes, [
  enums.ProgramsGetMaxRes? defaultValue,
]) {
  return enums.ProgramsGetMaxRes.values
          .firstWhereOrNull((e) => e.value == programsGetMaxRes) ??
      defaultValue ??
      enums.ProgramsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> programsGetMaxResListToJson(
    List<enums.ProgramsGetMaxRes>? programsGetMaxRes) {
  if (programsGetMaxRes == null) {
    return [];
  }

  return programsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.ProgramsGetMaxRes> programsGetMaxResListFromJson(
  List? programsGetMaxRes, [
  List<enums.ProgramsGetMaxRes>? defaultValue,
]) {
  if (programsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return programsGetMaxRes
      .map((e) => programsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ProgramsGetMaxRes>? programsGetMaxResNullableListFromJson(
  List? programsGetMaxRes, [
  List<enums.ProgramsGetMaxRes>? defaultValue,
]) {
  if (programsGetMaxRes == null) {
    return defaultValue;
  }

  return programsGetMaxRes
      .map((e) => programsGetMaxResFromJson(e.toString()))
      .toList();
}

String? programsContextualMenuGetMaxResToJson(
    enums.ProgramsContextualMenuGetMaxRes? programsContextualMenuGetMaxRes) {
  return programsContextualMenuGetMaxRes?.value;
}

enums.ProgramsContextualMenuGetMaxRes programsContextualMenuGetMaxResFromJson(
  Object? programsContextualMenuGetMaxRes, [
  enums.ProgramsContextualMenuGetMaxRes? defaultValue,
]) {
  return enums.ProgramsContextualMenuGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == programsContextualMenuGetMaxRes) ??
      defaultValue ??
      enums.ProgramsContextualMenuGetMaxRes.swaggerGeneratedUnknown;
}

List<String> programsContextualMenuGetMaxResListToJson(
    List<enums.ProgramsContextualMenuGetMaxRes>?
        programsContextualMenuGetMaxRes) {
  if (programsContextualMenuGetMaxRes == null) {
    return [];
  }

  return programsContextualMenuGetMaxRes.map((e) => e.value!).toList();
}

List<enums.ProgramsContextualMenuGetMaxRes>
    programsContextualMenuGetMaxResListFromJson(
  List? programsContextualMenuGetMaxRes, [
  List<enums.ProgramsContextualMenuGetMaxRes>? defaultValue,
]) {
  if (programsContextualMenuGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return programsContextualMenuGetMaxRes
      .map((e) => programsContextualMenuGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ProgramsContextualMenuGetMaxRes>?
    programsContextualMenuGetMaxResNullableListFromJson(
  List? programsContextualMenuGetMaxRes, [
  List<enums.ProgramsContextualMenuGetMaxRes>? defaultValue,
]) {
  if (programsContextualMenuGetMaxRes == null) {
    return defaultValue;
  }

  return programsContextualMenuGetMaxRes
      .map((e) => programsContextualMenuGetMaxResFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
