// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'session_manager.swagger.chopper.dart';
part 'session_manager.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class SessionManager extends ChopperService {
  static SessionManager create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$SessionManager(client);
    }

    final newClient = ChopperClient(
        services: [_$SessionManager()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$SessionManager(newClient);
  }

  ///Provide the license
  ///@param ContentId DRM ContentId. It could be extracted from the session-service response (drmContentId).
  ///@param x-drm-schemeId Id (guid) of the drm system. Possible values are:   <ul>     <li>9a04f079-9840-4286-ab92-e65be0885f95 - Playready</li>     <li>edef8ba9-79d6-4ace-a3c8-27dcd51d21ed - Widevine</li>     <li>94ce86fb-07ff-4f43-adb8-93d2fa968ca2 - Fairplay</li>   </ul>
  ///@param deviceName Customer friendly device name.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param keyId is required for Fairplay only
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  Future<chopper.Response<String>> licensePost({
    required String? contentId,
    String? xDrmSchemeId,
    String? deviceName,
    String? xStreamingToken,
    String? keyId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? cacheControl,
    required Object? body,
  }) {
    return _licensePost(
        contentId: contentId,
        xDrmSchemeId: xDrmSchemeId,
        deviceName: deviceName,
        xStreamingToken: xStreamingToken,
        keyId: keyId,
        xCus: xCus,
        xDev: xDev,
        cacheControl: cacheControl,
        body: body);
  }

  ///Provide the license
  ///@param ContentId DRM ContentId. It could be extracted from the session-service response (drmContentId).
  ///@param x-drm-schemeId Id (guid) of the drm system. Possible values are:   <ul>     <li>9a04f079-9840-4286-ab92-e65be0885f95 - Playready</li>     <li>edef8ba9-79d6-4ace-a3c8-27dcd51d21ed - Widevine</li>     <li>94ce86fb-07ff-4f43-adb8-93d2fa968ca2 - Fairplay</li>   </ul>
  ///@param deviceName Customer friendly device name.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param keyId is required for Fairplay only
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  @Post(
    path: '/license',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _licensePost({
    @Query('ContentId') required String? contentId,
    @Header('x-drm-schemeId') String? xDrmSchemeId,
    @Header('deviceName') String? deviceName,
    @Header('x-streaming-token') String? xStreamingToken,
    @Query('keyId') String? keyId,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Object? body,
  });

  ///Provide Fairplay certificate
  Future<chopper.Response<String>> licenseCertificateFairplayGet(
      {String? cacheControl}) {
    return _licenseCertificateFairplayGet(cacheControl: cacheControl);
  }

  ///Provide Fairplay certificate
  @Get(path: '/license/certificate/fairplay')
  Future<chopper.Response<String>> _licenseCertificateFairplayGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Provide Widevine certificate
  Future<chopper.Response<String>> licenseCertificateWidevineGet(
      {String? cacheControl}) {
    return _licenseCertificateWidevineGet(cacheControl: cacheControl);
  }

  ///Provide Widevine certificate
  @Get(path: '/license/certificate/widevine')
  Future<chopper.Response<String>> _licenseCertificateWidevineGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Provides the status if device is onNet with the IP Address visible for the session-manager.
  Future<chopper.Response<OnNetStatus>> networkGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(
        OnNetStatus, () => OnNetStatus.fromJsonFactory);

    return _networkGet(cacheControl: cacheControl);
  }

  ///Provides the status if device is onNet with the IP Address visible for the session-manager.
  @Get(path: '/network')
  Future<chopper.Response<OnNetStatus>> _networkGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Refresh the streaming token
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param position last known position received from the player.
  ///@param partiallyWatchedBreakId ID of partially wathched break
  ///@param timingBasis Indicates the basis under which the stored bookmark was calculated, e.g. manifestStartIncludingMidRolls, contentStartIncludingMidRolls, epgStartIncludingMidRolls
  ///@param duration Duration of the content in seconds
  ///@param eventId eventId of Live or Review Buffer content
  Future<chopper.Response> licenseTokenPost({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xStreamingToken,
    String? position,
    String? partiallyWatchedBreakId,
    String? timingBasis,
    int? duration,
    String? eventId,
    String? cacheControl,
  }) {
    return _licenseTokenPost(
        xCus: xCus,
        xDev: xDev,
        xStreamingToken: xStreamingToken,
        position: position,
        partiallyWatchedBreakId: partiallyWatchedBreakId,
        timingBasis: timingBasis,
        duration: duration,
        eventId: eventId,
        cacheControl: cacheControl);
  }

  ///Refresh the streaming token
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param position last known position received from the player.
  ///@param partiallyWatchedBreakId ID of partially wathched break
  ///@param timingBasis Indicates the basis under which the stored bookmark was calculated, e.g. manifestStartIncludingMidRolls, contentStartIncludingMidRolls, epgStartIncludingMidRolls
  ///@param duration Duration of the content in seconds
  ///@param eventId eventId of Live or Review Buffer content
  @Post(
    path: '/license/token',
    optionalBody: true,
  )
  Future<chopper.Response> _licenseTokenPost({
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-streaming-token') String? xStreamingToken,
    @Query('position') String? position,
    @Query('partiallyWatchedBreakId') String? partiallyWatchedBreakId,
    @Query('timingBasis') String? timingBasis,
    @Query('duration') int? duration,
    @Query('eventId') String? eventId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete the session
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param eventId eventId of Live or Review Buffer content
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  Future<chopper.Response> licenseTokenDelete({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xStreamingToken,
    String? eventId,
    int? sessionEndCode,
    String? additionalInfo,
    String? cacheControl,
  }) {
    return _licenseTokenDelete(
        xCus: xCus,
        xDev: xDev,
        xStreamingToken: xStreamingToken,
        eventId: eventId,
        sessionEndCode: sessionEndCode,
        additionalInfo: additionalInfo,
        cacheControl: cacheControl);
  }

  ///Delete the session
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param eventId eventId of Live or Review Buffer content
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  @Delete(path: '/license/token')
  Future<chopper.Response> _licenseTokenDelete({
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-streaming-token') String? xStreamingToken,
    @Query('eventId') String? eventId,
    @Query('sessionEndCode') int? sessionEndCode,
    @Query('additionalInfo') String? additionalInfo,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get active customer's sessions
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param profileId might be specified in order to filter the results.
  Future<chopper.Response<ActiveSessionsResponse>> servicesSessionsGet({
    String? xCus = 'X-Cus',
    String? profileId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ActiveSessionsResponse, () => ActiveSessionsResponse.fromJsonFactory);

    return _servicesSessionsGet(
        xCus: xCus, profileId: profileId, cacheControl: cacheControl);
  }

  ///Get active customer's sessions
  ///@param x-cus HouseholdId for which the session should be created. It should contain CustomerId and country code, e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param profileId might be specified in order to filter the results.
  @Get(path: '/services/sessions')
  Future<chopper.Response<ActiveSessionsResponse>> _servicesSessionsGet({
    @Header('x-cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class ActiveSessionsResponse {
  ActiveSessionsResponse({
    required this.activeSessions,
  });

  factory ActiveSessionsResponse.fromJson(Map<String, dynamic> json) =>
      _$ActiveSessionsResponseFromJson(json);

  static const toJsonFactory = _$ActiveSessionsResponseToJson;
  Map<String, dynamic> toJson() => _$ActiveSessionsResponseToJson(this);

  @JsonKey(
      name: 'activeSessions',
      includeIfNull: false,
      defaultValue: <ActiveSessionResponse>[])
  final List<ActiveSessionResponse> activeSessions;
  static const fromJsonFactory = _$ActiveSessionsResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ActiveSessionsResponse &&
            (identical(other.activeSessions, activeSessions) ||
                const DeepCollectionEquality()
                    .equals(other.activeSessions, activeSessions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(activeSessions) ^
      runtimeType.hashCode;
}

extension $ActiveSessionsResponseExtension on ActiveSessionsResponse {
  ActiveSessionsResponse copyWith(
      {List<ActiveSessionResponse>? activeSessions}) {
    return ActiveSessionsResponse(
        activeSessions: activeSessions ?? this.activeSessions);
  }

  ActiveSessionsResponse copyWithWrapped(
      {Wrapped<List<ActiveSessionResponse>>? activeSessions}) {
    return ActiveSessionsResponse(
        activeSessions: (activeSessions != null
            ? activeSessions.value
            : this.activeSessions));
  }
}

@JsonSerializable(explicitToJson: true)
class OnNetStatus {
  OnNetStatus({
    this.ipAddress,
    this.onNet,
  });

  factory OnNetStatus.fromJson(Map<String, dynamic> json) =>
      _$OnNetStatusFromJson(json);

  static const toJsonFactory = _$OnNetStatusToJson;
  Map<String, dynamic> toJson() => _$OnNetStatusToJson(this);

  @JsonKey(name: 'ipAddress', includeIfNull: false, defaultValue: '')
  final String? ipAddress;
  @JsonKey(name: 'onNet', includeIfNull: false)
  final bool? onNet;
  static const fromJsonFactory = _$OnNetStatusFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OnNetStatus &&
            (identical(other.ipAddress, ipAddress) ||
                const DeepCollectionEquality()
                    .equals(other.ipAddress, ipAddress)) &&
            (identical(other.onNet, onNet) ||
                const DeepCollectionEquality().equals(other.onNet, onNet)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ipAddress) ^
      const DeepCollectionEquality().hash(onNet) ^
      runtimeType.hashCode;
}

extension $OnNetStatusExtension on OnNetStatus {
  OnNetStatus copyWith({String? ipAddress, bool? onNet}) {
    return OnNetStatus(
        ipAddress: ipAddress ?? this.ipAddress, onNet: onNet ?? this.onNet);
  }

  OnNetStatus copyWithWrapped(
      {Wrapped<String?>? ipAddress, Wrapped<bool?>? onNet}) {
    return OnNetStatus(
        ipAddress: (ipAddress != null ? ipAddress.value : this.ipAddress),
        onNet: (onNet != null ? onNet.value : this.onNet));
  }
}

@JsonSerializable(explicitToJson: true)
class ActiveSessionResponse {
  ActiveSessionResponse({
    this.sessionId,
    this.startTime,
    this.lastUpdateTime,
    this.profileId,
    this.contentType,
    this.contentId,
    this.position,
    this.partiallyWatchedBreakId,
    this.timingBasis,
    this.duration,
    this.sessionType,
    this.isOverwritten,
    this.deviceId,
  });

  factory ActiveSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$ActiveSessionResponseFromJson(json);

  static const toJsonFactory = _$ActiveSessionResponseToJson;
  Map<String, dynamic> toJson() => _$ActiveSessionResponseToJson(this);

  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String? sessionId;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'lastUpdateTime', includeIfNull: false, defaultValue: '')
  final String? lastUpdateTime;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String? contentId;
  @JsonKey(name: 'position', includeIfNull: false, defaultValue: '')
  final String? position;
  @JsonKey(
      name: 'partiallyWatchedBreakId', includeIfNull: false, defaultValue: '')
  final String? partiallyWatchedBreakId;
  @JsonKey(name: 'timingBasis', includeIfNull: false, defaultValue: '')
  final String? timingBasis;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'sessionType', includeIfNull: false, defaultValue: '')
  final String? sessionType;
  @JsonKey(name: 'isOverwritten', includeIfNull: false)
  final bool? isOverwritten;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  static const fromJsonFactory = _$ActiveSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ActiveSessionResponse &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.lastUpdateTime, lastUpdateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdateTime, lastUpdateTime)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId) ||
                const DeepCollectionEquality().equals(
                    other.partiallyWatchedBreakId, partiallyWatchedBreakId)) &&
            (identical(other.timingBasis, timingBasis) ||
                const DeepCollectionEquality()
                    .equals(other.timingBasis, timingBasis)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.sessionType, sessionType) ||
                const DeepCollectionEquality()
                    .equals(other.sessionType, sessionType)) &&
            (identical(other.isOverwritten, isOverwritten) ||
                const DeepCollectionEquality()
                    .equals(other.isOverwritten, isOverwritten)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sessionId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(lastUpdateTime) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(partiallyWatchedBreakId) ^
      const DeepCollectionEquality().hash(timingBasis) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(sessionType) ^
      const DeepCollectionEquality().hash(isOverwritten) ^
      const DeepCollectionEquality().hash(deviceId) ^
      runtimeType.hashCode;
}

extension $ActiveSessionResponseExtension on ActiveSessionResponse {
  ActiveSessionResponse copyWith(
      {String? sessionId,
      String? startTime,
      String? lastUpdateTime,
      String? profileId,
      String? contentType,
      String? contentId,
      String? position,
      String? partiallyWatchedBreakId,
      String? timingBasis,
      int? duration,
      String? sessionType,
      bool? isOverwritten,
      String? deviceId}) {
    return ActiveSessionResponse(
        sessionId: sessionId ?? this.sessionId,
        startTime: startTime ?? this.startTime,
        lastUpdateTime: lastUpdateTime ?? this.lastUpdateTime,
        profileId: profileId ?? this.profileId,
        contentType: contentType ?? this.contentType,
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        partiallyWatchedBreakId:
            partiallyWatchedBreakId ?? this.partiallyWatchedBreakId,
        timingBasis: timingBasis ?? this.timingBasis,
        duration: duration ?? this.duration,
        sessionType: sessionType ?? this.sessionType,
        isOverwritten: isOverwritten ?? this.isOverwritten,
        deviceId: deviceId ?? this.deviceId);
  }

  ActiveSessionResponse copyWithWrapped(
      {Wrapped<String?>? sessionId,
      Wrapped<String?>? startTime,
      Wrapped<String?>? lastUpdateTime,
      Wrapped<String?>? profileId,
      Wrapped<String?>? contentType,
      Wrapped<String?>? contentId,
      Wrapped<String?>? position,
      Wrapped<String?>? partiallyWatchedBreakId,
      Wrapped<String?>? timingBasis,
      Wrapped<int?>? duration,
      Wrapped<String?>? sessionType,
      Wrapped<bool?>? isOverwritten,
      Wrapped<String?>? deviceId}) {
    return ActiveSessionResponse(
        sessionId: (sessionId != null ? sessionId.value : this.sessionId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        lastUpdateTime: (lastUpdateTime != null
            ? lastUpdateTime.value
            : this.lastUpdateTime),
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        partiallyWatchedBreakId: (partiallyWatchedBreakId != null
            ? partiallyWatchedBreakId.value
            : this.partiallyWatchedBreakId),
        timingBasis:
            (timingBasis != null ? timingBasis.value : this.timingBasis),
        duration: (duration != null ? duration.value : this.duration),
        sessionType:
            (sessionType != null ? sessionType.value : this.sessionType),
        isOverwritten:
            (isOverwritten != null ? isOverwritten.value : this.isOverwritten),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
