// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'watermark_settings_service.swagger.chopper.dart';
part 'watermark_settings_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class WatermarkSettingsService extends ChopperService {
  static WatermarkSettingsService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$WatermarkSettingsService(client);
    }

    final newClient = ChopperClient(
        services: [_$WatermarkSettingsService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$WatermarkSettingsService(newClient);
  }

  ///
  Future<chopper.Response<Settings>> settingsGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Settings, () => Settings.fromJsonFactory);

    return _settingsGet(cacheControl: cacheControl);
  }

  ///
  @Get(path: '/settings')
  Future<chopper.Response<Settings>> _settingsGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class Settings {
  Settings({
    required this.settingsToken,
  });

  factory Settings.fromJson(Map<String, dynamic> json) =>
      _$SettingsFromJson(json);

  static const toJsonFactory = _$SettingsToJson;
  Map<String, dynamic> toJson() => _$SettingsToJson(this);

  @JsonKey(name: 'settingsToken', includeIfNull: false, defaultValue: '')
  final String settingsToken;
  static const fromJsonFactory = _$SettingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Settings &&
            (identical(other.settingsToken, settingsToken) ||
                const DeepCollectionEquality()
                    .equals(other.settingsToken, settingsToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(settingsToken) ^ runtimeType.hashCode;
}

extension $SettingsExtension on Settings {
  Settings copyWith({String? settingsToken}) {
    return Settings(settingsToken: settingsToken ?? this.settingsToken);
  }

  Settings copyWithWrapped({Wrapped<String>? settingsToken}) {
    return Settings(
        settingsToken:
            (settingsToken != null ? settingsToken.value : this.settingsToken));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorList {
  ErrorList({
    required this.errors,
  });

  factory ErrorList.fromJson(Map<String, dynamic> json) =>
      _$ErrorListFromJson(json);

  static const toJsonFactory = _$ErrorListToJson;
  Map<String, dynamic> toJson() => _$ErrorListToJson(this);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ErrorListFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorList &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ErrorListExtension on ErrorList {
  ErrorList copyWith({List<String>? errors}) {
    return ErrorList(errors: errors ?? this.errors);
  }

  ErrorList copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ErrorList(errors: (errors != null ? errors.value : this.errors));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerAccessError {
  CustomerAccessError({
    this.errorMessage,
  });

  factory CustomerAccessError.fromJson(Map<String, dynamic> json) =>
      _$CustomerAccessErrorFromJson(json);

  static const toJsonFactory = _$CustomerAccessErrorToJson;
  Map<String, dynamic> toJson() => _$CustomerAccessErrorToJson(this);

  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  static const fromJsonFactory = _$CustomerAccessErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerAccessError &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errorMessage) ^ runtimeType.hashCode;
}

extension $CustomerAccessErrorExtension on CustomerAccessError {
  CustomerAccessError copyWith({String? errorMessage}) {
    return CustomerAccessError(errorMessage: errorMessage ?? this.errorMessage);
  }

  CustomerAccessError copyWithWrapped({Wrapped<String?>? errorMessage}) {
    return CustomerAccessError(
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
