// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'yelo_booking_service.enums.swagger.dart' as enums;
export 'yelo_booking_service.enums.swagger.dart';

part 'yelo_booking_service.swagger.chopper.dart';
part 'yelo_booking_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class YeloBookingService extends ChopperService {
  static YeloBookingService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$YeloBookingService(client);
    }

    final newClient = ChopperClient(
        services: [_$YeloBookingService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$YeloBookingService(newClient);
  }

  ///
  ///@param customerId
  ///@param X-Cus
  ///@param X-Entitlements-Token
  ///@param language
  ///@param sort
  ///@param sortOrder
  Future<chopper.Response<GetBookingsResponse>> customerCustomerIdBookingsGet({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? language,
    enums.CustomerCustomerIdBookingsGetSort? sort,
    enums.CustomerCustomerIdBookingsGetSortOrder? sortOrder,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GetBookingsResponse, () => GetBookingsResponse.fromJsonFactory);

    return _customerCustomerIdBookingsGet(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        language: language,
        sort: sort?.value?.toString(),
        sortOrder: sortOrder?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///
  ///@param customerId
  ///@param X-Cus
  ///@param X-Entitlements-Token
  ///@param language
  ///@param sort
  ///@param sortOrder
  @Get(path: '/customer/{customerId}/bookings')
  Future<chopper.Response<GetBookingsResponse>> _customerCustomerIdBookingsGet({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('language')
        String? language,
    @Query('sort')
        String? sort,
    @Query('sortOrder')
        String? sortOrder,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param customerId
  ///@param X-Cus
  Future<chopper.Response> customerCustomerIdBookingsSinglePost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required PostBookingRequestSingle? body,
  }) {
    return _customerCustomerIdBookingsSinglePost(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///
  ///@param customerId
  ///@param X-Cus
  @Post(
    path: '/customer/{customerId}/bookings/single',
    optionalBody: true,
  )
  Future<chopper.Response> _customerCustomerIdBookingsSinglePost({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required PostBookingRequestSingle? body,
  });

  ///
  ///@param customerId
  ///@param X-Cus
  Future<chopper.Response> customerCustomerIdBookingsSingleDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required DeleteBookingRequestSingle? body,
  }) {
    return _customerCustomerIdBookingsSingleDelete(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///
  ///@param customerId
  ///@param X-Cus
  @Delete(path: '/customer/{customerId}/bookings/single')
  Future<chopper.Response> _customerCustomerIdBookingsSingleDelete({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeleteBookingRequestSingle? body,
  });

  ///
  ///@param customerId
  ///@param X-Cus
  Future<chopper.Response> customerCustomerIdBookingsShowPost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required PostBookingRequestShow? body,
  }) {
    return _customerCustomerIdBookingsShowPost(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///
  ///@param customerId
  ///@param X-Cus
  @Post(
    path: '/customer/{customerId}/bookings/show',
    optionalBody: true,
  )
  Future<chopper.Response> _customerCustomerIdBookingsShowPost({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required PostBookingRequestShow? body,
  });

  ///
  ///@param customerId
  ///@param X-Cus
  Future<chopper.Response> customerCustomerIdBookingsShowDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required DeleteBookingRequestShow? body,
  }) {
    return _customerCustomerIdBookingsShowDelete(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///
  ///@param customerId
  ///@param X-Cus
  @Delete(path: '/customer/{customerId}/bookings/show')
  Future<chopper.Response> _customerCustomerIdBookingsShowDelete({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeleteBookingRequestShow? body,
  });
}

@JsonSerializable(explicitToJson: true)
class STBBookings {
  STBBookings({
    required this.stbId,
    required this.freeSpacePct,
    this.friendlyName,
    required this.bookings,
  });

  factory STBBookings.fromJson(Map<String, dynamic> json) =>
      _$STBBookingsFromJson(json);

  static const toJsonFactory = _$STBBookingsToJson;
  Map<String, dynamic> toJson() => _$STBBookingsToJson(this);

  @JsonKey(name: 'stbId', includeIfNull: false, defaultValue: '')
  final String stbId;
  @JsonKey(name: 'freeSpacePct', includeIfNull: false)
  final int freeSpacePct;
  @JsonKey(name: 'friendlyName', includeIfNull: false, defaultValue: '')
  final String? friendlyName;
  @JsonKey(
      name: 'bookings', includeIfNull: false, defaultValue: <BookingsItem>[])
  final List<BookingsItem> bookings;
  static const fromJsonFactory = _$STBBookingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is STBBookings &&
            (identical(other.stbId, stbId) ||
                const DeepCollectionEquality().equals(other.stbId, stbId)) &&
            (identical(other.freeSpacePct, freeSpacePct) ||
                const DeepCollectionEquality()
                    .equals(other.freeSpacePct, freeSpacePct)) &&
            (identical(other.friendlyName, friendlyName) ||
                const DeepCollectionEquality()
                    .equals(other.friendlyName, friendlyName)) &&
            (identical(other.bookings, bookings) ||
                const DeepCollectionEquality()
                    .equals(other.bookings, bookings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stbId) ^
      const DeepCollectionEquality().hash(freeSpacePct) ^
      const DeepCollectionEquality().hash(friendlyName) ^
      const DeepCollectionEquality().hash(bookings) ^
      runtimeType.hashCode;
}

extension $STBBookingsExtension on STBBookings {
  STBBookings copyWith(
      {String? stbId,
      int? freeSpacePct,
      String? friendlyName,
      List<BookingsItem>? bookings}) {
    return STBBookings(
        stbId: stbId ?? this.stbId,
        freeSpacePct: freeSpacePct ?? this.freeSpacePct,
        friendlyName: friendlyName ?? this.friendlyName,
        bookings: bookings ?? this.bookings);
  }

  STBBookings copyWithWrapped(
      {Wrapped<String>? stbId,
      Wrapped<int>? freeSpacePct,
      Wrapped<String?>? friendlyName,
      Wrapped<List<BookingsItem>>? bookings}) {
    return STBBookings(
        stbId: (stbId != null ? stbId.value : this.stbId),
        freeSpacePct:
            (freeSpacePct != null ? freeSpacePct.value : this.freeSpacePct),
        friendlyName:
            (friendlyName != null ? friendlyName.value : this.friendlyName),
        bookings: (bookings != null ? bookings.value : this.bookings));
  }
}

typedef BookingsItem = Map<String, dynamic>;

@JsonSerializable(explicitToJson: true)
class BookingBaseType {
  BookingBaseType({
    required this.type,
    required this.minimumAge,
  });

  factory BookingBaseType.fromJson(Map<String, dynamic> json) =>
      _$BookingBaseTypeFromJson(json);

  static const toJsonFactory = _$BookingBaseTypeToJson;
  Map<String, dynamic> toJson() => _$BookingBaseTypeToJson(this);

  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: bookingBaseTypeTypeToJson,
    fromJson: bookingBaseTypeTypeFromJson,
  )
  final enums.BookingBaseTypeType type;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int minimumAge;
  static const fromJsonFactory = _$BookingBaseTypeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookingBaseType &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      runtimeType.hashCode;
}

extension $BookingBaseTypeExtension on BookingBaseType {
  BookingBaseType copyWith({enums.BookingBaseTypeType? type, int? minimumAge}) {
    return BookingBaseType(
        type: type ?? this.type, minimumAge: minimumAge ?? this.minimumAge);
  }

  BookingBaseType copyWithWrapped(
      {Wrapped<enums.BookingBaseTypeType>? type, Wrapped<int>? minimumAge}) {
    return BookingBaseType(
        type: (type != null ? type.value : this.type),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesBaseType {
  SeriesBaseType({
    required this.seriesId,
    required this.title,
    this.synopsis,
    required this.containsAdult,
    this.channelId,
    required this.type,
    required this.minimumAge,
  });

  factory SeriesBaseType.fromJson(Map<String, dynamic> json) =>
      _$SeriesBaseTypeFromJson(json);

  static const toJsonFactory = _$SeriesBaseTypeToJson;
  Map<String, dynamic> toJson() => _$SeriesBaseTypeToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String seriesId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool containsAdult;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: seriesBaseTypeTypeToJson,
    fromJson: seriesBaseTypeTypeFromJson,
  )
  final enums.SeriesBaseTypeType type;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int minimumAge;
  static const fromJsonFactory = _$SeriesBaseTypeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesBaseType &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      runtimeType.hashCode;
}

extension $SeriesBaseTypeExtension on SeriesBaseType {
  SeriesBaseType copyWith(
      {String? seriesId,
      String? title,
      String? synopsis,
      bool? containsAdult,
      String? channelId,
      enums.SeriesBaseTypeType? type,
      int? minimumAge}) {
    return SeriesBaseType(
        seriesId: seriesId ?? this.seriesId,
        title: title ?? this.title,
        synopsis: synopsis ?? this.synopsis,
        containsAdult: containsAdult ?? this.containsAdult,
        channelId: channelId ?? this.channelId,
        type: type ?? this.type,
        minimumAge: minimumAge ?? this.minimumAge);
  }

  SeriesBaseType copyWithWrapped(
      {Wrapped<String>? seriesId,
      Wrapped<String>? title,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? containsAdult,
      Wrapped<String?>? channelId,
      Wrapped<enums.SeriesBaseTypeType>? type,
      Wrapped<int>? minimumAge}) {
    return SeriesBaseType(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        title: (title != null ? title.value : this.title),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        channelId: (channelId != null ? channelId.value : this.channelId),
        type: (type != null ? type.value : this.type),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge));
  }
}

@JsonSerializable(explicitToJson: true)
class Show {
  Show({
    this.seasons,
    this.episodes,
    required this.type,
    required this.minimumAge,
    required this.seriesId,
    required this.title,
    this.synopsis,
    required this.containsAdult,
    this.channelId,
  });

  factory Show.fromJson(Map<String, dynamic> json) => _$ShowFromJson(json);

  static const toJsonFactory = _$ShowToJson;
  Map<String, dynamic> toJson() => _$ShowToJson(this);

  @JsonKey(name: 'seasons', includeIfNull: false, defaultValue: <Season>[])
  final List<Season>? seasons;
  @JsonKey(
      name: 'episodes', includeIfNull: false, defaultValue: <SingleBooking>[])
  final List<SingleBooking>? episodes;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: showTypeToJson,
    fromJson: showTypeFromJson,
  )
  final enums.ShowType type;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int minimumAge;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String seriesId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool containsAdult;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  static const fromJsonFactory = _$ShowFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Show &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $ShowExtension on Show {
  Show copyWith(
      {List<Season>? seasons,
      List<SingleBooking>? episodes,
      enums.ShowType? type,
      int? minimumAge,
      String? seriesId,
      String? title,
      String? synopsis,
      bool? containsAdult,
      String? channelId}) {
    return Show(
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        type: type ?? this.type,
        minimumAge: minimumAge ?? this.minimumAge,
        seriesId: seriesId ?? this.seriesId,
        title: title ?? this.title,
        synopsis: synopsis ?? this.synopsis,
        containsAdult: containsAdult ?? this.containsAdult,
        channelId: channelId ?? this.channelId);
  }

  Show copyWithWrapped(
      {Wrapped<List<Season>?>? seasons,
      Wrapped<List<SingleBooking>?>? episodes,
      Wrapped<enums.ShowType>? type,
      Wrapped<int>? minimumAge,
      Wrapped<String>? seriesId,
      Wrapped<String>? title,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? containsAdult,
      Wrapped<String?>? channelId}) {
    return Show(
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        type: (type != null ? type.value : this.type),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        title: (title != null ? title.value : this.title),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class Season {
  Season({
    this.seasonNumber,
    this.episodes,
    required this.type,
    required this.minimumAge,
    required this.seriesId,
    required this.title,
    this.synopsis,
    required this.containsAdult,
    this.channelId,
  });

  factory Season.fromJson(Map<String, dynamic> json) => _$SeasonFromJson(json);

  static const toJsonFactory = _$SeasonToJson;
  Map<String, dynamic> toJson() => _$SeasonToJson(this);

  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(
      name: 'episodes', includeIfNull: false, defaultValue: <SingleBooking>[])
  final List<SingleBooking>? episodes;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: seasonTypeToJson,
    fromJson: seasonTypeFromJson,
  )
  final enums.SeasonType type;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int minimumAge;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String seriesId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool containsAdult;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  static const fromJsonFactory = _$SeasonFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Season &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $SeasonExtension on Season {
  Season copyWith(
      {int? seasonNumber,
      List<SingleBooking>? episodes,
      enums.SeasonType? type,
      int? minimumAge,
      String? seriesId,
      String? title,
      String? synopsis,
      bool? containsAdult,
      String? channelId}) {
    return Season(
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodes: episodes ?? this.episodes,
        type: type ?? this.type,
        minimumAge: minimumAge ?? this.minimumAge,
        seriesId: seriesId ?? this.seriesId,
        title: title ?? this.title,
        synopsis: synopsis ?? this.synopsis,
        containsAdult: containsAdult ?? this.containsAdult,
        channelId: channelId ?? this.channelId);
  }

  Season copyWithWrapped(
      {Wrapped<int?>? seasonNumber,
      Wrapped<List<SingleBooking>?>? episodes,
      Wrapped<enums.SeasonType>? type,
      Wrapped<int>? minimumAge,
      Wrapped<String>? seriesId,
      Wrapped<String>? title,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? containsAdult,
      Wrapped<String?>? channelId}) {
    return Season(
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodes: (episodes != null ? episodes.value : this.episodes),
        type: (type != null ? type.value : this.type),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        title: (title != null ? title.value : this.title),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class SingleBooking {
  SingleBooking({
    required this.bookingId,
    this.eventId,
    this.channelId,
    this.seriesId,
    this.episodeNumber,
    required this.title,
    this.episodeTitle,
    this.synopsis,
    required this.isAdult,
    required this.recordingState,
    required this.startTime,
    required this.endTime,
    this.duration,
    required this.isPlayable,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    required this.type,
    required this.minimumAge,
  });

  factory SingleBooking.fromJson(Map<String, dynamic> json) =>
      _$SingleBookingFromJson(json);

  static const toJsonFactory = _$SingleBookingToJson;
  Map<String, dynamic> toJson() => _$SingleBookingToJson(this);

  @JsonKey(name: 'bookingId', includeIfNull: false, defaultValue: '')
  final String bookingId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: singleBookingRecordingStateToJson,
    fromJson: singleBookingRecordingStateFromJson,
  )
  final enums.SingleBookingRecordingState recordingState;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'isPlayable', includeIfNull: false)
  final bool isPlayable;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: singleBookingTypeToJson,
    fromJson: singleBookingTypeFromJson,
  )
  final enums.SingleBookingType type;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int minimumAge;
  static const fromJsonFactory = _$SingleBookingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SingleBooking &&
            (identical(other.bookingId, bookingId) ||
                const DeepCollectionEquality()
                    .equals(other.bookingId, bookingId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.isPlayable, isPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isPlayable, isPlayable)) &&
            (identical(other.audioLanguages, audioLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.signLanguages, signLanguages)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(bookingId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(isPlayable) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      runtimeType.hashCode;
}

extension $SingleBookingExtension on SingleBooking {
  SingleBooking copyWith(
      {String? bookingId,
      String? eventId,
      String? channelId,
      String? seriesId,
      int? episodeNumber,
      String? title,
      String? episodeTitle,
      String? synopsis,
      bool? isAdult,
      enums.SingleBookingRecordingState? recordingState,
      DateTime? startTime,
      DateTime? endTime,
      int? duration,
      bool? isPlayable,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      enums.SingleBookingType? type,
      int? minimumAge}) {
    return SingleBooking(
        bookingId: bookingId ?? this.bookingId,
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        seriesId: seriesId ?? this.seriesId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        title: title ?? this.title,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        synopsis: synopsis ?? this.synopsis,
        isAdult: isAdult ?? this.isAdult,
        recordingState: recordingState ?? this.recordingState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        isPlayable: isPlayable ?? this.isPlayable,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        type: type ?? this.type,
        minimumAge: minimumAge ?? this.minimumAge);
  }

  SingleBooking copyWithWrapped(
      {Wrapped<String>? bookingId,
      Wrapped<String?>? eventId,
      Wrapped<String?>? channelId,
      Wrapped<String?>? seriesId,
      Wrapped<int?>? episodeNumber,
      Wrapped<String>? title,
      Wrapped<String?>? episodeTitle,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? isAdult,
      Wrapped<enums.SingleBookingRecordingState>? recordingState,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? duration,
      Wrapped<bool>? isPlayable,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<enums.SingleBookingType>? type,
      Wrapped<int>? minimumAge}) {
    return SingleBooking(
        bookingId: (bookingId != null ? bookingId.value : this.bookingId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        title: (title != null ? title.value : this.title),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        isPlayable: (isPlayable != null ? isPlayable.value : this.isPlayable),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        type: (type != null ? type.value : this.type),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge));
  }
}

@JsonSerializable(explicitToJson: true)
class GetBookingsResponse {
  GetBookingsResponse({
    this.stbs,
    this.token,
  });

  factory GetBookingsResponse.fromJson(Map<String, dynamic> json) =>
      _$GetBookingsResponseFromJson(json);

  static const toJsonFactory = _$GetBookingsResponseToJson;
  Map<String, dynamic> toJson() => _$GetBookingsResponseToJson(this);

  @JsonKey(name: 'stbs', includeIfNull: false, defaultValue: <STBBookings>[])
  final List<STBBookings>? stbs;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$GetBookingsResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetBookingsResponse &&
            (identical(other.stbs, stbs) ||
                const DeepCollectionEquality().equals(other.stbs, stbs)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stbs) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $GetBookingsResponseExtension on GetBookingsResponse {
  GetBookingsResponse copyWith({List<STBBookings>? stbs, String? token}) {
    return GetBookingsResponse(
        stbs: stbs ?? this.stbs, token: token ?? this.token);
  }

  GetBookingsResponse copyWithWrapped(
      {Wrapped<List<STBBookings>?>? stbs, Wrapped<String?>? token}) {
    return GetBookingsResponse(
        stbs: (stbs != null ? stbs.value : this.stbs),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class PostBookingRequestSingle {
  PostBookingRequestSingle({
    required this.stbId,
    required this.eventId,
    required this.channelId,
    required this.startTime,
    required this.endTime,
  });

  factory PostBookingRequestSingle.fromJson(Map<String, dynamic> json) =>
      _$PostBookingRequestSingleFromJson(json);

  static const toJsonFactory = _$PostBookingRequestSingleToJson;
  Map<String, dynamic> toJson() => _$PostBookingRequestSingleToJson(this);

  @JsonKey(name: 'stbId', includeIfNull: false, defaultValue: '')
  final String stbId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  static const fromJsonFactory = _$PostBookingRequestSingleFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostBookingRequestSingle &&
            (identical(other.stbId, stbId) ||
                const DeepCollectionEquality().equals(other.stbId, stbId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality().equals(other.endTime, endTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stbId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      runtimeType.hashCode;
}

extension $PostBookingRequestSingleExtension on PostBookingRequestSingle {
  PostBookingRequestSingle copyWith(
      {String? stbId,
      String? eventId,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime}) {
    return PostBookingRequestSingle(
        stbId: stbId ?? this.stbId,
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime);
  }

  PostBookingRequestSingle copyWithWrapped(
      {Wrapped<String>? stbId,
      Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime}) {
    return PostBookingRequestSingle(
        stbId: (stbId != null ? stbId.value : this.stbId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteBookingRequestSingle {
  DeleteBookingRequestSingle({
    required this.stbId,
    required this.bookingId,
  });

  factory DeleteBookingRequestSingle.fromJson(Map<String, dynamic> json) =>
      _$DeleteBookingRequestSingleFromJson(json);

  static const toJsonFactory = _$DeleteBookingRequestSingleToJson;
  Map<String, dynamic> toJson() => _$DeleteBookingRequestSingleToJson(this);

  @JsonKey(name: 'stbId', includeIfNull: false, defaultValue: '')
  final String stbId;
  @JsonKey(name: 'bookingId', includeIfNull: false, defaultValue: '')
  final String bookingId;
  static const fromJsonFactory = _$DeleteBookingRequestSingleFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteBookingRequestSingle &&
            (identical(other.stbId, stbId) ||
                const DeepCollectionEquality().equals(other.stbId, stbId)) &&
            (identical(other.bookingId, bookingId) ||
                const DeepCollectionEquality()
                    .equals(other.bookingId, bookingId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stbId) ^
      const DeepCollectionEquality().hash(bookingId) ^
      runtimeType.hashCode;
}

extension $DeleteBookingRequestSingleExtension on DeleteBookingRequestSingle {
  DeleteBookingRequestSingle copyWith({String? stbId, String? bookingId}) {
    return DeleteBookingRequestSingle(
        stbId: stbId ?? this.stbId, bookingId: bookingId ?? this.bookingId);
  }

  DeleteBookingRequestSingle copyWithWrapped(
      {Wrapped<String>? stbId, Wrapped<String>? bookingId}) {
    return DeleteBookingRequestSingle(
        stbId: (stbId != null ? stbId.value : this.stbId),
        bookingId: (bookingId != null ? bookingId.value : this.bookingId));
  }
}

@JsonSerializable(explicitToJson: true)
class PostBookingRequestShow {
  PostBookingRequestShow({
    required this.stbId,
    required this.eventId,
    required this.channelId,
    required this.startTime,
    required this.endTime,
  });

  factory PostBookingRequestShow.fromJson(Map<String, dynamic> json) =>
      _$PostBookingRequestShowFromJson(json);

  static const toJsonFactory = _$PostBookingRequestShowToJson;
  Map<String, dynamic> toJson() => _$PostBookingRequestShowToJson(this);

  @JsonKey(name: 'stbId', includeIfNull: false, defaultValue: '')
  final String stbId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  static const fromJsonFactory = _$PostBookingRequestShowFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostBookingRequestShow &&
            (identical(other.stbId, stbId) ||
                const DeepCollectionEquality().equals(other.stbId, stbId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality().equals(other.endTime, endTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stbId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      runtimeType.hashCode;
}

extension $PostBookingRequestShowExtension on PostBookingRequestShow {
  PostBookingRequestShow copyWith(
      {String? stbId,
      String? eventId,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime}) {
    return PostBookingRequestShow(
        stbId: stbId ?? this.stbId,
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime);
  }

  PostBookingRequestShow copyWithWrapped(
      {Wrapped<String>? stbId,
      Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime}) {
    return PostBookingRequestShow(
        stbId: (stbId != null ? stbId.value : this.stbId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteBookingRequestShow {
  DeleteBookingRequestShow({
    required this.stbId,
    required this.bookingId,
    required this.deleteBookings,
  });

  factory DeleteBookingRequestShow.fromJson(Map<String, dynamic> json) =>
      _$DeleteBookingRequestShowFromJson(json);

  static const toJsonFactory = _$DeleteBookingRequestShowToJson;
  Map<String, dynamic> toJson() => _$DeleteBookingRequestShowToJson(this);

  @JsonKey(name: 'stbId', includeIfNull: false, defaultValue: '')
  final String stbId;
  @JsonKey(name: 'bookingId', includeIfNull: false, defaultValue: '')
  final String bookingId;
  @JsonKey(
    name: 'deleteBookings',
    includeIfNull: false,
    toJson: deleteBookingRequestShowDeleteBookingsToJson,
    fromJson: deleteBookingRequestShowDeleteBookingsFromJson,
  )
  final enums.DeleteBookingRequestShowDeleteBookings deleteBookings;
  static const fromJsonFactory = _$DeleteBookingRequestShowFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteBookingRequestShow &&
            (identical(other.stbId, stbId) ||
                const DeepCollectionEquality().equals(other.stbId, stbId)) &&
            (identical(other.bookingId, bookingId) ||
                const DeepCollectionEquality()
                    .equals(other.bookingId, bookingId)) &&
            (identical(other.deleteBookings, deleteBookings) ||
                const DeepCollectionEquality()
                    .equals(other.deleteBookings, deleteBookings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stbId) ^
      const DeepCollectionEquality().hash(bookingId) ^
      const DeepCollectionEquality().hash(deleteBookings) ^
      runtimeType.hashCode;
}

extension $DeleteBookingRequestShowExtension on DeleteBookingRequestShow {
  DeleteBookingRequestShow copyWith(
      {String? stbId,
      String? bookingId,
      enums.DeleteBookingRequestShowDeleteBookings? deleteBookings}) {
    return DeleteBookingRequestShow(
        stbId: stbId ?? this.stbId,
        bookingId: bookingId ?? this.bookingId,
        deleteBookings: deleteBookings ?? this.deleteBookings);
  }

  DeleteBookingRequestShow copyWithWrapped(
      {Wrapped<String>? stbId,
      Wrapped<String>? bookingId,
      Wrapped<enums.DeleteBookingRequestShowDeleteBookings>? deleteBookings}) {
    return DeleteBookingRequestShow(
        stbId: (stbId != null ? stbId.value : this.stbId),
        bookingId: (bookingId != null ? bookingId.value : this.bookingId),
        deleteBookings: (deleteBookings != null
            ? deleteBookings.value
            : this.deleteBookings));
  }
}

@JsonSerializable(explicitToJson: true)
class AudioLanguage {
  AudioLanguage({
    required this.lang,
    this.purpose,
  });

  factory AudioLanguage.fromJson(Map<String, dynamic> json) =>
      _$AudioLanguageFromJson(json);

  static const toJsonFactory = _$AudioLanguageToJson;
  Map<String, dynamic> toJson() => _$AudioLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$AudioLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AudioLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $AudioLanguageExtension on AudioLanguage {
  AudioLanguage copyWith({String? lang, int? purpose}) {
    return AudioLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  AudioLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return AudioLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class CaptionLanguage {
  CaptionLanguage({
    required this.lang,
    this.purpose,
  });

  factory CaptionLanguage.fromJson(Map<String, dynamic> json) =>
      _$CaptionLanguageFromJson(json);

  static const toJsonFactory = _$CaptionLanguageToJson;
  Map<String, dynamic> toJson() => _$CaptionLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$CaptionLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CaptionLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $CaptionLanguageExtension on CaptionLanguage {
  CaptionLanguage copyWith({String? lang, int? purpose}) {
    return CaptionLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  CaptionLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return CaptionLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class SignLanguage {
  SignLanguage({
    required this.lang,
    this.purpose,
  });

  factory SignLanguage.fromJson(Map<String, dynamic> json) =>
      _$SignLanguageFromJson(json);

  static const toJsonFactory = _$SignLanguageToJson;
  Map<String, dynamic> toJson() => _$SignLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$SignLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SignLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $SignLanguageExtension on SignLanguage {
  SignLanguage copyWith({String? lang, int? purpose}) {
    return SignLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  SignLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return SignLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error?>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? bookingBaseTypeTypeToJson(
    enums.BookingBaseTypeType? bookingBaseTypeType) {
  return bookingBaseTypeType?.value;
}

enums.BookingBaseTypeType bookingBaseTypeTypeFromJson(
  Object? bookingBaseTypeType, [
  enums.BookingBaseTypeType? defaultValue,
]) {
  return enums.BookingBaseTypeType.values
          .firstWhereOrNull((e) => e.value == bookingBaseTypeType) ??
      defaultValue ??
      enums.BookingBaseTypeType.swaggerGeneratedUnknown;
}

List<String> bookingBaseTypeTypeListToJson(
    List<enums.BookingBaseTypeType>? bookingBaseTypeType) {
  if (bookingBaseTypeType == null) {
    return [];
  }

  return bookingBaseTypeType.map((e) => e.value!).toList();
}

List<enums.BookingBaseTypeType> bookingBaseTypeTypeListFromJson(
  List? bookingBaseTypeType, [
  List<enums.BookingBaseTypeType>? defaultValue,
]) {
  if (bookingBaseTypeType == null) {
    return defaultValue ?? [];
  }

  return bookingBaseTypeType
      .map((e) => bookingBaseTypeTypeFromJson(e.toString()))
      .toList();
}

List<enums.BookingBaseTypeType>? bookingBaseTypeTypeNullableListFromJson(
  List? bookingBaseTypeType, [
  List<enums.BookingBaseTypeType>? defaultValue,
]) {
  if (bookingBaseTypeType == null) {
    return defaultValue;
  }

  return bookingBaseTypeType
      .map((e) => bookingBaseTypeTypeFromJson(e.toString()))
      .toList();
}

String? seriesBaseTypeTypeToJson(enums.SeriesBaseTypeType? seriesBaseTypeType) {
  return seriesBaseTypeType?.value;
}

enums.SeriesBaseTypeType seriesBaseTypeTypeFromJson(
  Object? seriesBaseTypeType, [
  enums.SeriesBaseTypeType? defaultValue,
]) {
  return enums.SeriesBaseTypeType.values
          .firstWhereOrNull((e) => e.value == seriesBaseTypeType) ??
      defaultValue ??
      enums.SeriesBaseTypeType.swaggerGeneratedUnknown;
}

List<String> seriesBaseTypeTypeListToJson(
    List<enums.SeriesBaseTypeType>? seriesBaseTypeType) {
  if (seriesBaseTypeType == null) {
    return [];
  }

  return seriesBaseTypeType.map((e) => e.value!).toList();
}

List<enums.SeriesBaseTypeType> seriesBaseTypeTypeListFromJson(
  List? seriesBaseTypeType, [
  List<enums.SeriesBaseTypeType>? defaultValue,
]) {
  if (seriesBaseTypeType == null) {
    return defaultValue ?? [];
  }

  return seriesBaseTypeType
      .map((e) => seriesBaseTypeTypeFromJson(e.toString()))
      .toList();
}

List<enums.SeriesBaseTypeType>? seriesBaseTypeTypeNullableListFromJson(
  List? seriesBaseTypeType, [
  List<enums.SeriesBaseTypeType>? defaultValue,
]) {
  if (seriesBaseTypeType == null) {
    return defaultValue;
  }

  return seriesBaseTypeType
      .map((e) => seriesBaseTypeTypeFromJson(e.toString()))
      .toList();
}

String? showTypeToJson(enums.ShowType? showType) {
  return showType?.value;
}

enums.ShowType showTypeFromJson(
  Object? showType, [
  enums.ShowType? defaultValue,
]) {
  return enums.ShowType.values.firstWhereOrNull((e) => e.value == showType) ??
      defaultValue ??
      enums.ShowType.swaggerGeneratedUnknown;
}

List<String> showTypeListToJson(List<enums.ShowType>? showType) {
  if (showType == null) {
    return [];
  }

  return showType.map((e) => e.value!).toList();
}

List<enums.ShowType> showTypeListFromJson(
  List? showType, [
  List<enums.ShowType>? defaultValue,
]) {
  if (showType == null) {
    return defaultValue ?? [];
  }

  return showType.map((e) => showTypeFromJson(e.toString())).toList();
}

List<enums.ShowType>? showTypeNullableListFromJson(
  List? showType, [
  List<enums.ShowType>? defaultValue,
]) {
  if (showType == null) {
    return defaultValue;
  }

  return showType.map((e) => showTypeFromJson(e.toString())).toList();
}

String? seasonTypeToJson(enums.SeasonType? seasonType) {
  return seasonType?.value;
}

enums.SeasonType seasonTypeFromJson(
  Object? seasonType, [
  enums.SeasonType? defaultValue,
]) {
  return enums.SeasonType.values
          .firstWhereOrNull((e) => e.value == seasonType) ??
      defaultValue ??
      enums.SeasonType.swaggerGeneratedUnknown;
}

List<String> seasonTypeListToJson(List<enums.SeasonType>? seasonType) {
  if (seasonType == null) {
    return [];
  }

  return seasonType.map((e) => e.value!).toList();
}

List<enums.SeasonType> seasonTypeListFromJson(
  List? seasonType, [
  List<enums.SeasonType>? defaultValue,
]) {
  if (seasonType == null) {
    return defaultValue ?? [];
  }

  return seasonType.map((e) => seasonTypeFromJson(e.toString())).toList();
}

List<enums.SeasonType>? seasonTypeNullableListFromJson(
  List? seasonType, [
  List<enums.SeasonType>? defaultValue,
]) {
  if (seasonType == null) {
    return defaultValue;
  }

  return seasonType.map((e) => seasonTypeFromJson(e.toString())).toList();
}

String? singleBookingRecordingStateToJson(
    enums.SingleBookingRecordingState? singleBookingRecordingState) {
  return singleBookingRecordingState?.value;
}

enums.SingleBookingRecordingState singleBookingRecordingStateFromJson(
  Object? singleBookingRecordingState, [
  enums.SingleBookingRecordingState? defaultValue,
]) {
  return enums.SingleBookingRecordingState.values
          .firstWhereOrNull((e) => e.value == singleBookingRecordingState) ??
      defaultValue ??
      enums.SingleBookingRecordingState.swaggerGeneratedUnknown;
}

List<String> singleBookingRecordingStateListToJson(
    List<enums.SingleBookingRecordingState>? singleBookingRecordingState) {
  if (singleBookingRecordingState == null) {
    return [];
  }

  return singleBookingRecordingState.map((e) => e.value!).toList();
}

List<enums.SingleBookingRecordingState> singleBookingRecordingStateListFromJson(
  List? singleBookingRecordingState, [
  List<enums.SingleBookingRecordingState>? defaultValue,
]) {
  if (singleBookingRecordingState == null) {
    return defaultValue ?? [];
  }

  return singleBookingRecordingState
      .map((e) => singleBookingRecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.SingleBookingRecordingState>?
    singleBookingRecordingStateNullableListFromJson(
  List? singleBookingRecordingState, [
  List<enums.SingleBookingRecordingState>? defaultValue,
]) {
  if (singleBookingRecordingState == null) {
    return defaultValue;
  }

  return singleBookingRecordingState
      .map((e) => singleBookingRecordingStateFromJson(e.toString()))
      .toList();
}

String? singleBookingTypeToJson(enums.SingleBookingType? singleBookingType) {
  return singleBookingType?.value;
}

enums.SingleBookingType singleBookingTypeFromJson(
  Object? singleBookingType, [
  enums.SingleBookingType? defaultValue,
]) {
  return enums.SingleBookingType.values
          .firstWhereOrNull((e) => e.value == singleBookingType) ??
      defaultValue ??
      enums.SingleBookingType.swaggerGeneratedUnknown;
}

List<String> singleBookingTypeListToJson(
    List<enums.SingleBookingType>? singleBookingType) {
  if (singleBookingType == null) {
    return [];
  }

  return singleBookingType.map((e) => e.value!).toList();
}

List<enums.SingleBookingType> singleBookingTypeListFromJson(
  List? singleBookingType, [
  List<enums.SingleBookingType>? defaultValue,
]) {
  if (singleBookingType == null) {
    return defaultValue ?? [];
  }

  return singleBookingType
      .map((e) => singleBookingTypeFromJson(e.toString()))
      .toList();
}

List<enums.SingleBookingType>? singleBookingTypeNullableListFromJson(
  List? singleBookingType, [
  List<enums.SingleBookingType>? defaultValue,
]) {
  if (singleBookingType == null) {
    return defaultValue;
  }

  return singleBookingType
      .map((e) => singleBookingTypeFromJson(e.toString()))
      .toList();
}

String? deleteBookingRequestShowDeleteBookingsToJson(
    enums.DeleteBookingRequestShowDeleteBookings?
        deleteBookingRequestShowDeleteBookings) {
  return deleteBookingRequestShowDeleteBookings?.value;
}

enums.DeleteBookingRequestShowDeleteBookings
    deleteBookingRequestShowDeleteBookingsFromJson(
  Object? deleteBookingRequestShowDeleteBookings, [
  enums.DeleteBookingRequestShowDeleteBookings? defaultValue,
]) {
  return enums.DeleteBookingRequestShowDeleteBookings.values.firstWhereOrNull(
          (e) => e.value == deleteBookingRequestShowDeleteBookings) ??
      defaultValue ??
      enums.DeleteBookingRequestShowDeleteBookings.swaggerGeneratedUnknown;
}

List<String> deleteBookingRequestShowDeleteBookingsListToJson(
    List<enums.DeleteBookingRequestShowDeleteBookings>?
        deleteBookingRequestShowDeleteBookings) {
  if (deleteBookingRequestShowDeleteBookings == null) {
    return [];
  }

  return deleteBookingRequestShowDeleteBookings.map((e) => e.value!).toList();
}

List<enums.DeleteBookingRequestShowDeleteBookings>
    deleteBookingRequestShowDeleteBookingsListFromJson(
  List? deleteBookingRequestShowDeleteBookings, [
  List<enums.DeleteBookingRequestShowDeleteBookings>? defaultValue,
]) {
  if (deleteBookingRequestShowDeleteBookings == null) {
    return defaultValue ?? [];
  }

  return deleteBookingRequestShowDeleteBookings
      .map((e) => deleteBookingRequestShowDeleteBookingsFromJson(e.toString()))
      .toList();
}

List<enums.DeleteBookingRequestShowDeleteBookings>?
    deleteBookingRequestShowDeleteBookingsNullableListFromJson(
  List? deleteBookingRequestShowDeleteBookings, [
  List<enums.DeleteBookingRequestShowDeleteBookings>? defaultValue,
]) {
  if (deleteBookingRequestShowDeleteBookings == null) {
    return defaultValue;
  }

  return deleteBookingRequestShowDeleteBookings
      .map((e) => deleteBookingRequestShowDeleteBookingsFromJson(e.toString()))
      .toList();
}

String? customerCustomerIdBookingsGetSortToJson(
    enums.CustomerCustomerIdBookingsGetSort?
        customerCustomerIdBookingsGetSort) {
  return customerCustomerIdBookingsGetSort?.value;
}

enums.CustomerCustomerIdBookingsGetSort
    customerCustomerIdBookingsGetSortFromJson(
  Object? customerCustomerIdBookingsGetSort, [
  enums.CustomerCustomerIdBookingsGetSort? defaultValue,
]) {
  return enums.CustomerCustomerIdBookingsGetSort.values.firstWhereOrNull(
          (e) => e.value == customerCustomerIdBookingsGetSort) ??
      defaultValue ??
      enums.CustomerCustomerIdBookingsGetSort.swaggerGeneratedUnknown;
}

List<String> customerCustomerIdBookingsGetSortListToJson(
    List<enums.CustomerCustomerIdBookingsGetSort>?
        customerCustomerIdBookingsGetSort) {
  if (customerCustomerIdBookingsGetSort == null) {
    return [];
  }

  return customerCustomerIdBookingsGetSort.map((e) => e.value!).toList();
}

List<enums.CustomerCustomerIdBookingsGetSort>
    customerCustomerIdBookingsGetSortListFromJson(
  List? customerCustomerIdBookingsGetSort, [
  List<enums.CustomerCustomerIdBookingsGetSort>? defaultValue,
]) {
  if (customerCustomerIdBookingsGetSort == null) {
    return defaultValue ?? [];
  }

  return customerCustomerIdBookingsGetSort
      .map((e) => customerCustomerIdBookingsGetSortFromJson(e.toString()))
      .toList();
}

List<enums.CustomerCustomerIdBookingsGetSort>?
    customerCustomerIdBookingsGetSortNullableListFromJson(
  List? customerCustomerIdBookingsGetSort, [
  List<enums.CustomerCustomerIdBookingsGetSort>? defaultValue,
]) {
  if (customerCustomerIdBookingsGetSort == null) {
    return defaultValue;
  }

  return customerCustomerIdBookingsGetSort
      .map((e) => customerCustomerIdBookingsGetSortFromJson(e.toString()))
      .toList();
}

String? customerCustomerIdBookingsGetSortOrderToJson(
    enums.CustomerCustomerIdBookingsGetSortOrder?
        customerCustomerIdBookingsGetSortOrder) {
  return customerCustomerIdBookingsGetSortOrder?.value;
}

enums.CustomerCustomerIdBookingsGetSortOrder
    customerCustomerIdBookingsGetSortOrderFromJson(
  Object? customerCustomerIdBookingsGetSortOrder, [
  enums.CustomerCustomerIdBookingsGetSortOrder? defaultValue,
]) {
  return enums.CustomerCustomerIdBookingsGetSortOrder.values.firstWhereOrNull(
          (e) => e.value == customerCustomerIdBookingsGetSortOrder) ??
      defaultValue ??
      enums.CustomerCustomerIdBookingsGetSortOrder.swaggerGeneratedUnknown;
}

List<String> customerCustomerIdBookingsGetSortOrderListToJson(
    List<enums.CustomerCustomerIdBookingsGetSortOrder>?
        customerCustomerIdBookingsGetSortOrder) {
  if (customerCustomerIdBookingsGetSortOrder == null) {
    return [];
  }

  return customerCustomerIdBookingsGetSortOrder.map((e) => e.value!).toList();
}

List<enums.CustomerCustomerIdBookingsGetSortOrder>
    customerCustomerIdBookingsGetSortOrderListFromJson(
  List? customerCustomerIdBookingsGetSortOrder, [
  List<enums.CustomerCustomerIdBookingsGetSortOrder>? defaultValue,
]) {
  if (customerCustomerIdBookingsGetSortOrder == null) {
    return defaultValue ?? [];
  }

  return customerCustomerIdBookingsGetSortOrder
      .map((e) => customerCustomerIdBookingsGetSortOrderFromJson(e.toString()))
      .toList();
}

List<enums.CustomerCustomerIdBookingsGetSortOrder>?
    customerCustomerIdBookingsGetSortOrderNullableListFromJson(
  List? customerCustomerIdBookingsGetSortOrder, [
  List<enums.CustomerCustomerIdBookingsGetSortOrder>? defaultValue,
]) {
  if (customerCustomerIdBookingsGetSortOrder == null) {
    return defaultValue;
  }

  return customerCustomerIdBookingsGetSortOrder
      .map((e) => customerCustomerIdBookingsGetSortOrderFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
