const String ref = '\$ref';
const String modelWithParametersV3 = '''
{
 "components": {
    "schemas": {
      "SomeEnumModel" : {
        "enum" : ["one", "two"]
      },
      "trickPlayControl": {
      "type": "array",
      "items": {
        "type": "string",
        "enum": [
          "disallowFastForward",
          "disallowPause",
          "disallowPlay",
          "disallowRewind",
          "disallowSkipForward",
          "disallowSkipBackward",
          "adRestrictionOnly"
        ]
      }
    },
      "AuthorizationDetails": {
        "type": "object",
        "properties": {
          "state": {
            "type": "string",
            "format": "uuid",
            "description": "Opaque value generated. The state will be echoed back in the token response, therefore state needs to be maintained between the request and the response.",
            "example": "00001-00002-00003-00004"
          },
          "authorizationUri": {
            "type": "string",
            "format": "uri",
            "description": "URI to follow for authorization",
            "example": "https://sso.service.some.country/oidc/authorize?response_type=code&state=00001-00002-00003-00004&nonce=54345345-345345345-345345345-435345&client_id=some-client-id&redirect_uri=https%3A%2F%2Fsome-success-uri.com%2Fen_gb%2Flogin_success"
          },
          "enumValue": {
            "type": "enum",
            "enum": ["one", "two"]
          },
          "redirectUri": {
            "type": "string",
            "format": "uri",
            "description": "Redirect URI used after successful authentication",
            "example": "https%3A%2F%2Fsome-success-uri.com%2Fen_gb%2Flogin_success"
          },
          "logoutUri": {
            "type": "string",
            "format": "uri",
            "description": "URI to follow to logout"
          },
          "validityToken": {
            "type": "string",
            "description": "The validity token will contain the payload of the generated nonce and state value.",
            "example": ""
          }
        }
      },
      "CompleteAuthorizationRequest": {
        "type": "object",
        "properties": {
          "code": {
            "type": "string",
            "description": "Code value obtained for SSO authorization service"
          },
          "state": {
            "type": "string",
            "format": "uuid",
            "description": "State value obtained previously",
            "example": "00001-00002-00003-00004"
          },
          "validityToken": {
            "type": "string",
            "description": "The validity token obtained previously",
            "example": ""
          }
        }
      },
      "TokensResponse": {
        "type": "object",
        "properties": {
          "token_type": {
            "type": "string",
            "enum": [
              "bearer"
            ]
          },
          "access_token": {
            "$ref": "#/components/schemas/SvcAccessToken"
          },
          "refresh_token": {
            "$ref": "#/components/schemas/SvcRefreshToken"
          },
          "expires_in": {
            "type": "integer",
            "description": "access token expiration in seconds"
          },
          "username": {
            "type": "string",
            "description": "username of authenticated client"
          },
          "givenName": {
            "type": "string",
            "description": "first name"
          },
          "familyName": {
            "type": "string",
            "description": "family name"
          }
        }
      },
      "RefreshAuthorizationRequest": {
        "type": "object",
        "properties": {
          "svcRefreshToken": {
            "$ref": "#/components/schemas/SvcRefreshToken"
          }
        }
      },
      "DeleteAuthorizationRequest": {
        "type": "object",
        "properties": {
          "svcRefreshToken": {
            "$ref": "#/components/schemas/SvcRefreshToken"
          }
        }
      },
      "SvcRefreshToken": {
        "type": "string",
        "description": "Valid service refresh token"
      },
      "SvcAccessToken": {
        "type": "string",
        "description": "jwt service access token used as ACCESS_TOKEN with calls to services"
      }
    }
  }
}
''';

const String modelWithParametersV2 = '''
{
  "definitions": {
    "trickPlayControl": {
      "type": "array",
      "items": {
        "type": "string",
        "enum": [
          "disallowFastForward",
          "disallowPause",
          "disallowPlay",
          "disallowRewind",
          "disallowSkipForward",
          "disallowSkipBackward",
          "adRestrictionOnly"
        ]
      }
    },
    "ActiveOrderAndListSummary": {
      "type": "object",
      "required": [
        "closingTime",
        "id",
        "shoppingType",
        "slotReservationHours",
        "state"
      ],
      "properties": {
        "closingTime": {
          "type": "string",
          "format": "date-time"
        },
        "deliveryDate": {
          "originalRef": "DeliveryDto",
          "\$ref": "#/definitions/DeliveryDto"
        },
        "id": {
          "type": "integer",
          "format": "int64"
        },
        "lastSyncedDate": {
          "type": "string",
          "format": "date-time"
        },
        "enumValue": {
            "type": "enum",
            "enum": ["one", "two"]
          },
        "orderLastChangedTime": {
          "type": "string",
          "format": "date-time"
        },
        "orderedProducts": {
          "type": "array",
          "items": {
            "originalRef": "OrderedProductCard",
            "\$ref": "#/definitions/OrderedProductCard"
          }
        },
        "price": {
          "originalRef": "PriceDto",
          "\$ref": "#/definitions/PriceDto"
        },
        "shoppingListItems": {
          "type": "array",
          "items": {
            "originalRef": "Item",
            "\$ref": "#/definitions/Item"
          }
        },
        "shoppingType": {
          "type": "string",
          "enum": [
            "UNKNOWN",
            "PHYSICAL_STORE",
            "DELIVERY",
            "PICKUP_DELIVERY",
            "DELIVERY_POINT",
            "PICKUP",
            "IN_STORE_PICK",
            "SPECIALS_ONLY"
          ]
        },
        "slotReservationHours": {
          "type": "number",
          "format": "double"
        },
        "state": {
          "type": "string",
          "enum": [
            "CONFIRMED",
            "REOPENED",
            "IN_PREPARATION",
            "UNCONFIRMED",
            "DELIVERED",
            "CANCELLED",
            "PLANNED_FOR_DELIVERY",
            "OUT_FOR_DELIVERY",
            "UNKNOWN"
          ]
        }
      },
      "title": "ActiveOrderAndListSummary"
    }
  }
}
''';

const String requestWithRnumInParameter = '''
{
  "paths": {
    "/v3/order/{orderId}/state": {
      "put": {
        "tags": [
          "appie-order-controller-v-3"
        ],
        "summary": "Update state of an order.",
        "operationId": "changeOrderStateUsingPUT",
        "consumes": [
          "application/json"
        ],
        "produces": [
          "*/*"
        ],
        "parameters": [
          {
            "name": "orderId",
            "in": "path",
            "description": "Id of the order",
            "required": false,
            "type": "integer",
            "format": "int64"
          },
          {
            "in": "body",
            "name": "orderStateRequest",
            "description": "Order state",
            "required": false,
            "schema": {
              "type": "string",
              "enum": [
                "SUBMITTED",
                "CANCELLED",
                "REOPENED",
                "RESET"
              ]
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "object"
            }
          },
          "201": {
            "description": "Created"
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String requestWithListOfEnumInParameter = '''
{
  "paths": {
    "/v3/order/{orderId}/state": {
      "put": {
        "tags": [
          "appie-order-controller-v-3"
        ],
        "summary": "Update state of an order.",
        "operationId": "changeOrderStateUsingPUT",
        "consumes": [
          "application/json"
        ],
        "produces": [
          "*/*"
        ],
        "parameters": [
          {
            "name": "orderId",
            "in": "path",
            "description": "Id of the order",
            "required": false,
            "type": "integer",
            "format": "int64"
          },
          {
            "in": "body",
            "name": "orderStateRequest",
            "description": "Order state",
            "required": false,
            "items": {
              "type": "string",
              "enum": [
                "SUBMITTED",
                "CANCELLED",
                "REOPENED",
                "RESET"
              ]
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "object"
            }
          },
          "201": {
            "description": "Created"
          },
          "401": {
            "description": "Unauthorized"
          },
          "403": {
            "description": "Forbidden"
          },
          "404": {
            "description": "Not Found"
          }
        },
        "security": [
          {
            "apiKey": []
          }
        ],
        "deprecated": false
      }
    }
  }
}
''';

const String schemasResponsesWithResponse = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "required": [
                "showPageAvailable"
              ],
              "properties": {
                "id": {
                  "type": "string",
                  "description": "Some description"
                },
                "showPageAvailable": {
                  "type": "boolean",
                  "description": "Flag indicating showPage availability"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String schemasResponsesWithResponseAndSchemas = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "required": [
                "showPageAvailable"
              ],
              "properties": {
                "id": {
                  "type": "string",
                  "description": "Some description"
                },
                "showPageAvailable": {
                  "type": "boolean",
                  "description": "Flag indicating showPage availability"
                }
              }
            }
          }
        }
      }
    },
    "schemas": {
      "SpaSchema": {
        "type": "object",
        "properties": {
          "id": {
            "type": "string",
            "description": "Some description"
          },
          "showPageAvailable": {
            "type": "boolean",
            "description": "Flag indicating showPage availability"
          }
        }
      }
    }
  }
}
''';

const String enumAsDefinitionV2 = '''
{
  "openapi": "2.0.1",
  "definitions": {
      "SpaResponse": {
        "description": "Success",
        "enum": [
          "one",
          "two"
        ]
    }
  }
}
''';

const String schemasWithEnumsInProperties = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "schemas": {
      "SpaSchema": {
        "type": "object",
        "properties": {
          "id": {
            "type": "string",
            "description": "Some description"
          },
          "showPageAvailable": {
            "type": "boolean",
            "description": "Flag indicating showPage availability"
          },
          "successValues": {
            "enum": [
              "one",
              "two"
            ]
          }
        }
      }
    },
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "enum": [
                "one",
                "two"
              ]
            }
          }
        }
      },
      "SpaEnumResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "properties": {
                "failedValued": {
                  "enum": [
                    "one",
                    "two"
                  ]
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String schemasWithIntegers = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "schemas": {
      "AccountType": {
        "title": "AccountType",
        "enum": [
          0,
          1,
          2,
          6
        ],
        "type": "integer",
        "description": "An enumeration."
      },
      "SpaSchema": {
        "type": "object",
        "properties": {
          "id": {
            "type": "string",
            "description": "Some description"
          },
          "showPageAvailable": {
            "type": "boolean",
            "description": "Flag indicating showPage availability"
          },
          "successValues": {
            "enum": [
              1, 2
            ],
            "type": "integer",
            "default": 1
          }
        }
      }
    },
    "responses": {
      "SpaResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "enum": [
                1, 1
              ],
              "type": "integer"
            }
          }
        }
      },
      "SpaEnumResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "properties": {
                "failedValued": {
                  "enum": [
                    1, 2
                  ],
                  "type": "integer"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String schemasWithEnumsFromAllOf = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "schemas": {
      "Success": {
        "title": "Success",
        "enum": [
          "one",
          "two"
        ],
        "type": "string",
        "description": "An enumeration."
      }
    },
    "responses": {
      "SpaEnumResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "properties": {
                "success": {
                  "allOf": [
                    {
                      "\$ref": "#/components/schemas/Success"
                    }
                  ],
                  "default": "one"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String schemasWithEnumsArrayRef = '''
{
  "openapi": "3.0.1",
  "info": {
    "title": "Some service",
    "version": "1.0"
  },
  "components": {
    "schemas": {
      "Success": {
        "title": "Success",
        "enum": [
          "one",
          "two"
        ],
        "type": "string",
        "description": "An enumeration."
      }
    },
    "responses": {
      "SpaEnumResponse": {
        "description": "Success",
        "content": {
          "application/json": {
            "schema": {
              "properties": {
                "success": {
                  "items": {
                    "\$ref": "#/components/schemas/Success"
                  },
                  "type": "array"
                },
                "successOther": {
                  "items": {
                    "\$ref": "#/components/schemas/Success"
                  },
                  "type": "array",
                  "default": ["one", "two"]
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const String requestWithReturnTypeInjected = '''
{
  "paths": {
    "/model/items": {
      "get": {
        "summary": "Some test request",
        "operationId": "getModelItems",
        "parameters": [
          {
            "name": "testName",
            "in": "query",
            "description": "test name",
            "required": false,
            "type": "array",
            "items": {
              "type": "string"
            },
            "collectionFormat": "multi"
          }
        ],
        "responses": {
          "200": {
            "schema": {
              "type": "object",
              "properties": {
                "id": {
                  "type": "integer",
                  "format": "int64"
                },
                "petId": {
                  "type": "integer",
                  "format": "int64"
                }
              }
            }
          }
        }
      }
    }
  }
}
''';

const requestWithEnum = '''
{
  "paths": {
    "/pets/{petId}/items": {
      "get": {
        "summary": "Some summary",
        "tags": [
          "Bookmarks"
        ],
        "parameters": [
          {
            "name": "contentType",
            "in": "query",
            "description": "content source type",
            "type": "string",
            "schema": {
              "enum": [
              "vod",
              "replay",
              "network-recording",
              "local-recording"
            ]
            }
          }
        ],
        "responses": {
          "200": {
            "description": "Bookmarks for given profile and content is returned.",
            "schema": {
              "\$ref": "#/definitions/Pet"
            }
          }
        }
      }
    }
  }
}
''';

const objectWithadditionalProperties = '''
{
  "components" : {
    "schemas" : {
      "FooDto": {
        "type": "object",
        "properties": {
          "metadata": {
            "type": "object",
            "additionalProperties": {
              "type": "string"
            },
            "nullable": true
          }
        },
        "additionalProperties": false
      }
    }
  }
}
''';

const aaa = '''
{
    "openapi": "3.0.1",
    "info": {
        "title": "settings application service API",
        "description": "For more details see: https://wikiprojects.upc.biz/display/CTOM/settingsn",
        "version": "0.0.8"
    },
    "servers": [
        {
            "url": "http://localhost:10014/settings"
        }
    ],
    "paths": {
        "/getSetting/{key}": {
            "get": {
                "tags": [
                    "operations"
                ],
                "summary": "Gets specified setting value.",
                "parameters": [
                    {
                        "name": "key",
                        "in": "path",
                        "description": "Setting key. `*` to get all settings' values.n",
                        "required": true,
                        "schema": {
                            "allOf": [
                                {
                                    "$ref": "#/components/schemas/Key"
                                },
                                {
                                    "type": "string",
                                    "enum": [
                                        "*"
                                    ]
                                }
                            ]
                        }
                    }
                ],
                "responses": {
                    "200": {
                        "description": "Setting value.n`null` if specified setting is undefined.n",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "oneOf": [
                                        {
                                            "$ref": "#/components/schemas/Value"
                                        },
                                        {
                                            "$ref": "#/components/schemas/Settings"
                                        }
                                    ],
                                    "nullable": true
                                }
                            }
                        }
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                }
            }
        },
        "/setSetting/{key}": {
            "put": {
                "tags": [
                    "operations"
                ],
                "summary": "Sets specified setting value.",
                "parameters": [
                    {
                        "name": "key",
                        "in": "path",
                        "description": "Setting key.",
                        "required": true,
                        "schema": {
                            "$ref": "#/components/schemas/Key"
                        }
                    }
                ],
                "requestBody": {
                    "description": "Setting value.",
                    "content": {
                        "application/json": {
                            "schema": {
                                "$ref": "#/components/schemas/Value"
                            }
                        }
                    },
                    "required": true
                },
                "responses": {
                    "200": {
                        "description": "Success",
                        "content": {}
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                },
                "x-codegen-request-body-name": "value"
            }
        },
        "/resetSetting/{key}": {
            "put": {
                "tags": [
                    "operations"
                ],
                "summary": "Resets specified setting to its default value.",
                "parameters": [
                    {
                        "name": "key",
                        "in": "path",
                        "description": "Setting key.",
                        "required": true,
                        "schema": {
                            "$ref": "#/components/schemas/Key"
                        }
                    }
                ],
                "responses": {
                    "200": {
                        "description": "Setting value after reset.",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/Value"
                                }
                            }
                        }
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                }
            }
        },
        "/getRemoteSetting/{key}": {
            "get": {
                "tags": [
                    "operations"
                ],
                "summary": "Gets specified setting value from the remote household device.",
                "parameters": [
                    {
                        "name": "key",
                        "in": "path",
                        "description": "Setting key.nnOnly Personalization Service supported device settings' keys are allowed.n",
                        "required": true,
                        "schema": {
                            "$ref": "#/components/schemas/RemoteKey"
                        }
                    },
                    {
                        "name": "cpeId",
                        "in": "query",
                        "description": "CPE identifier of the remote household device.nnMust be different than CPE ID of the local device.n",
                        "required": true,
                        "schema": {
                            "type": "string"
                        }
                    }
                ],
                "responses": {
                    "200": {
                        "description": "Setting value.n`null` if specified setting is undefined.n",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/RemoteValue"
                                }
                            }
                        }
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                }
            }
        },
        "/setRemoteSetting/{key}": {
            "put": {
                "tags": [
                    "operations"
                ],
                "summary": "Sets specified setting value of the remote household device.",
                "parameters": [
                    {
                        "name": "key",
                        "in": "path",
                        "description": "Setting key.nnOnly Personalization Service supported device settings' keys are allowed.n",
                        "required": true,
                        "schema": {
                            "$ref": "#/components/schemas/RemoteKey"
                        }
                    },
                    {
                        "name": "cpeId",
                        "in": "query",
                        "description": "CPE identifier of the remote household device.nnMust be different than CPE ID of the local device.n",
                        "required": true,
                        "schema": {
                            "type": "string"
                        }
                    }
                ],
                "requestBody": {
                    "description": "Setting value.",
                    "content": {
                        "application/json": {
                            "schema": {
                                "$ref": "#/components/schemas/RemoteValue"
                            }
                        }
                    },
                    "required": true
                },
                "responses": {
                    "200": {
                        "description": "Success",
                        "content": {}
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                },
                "x-codegen-request-body-name": "value"
            }
        },
        "/getSettings": {
            "put": {
                "tags": [
                    "operations"
                ],
                "summary": "Gets specified settings' values.",
                "requestBody": {
                    "description": "Settings' keys.n",
                    "content": {
                        "application/json": {
                            "schema": {
                                "type": "array",
                                "items": {
                                    "$ref": "#/components/schemas/Key"
                                }
                            }
                        }
                    },
                    "required": true
                },
                "responses": {
                    "200": {
                        "description": "Settings' key-value pairs.n",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/Settings"
                                }
                            }
                        }
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                },
                "x-codegen-request-body-name": "keys"
            }
        },
        "/setSettings": {
            "put": {
                "tags": [
                    "operations"
                ],
                "summary": "Sets specified settings.",
                "description": "Allows to set many settings at once.nThe change is performed by grouping the settings by type (ie. profile, device, customer ...) attempting to reduce amount of underlying update transactions.n",
                "requestBody": {
                    "description": "Settings' key-value pairs.",
                    "content": {
                        "application/json": {
                            "schema": {
                                "$ref": "#/components/schemas/Settings"
                            }
                        }
                    },
                    "required": true
                },
                "responses": {
                    "200": {
                        "description": "Success",
                        "content": {}
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                },
                "x-codegen-request-body-name": "settings"
            }
        },
        "/settingChange/{key}": {
            "get": {
                "tags": [
                    "events"
                ],
                "summary": "Settings change event.",
                "parameters": [
                    {
                        "name": "key",
                        "in": "path",
                        "description": "Setting key.",
                        "required": true,
                        "schema": {
                            "allOf": [
                                {
                                    "$ref": "#/components/schemas/Key"
                                },
                                {
                                    "type": "string",
                                    "enum": [
                                        "*"
                                    ]
                                }
                            ]
                        }
                    }
                ],
                "responses": {
                    "200": {
                        "description": "Success.",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/OnChangeEvent"
                                }
                            }
                        }
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                }
            }
        },
        "/profileSwitchChangesApplied": {
            "get": {
                "tags": [
                    "events"
                ],
                "summary": "Profile switch changes applied event.n",
                "description": "An event emitted after all changes in the settings related to the profile switching have been applied.nnThe profile switch is triggered by the `auth/profileSwitch` event.nnNote: this event is emitted even if the profile switch did not cause any changes of the settings.n",
                "responses": {
                    "200": {
                        "description": "Success.",
                        "content": {}
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                }
            }
        },
        "/ready": {
            "get": {
                "tags": [
                    "events"
                ],
                "summary": "Service ready for operation event.",
                "description": "Retained (a.k.a. persistent) event. Emitted when the service has completed its initialisation.n",
                "responses": {
                    "200": {
                        "description": "Success.",
                        "content": {}
                    },
                    "default": {
                        "description": "Error",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "$ref": "#/components/schemas/ErrorResponse"
                                }
                            }
                        }
                    }
                }
            }
        }
    },
    "components": {
        "schemas": {
            "Any": {
                "description": "Any valid JSON instance.",
                "x-type": "JSON value"
            },
            "ErrorResponse": {
                "required": [
                    "message"
                ],
                "type": "object",
                "properties": {
                    "message": {
                        "type": "string"
                    }
                }
            },
            "OnChangeEvent": {
                "required": [
                    "key"
                ],
                "type": "object",
                "properties": {
                    "key": {
                        "description": "Setting key.",
                        "allOf": [
                            {
                                "$ref": "#/components/schemas/Key"
                            }
                        ]
                    },
                    "newValue": {
                        "type": "object"
                    },
                    "oldValue": {
                        "type": "object"
                    }
                },
                "description": "Setting change event."
            },
            "Key": {
                "type": "string",
                "enum": [
                    "cpe.16by9Handling",
                    "cpe.4by3Handling",
                    "cpe.adsOptInShownForRelease",
                    "cpe.appSubscriptions",
                    "cpe.askPurchasePin",
                    "cpe.askRecPlayPin",
                    "cpe.aspectRatio",
                    "cpe.audioDelayDD",
                    "cpe.audioDelayPCM",
                    "cpe.audioDolbyDigital",
                    "cpe.audioDolbyDigitalMode",
                    "cpe.autoStandby",
                    "cpe.autoTvStartup",
                    "cpe.ccAnalogService",
                    "cpe.ccDigitalService",
                    "cpe.ccsMessages",
                    "cpe.country",
                    "cpe.defaultProfileId",
                    "cpe.defaultPvrStb",
                    "cpe.displayedStandByMessageCount",
                    "cpe.enableCEC",
                    "cpe.factoryResetState",
                    "cpe.factoryResetType",
                    "cpe.friendlyName",
                    "cpe.ftiState",
                    "cpe.hdmiColorOutput",
                    "cpe.hdmiDeviceInfo",
                    "cpe.hdmiResolution",
                    "cpe.isAlexaLinked",
                    "cpe.isSilentDowngrade",
                    "cpe.lastUsedBrandedScreenKey",
                    "cpe.lastUseNetflix",
                    "cpe.lockedApps",
                    "cpe.matchFrameRate",
                    "cpe.netflixRailCache",
                    "cpe.netflixToken",
                    "cpe.netflixVdid",
                    "cpe.oneTouchViewTurnOffPolicy",
                    "cpe.powerCheck",
                    "cpe.powerSource",
                    "cpe.primaryVideoOutput",
                    "cpe.quicksetPairedDevicesInfo",
                    "cpe.rcuUpgradeStatus",
                    "cpe.rebootReason",
                    "cpe.recordPaddingAfter",
                    "cpe.recordPaddingBefore",
                    "cpe.showColdStandByMessage",
                    "cpe.showReplayOptInMessage",
                    "cpe.slowStandByCyclesCount",
                    "cpe.speedTestResults",
                    "cpe.standByMode",
                    "cpe.uiTestTools",
                    "cpe.upgradeStatus",
                    "cpe.useHighContrastUI",
                    "cpe.volume",
                    "cpe.wifiClientEnabled",
                    "cpe.wifiClientPass",
                    "cpe.wifiClientSsid",
                    "cpe.xaBrokerUrl",
                    "customer.a2aHgoOptIn",
                    "customer.a2aStbOptIn",
                    "customer.adsOptIn",
                    "customer.appsOptIn",
                    "customer.autoDeleteFunction",
                    "customer.cityId",
                    "customer.customerId",
                    "customer.defaultHhStb",
                    "customer.deleteRecordingReminder",
                    "customer.isAdultPinUsed",
                    "customer.isFtiPassed",
                    "customer.isSuspended",
                    "customer.personalSuggestions",
                    "customer.recordingRetentionPeriod",
                    "customer.replayOptIn",
                    "customer.replayOptInTime",
                    "customer.zipCode",
                    "profile.accessibleViews",
                    "profile.ageLock",
                    "profile.audioDescription",
                    "profile.audioLang",
                    "profile.onScreenKeyboardMode",
                    "profile.osdLang",
                    "profile.recentlyListenedRadios",
                    "profile.recentlyUsedAppsItems",
                    "profile.recentlyUsedSettingsItems",
                    "profile.signLanguage",
                    "profile.subControl",
                    "profile.subHardOfHearing",
                    "profile.subLang",
                    "profile.surfFavoriteChannels",
                    "profile.textToSpeech",
                    "profile.textToSpeechSpeed",
                    "profile.textToSpeechVoice",
                    "profile.textToSpeechVolume",
                    "profile.tipsAndTricks"
                ]
            },
            "Value": {
                "oneOf": [
                    {
                        "$ref": "#/components/schemas/cpe.16by9Handling"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.4by3Handling"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.adsOptInShownForRelease"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.appSubscriptions"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.askPurchasePin"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.askRecPlayPin"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.aspectRatio"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.audioDelayDD"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.audioDelayPCM"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.audioDolbyDigital"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.audioDolbyDigitalMode"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.autoStandby"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.autoTvStartup"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ccAnalogService"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ccDigitalService"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ccsMessages"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.country"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.defaultProfileId"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.defaultPvrStb"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.displayedStandByMessageCount"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.enableCEC"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.factoryResetState"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.factoryResetType"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.friendlyName"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ftiState"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.hdmiColorOutput"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.hdmiDeviceInfo"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.hdmiResolution"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.isAlexaLinked"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.isSilentDowngrade"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.lastUsedBrandedScreenKey"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.lastUseNetflix"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.lockedApps"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.matchFrameRate"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.netflixRailCache"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.netflixToken"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.netflixVdid"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.oneTouchViewTurnOffPolicy"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.powerCheck"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.powerSource"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.primaryVideoOutput"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.quicksetPairedDevicesInfo"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.rcuUpgradeStatus"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.rebootReason"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.recordPaddingAfter"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.recordPaddingBefore"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.showColdStandByMessage"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.showReplayOptInMessage"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.slowStandByCyclesCount"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.speedTestResults"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.standByMode"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.uiTestTools"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.upgradeStatus"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.useHighContrastUI"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.volume"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.wifiClientEnabled"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.wifiClientPass"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.wifiClientSsid"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.xaBrokerUrl"
                    },
                    {
                        "$ref": "#/components/schemas/customer.a2aHgoOptIn"
                    },
                    {
                        "$ref": "#/components/schemas/customer.a2aStbOptIn"
                    },
                    {
                        "$ref": "#/components/schemas/customer.adsOptIn"
                    },
                    {
                        "$ref": "#/components/schemas/customer.appsOptIn"
                    },
                    {
                        "$ref": "#/components/schemas/customer.autoDeleteFunction"
                    },
                    {
                        "$ref": "#/components/schemas/customer.cityId"
                    },
                    {
                        "$ref": "#/components/schemas/customer.customerId"
                    },
                    {
                        "$ref": "#/components/schemas/customer.defaultHhStb"
                    },
                    {
                        "$ref": "#/components/schemas/customer.deleteRecordingReminder"
                    },
                    {
                        "$ref": "#/components/schemas/customer.isAdultPinUsed"
                    },
                    {
                        "$ref": "#/components/schemas/customer.isFtiPassed"
                    },
                    {
                        "$ref": "#/components/schemas/customer.isSuspended"
                    },
                    {
                        "$ref": "#/components/schemas/customer.personalSuggestions"
                    },
                    {
                        "$ref": "#/components/schemas/customer.recordingRetentionPeriod"
                    },
                    {
                        "$ref": "#/components/schemas/customer.replayOptIn"
                    },
                    {
                        "$ref": "#/components/schemas/customer.replayOptInTime"
                    },
                    {
                        "$ref": "#/components/schemas/customer.zipCode"
                    },
                    {
                        "$ref": "#/components/schemas/profile.accessibleViews"
                    },
                    {
                        "$ref": "#/components/schemas/profile.ageLock"
                    },
                    {
                        "$ref": "#/components/schemas/profile.audioDescription"
                    },
                    {
                        "$ref": "#/components/schemas/profile.audioLang"
                    },
                    {
                        "$ref": "#/components/schemas/profile.onScreenKeyboardMode"
                    },
                    {
                        "$ref": "#/components/schemas/profile.osdLang"
                    },
                    {
                        "$ref": "#/components/schemas/profile.recentlyListenedRadios"
                    },
                    {
                        "$ref": "#/components/schemas/profile.recentlyUsedAppsItems"
                    },
                    {
                        "$ref": "#/components/schemas/profile.recentlyUsedSettingsItems"
                    },
                    {
                        "$ref": "#/components/schemas/profile.signLanguage"
                    },
                    {
                        "$ref": "#/components/schemas/profile.subControl"
                    },
                    {
                        "$ref": "#/components/schemas/profile.subHardOfHearing"
                    },
                    {
                        "$ref": "#/components/schemas/profile.subLang"
                    },
                    {
                        "$ref": "#/components/schemas/profile.surfFavoriteChannels"
                    },
                    {
                        "$ref": "#/components/schemas/profile.textToSpeech"
                    },
                    {
                        "$ref": "#/components/schemas/profile.textToSpeechSpeed"
                    },
                    {
                        "$ref": "#/components/schemas/profile.textToSpeechVoice"
                    },
                    {
                        "$ref": "#/components/schemas/profile.textToSpeechVolume"
                    },
                    {
                        "$ref": "#/components/schemas/profile.tipsAndTricks"
                    }
                ]
            },
            "RemoteKey": {
                "type": "string",
                "enum": [
                    "cpe.16by9Handling",
                    "cpe.4by3Handling",
                    "cpe.aspectRatio",
                    "cpe.autoStandby",
                    "cpe.autoTvStartup",
                    "cpe.ccAnalogService",
                    "cpe.ccDigitalService",
                    "cpe.ccsMessages",
                    "cpe.defaultProfileId",
                    "cpe.enableCEC",
                    "cpe.friendlyName",
                    "cpe.hdmiColorOutput",
                    "cpe.hdmiResolution",
                    "cpe.isAlexaLinked",
                    "cpe.oneTouchViewTurnOffPolicy",
                    "cpe.primaryVideoOutput",
                    "cpe.recordPaddingAfter",
                    "cpe.recordPaddingBefore",
                    "cpe.standByMode",
                    "cpe.volume",
                    "profile.surfFavoriteChannels"
                ]
            },
            "RemoteValue": {
                "oneOf": [
                    {
                        "$ref": "#/components/schemas/cpe.16by9Handling"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.4by3Handling"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.aspectRatio"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.autoStandby"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.autoTvStartup"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ccAnalogService"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ccDigitalService"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.ccsMessages"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.defaultProfileId"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.enableCEC"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.friendlyName"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.hdmiColorOutput"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.hdmiResolution"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.isAlexaLinked"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.oneTouchViewTurnOffPolicy"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.primaryVideoOutput"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.recordPaddingAfter"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.recordPaddingBefore"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.standByMode"
                    },
                    {
                        "$ref": "#/components/schemas/cpe.volume"
                    },
                    {
                        "$ref": "#/components/schemas/profile.surfFavoriteChannels"
                    }
                ]
            },
            "Settings": {
                "type": "object",
                "properties": {
                    "cpe.16by9Handling": {
                        "$ref": "#/components/schemas/cpe.16by9Handling"
                    },
                    "cpe.4by3Handling": {
                        "$ref": "#/components/schemas/cpe.4by3Handling"
                    },
                    "cpe.adsOptInShownForRelease": {
                        "$ref": "#/components/schemas/cpe.adsOptInShownForRelease"
                    },
                    "cpe.appSubscriptions": {
                        "$ref": "#/components/schemas/cpe.appSubscriptions"
                    },
                    "cpe.askPurchasePin": {
                        "$ref": "#/components/schemas/cpe.askPurchasePin"
                    },
                    "cpe.askRecPlayPin": {
                        "$ref": "#/components/schemas/cpe.askRecPlayPin"
                    },
                    "cpe.aspectRatio": {
                        "$ref": "#/components/schemas/cpe.aspectRatio"
                    },
                    "cpe.audioDelayDD": {
                        "$ref": "#/components/schemas/cpe.audioDelayDD"
                    },
                    "cpe.audioDelayPCM": {
                        "$ref": "#/components/schemas/cpe.audioDelayPCM"
                    },
                    "cpe.audioDolbyDigital": {
                        "$ref": "#/components/schemas/cpe.audioDolbyDigital"
                    },
                    "cpe.audioDolbyDigitalMode": {
                        "$ref": "#/components/schemas/cpe.audioDolbyDigitalMode"
                    },
                    "cpe.autoStandby": {
                        "$ref": "#/components/schemas/cpe.autoStandby"
                    },
                    "cpe.autoTvStartup": {
                        "$ref": "#/components/schemas/cpe.autoTvStartup"
                    },
                    "cpe.ccAnalogService": {
                        "$ref": "#/components/schemas/cpe.ccAnalogService"
                    },
                    "cpe.ccDigitalService": {
                        "$ref": "#/components/schemas/cpe.ccDigitalService"
                    },
                    "cpe.ccsMessages": {
                        "$ref": "#/components/schemas/cpe.ccsMessages"
                    },
                    "cpe.country": {
                        "$ref": "#/components/schemas/cpe.country"
                    },
                    "cpe.defaultProfileId": {
                        "$ref": "#/components/schemas/cpe.defaultProfileId"
                    },
                    "cpe.defaultPvrStb": {
                        "$ref": "#/components/schemas/cpe.defaultPvrStb"
                    },
                    "cpe.displayedStandByMessageCount": {
                        "$ref": "#/components/schemas/cpe.displayedStandByMessageCount"
                    },
                    "cpe.enableCEC": {
                        "$ref": "#/components/schemas/cpe.enableCEC"
                    },
                    "cpe.factoryResetState": {
                        "$ref": "#/components/schemas/cpe.factoryResetState"
                    },
                    "cpe.factoryResetType": {
                        "$ref": "#/components/schemas/cpe.factoryResetType"
                    },
                    "cpe.friendlyName": {
                        "$ref": "#/components/schemas/cpe.friendlyName"
                    },
                    "cpe.ftiState": {
                        "$ref": "#/components/schemas/cpe.ftiState"
                    },
                    "cpe.hdmiColorOutput": {
                        "$ref": "#/components/schemas/cpe.hdmiColorOutput"
                    },
                    "cpe.hdmiDeviceInfo": {
                        "$ref": "#/components/schemas/cpe.hdmiDeviceInfo"
                    },
                    "cpe.hdmiResolution": {
                        "$ref": "#/components/schemas/cpe.hdmiResolution"
                    },
                    "cpe.isAlexaLinked": {
                        "$ref": "#/components/schemas/cpe.isAlexaLinked"
                    },
                    "cpe.isSilentDowngrade": {
                        "$ref": "#/components/schemas/cpe.isSilentDowngrade"
                    },
                    "cpe.lastUsedBrandedScreenKey": {
                        "$ref": "#/components/schemas/cpe.lastUsedBrandedScreenKey"
                    },
                    "cpe.lastUseNetflix": {
                        "$ref": "#/components/schemas/cpe.lastUseNetflix"
                    },
                    "cpe.lockedApps": {
                        "$ref": "#/components/schemas/cpe.lockedApps"
                    },
                    "cpe.matchFrameRate": {
                        "$ref": "#/components/schemas/cpe.matchFrameRate"
                    },
                    "cpe.netflixRailCache": {
                        "$ref": "#/components/schemas/cpe.netflixRailCache"
                    },
                    "cpe.netflixToken": {
                        "$ref": "#/components/schemas/cpe.netflixToken"
                    },
                    "cpe.netflixVdid": {
                        "$ref": "#/components/schemas/cpe.netflixVdid"
                    },
                    "cpe.oneTouchViewTurnOffPolicy": {
                        "$ref": "#/components/schemas/cpe.oneTouchViewTurnOffPolicy"
                    },
                    "cpe.powerCheck": {
                        "$ref": "#/components/schemas/cpe.powerCheck"
                    },
                    "cpe.powerSource": {
                        "$ref": "#/components/schemas/cpe.powerSource"
                    },
                    "cpe.primaryVideoOutput": {
                        "$ref": "#/components/schemas/cpe.primaryVideoOutput"
                    },
                    "cpe.quicksetPairedDevicesInfo": {
                        "$ref": "#/components/schemas/cpe.quicksetPairedDevicesInfo"
                    },
                    "cpe.rcuUpgradeStatus": {
                        "$ref": "#/components/schemas/cpe.rcuUpgradeStatus"
                    },
                    "cpe.rebootReason": {
                        "$ref": "#/components/schemas/cpe.rebootReason"
                    },
                    "cpe.recordPaddingAfter": {
                        "$ref": "#/components/schemas/cpe.recordPaddingAfter"
                    },
                    "cpe.recordPaddingBefore": {
                        "$ref": "#/components/schemas/cpe.recordPaddingBefore"
                    },
                    "cpe.showColdStandByMessage": {
                        "$ref": "#/components/schemas/cpe.showColdStandByMessage"
                    },
                    "cpe.showReplayOptInMessage": {
                        "$ref": "#/components/schemas/cpe.showReplayOptInMessage"
                    },
                    "cpe.slowStandByCyclesCount": {
                        "$ref": "#/components/schemas/cpe.slowStandByCyclesCount"
                    },
                    "cpe.speedTestResults": {
                        "$ref": "#/components/schemas/cpe.speedTestResults"
                    },
                    "cpe.standByMode": {
                        "$ref": "#/components/schemas/cpe.standByMode"
                    },
                    "cpe.uiTestTools": {
                        "$ref": "#/components/schemas/cpe.uiTestTools"
                    },
                    "cpe.upgradeStatus": {
                        "$ref": "#/components/schemas/cpe.upgradeStatus"
                    },
                    "cpe.useHighContrastUI": {
                        "$ref": "#/components/schemas/cpe.useHighContrastUI"
                    },
                    "cpe.volume": {
                        "$ref": "#/components/schemas/cpe.volume"
                    },
                    "cpe.wifiClientEnabled": {
                        "$ref": "#/components/schemas/cpe.wifiClientEnabled"
                    },
                    "cpe.wifiClientPass": {
                        "$ref": "#/components/schemas/cpe.wifiClientPass"
                    },
                    "cpe.wifiClientSsid": {
                        "$ref": "#/components/schemas/cpe.wifiClientSsid"
                    },
                    "cpe.xaBrokerUrl": {
                        "$ref": "#/components/schemas/cpe.xaBrokerUrl"
                    },
                    "customer.a2aHgoOptIn": {
                        "$ref": "#/components/schemas/customer.a2aHgoOptIn"
                    },
                    "customer.a2aStbOptIn": {
                        "$ref": "#/components/schemas/customer.a2aStbOptIn"
                    },
                    "customer.adsOptIn": {
                        "$ref": "#/components/schemas/customer.adsOptIn"
                    },
                    "customer.appsOptIn": {
                        "$ref": "#/components/schemas/customer.appsOptIn"
                    },
                    "customer.autoDeleteFunction": {
                        "$ref": "#/components/schemas/customer.autoDeleteFunction"
                    },
                    "customer.cityId": {
                        "$ref": "#/components/schemas/customer.cityId"
                    },
                    "customer.customerId": {
                        "$ref": "#/components/schemas/customer.customerId"
                    },
                    "customer.defaultHhStb": {
                        "$ref": "#/components/schemas/customer.defaultHhStb"
                    },
                    "customer.deleteRecordingReminder": {
                        "$ref": "#/components/schemas/customer.deleteRecordingReminder"
                    },
                    "customer.isAdultPinUsed": {
                        "$ref": "#/components/schemas/customer.isAdultPinUsed"
                    },
                    "customer.isFtiPassed": {
                        "$ref": "#/components/schemas/customer.isFtiPassed"
                    },
                    "customer.isSuspended": {
                        "$ref": "#/components/schemas/customer.isSuspended"
                    },
                    "customer.personalSuggestions": {
                        "$ref": "#/components/schemas/customer.personalSuggestions"
                    },
                    "customer.recordingRetentionPeriod": {
                        "$ref": "#/components/schemas/customer.recordingRetentionPeriod"
                    },
                    "customer.replayOptIn": {
                        "$ref": "#/components/schemas/customer.replayOptIn"
                    },
                    "customer.replayOptInTime": {
                        "$ref": "#/components/schemas/customer.replayOptInTime"
                    },
                    "customer.zipCode": {
                        "$ref": "#/components/schemas/customer.zipCode"
                    },
                    "profile.accessibleViews": {
                        "$ref": "#/components/schemas/profile.accessibleViews"
                    },
                    "profile.ageLock": {
                        "$ref": "#/components/schemas/profile.ageLock"
                    },
                    "profile.audioDescription": {
                        "$ref": "#/components/schemas/profile.audioDescription"
                    },
                    "profile.audioLang": {
                        "$ref": "#/components/schemas/profile.audioLang"
                    },
                    "profile.onScreenKeyboardMode": {
                        "$ref": "#/components/schemas/profile.onScreenKeyboardMode"
                    },
                    "profile.osdLang": {
                        "$ref": "#/components/schemas/profile.osdLang"
                    },
                    "profile.recentlyListenedRadios": {
                        "$ref": "#/components/schemas/profile.recentlyListenedRadios"
                    },
                    "profile.recentlyUsedAppsItems": {
                        "$ref": "#/components/schemas/profile.recentlyUsedAppsItems"
                    },
                    "profile.recentlyUsedSettingsItems": {
                        "$ref": "#/components/schemas/profile.recentlyUsedSettingsItems"
                    },
                    "profile.signLanguage": {
                        "$ref": "#/components/schemas/profile.signLanguage"
                    },
                    "profile.subControl": {
                        "$ref": "#/components/schemas/profile.subControl"
                    },
                    "profile.subHardOfHearing": {
                        "$ref": "#/components/schemas/profile.subHardOfHearing"
                    },
                    "profile.subLang": {
                        "$ref": "#/components/schemas/profile.subLang"
                    },
                    "profile.surfFavoriteChannels": {
                        "$ref": "#/components/schemas/profile.surfFavoriteChannels"
                    },
                    "profile.textToSpeech": {
                        "$ref": "#/components/schemas/profile.textToSpeech"
                    },
                    "profile.textToSpeechSpeed": {
                        "$ref": "#/components/schemas/profile.textToSpeechSpeed"
                    },
                    "profile.textToSpeechVoice": {
                        "$ref": "#/components/schemas/profile.textToSpeechVoice"
                    },
                    "profile.textToSpeechVolume": {
                        "$ref": "#/components/schemas/profile.textToSpeechVolume"
                    },
                    "profile.tipsAndTricks": {
                        "$ref": "#/components/schemas/profile.tipsAndTricks"
                    }
                }
            },
            "cpe.16by9Handling": {
                "x-device": true,
                "x-pers-path": "settings.widescreenDisplayMode",
                "type": "string",
                "default": "FullScreen",
                "enum": [
                    "FullScreen",
                    "Letterbox",
                    "PanScan"
                ]
            },
            "cpe.4by3Handling": {
                "x-device": true,
                "x-pers-path": "settings.sdtvDisplayMode",
                "type": "string",
                "default": "FullMode",
                "enum": [
                    "FullMode",
                    "PillarBox",
                    "ZoomMode"
                ]
            },
            "cpe.adsOptInShownForRelease": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": ""
            },
            "cpe.appSubscriptions": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "object",
                "additionalProperties": {
                    "type": "object",
                    "properties": {
                        "frequency": {
                            "type": "number"
                        },
                        "period": {
                            "type": "number"
                        },
                        "next": {
                            "type": "number"
                        },
                        "end": {
                            "type": "number"
                        }
                    },
                    "required": [
                        "frequency",
                        "period",
                        "next",
                        "end"
                    ],
                    "additionalProperties": false
                },
                "default": {}
            },
            "cpe.askPurchasePin": {
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "type": "boolean",
                "default": true
            },
            "cpe.askRecPlayPin": {
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "type": "boolean",
                "default": true
            },
            "cpe.aspectRatio": {
                "x-device": true,
                "x-pers-path": "settings.aspectRatio",
                "type": "string",
                "default": "16:9",
                "enum": [
                    "16:9",
                    "4:3"
                ]
            },
            "cpe.audioDelayDD": {
                "x-device": true,
                "x-local-only": true,
                "type": "integer",
                "default": 0
            },
            "cpe.audioDelayPCM": {
                "x-device": true,
                "x-local-only": true,
                "type": "integer",
                "default": 0
            },
            "cpe.audioDolbyDigital": {
                "x-device": true,
                "x-local-only": true,
                "type": "boolean",
                "default": true
            },
            "cpe.audioDolbyDigitalMode": {
                "x-device": true,
                "x-local-only": true,
                "type": "string",
                "default": "",
                "enum": [
                    "",
                    "passthru",
                    "dolby digital 5.1",
                    "auto",
                    "stereo",
                    "multichannel PCM"
                ]
            },
            "cpe.autoStandby": {
                "x-built-in": true,
                "x-device": true,
                "x-pers-path": "settings.autoStandby",
                "type": "number",
                "default": 240,
                "enum": [
                    240,
                    300,
                    360,
                    1440
                ]
            },
            "cpe.autoTvStartup": {
                "x-device": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "settings.isTvAutoStartup",
                "type": "boolean",
                "default": true
            },
            "cpe.ccAnalogService": {
                "x-device": true,
                "x-pers-path": "settings.ccAnalogService",
                "type": "string",
                "default": "CC1",
                "enum": [
                    "CC1",
                    "CC2",
                    "CC3",
                    "CC4"
                ]
            },
            "cpe.ccDigitalService": {
                "x-device": true,
                "x-pers-path": "settings.ccDigitalService",
                "type": "string",
                "default": "Primary",
                "enum": [
                    "Primary",
                    "Secondary",
                    "S3",
                    "S4",
                    "S5",
                    "S6"
                ]
            },
            "cpe.ccsMessages": {
                "items": {
                    "type": "string"
                },
                "x-device": true,
                "x-pers-path": "settings.ccsMessages",
                "x-technical": true,
                "type": "array",
                "default": []
            },
            "cpe.country": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "string",
                "default": ""
            },
            "cpe.defaultProfileId": {
                "x-device": true,
                "x-reset-protected": true,
                "x-pers-path": "defaultProfileId",
                "x-pers-critical": true,
                "type": "string",
                "default": ""
            },
            "cpe.defaultPvrStb": {
                "x-device": true,
                "x-local-only": true,
                "type": "string",
                "default": null,
                "nullable": true
            },
            "cpe.displayedStandByMessageCount": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "integer",
                "default": 0,
                "minimum": 0
            },
            "cpe.enableCEC": {
                "x-device": true,
                "x-pers-path": "settings.isCecEnabled",
                "type": "boolean",
                "default": true
            },
            "cpe.factoryResetState": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "string",
                "default": "initial",
                "enum": [
                    "initial",
                    "started",
                    "succeeded",
                    "failed"
                ]
            },
            "cpe.factoryResetType": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "string",
                "default": null,
                "enum": [
                    null,
                    "UI",
                    "FPCombo4",
                    "FPCombo6",
                    "downgrade"
                ],
                "nullable": true
            },
            "cpe.friendlyName": {
                "x-device": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "settings.deviceFriendlyName",
                "type": "string",
                "default": "Horizon EOS"
            },
            "cpe.ftiState": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-reset-protected": true,
                "type": "string",
                "default": "init",
                "enum": [
                    "init",
                    "initManual",
                    "countrySelected",
                    "networkSelected",
                    "autoConfAndNetworkSelected",
                    "autoConfAndProvisioned",
                    "provisioned",
                    "updated",
                    "speedTested",
                    "boxConfigured",
                    "linkChanged",
                    "readyToComplete",
                    "languageSelected",
                    "personalised",
                    "adsOpted",
                    "rcuPaired",
                    "completed",
                    "completedAndNotified"
                ]
            },
            "cpe.hdmiColorOutput": {
                "x-device": true,
                "x-pers-path": "settings.hdmiColorOutput",
                "type": "string",
                "default": "auto",
                "enum": [
                    "auto",
                    "RGB",
                    "YCbCr-4:4:4",
                    "YCbCr-4:2:2"
                ]
            },
            "cpe.hdmiDeviceInfo": {
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "object",
                "additionalProperties": false,
                "default": {},
                "properties": {
                    "maxSupportedResolution": {
                        "type": "string"
                    }
                }
            },
            "cpe.hdmiResolution": {
                "x-device": true,
                "x-pers-path": "settings.hdmiResolution",
                "type": "string",
                "default": "FromTv",
                "enum": [
                    "FromTv",
                    "4K",
                    "1080p",
                    "1080i",
                    "720p",
                    "576p"
                ]
            },
            "cpe.isAlexaLinked": {
                "x-device": true,
                "x-pers-path": "settings.isAlexaLinked",
                "x-technical": true,
                "type": "boolean",
                "default": false
            },
            "cpe.isSilentDowngrade": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "boolean",
                "default": false
            },
            "cpe.lastUsedBrandedScreenKey": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": ""
            },
            "cpe.lastUseNetflix": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "number",
                "default": null,
                "nullable": true
            },
            "cpe.lockedApps": {
                "items": {
                    "type": "string"
                },
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "type": "array",
                "default": []
            },
            "cpe.matchFrameRate": {
                "x-device": true,
                "x-local-only": true,
                "type": "boolean",
                "default": false
            },
            "cpe.netflixRailCache": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": null,
                "nullable": true
            },
            "cpe.netflixToken": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": ""
            },
            "cpe.netflixVdid": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": ""
            },
            "cpe.oneTouchViewTurnOffPolicy": {
                "x-device": true,
                "x-pers-path": "settings.oneTouchViewTurnOffPolicy",
                "type": "boolean",
                "default": true
            },
            "cpe.powerCheck": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": null,
                "enum": [
                    "success",
                    "failure",
                    "uncertain",
                    null
                ],
                "nullable": true
            },
            "cpe.powerSource": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": null,
                "enum": [
                    "lg_psu",
                    "other",
                    null
                ],
                "nullable": true
            },
            "cpe.primaryVideoOutput": {
                "x-device": true,
                "x-pers-path": "settings.primaryVideoOutput",
                "type": "string",
                "default": "HDMI",
                "enum": [
                    "HDMI",
                    "SCART"
                ]
            },
            "cpe.quicksetPairedDevicesInfo": {
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "properties": {
                    "physicalAddress": {
                        "type": "string"
                    },
                    "edid": {
                        "type": "string"
                    },
                    "volumeLock": {
                        "type": "integer"
                    },
                    "volumeLockMethod": {
                        "type": "string"
                    },
                    "tv": {
                        "properties": {
                            "brand": {
                                "type": "string"
                            },
                            "model": {
                                "type": "string"
                            },
                            "vendorId": {
                                "type": "string"
                            },
                            "osd": {
                                "type": "string"
                            },
                            "codeset": {
                                "type": "string"
                            },
                            "codesetBlob": {
                                "type": "string"
                            },
                            "discreteCodeset": {
                                "type": "string"
                            },
                            "discreteCodesetBlob": {
                                "type": "string"
                            },
                            "controlRule": {
                                "type": "string"
                            },
                            "cecCmdDataPowerOn": {
                                "type": "string"
                            },
                            "cecCmdDataPowerOff": {
                                "type": "string"
                            },
                            "cecCmdDataInputSelect": {
                                "type": "string"
                            },
                            "isPaired": {
                                "type": "boolean"
                            },
                            "pairingMethod": {
                                "type": "string"
                            }
                        },
                        "additionalProperties": false,
                        "required": [
                            "brand",
                            "model",
                            "vendorId",
                            "osd",
                            "codeset",
                            "discreteCodeset",
                            "controlRule",
                            "isPaired",
                            "cecCmdDataPowerOn",
                            "cecCmdDataPowerOff",
                            "cecCmdDataInputSelect",
                            "pairingMethod"
                        ],
                        "type": "object"
                    },
                    "amp": {
                        "properties": {
                            "brand": {
                                "type": "string"
                            },
                            "model": {
                                "type": "string"
                            },
                            "vendorId": {
                                "type": "string"
                            },
                            "osd": {
                                "type": "string"
                            },
                            "codeset": {
                                "type": "string"
                            },
                            "codesetBlob": {
                                "type": "string"
                            },
                            "discreteCodeset": {
                                "type": "string"
                            },
                            "discreteCodesetBlob": {
                                "type": "string"
                            },
                            "controlRule": {
                                "type": "string"
                            },
                            "cecCmdDataPowerOn": {
                                "type": "string"
                            },
                            "cecCmdDataPowerOff": {
                                "type": "string"
                            },
                            "cecCmdDataInputSelect": {
                                "type": "string"
                            },
                            "isPaired": {
                                "type": "boolean"
                            },
                            "pairingMethod": {
                                "type": "string"
                            }
                        },
                        "additionalProperties": false,
                        "required": [
                            "brand",
                            "model",
                            "vendorId",
                            "osd",
                            "codeset",
                            "discreteCodeset",
                            "controlRule",
                            "cecCmdDataPowerOn",
                            "cecCmdDataPowerOff",
                            "cecCmdDataInputSelect",
                            "isPaired",
                            "pairingMethod"
                        ],
                        "type": "object"
                    },
                    "stats": {
                        "properties": {
                            "edidDiscoveryCount": {
                                "type": "integer"
                            },
                            "cecDiscoveryCount": {
                                "type": "integer"
                            },
                            "createSessionCount": {
                                "type": "integer"
                            },
                            "autoLookupCount": {
                                "type": "integer"
                            },
                            "getPickCount": {
                                "type": "integer"
                            },
                            "getControlRuleCount": {
                                "type": "integer"
                            }
                        },
                        "additionalProperties": false,
                        "required": [
                            "edidDiscoveryCount",
                            "cecDiscoveryCount",
                            "createSessionCount",
                            "autoLookupCount",
                            "getPickCount",
                            "getControlRuleCount"
                        ],
                        "type": "object"
                    }
                },
                "additionalProperties": false,
                "required": [
                    "physicalAddress",
                    "edid",
                    "volumeLock",
                    "tv",
                    "amp"
                ],
                "type": "object",
                "default": null,
                "nullable": true
            },
            "cpe.rcuUpgradeStatus": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": "upToDate",
                "enum": [
                    "upToDate",
                    "applied",
                    "timerForceApplied",
                    "acsForceApplied",
                    "applyFailed",
                    "timerForceApplyFailed",
                    "acsForceApplyFailed"
                ]
            },
            "cpe.rebootReason": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "object",
                "required": [
                    "reason",
                    "ts"
                ],
                "additionalProperties": false,
                "default": null,
                "properties": {
                    "reason": {
                        "type": "string"
                    },
                    "ts": {
                        "type": "number"
                    }
                },
                "nullable": true
            },
            "cpe.recordPaddingAfter": {
                "x-device": true,
                "x-pers-path": "settings.postPadding",
                "type": "number",
                "default": 120,
                "enum": [
                    0,
                    60,
                    120,
                    300,
                    900,
                    1800
                ]
            },
            "cpe.recordPaddingBefore": {
                "x-device": true,
                "x-pers-path": "settings.prePadding",
                "type": "number",
                "default": 60,
                "enum": [
                    0,
                    15,
                    30,
                    60,
                    120,
                    300
                ]
            },
            "cpe.showColdStandByMessage": {
                "x-device": true,
                "x-local-only": true,
                "type": "boolean",
                "default": true
            },
            "cpe.showReplayOptInMessage": {
                "x-device": true,
                "x-local-only": true,
                "type": "boolean",
                "default": true
            },
            "cpe.slowStandByCyclesCount": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "integer",
                "default": 0,
                "minimum": 0
            },
            "cpe.speedTestResults": {
                "items": {
                    "type": "object",
                    "properties": {
                        "timestamp": {
                            "type": "number"
                        },
                        "interface": {
                            "type": "string"
                        },
                        "downstreamBitrate": {
                            "type": "number"
                        },
                        "upstreamBitrate": {
                            "type": "number"
                        }
                    }
                },
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "array",
                "default": []
            },
            "cpe.standByMode": {
                "x-built-in": true,
                "x-device": true,
                "x-pers-path": "settings.standbyMode",
                "type": "string",
                "default": "ColdStandby",
                "enum": [
                    "ActiveStandby",
                    "LukewarmStandby",
                    "ColdStandby"
                ]
            },
            "cpe.uiTestTools": {
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "boolean",
                "default": false
            },
            "cpe.upgradeStatus": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "string",
                "default": "upToDate",
                "enum": [
                    "upToDate",
                    "preApplied",
                    "applied",
                    "timerForceApplied",
                    "acsForceApplied",
                    "applyFailed",
                    "timerForceApplyFailed",
                    "acsForceApplyFailed"
                ]
            },
            "cpe.useHighContrastUI": {
                "x-device": true,
                "x-local-only": true,
                "type": "boolean",
                "default": false
            },
            "cpe.volume": {
                "x-device": true,
                "x-pers-path": "settings.volume",
                "type": "number",
                "default": 50,
                "minimum": 0,
                "maximum": 100
            },
            "cpe.wifiClientEnabled": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "type": "boolean",
                "default": false
            },
            "cpe.wifiClientPass": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-sensitive": true,
                "type": "string",
                "default": null,
                "nullable": true
            },
            "cpe.wifiClientSsid": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "type": "string",
                "default": null,
                "nullable": true
            },
            "cpe.xaBrokerUrl": {
                "x-built-in": true,
                "x-device": true,
                "x-local-only": true,
                "x-preserved-after-factory-reset": true,
                "x-technical": true,
                "type": "string",
                "default": ""
            },
            "customer.a2aHgoOptIn": {
                "x-customer": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "a2a-hgo",
                "type": "boolean",
                "default": null,
                "nullable": true
            },
            "customer.a2aStbOptIn": {
                "x-customer": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "a2a-stb",
                "type": "boolean",
                "default": null,
                "nullable": true
            },
            "customer.adsOptIn": {
                "x-customer": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "ads",
                "type": "boolean",
                "default": null,
                "nullable": true
            },
            "customer.appsOptIn": {
                "x-customer": true,
                "x-pers-path": "apps",
                "type": "boolean",
                "default": false
            },
            "customer.autoDeleteFunction": {
                "x-customer": true,
                "x-pers-path": "autoDeleteFunction",
                "type": "boolean",
                "default": false
            },
            "customer.cityId": {
                "x-customer": true,
                "x-read-only": true,
                "x-technical": true,
                "type": "string",
                "default": null,
                "nullable": true
            },
            "customer.customerId": {
                "x-customer": true,
                "x-read-only": true,
                "x-technical": true,
                "type": "string"
            },
            "customer.defaultHhStb": {
                "x-customer": true,
                "x-read-only": true,
                "x-pers-path": "defaultHhStb",
                "x-technical": true,
                "type": "string",
                "default": null,
                "nullable": true
            },
            "customer.deleteRecordingReminder": {
                "x-customer": true,
                "x-pers-path": "deleteRecordingReminder",
                "type": "boolean",
                "default": false
            },
            "customer.isAdultPinUsed": {
                "x-customer": true,
                "x-read-only": true,
                "type": "boolean",
                "default": false
            },
            "customer.isFtiPassed": {
                "x-customer": true,
                "x-reset-protected": true,
                "x-pers-path": "isFtiPassed",
                "x-technical": true,
                "type": "boolean",
                "default": false
            },
            "customer.isSuspended": {
                "x-customer": true,
                "x-read-only": true,
                "x-technical": true,
                "type": "boolean",
                "default": false
            },
            "customer.personalSuggestions": {
                "x-customer": true,
                "x-pers-path": "personalization",
                "type": "boolean",
                "default": null,
                "nullable": true
            },
            "customer.recordingRetentionPeriod": {
                "x-customer": true,
                "x-pers-path": "recordingRetentionPeriod",
                "type": "number",
                "enum": [
                    -1,
                    0,
                    7,
                    30,
                    90,
                    120,
                    365
                ],
                "default": 0
            },
            "customer.replayOptIn": {
                "x-customer": true,
                "x-pers-path": "replay",
                "type": "boolean",
                "default": null,
                "nullable": true
            },
            "customer.replayOptInTime": {
                "x-customer": true,
                "x-read-only": true,
                "x-pers-path": "replay",
                "type": "number",
                "default": null,
                "nullable": true
            },
            "customer.zipCode": {
                "x-customer": true,
                "x-read-only": true,
                "x-pers-path": "zipCode",
                "type": "string",
                "default": null,
                "nullable": true
            },
            "profile.accessibleViews": {
                "items": {
                    "type": "string"
                },
                "x-profile": true,
                "x-pers-path": "accessibleViews",
                "type": "array",
                "default": []
            },
            "profile.ageLock": {
                "x-customer": true,
                "x-pers-path": "ageLock",
                "x-pers-critical": true,
                "type": "number",
                "enum": [
                    -2,
                    -1,
                    3,
                    4,
                    5,
                    6,
                    7,
                    8,
                    9,
                    10,
                    11,
                    12,
                    13,
                    14,
                    15,
                    16,
                    17,
                    18
                ],
                "default": -1
            },
            "profile.audioDescription": {
                "x-profile": true,
                "x-pers-path": "options.audioDescription",
                "type": "boolean",
                "default": false
            },
            "profile.audioLang": {
                "x-profile": true,
                "x-pers-path": "options.audioLang",
                "type": "string",
                "default": "",
                "enum": [
                    "",
                    "ar",
                    "bs",
                    "zh",
                    "hr",
                    "cs",
                    "da",
                    "nl",
                    "et",
                    "en",
                    "el",
                    "fi",
                    "fr",
                    "de",
                    "he",
                    "hi",
                    "hu",
                    "it",
                    "lv",
                    "lt",
                    "no",
                    "mt",
                    "mk",
                    "pl",
                    "pt",
                    "ro",
                    "ru",
                    "sr",
                    "sk",
                    "es",
                    "sv",
                    "tr",
                    "ur"
                ]
            },
            "profile.onScreenKeyboardMode": {
                "x-built-in": true,
                "x-profile": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "options.keyboardMode",
                "type": "string",
                "default": "Normal",
                "enum": [
                    "Normal",
                    "Flo"
                ]
            },
            "profile.osdLang": {
                "x-built-in": true,
                "x-profile": true,
                "x-preserved-after-factory-reset": true,
                "x-pers-path": "options.lang",
                "x-pers-critical": true,
                "type": "string",
                "default": "nl",
                "enum": [
                    "ar",
                    "bs",
                    "zh",
                    "hr",
                    "cs",
                    "da",
                    "nl",
                    "et",
                    "en",
                    "el",
                    "fi",
                    "fr",
                    "de",
                    "he",
                    "hi",
                    "hu",
                    "it",
                    "lv",
                    "lt",
                    "no",
                    "mt",
                    "mk",
                    "pl",
                    "pt",
                    "ro",
                    "ru",
                    "sr",
                    "sk",
                    "es",
                    "sv",
                    "tr",
                    "ur"
                ]
            },
            "profile.recentlyListenedRadios": {
                "items": {
                    "type": "string"
                },
                "x-profile": true,
                "x-local-only": true,
                "x-technical": true,
                "type": "array",
                "default": []
            },
            "profile.recentlyUsedAppsItems": {
                "items": {},
                "x-profile": true,
                "x-pers-path": "recentlyUsedApps",
                "x-technical": true,
                "type": "array",
                "default": []
            },
            "profile.recentlyUsedSettingsItems": {
                "items": {},
                "x-profile": true,
                "x-pers-path": "recentlyUsedSettings",
                "x-technical": true,
                "type": "array",
                "default": [
                    "ageLock",
                    "changePin",
                    "audioLanguage",
                    "subtitleOptions",
                    "standByMode",
                    "lockChannels"
                ]
            },
            "profile.signLanguage": {
                "x-profile": true,
                "x-pers-path": "options.signLanguage",
                "type": "boolean",
                "default": false
            },
            "profile.subControl": {
                "x-profile": true,
                "x-pers-path": "options.showSubtitles",
                "type": "boolean",
                "default": false
            },
            "profile.subHardOfHearing": {
                "x-profile": true,
                "x-pers-path": "options.hardOfHearing",
                "type": "boolean",
                "default": false
            },
            "profile.subLang": {
                "x-profile": true,
                "x-pers-path": "options.subLang",
                "type": "string",
                "default": "en",
                "enum": [
                    "ar",
                    "bs",
                    "zh",
                    "hr",
                    "cs",
                    "da",
                    "nl",
                    "et",
                    "en",
                    "el",
                    "fi",
                    "fr",
                    "de",
                    "he",
                    "hi",
                    "hu",
                    "it",
                    "lv",
                    "lt",
                    "no",
                    "mt",
                    "mk",
                    "pl",
                    "pt",
                    "ro",
                    "ru",
                    "sr",
                    "sk",
                    "es",
                    "sv",
                    "tr",
                    "ur"
                ]
            },
            "profile.surfFavoriteChannels": {
                "x-device": true,
                "x-pers-path": "settings.surfFavoriteChannels",
                "type": "boolean",
                "default": false
            },
            "profile.textToSpeech": {
                "x-profile": true,
                "x-pers-path": "options.isVoiceOverGuidanceEnabled",
                "type": "boolean",
                "default": false
            },
            "profile.textToSpeechSpeed": {
                "x-profile": true,
                "x-pers-path": "options.voiceOverGuidanceSpeed",
                "type": "string",
                "enum": [
                    "Slower",
                    "Slow",
                    "Average",
                    "Fast",
                    "Faster",
                    "VeryFast",
                    "Fastest"
                ],
                "default": "Average"
            },
            "profile.textToSpeechVoice": {
                "x-profile": true,
                "x-pers-path": "jsonOptions.voiceOverGuidanceVoice",
                "type": "object",
                "additionalProperties": {
                    "type": "string"
                },
                "default": {
                    "en": "Serena"
                }
            },
            "profile.textToSpeechVolume": {
                "x-profile": true,
                "x-pers-path": "options.voiceOverGuidanceVolume",
                "type": "string",
                "enum": [
                    "20",
                    "40",
                    "60",
                    "80",
                    "100"
                ],
                "default": "80"
            },
            "profile.tipsAndTricks": {
                "x-profile": true,
                "x-pers-path": "jsonOptions.tipsAndTricks",
                "x-technical": true,
                "type": "object",
                "required": [
                    "ids",
                    "timestamps"
                ],
                "additionalProperties": false,
                "default": {
                    "ids": [],
                    "timestamps": []
                },
                "properties": {
                    "ids": {
                        "type": "array",
                        "items": {
                            "type": "string"
                        }
                    },
                    "timestamps": {
                        "type": "array",
                        "items": {
                            "type": "number"
                        }
                    },
                    "counters": {
                        "type": "object",
                        "additionalProperties": {
                            "type": "integer"
                        }
                    }
                }
            }
        }
    }
}
''';