// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'discovery_service.enums.swagger.dart' as enums;
export 'discovery_service.enums.swagger.dart';

part 'discovery_service.swagger.chopper.dart';
part 'discovery_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class DiscoveryService extends ChopperService {
  static DiscoveryService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$DiscoveryService(client);
    }

    final newClient = ChopperClient(
        services: [_$DiscoveryService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$DiscoveryService(newClient);
  }

  ///Handles learn action events
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  Future<chopper.Response> v2LearnActionsPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? headerNameTakenFromConfiguration,
    String? xExplicitLogging,
    String? cacheControl,
    required LearnAction$RequestBody? body,
  }) {
    return _v2LearnActionsPost(
        xDev: xDev,
        xCus: xCus,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        xExplicitLogging: xExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Handles learn action events
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  @Post(
    path: '/v2/learn-actions',
    optionalBody: true,
  )
  Future<chopper.Response> _v2LearnActionsPost({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required LearnAction$RequestBody? body,
  });

  ///Retrieve recommendations related to a given content.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR),1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD). Discovery-service does not validate these parameters.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  Future<chopper.Response<MoreLikeThisResponse>>
      v2RecommendationsMoreLikeThisGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    List<String>? contentSourceId,
    String? profileId,
    bool? sharedProfile,
    required enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId?
        resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    enums.V2RecommendationsMoreLikeThisGetMaxRes? maxRes,
    String? channelId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisResponse, () => MoreLikeThisResponse.fromJsonFactory);

    return _v2RecommendationsMoreLikeThisGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId?.value?.toString(),
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes?.value?.toString(),
        channelId: channelId,
        cacheControl: cacheControl);
  }

  ///Retrieve recommendations related to a given content.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR),1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD). Discovery-service does not validate these parameters.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  @Get(path: '/v2/recommendations/more-like-this')
  Future<chopper.Response<MoreLikeThisResponse>>
      _v2RecommendationsMoreLikeThisGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('resourceContentSourceId')
        required String? resourceContentSourceId,
    @Query('resourceId')
        required String? resourceId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations')
        bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('channelId')
        String? channelId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieve the most popular searches.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD), 200(Provider)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  Future<chopper.Response<TopSearchResponse>>
      v2RecommendationsTopSearchListGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    List<String>? contentSourceId,
    String? profileId,
    required int? maxResults,
    required bool? includeNotEntitled,
    String? queryLanguage,
    enums.V2RecommendationsTopSearchListGetMaxRes? maxRes,
    int? cityId,
    String? includeExternalProvider,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopSearchResponse, () => TopSearchResponse.fromJsonFactory);

    return _v2RecommendationsTopSearchListGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        queryLanguage: queryLanguage,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Retrieve the most popular searches.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD), 200(Provider)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  @Get(path: '/v2/recommendations/top-search-list')
  Future<chopper.Response<TopSearchResponse>>
      _v2RecommendationsTopSearchListGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('profileId')
        String? profileId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieve recommendations related to a given content.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR),1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD). Discovery-service does not validate these parameters.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  ///@param subscriptionId Used for call to SARE
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param recommendationMode Recommendation Mode used by SARE
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content when "svod". When "tvod" only forwarded to RENG/SARE (no filtering in DS).
  ///@param noBookmarks Default: false. Specifies if DS should enrich the response with bookmark information.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  Future<chopper.Response<MoreLikeThisResponseV3>>
      v3RecommendationsMoreLikeThisGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    List<String>? contentSourceId,
    String? profileId,
    bool? sharedProfile,
    required enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId?
        resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    enums.V3RecommendationsMoreLikeThisGetMaxRes? maxRes,
    String? channelId,
    List<String>? subscriptionId,
    bool? goPlayableOnly,
    String? recommendationMode,
    enums.V3RecommendationsMoreLikeThisGetFilterOnDemand? filterOnDemand,
    String? noBookmarks,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisResponseV3, () => MoreLikeThisResponseV3.fromJsonFactory);

    return _v3RecommendationsMoreLikeThisGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId?.value?.toString(),
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes?.value?.toString(),
        channelId: channelId,
        subscriptionId: subscriptionId,
        goPlayableOnly: goPlayableOnly,
        recommendationMode: recommendationMode,
        filterOnDemand: filterOnDemand?.value?.toString(),
        noBookmarks: noBookmarks,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Retrieve recommendations related to a given content.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR),1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD). Discovery-service does not validate these parameters.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  ///@param subscriptionId Used for call to SARE
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param recommendationMode Recommendation Mode used by SARE
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content when "svod". When "tvod" only forwarded to RENG/SARE (no filtering in DS).
  ///@param noBookmarks Default: false. Specifies if DS should enrich the response with bookmark information.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  @Get(path: '/v3/recommendations/more-like-this')
  Future<chopper.Response<MoreLikeThisResponseV3>>
      _v3RecommendationsMoreLikeThisGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('resourceContentSourceId')
        required String? resourceContentSourceId,
    @Query('resourceId')
        required String? resourceId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations')
        bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('channelId')
        String? channelId,
    @Query('subscriptionId')
        List<String>? subscriptionId,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('recommendationMode')
        String? recommendationMode,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('noBookmarks')
        String? noBookmarks,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieve the most popular searches.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD), 200(Provider)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  Future<chopper.Response<TopSearchResponseV3>>
      v3RecommendationsTopSearchListGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    List<String>? contentSourceId,
    String? profileId,
    required int? maxResults,
    required bool? includeNotEntitled,
    String? queryLanguage,
    enums.V3RecommendationsTopSearchListGetMaxRes? maxRes,
    int? cityId,
    String? includeExternalProvider,
    bool? goPlayableOnly,
    enums.V3RecommendationsTopSearchListGetFilterOnDemand? filterOnDemand,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopSearchResponseV3, () => TopSearchResponseV3.fromJsonFactory);

    return _v3RecommendationsTopSearchListGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        queryLanguage: queryLanguage,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        goPlayableOnly: goPlayableOnly,
        filterOnDemand: filterOnDemand?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Retrieve the most popular searches.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD), 200(Provider)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  @Get(path: '/v3/recommendations/top-search-list')
  Future<chopper.Response<TopSearchResponseV3>>
      _v3RecommendationsTopSearchListGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('profileId')
        String? profileId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Collaborative recommendations
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase) or 311 (Adult Content Related)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId This is the content source of the resource given in resourceId parameter.
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param channelId Used to filter the more-like-this for a specific broadcaster. If the content is VOD then the brandingProvider can be used here
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content when "svod". When "tvod" only forwarded to RENG/SARE (no filtering in DS).
  Future<chopper.Response<CollaborativeResponseV3>>
      v3RecommendationsCollaborativeGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    String? profileId,
    bool? sharedProfile,
    required enums.V3RecommendationsCollaborativeGetResourceContentSourceId?
        resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    enums.V3RecommendationsCollaborativeGetMaxRes? maxRes,
    String? channelId,
    bool? goPlayableOnly,
    enums.V3RecommendationsCollaborativeGetFilterOnDemand? filterOnDemand,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CollaborativeResponseV3, () => CollaborativeResponseV3.fromJsonFactory);

    return _v3RecommendationsCollaborativeGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        profileId: profileId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId?.value?.toString(),
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes?.value?.toString(),
        channelId: channelId,
        goPlayableOnly: goPlayableOnly,
        filterOnDemand: filterOnDemand?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Collaborative recommendations
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase) or 311 (Adult Content Related)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId This is the content source of the resource given in resourceId parameter.
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param channelId Used to filter the more-like-this for a specific broadcaster. If the content is VOD then the brandingProvider can be used here
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content when "svod". When "tvod" only forwarded to RENG/SARE (no filtering in DS).
  @Get(path: '/v3/recommendations/collaborative')
  Future<chopper.Response<CollaborativeResponseV3>>
      _v3RecommendationsCollaborativeGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('resourceContentSourceId')
        required String? resourceContentSourceId,
    @Query('resourceId')
        required String? resourceId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations')
        bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('channelId')
        String? channelId,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Personal recommendations
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param clientType Client type. This parameter is to be passed to search engine without validation
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param contentSourceId 1(LTV), 2(VOD), 102(Replay), 200(Provider)
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param maxRes Highest possible maxResolution.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param noBookmarks Default: false. Specifies if DS should enrich the response with bookmark information.
  Future<chopper.Response<ProfileResponse>> v3RecommendationsProfileGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? profileId,
    bool? sharedProfile,
    required String? clientType,
    required int? maxResults,
    required bool? includeNotEntitled,
    required List<String>? contentSourceId,
    bool? allowPreviousRecommendations,
    enums.V3RecommendationsProfileGetMaxRes? maxRes,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? noBookmarks,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProfileResponse, () => ProfileResponse.fromJsonFactory);

    return _v3RecommendationsProfileGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        clientType: clientType,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        contentSourceId: contentSourceId,
        allowPreviousRecommendations: allowPreviousRecommendations,
        maxRes: maxRes?.value?.toString(),
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        noBookmarks: noBookmarks,
        cacheControl: cacheControl);
  }

  ///Personal recommendations
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param clientType Client type. This parameter is to be passed to search engine without validation
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param contentSourceId 1(LTV), 2(VOD), 102(Replay), 200(Provider)
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param maxRes Highest possible maxResolution.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param noBookmarks Default: false. Specifies if DS should enrich the response with bookmark information.
  @Get(path: '/v3/recommendations/profile')
  Future<chopper.Response<ProfileResponse>> _v3RecommendationsProfileGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        required String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('clientType')
        required String? clientType,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('contentSourceId')
        required List<String>? contentSourceId,
    @Query('allowPreviousRecommendations')
        bool? allowPreviousRecommendations,
    @Query('maxRes')
        String? maxRes,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('noBookmarks')
        String? noBookmarks,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///User Collaborative recommendations (only for SARE)
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param clientType Client type. This parameter is to be passed to search engine without validation
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay), 200(Provider)
  ///@param queryLanguage UI language.
  ///@param subscriptionId Used for call to SARE
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param cityId City Id used for regional filtering
  ///@param recommendationMode Recommendation Mode used by SARE
  Future<chopper.Response<UserCollaborativeResponse>>
      v3RecommendationsUserCollaborativeGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? profileId,
    required String? clientType,
    required int? maxResults,
    required bool? includeNotEntitled,
    required List<String>? contentSourceId,
    String? queryLanguage,
    List<String>? subscriptionId,
    bool? goPlayableOnly,
    int? cityId,
    String? recommendationMode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(UserCollaborativeResponse,
        () => UserCollaborativeResponse.fromJsonFactory);

    return _v3RecommendationsUserCollaborativeGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        clientType: clientType,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        contentSourceId: contentSourceId,
        queryLanguage: queryLanguage,
        subscriptionId: subscriptionId,
        goPlayableOnly: goPlayableOnly,
        cityId: cityId,
        recommendationMode: recommendationMode,
        cacheControl: cacheControl);
  }

  ///User Collaborative recommendations (only for SARE)
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param clientType Client type. This parameter is to be passed to search engine without validation
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay), 200(Provider)
  ///@param queryLanguage UI language.
  ///@param subscriptionId Used for call to SARE
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param cityId City Id used for regional filtering
  ///@param recommendationMode Recommendation Mode used by SARE
  @Get(path: '/v3/recommendations/user-collaborative')
  Future<chopper.Response<UserCollaborativeResponse>>
      _v3RecommendationsUserCollaborativeGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        required String? profileId,
    @Query('clientType')
        required String? clientType,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('contentSourceId')
        required List<String>? contentSourceId,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('subscriptionId')
        List<String>? subscriptionId,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('cityId')
        int? cityId,
    @Query('recommendationMode')
        String? recommendationMode,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Search for content
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Default: false. Specifies if only entitled content should be included in the response.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  Future<chopper.Response<StbSearchResponse>> v2SearchContentsGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? headerNameTakenFromConfiguration,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    bool? sharedProfile,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    required int? clientType,
    List<String>? contentSourceId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    bool? includeNotEntitled,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    enums.V2SearchContentsGetMaxRes? maxRes,
    bool? mergingOn,
    String? includeExternalProvider,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponse, () => StbSearchResponse.fromJsonFactory);

    return _v2SearchContentsGet(
        xDev: xDev,
        xCus: xCus,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        clientType: clientType,
        contentSourceId: contentSourceId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes?.value?.toString(),
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Search for content
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Default: false. Specifies if only entitled content should be included in the response.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  @Get(path: '/v2/search/contents')
  Future<chopper.Response<StbSearchResponse>> _v2SearchContentsGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Query('clientType')
        required int? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('searchTerm')
        required String? searchTerm,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('startResults')
        required int? startResults,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        bool? includeNotEntitled,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('maxRes')
        String? maxRes,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Search for content as anonymous user
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param sessionId Session identifier.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  Future<chopper.Response<StbSearchResponse>> v2SearchContentsAnonymousGet({
    String? xSessionId,
    String? xExplicitLogging,
    bool? includeDetails,
    required int? clientType,
    List<String>? contentSourceId,
    required String? sessionId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    enums.V2SearchContentsAnonymousGetMaxRes? maxRes,
    bool? goPlayableOnly,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponse, () => StbSearchResponse.fromJsonFactory);

    return _v2SearchContentsAnonymousGet(
        xSessionId: xSessionId,
        xExplicitLogging: xExplicitLogging,
        includeDetails: includeDetails,
        clientType: clientType,
        contentSourceId: contentSourceId,
        sessionId: sessionId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///Search for content as anonymous user
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param sessionId Session identifier.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  @Get(path: '/v2/search/contents-anonymous')
  Future<chopper.Response<StbSearchResponse>> _v2SearchContentsAnonymousGet({
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-explicit-logging') String? xExplicitLogging,
    @Query('includeDetails') bool? includeDetails,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('sessionId') required String? sessionId,
    @Query('searchTerm') required String? searchTerm,
    @Query('queryLanguage') String? queryLanguage,
    @Query('startResults') required int? startResults,
    @Query('maxResults') required int? maxResults,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('maxRes') String? maxRes,
    @Query('goPlayableOnly') bool? goPlayableOnly,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search using voice info.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  Future<chopper.Response<VoiceSearchResponse>> v2SearchVoicePost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? headerNameTakenFromConfiguration,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    bool? sharedProfile,
    required int? maxResults,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    enums.V2SearchVoicePostMaxRes? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    bool? applyMarketingBias,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    bool? mergingOn,
    bool? goPlayableOnly,
    String? cacheControl,
    required NuanceResponse? body,
  }) {
    generatedMapping.putIfAbsent(
        VoiceSearchResponse, () => VoiceSearchResponse.fromJsonFactory);

    return _v2SearchVoicePost(
        xDev: xDev,
        xCus: xCus,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        applyMarketingBias: applyMarketingBias,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        mergingOn: mergingOn,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search using voice info.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  @Post(
    path: '/v2/search/voice',
    optionalBody: true,
  )
  Future<chopper.Response<VoiceSearchResponse>> _v2SearchVoicePost({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Query('maxRes')
        String? maxRes,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('applyMarketingBias')
        bool? applyMarketingBias,
    @Query('searchLiteral')
        String? searchLiteral,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('nuanceSessionId')
        required String? nuanceSessionId,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required NuanceResponse? body,
  });

  ///Anonymous search using voice info.
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param sessionId Session identifier.
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  Future<chopper.Response<VoiceSearchResponse>> v2SearchVoiceAnonymousPost({
    String? xExplicitLogging,
    required String? sessionId,
    required int? maxResults,
    bool? includeDetails,
    enums.V2SearchVoiceAnonymousPostMaxRes? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    bool? goPlayableOnly,
    bool? mergingOn,
    String? cacheControl,
    required NuanceResponse? body,
  }) {
    generatedMapping.putIfAbsent(
        VoiceSearchResponse, () => VoiceSearchResponse.fromJsonFactory);

    return _v2SearchVoiceAnonymousPost(
        xExplicitLogging: xExplicitLogging,
        sessionId: sessionId,
        maxResults: maxResults,
        includeDetails: includeDetails,
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        cacheControl: cacheControl,
        body: body);
  }

  ///Anonymous search using voice info.
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param sessionId Session identifier.
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  @Post(
    path: '/v2/search/voice-anonymous',
    optionalBody: true,
  )
  Future<chopper.Response<VoiceSearchResponse>> _v2SearchVoiceAnonymousPost({
    @Header('x-explicit-logging') String? xExplicitLogging,
    @Query('sessionId') required String? sessionId,
    @Query('maxResults') required int? maxResults,
    @Query('includeDetails') bool? includeDetails,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('queryLanguage') String? queryLanguage,
    @Query('searchLiteral') String? searchLiteral,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('nuanceSessionId') required String? nuanceSessionId,
    @Query('goPlayableOnly') bool? goPlayableOnly,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
    @Body() required NuanceResponse? body,
  });

  ///Search for content
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 103(OTT or EST only), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Default: false. Specifies if only entitled content should be included in the response.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param includeYoutube Flag to tell the Backoffice that the CPE is cap
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param includeSuggestions Flag to ask for search suggestions. Applicable only for RENG. Default is false.
  Future<chopper.Response<StbSearchResponseV3>> v3SearchContentsGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? headerNameTakenFromConfiguration,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    bool? sharedProfile,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    required int? clientType,
    List<String>? contentSourceId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    bool? includeNotEntitled,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    enums.V3SearchContentsGetMaxRes? maxRes,
    bool? mergingOn,
    String? includeExternalProvider,
    bool? includeYoutube,
    bool? goPlayableOnly,
    enums.V3SearchContentsGetFilterOnDemand? filterOnDemand,
    bool? includeSuggestions,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponseV3, () => StbSearchResponseV3.fromJsonFactory);

    return _v3SearchContentsGet(
        xDev: xDev,
        xCus: xCus,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        clientType: clientType,
        contentSourceId: contentSourceId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes?.value?.toString(),
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        includeYoutube: includeYoutube,
        goPlayableOnly: goPlayableOnly,
        filterOnDemand: filterOnDemand?.value?.toString(),
        includeSuggestions: includeSuggestions,
        cacheControl: cacheControl);
  }

  ///Search for content
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 103(OTT or EST only), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Default: false. Specifies if only entitled content should be included in the response.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param includeYoutube Flag to tell the Backoffice that the CPE is cap
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param includeSuggestions Flag to ask for search suggestions. Applicable only for RENG. Default is false.
  @Get(path: '/v3/search/contents')
  Future<chopper.Response<StbSearchResponseV3>> _v3SearchContentsGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Query('clientType')
        required int? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('searchTerm')
        required String? searchTerm,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('startResults')
        required int? startResults,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        bool? includeNotEntitled,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('maxRes')
        String? maxRes,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('includeYoutube')
        bool? includeYoutube,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('includeSuggestions')
        bool? includeSuggestions,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Search for content as anonymous user
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 103(OTT or EST only), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param sessionId Session identifier.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param includeYoutube Flag to tell the Backoffice that the CPE is cap
  Future<chopper.Response<StbSearchResponseV3>> v3SearchContentsAnonymousGet({
    String? xSessionId,
    String? xExplicitLogging,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    bool? includeDetails,
    required int? clientType,
    List<String>? contentSourceId,
    required String? sessionId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    enums.V3SearchContentsAnonymousGetMaxRes? maxRes,
    bool? goPlayableOnly,
    bool? mergingOn,
    String? includeExternalProvider,
    bool? includeYoutube,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponseV3, () => StbSearchResponseV3.fromJsonFactory);

    return _v3SearchContentsAnonymousGet(
        xSessionId: xSessionId,
        xExplicitLogging: xExplicitLogging,
        xEntitlementsToken: xEntitlementsToken,
        includeDetails: includeDetails,
        clientType: clientType,
        contentSourceId: contentSourceId,
        sessionId: sessionId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        includeYoutube: includeYoutube,
        cacheControl: cacheControl);
  }

  ///Search for content as anonymous user
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay), 103(OTT or EST only), 200(Provider). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param sessionId Session identifier.
  ///@param searchTerm Term to be searched for.
  ///@param queryLanguage UI language.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param maxRes Highest possible maxResolution.
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param includeYoutube Flag to tell the Backoffice that the CPE is cap
  @Get(path: '/v3/search/contents-anonymous')
  Future<chopper.Response<StbSearchResponseV3>> _v3SearchContentsAnonymousGet({
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('includeDetails')
        bool? includeDetails,
    @Query('clientType')
        required int? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('sessionId')
        required String? sessionId,
    @Query('searchTerm')
        required String? searchTerm,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('startResults')
        required int? startResults,
    @Query('maxResults')
        required int? maxResults,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('maxRes')
        String? maxRes,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('includeYoutube')
        bool? includeYoutube,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Search using voice info.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeYoutube Flag to tell the Backoffice that the CPE is cap
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  Future<chopper.Response<VoiceSearchResponseV3>> v3SearchVoicePost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? headerNameTakenFromConfiguration,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    bool? sharedProfile,
    required int? maxResults,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    enums.V3SearchVoicePostMaxRes? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    bool? applyMarketingBias,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    bool? goPlayableOnly,
    bool? mergingOn,
    bool? includeYoutube,
    enums.V3SearchVoicePostFilterOnDemand? filterOnDemand,
    String? cacheControl,
    required NuanceResponse? body,
  }) {
    generatedMapping.putIfAbsent(
        VoiceSearchResponseV3, () => VoiceSearchResponseV3.fromJsonFactory);

    return _v3SearchVoicePost(
        xDev: xDev,
        xCus: xCus,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        applyMarketingBias: applyMarketingBias,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        includeYoutube: includeYoutube,
        filterOnDemand: filterOnDemand?.value?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Search using voice info.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param includeYoutube Flag to tell the Backoffice that the CPE is cap
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  @Post(
    path: '/v3/search/voice',
    optionalBody: true,
  )
  Future<chopper.Response<VoiceSearchResponseV3>> _v3SearchVoicePost({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Query('maxRes')
        String? maxRes,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('applyMarketingBias')
        bool? applyMarketingBias,
    @Query('searchLiteral')
        String? searchLiteral,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('nuanceSessionId')
        required String? nuanceSessionId,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeYoutube')
        bool? includeYoutube,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required NuanceResponse? body,
  });

  ///Anonymous search using voice info.
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param sessionId Session identifier.
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  Future<chopper.Response<VoiceSearchResponseV3>> v3SearchVoiceAnonymousPost({
    String? xExplicitLogging,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? sessionId,
    required int? maxResults,
    bool? includeDetails,
    enums.V3SearchVoiceAnonymousPostMaxRes? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    bool? goPlayableOnly,
    bool? mergingOn,
    String? cacheControl,
    required NuanceResponse? body,
  }) {
    generatedMapping.putIfAbsent(
        VoiceSearchResponseV3, () => VoiceSearchResponseV3.fromJsonFactory);

    return _v3SearchVoiceAnonymousPost(
        xExplicitLogging: xExplicitLogging,
        xEntitlementsToken: xEntitlementsToken,
        sessionId: sessionId,
        maxResults: maxResults,
        includeDetails: includeDetails,
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        cacheControl: cacheControl,
        body: body);
  }

  ///Anonymous search using voice info.
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param sessionId Session identifier.
  ///@param maxResults The maximum number of results
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. Mandatory for clients versions 4.29 and above. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param queryLanguage UI language.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param goPlayableOnly Boolean to filter only Go playable content.
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  @Post(
    path: '/v3/search/voice-anonymous',
    optionalBody: true,
  )
  Future<chopper.Response<VoiceSearchResponseV3>> _v3SearchVoiceAnonymousPost({
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('sessionId')
        required String? sessionId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('maxRes')
        String? maxRes,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('searchLiteral')
        String? searchLiteral,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('nuanceSessionId')
        required String? nuanceSessionId,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required NuanceResponse? body,
  });

  ///Get recent search history.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay). At at least one contentSourceID is required.
  ///@param maxResults The maximum number of results
  ///@param queryLanguage UI language.
  Future<chopper.Response<GetRecentResponse>> v3SearchGetRecentGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xExplicitLogging,
    required String? profileId,
    bool? sharedProfile,
    required int? clientType,
    List<String>? contentSourceId,
    required int? maxResults,
    String? queryLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GetRecentResponse, () => GetRecentResponse.fromJsonFactory);

    return _v3SearchGetRecentGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        clientType: clientType,
        contentSourceId: contentSourceId,
        maxResults: maxResults,
        queryLanguage: queryLanguage,
        cacheControl: cacheControl);
  }

  ///Get recent search history.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay). At at least one contentSourceID is required.
  ///@param maxResults The maximum number of results
  ///@param queryLanguage UI language.
  @Get(path: '/v3/search/getRecent')
  Future<chopper.Response<GetRecentResponse>> _v3SearchGetRecentGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-explicit-logging') String? xExplicitLogging,
    @Query('profileId') required String? profileId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('maxResults') required int? maxResults,
    @Query('queryLanguage') String? queryLanguage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Use voice to record series or asset.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param maxRes Highest possible maxResolution.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  Future<chopper.Response<VoiceRecordResponseV3>> v3VoiceRecordPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? profileId,
    bool? sharedProfile,
    required String? queryLanguage,
    bool? applyMarketingBias,
    enums.V3VoiceRecordPostMaxRes? maxRes,
    String? searchLiteral,
    required String? nuanceSessionId,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    String? cacheControl,
    required NuanceResponseVoice? body,
  }) {
    generatedMapping.putIfAbsent(
        VoiceRecordResponseV3, () => VoiceRecordResponseV3.fromJsonFactory);

    return _v3VoiceRecordPost(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        queryLanguage: queryLanguage,
        applyMarketingBias: applyMarketingBias,
        maxRes: maxRes?.value?.toString(),
        searchLiteral: searchLiteral,
        nuanceSessionId: nuanceSessionId,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Use voice to record series or asset.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param maxRes Highest possible maxResolution.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  @Post(
    path: '/v3/voice/record',
    optionalBody: true,
  )
  Future<chopper.Response<VoiceRecordResponseV3>> _v3VoiceRecordPost({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        required String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('queryLanguage')
        required String? queryLanguage,
    @Query('applyMarketingBias')
        bool? applyMarketingBias,
    @Query('maxRes')
        String? maxRes,
    @Query('searchLiteral')
        String? searchLiteral,
    @Query('nuanceSessionId')
        required String? nuanceSessionId,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required NuanceResponseVoice? body,
  });

  ///Use voice to play series or asset.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param maxRes Highest possible maxResolution.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  Future<chopper.Response<VoicePlayResponseV3>> v3VoicePlayPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? profileId,
    bool? sharedProfile,
    required String? queryLanguage,
    bool? applyMarketingBias,
    enums.V3VoicePlayPostMaxRes? maxRes,
    String? searchLiteral,
    required String? nuanceSessionId,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    String? cacheControl,
    required NuanceResponseVoice? body,
  }) {
    generatedMapping.putIfAbsent(
        VoicePlayResponseV3, () => VoicePlayResponseV3.fromJsonFactory);

    return _v3VoicePlayPost(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        sharedProfile: sharedProfile,
        queryLanguage: queryLanguage,
        applyMarketingBias: applyMarketingBias,
        maxRes: maxRes?.value?.toString(),
        searchLiteral: searchLiteral,
        nuanceSessionId: nuanceSessionId,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Use voice to play series or asset.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token  Token from purchase-service with entitlements and rentals. <br /><br /> Call to purchase-service for token:<br /> http://purchase-service.labci.ecx.appdev.io/v2/customers/{{customerId}}/entitlements <br /><br /> Entitlements are expected to be present for all customers - even for anonymous ones. <br /> See https://bitbucket.upc.biz/projects/SPARK/repos/spark-auth/browse/entitlements-token <br /><br /> No token for obo-lite. <br /> See https://wikiprojects.upc.biz/pages/viewpage.action?pageId=338004551
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param queryLanguage UI language.
  ///@param applyMarketingBias Apply marketing bias
  ///@param maxRes Highest possible maxResolution.
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param nuanceSessionId This is the NMAS_PRFX_SESSION_ID form the Nuance response
  ///@param includeDetails Default: false. If set to true, additional data will be available in Grouped Series and Grouped Multisource models.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  @Post(
    path: '/v3/voice/play',
    optionalBody: true,
  )
  Future<chopper.Response<VoicePlayResponseV3>> _v3VoicePlayPost({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        required String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('queryLanguage')
        required String? queryLanguage,
    @Query('applyMarketingBias')
        bool? applyMarketingBias,
    @Query('maxRes')
        String? maxRes,
    @Query('searchLiteral')
        String? searchLiteral,
    @Query('nuanceSessionId')
        required String? nuanceSessionId,
    @Query('includeDetails')
        bool? includeDetails,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required NuanceResponseVoice? body,
  });

  ///Search for content
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param X-Session-Id Session Id header for the anonymous search
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId Default (LTV, VOD, PVR, Channel), 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel)
  ///@param sessionId Session identifier.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param searchTerm Term to be searched for.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Default: false. Specifies if only entitled content should be included in the response.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  Future<chopper.Response<StbSearchResponseV1>> v1SearchContentsGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? headerNameTakenFromConfiguration,
    String? xSessionId,
    required int? clientType,
    List<String>? contentSourceId,
    String? sessionId,
    String? profileId,
    bool? sharedProfile,
    required String? searchTerm,
    required int? startResults,
    required int? maxResults,
    bool? includeNotEntitled,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    enums.V1SearchContentsGetMaxRes? maxRes,
    int? cityId,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponseV1, () => StbSearchResponseV1.fromJsonFactory);

    return _v1SearchContentsGet(
        xDev: xDev,
        xCus: xCus,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        xSessionId: xSessionId,
        clientType: clientType,
        contentSourceId: contentSourceId,
        sessionId: sessionId,
        profileId: profileId,
        sharedProfile: sharedProfile,
        searchTerm: searchTerm,
        startResults: startResults,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Search for content
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. It is required in case of "x-entitlements-token" header is not provided.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param X-Session-Id Session Id header for the anonymous search
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId Default (LTV, VOD, PVR, Channel), 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel)
  ///@param sessionId Session identifier.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param searchTerm Term to be searched for.
  ///@param startResults The index of the first result to return in the result set.
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Default: false. Specifies if only entitled content should be included in the response.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  @Get(path: '/v1/search/contents')
  Future<chopper.Response<StbSearchResponseV1>> _v1SearchContentsGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Header('X-Session-Id')
        String? xSessionId,
    @Query('clientType')
        required int? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('sessionId')
        String? sessionId,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('searchTerm')
        required String? searchTerm,
    @Query('startResults')
        required int? startResults,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        bool? includeNotEntitled,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Search using voice info.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxResults The maximum number of results
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param uiLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param maxRes Highest possible maxResolution.
  Future<chopper.Response<List<VoiceSearchResponseV1>>> v1SearchVoicePost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xExplicitLogging,
    bool? sharedProfile,
    required String? profileId,
    required int? maxResults,
    int? cityId,
    bool? mergingOn,
    String? uiLanguage,
    bool? applyMarketingBias,
    enums.V1SearchVoicePostMaxRes? maxRes,
    String? cacheControl,
    required NuanceResponseV1? body,
  }) {
    generatedMapping.putIfAbsent(
        VoiceSearchResponseV1, () => VoiceSearchResponseV1.fromJsonFactory);

    return _v1SearchVoicePost(
        xDev: xDev,
        xCus: xCus,
        xExplicitLogging: xExplicitLogging,
        sharedProfile: sharedProfile,
        profileId: profileId,
        maxResults: maxResults,
        cityId: cityId,
        mergingOn: mergingOn,
        uiLanguage: uiLanguage,
        applyMarketingBias: applyMarketingBias,
        maxRes: maxRes?.value?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Search using voice info.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxResults The maximum number of results
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Boolean to signal whether client is prepared for linear / vod data merging
  ///@param uiLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param maxRes Highest possible maxResolution.
  @Post(
    path: '/v1/search/voice',
    optionalBody: true,
  )
  Future<chopper.Response<List<VoiceSearchResponseV1>>> _v1SearchVoicePost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-explicit-logging') String? xExplicitLogging,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('profileId') required String? profileId,
    @Query('maxResults') required int? maxResults,
    @Query('cityId') int? cityId,
    @Query('mergingOn') bool? mergingOn,
    @Query('uiLanguage') String? uiLanguage,
    @Query('applyMarketingBias') bool? applyMarketingBias,
    @Query('maxRes') String? maxRes,
    @Header('Cache-Control') String? cacheControl,
    @Body() required NuanceResponseV1? body,
  });

  ///Handles learn action events
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  Future<chopper.Response> v1LearnActionsPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xExplicitLogging,
    String? cacheControl,
    required LearnActionV1$RequestBody? body,
  }) {
    return _v1LearnActionsPost(
        xDev: xDev,
        xCus: xCus,
        xExplicitLogging: xExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Handles learn action events
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  @Post(
    path: '/v1/learn-actions',
    optionalBody: true,
  )
  Future<chopper.Response> _v1LearnActionsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-explicit-logging') String? xExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
    @Body() required LearnActionV1$RequestBody? body,
  });

  ///Retrieve the most popular searches.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  Future<chopper.Response<List<TopSearchResponseV1>>>
      v1RecommendationsTopSearchListGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    List<String>? contentSourceId,
    String? profileId,
    bool? sharedProfile,
    required int? maxResults,
    required bool? includeNotEntitled,
    String? queryLanguage,
    String? maxRes,
    int? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopSearchResponseV1, () => TopSearchResponseV1.fromJsonFactory);

    return _v1RecommendationsTopSearchListGet(
        xDev: xDev,
        xCus: xCus,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Retrieve the most popular searches.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  @Get(path: '/v1/recommendations/top-search-list')
  Future<chopper.Response<List<TopSearchResponseV1>>>
      _v1RecommendationsTopSearchListGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieve recommendations related to a given content.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  Future<chopper.Response<List<MoreLikeThisResponseV1>>>
      v1RecommendationsMoreLikeThisGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xExplicitLogging,
    String? headerNameTakenFromConfiguration,
    required String? clientType,
    List<String>? contentSourceId,
    String? profileId,
    bool? sharedProfile,
    required enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId?
        resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    String? maxRes,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisResponseV1, () => MoreLikeThisResponseV1.fromJsonFactory);

    return _v1RecommendationsMoreLikeThisGet(
        xDev: xDev,
        xCus: xCus,
        xExplicitLogging: xExplicitLogging,
        headerNameTakenFromConfiguration: headerNameTakenFromConfiguration,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId?.value?.toString(),
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cacheControl: cacheControl);
  }

  ///Retrieve recommendations related to a given content.
  ///@param X-Dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number
  ///@param x-explicit-logging ONLY for debugging. If set to true, then logs from below INFO will appear on INFO level for Discovery Service components.
  ///@param Header-Name-Taken-From-Configuration The header for identifying the originating IP address of a client. It is required in case x-cus is not provided or purchase-service can not provide entitlements in personalized endpoints. Name of the header needs to be checked in the service configuration:  customerPublicIPHeader
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param sharedProfile Flag to determine call mode to RENG service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param resourceId A program information CRID from the TVA metadata for the content item from which to derive the related recommendations. It needs to be a reference for a title. (eg: 'crid://bds.tv/162392685,imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxResults The maximum number of results
  ///@param includeNotEntitled Specifies if only entitled content should be included in the response.
  ///@param allowPreviousRecommendations Enables/disables info about previous recommendations.
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowEnd.
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). Can be used only along with filterTimeWindowStart.
  ///@param queryLanguage UI language.
  ///@param maxRes Highest possible maxResolution.
  @Get(path: '/v1/recommendations/more-like-this')
  Future<chopper.Response<List<MoreLikeThisResponseV1>>>
      _v1RecommendationsMoreLikeThisGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Header-Name-Taken-From-Configuration')
        String? headerNameTakenFromConfiguration,
    @Query('clientType')
        required String? clientType,
    @Query('contentSourceId')
        List<String>? contentSourceId,
    @Query('profileId')
        String? profileId,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('resourceContentSourceId')
        required String? resourceContentSourceId,
    @Query('resourceId')
        required String? resourceId,
    @Query('maxResults')
        required int? maxResults,
    @Query('includeNotEntitled')
        required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations')
        bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart')
        int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd')
        int? filterTimeWindowEnd,
    @Query('queryLanguage')
        String? queryLanguage,
    @Query('maxRes')
        String? maxRes,
    @Header('Cache-Control')
        String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisResponse {
  MoreLikeThisResponse({
    this.results,
  });

  factory MoreLikeThisResponse.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisResponseFromJson(json);

  static const toJsonFactory = _$MoreLikeThisResponseToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$MoreLikeThisResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MoreLikeThisResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $MoreLikeThisResponseExtension on MoreLikeThisResponse {
  MoreLikeThisResponse copyWith({List<Object>? results}) {
    return MoreLikeThisResponse(results: results ?? this.results);
  }

  MoreLikeThisResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return MoreLikeThisResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVRecommendationResponse {
  LTVRecommendationResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.replayContainsAdult,
    this.replayMinAge,
    this.series,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.replayAvailable,
    this.eventReplay,
    this.imageVersion,
  });

  factory LTVRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$LTVRecommendationResponseFromJson(json);

  static const toJsonFactory = _$LTVRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$LTVRecommendationResponseToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$LTVRecommendationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVRecommendationResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $LTVRecommendationResponseExtension on LTVRecommendationResponse {
  LTVRecommendationResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge,
      SeriesResponse? series,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      bool? replayAvailable,
      EventReplayResponse? eventReplay,
      String? imageVersion}) {
    return LTVRecommendationResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  LTVRecommendationResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay,
      Wrapped<String?>? imageVersion}) {
    return LTVRecommendationResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleChannelResponse {
  SimpleChannelResponse({
    this.channelId,
    this.channelName,
  });

  factory SimpleChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$SimpleChannelResponseFromJson(json);

  static const toJsonFactory = _$SimpleChannelResponseToJson;
  Map<String, dynamic> toJson() => _$SimpleChannelResponseToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  static const fromJsonFactory = _$SimpleChannelResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleChannelResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      runtimeType.hashCode;
}

extension $SimpleChannelResponseExtension on SimpleChannelResponse {
  SimpleChannelResponse copyWith({String? channelId, String? channelName}) {
    return SimpleChannelResponse(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName);
  }

  SimpleChannelResponse copyWithWrapped(
      {Wrapped<String?>? channelId, Wrapped<String?>? channelName}) {
    return SimpleChannelResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesResponse {
  SeriesResponse({
    this.mepSeriesFinale,
    this.premiereAirings,
    this.seriesId,
    this.seriesName,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    this.interacted,
    this.isBoxset,
    this.imageVersion,
    this.mergedId,
    this.isSplitProgram,
  });

  factory SeriesResponse.fromJson(Map<String, dynamic> json) =>
      _$SeriesResponseFromJson(json);

  static const toJsonFactory = _$SeriesResponseToJson;
  Map<String, dynamic> toJson() => _$SeriesResponseToJson(this);

  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'interacted', includeIfNull: false)
  final bool? interacted;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  static const fromJsonFactory = _$SeriesResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesResponse &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.interacted, interacted) ||
                const DeepCollectionEquality()
                    .equals(other.interacted, interacted)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.isSplitProgram, isSplitProgram) ||
                const DeepCollectionEquality()
                    .equals(other.isSplitProgram, isSplitProgram)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(interacted) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      runtimeType.hashCode;
}

extension $SeriesResponseExtension on SeriesResponse {
  SeriesResponse copyWith(
      {String? mepSeriesFinale,
      bool? premiereAirings,
      String? seriesId,
      String? seriesName,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      bool? interacted,
      bool? isBoxset,
      String? imageVersion,
      String? mergedId,
      bool? isSplitProgram}) {
    return SeriesResponse(
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings,
        seriesId: seriesId ?? this.seriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        interacted: interacted ?? this.interacted,
        isBoxset: isBoxset ?? this.isBoxset,
        imageVersion: imageVersion ?? this.imageVersion,
        mergedId: mergedId ?? this.mergedId,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram);
  }

  SeriesResponse copyWithWrapped(
      {Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<bool?>? interacted,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mergedId,
      Wrapped<bool?>? isSplitProgram}) {
    return SeriesResponse(
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        interacted: (interacted != null ? interacted.value : this.interacted),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesResponseVOD {
  SeriesResponseVOD({
    this.seriesId,
    this.seriesName,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    this.interacted,
    this.isBoxset,
    this.imageVersion,
    this.mergedId,
    this.isSplitProgram,
  });

  factory SeriesResponseVOD.fromJson(Map<String, dynamic> json) =>
      _$SeriesResponseVODFromJson(json);

  static const toJsonFactory = _$SeriesResponseVODToJson;
  Map<String, dynamic> toJson() => _$SeriesResponseVODToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'interacted', includeIfNull: false)
  final bool? interacted;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  static const fromJsonFactory = _$SeriesResponseVODFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesResponseVOD &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.interacted, interacted) ||
                const DeepCollectionEquality()
                    .equals(other.interacted, interacted)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.isSplitProgram, isSplitProgram) ||
                const DeepCollectionEquality()
                    .equals(other.isSplitProgram, isSplitProgram)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(interacted) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      runtimeType.hashCode;
}

extension $SeriesResponseVODExtension on SeriesResponseVOD {
  SeriesResponseVOD copyWith(
      {String? seriesId,
      String? seriesName,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      bool? interacted,
      bool? isBoxset,
      String? imageVersion,
      String? mergedId,
      bool? isSplitProgram}) {
    return SeriesResponseVOD(
        seriesId: seriesId ?? this.seriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        interacted: interacted ?? this.interacted,
        isBoxset: isBoxset ?? this.isBoxset,
        imageVersion: imageVersion ?? this.imageVersion,
        mergedId: mergedId ?? this.mergedId,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram);
  }

  SeriesResponseVOD copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<bool?>? interacted,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mergedId,
      Wrapped<bool?>? isSplitProgram}) {
    return SeriesResponseVOD(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        interacted: (interacted != null ? interacted.value : this.interacted),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram));
  }
}

@JsonSerializable(explicitToJson: true)
class EventReplayResponse {
  EventReplayResponse({
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.isGoPlayable,
  });

  factory EventReplayResponse.fromJson(Map<String, dynamic> json) =>
      _$EventReplayResponseFromJson(json);

  static const toJsonFactory = _$EventReplayResponseToJson;
  Map<String, dynamic> toJson() => _$EventReplayResponseToJson(this);

  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final int? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final int? replayAvailabilityEnd;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  static const fromJsonFactory = _$EventReplayResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventReplayResponse &&
            (identical(
                    other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      runtimeType.hashCode;
}

extension $EventReplayResponseExtension on EventReplayResponse {
  EventReplayResponse copyWith(
      {int? replayAvailabilityStart,
      int? replayAvailabilityEnd,
      bool? isGoPlayable}) {
    return EventReplayResponse(
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable);
  }

  EventReplayResponse copyWithWrapped(
      {Wrapped<int?>? replayAvailabilityStart,
      Wrapped<int?>? replayAvailabilityEnd,
      Wrapped<bool?>? isGoPlayable}) {
    return EventReplayResponse(
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable));
  }
}

@JsonSerializable(explicitToJson: true)
class VODResponse {
  VODResponse({
    this.series,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.est,
    this.estOnly,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.productType,
    this.imageVersion,
  });

  factory VODResponse.fromJson(Map<String, dynamic> json) =>
      _$VODResponseFromJson(json);

  static const toJsonFactory = _$VODResponseToJson;
  Map<String, dynamic> toJson() => _$VODResponseToJson(this);

  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponseVOD? series;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse>? est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODResponseProductTypeToJson,
    fromJson: vODResponseProductTypeFromJson,
  )
  final enums.VODResponseProductType? productType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$VODResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODResponse &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $VODResponseExtension on VODResponse {
  VODResponse copyWith(
      {SeriesResponseVOD? series,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODResponseProductType? productType,
      String? imageVersion}) {
    return VODResponse(
        series: series ?? this.series,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  VODResponse copyWithWrapped(
      {Wrapped<SeriesResponseVOD?>? series,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<List<EstResponse>?>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<enums.VODResponseProductType?>? productType,
      Wrapped<String?>? imageVersion}) {
    return VODResponse(
        series: (series != null ? series.value : this.series),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class VODResponseCommon {
  VODResponseCommon({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.est,
    this.estOnly,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.productType,
    this.imageVersion,
  });

  factory VODResponseCommon.fromJson(Map<String, dynamic> json) =>
      _$VODResponseCommonFromJson(json);

  static const toJsonFactory = _$VODResponseCommonToJson;
  Map<String, dynamic> toJson() => _$VODResponseCommonToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse>? est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODResponseCommonProductTypeToJson,
    fromJson: vODResponseCommonProductTypeFromJson,
  )
  final enums.VODResponseCommonProductType? productType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$VODResponseCommonFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODResponseCommon &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $VODResponseCommonExtension on VODResponseCommon {
  VODResponseCommon copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODResponseCommonProductType? productType,
      String? imageVersion}) {
    return VODResponseCommon(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  VODResponseCommon copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<List<EstResponse>?>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<enums.VODResponseCommonProductType?>? productType,
      Wrapped<String?>? imageVersion}) {
    return VODResponseCommon(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EstResponse {
  EstResponse({
    this.minPrice,
    required this.minPriceDisplay,
    required this.currency,
    required this.videoHost,
    required this.videoUrl,
  });

  factory EstResponse.fromJson(Map<String, dynamic> json) =>
      _$EstResponseFromJson(json);

  static const toJsonFactory = _$EstResponseToJson;
  Map<String, dynamic> toJson() => _$EstResponseToJson(this);

  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  static const fromJsonFactory = _$EstResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstResponse &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      runtimeType.hashCode;
}

extension $EstResponseExtension on EstResponse {
  EstResponse copyWith(
      {String? minPrice,
      String? minPriceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl}) {
    return EstResponse(
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl);
  }

  EstResponse copyWithWrapped(
      {Wrapped<String?>? minPrice,
      Wrapped<String>? minPriceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl}) {
    return EstResponse(
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRRecommendationResponse {
  PVRRecommendationResponse({
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.technicalDuration,
    this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.isRestricted,
    this.series,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.imageVersion,
  });

  factory PVRRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$PVRRecommendationResponseFromJson(json);

  static const toJsonFactory = _$PVRRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$PVRRecommendationResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$PVRRecommendationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRRecommendationResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $PVRRecommendationResponseExtension on PVRRecommendationResponse {
  PVRRecommendationResponse copyWith(
      {String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      int? technicalDuration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      bool? isRestricted,
      SeriesResponse? series,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      String? imageVersion}) {
    return PVRRecommendationResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  PVRRecommendationResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<String?>? imageVersion}) {
    return PVRRecommendationResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class ProviderResponse {
  ProviderResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    required this.providerType,
    required this.name,
    this.image,
  });

  factory ProviderResponse.fromJson(Map<String, dynamic> json) =>
      _$ProviderResponseFromJson(json);

  static const toJsonFactory = _$ProviderResponseToJson;
  Map<String, dynamic> toJson() => _$ProviderResponseToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'providerType', includeIfNull: false, defaultValue: '')
  final String providerType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$ProviderResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProviderResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.providerType, providerType) ||
                const DeepCollectionEquality()
                    .equals(other.providerType, providerType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(providerType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $ProviderResponseExtension on ProviderResponse {
  ProviderResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? providerType,
      String? name,
      String? image}) {
    return ProviderResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        providerType: providerType ?? this.providerType,
        name: name ?? this.name,
        image: image ?? this.image);
  }

  ProviderResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String>? providerType,
      Wrapped<String>? name,
      Wrapped<String?>? image}) {
    return ProviderResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        providerType:
            (providerType != null ? providerType.value : this.providerType),
        name: (name != null ? name.value : this.name),
        image: (image != null ? image.value : this.image));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class TopSearchResponse {
  TopSearchResponse({
    this.results,
  });

  factory TopSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$TopSearchResponseFromJson(json);

  static const toJsonFactory = _$TopSearchResponseToJson;
  Map<String, dynamic> toJson() => _$TopSearchResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$TopSearchResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopSearchResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $TopSearchResponseExtension on TopSearchResponse {
  TopSearchResponse copyWith({List<Object>? results}) {
    return TopSearchResponse(results: results ?? this.results);
  }

  TopSearchResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return TopSearchResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisResponseV3 {
  MoreLikeThisResponseV3({
    required this.results,
    this.providerSpecific,
  });

  factory MoreLikeThisResponseV3.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisResponseV3FromJson(json);

  static const toJsonFactory = _$MoreLikeThisResponseV3ToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> results;
  @JsonKey(
      name: 'providerSpecific', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? providerSpecific;
  static const fromJsonFactory = _$MoreLikeThisResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MoreLikeThisResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.providerSpecific, providerSpecific) ||
                const DeepCollectionEquality()
                    .equals(other.providerSpecific, providerSpecific)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(providerSpecific) ^
      runtimeType.hashCode;
}

extension $MoreLikeThisResponseV3Extension on MoreLikeThisResponseV3 {
  MoreLikeThisResponseV3 copyWith(
      {List<Object>? results, List<Object>? providerSpecific}) {
    return MoreLikeThisResponseV3(
        results: results ?? this.results,
        providerSpecific: providerSpecific ?? this.providerSpecific);
  }

  MoreLikeThisResponseV3 copyWithWrapped(
      {Wrapped<List<Object>>? results,
      Wrapped<List<Object>?>? providerSpecific}) {
    return MoreLikeThisResponseV3(
        results: (results != null ? results.value : this.results),
        providerSpecific: (providerSpecific != null
            ? providerSpecific.value
            : this.providerSpecific));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVRecommendationResponseV3 {
  LTVRecommendationResponseV3({
    this.mergedId,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.replayContainsAdult,
    this.replayMinAge,
    this.series,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.replayAvailable,
    this.eventReplay,
    this.imageVersion,
  });

  factory LTVRecommendationResponseV3.fromJson(Map<String, dynamic> json) =>
      _$LTVRecommendationResponseV3FromJson(json);

  static const toJsonFactory = _$LTVRecommendationResponseV3ToJson;
  Map<String, dynamic> toJson() => _$LTVRecommendationResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$LTVRecommendationResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVRecommendationResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $LTVRecommendationResponseV3Extension on LTVRecommendationResponseV3 {
  LTVRecommendationResponseV3 copyWith(
      {String? mergedId,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge,
      SeriesResponse? series,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      bool? replayAvailable,
      EventReplayResponse? eventReplay,
      String? imageVersion}) {
    return LTVRecommendationResponseV3(
        mergedId: mergedId ?? this.mergedId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  LTVRecommendationResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay,
      Wrapped<String?>? imageVersion}) {
    return LTVRecommendationResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class VODResponseV3 {
  VODResponseV3({
    this.mergedId,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.est,
    this.estOnly,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.productType,
    this.imageVersion,
    this.series,
  });

  factory VODResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VODResponseV3FromJson(json);

  static const toJsonFactory = _$VODResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VODResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse>? est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODResponseV3ProductTypeToJson,
    fromJson: vODResponseV3ProductTypeFromJson,
  )
  final enums.VODResponseV3ProductType? productType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponseVOD? series;
  static const fromJsonFactory = _$VODResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) || const DeepCollectionEquality().equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $VODResponseV3Extension on VODResponseV3 {
  VODResponseV3 copyWith(
      {String? mergedId,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODResponseV3ProductType? productType,
      String? imageVersion,
      SeriesResponseVOD? series}) {
    return VODResponseV3(
        mergedId: mergedId ?? this.mergedId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType,
        imageVersion: imageVersion ?? this.imageVersion,
        series: series ?? this.series);
  }

  VODResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<List<EstResponse>?>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<enums.VODResponseV3ProductType?>? productType,
      Wrapped<String?>? imageVersion,
      Wrapped<SeriesResponseVOD?>? series}) {
    return VODResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class OTTResponseV3 {
  OTTResponseV3({
    required this.contentType,
    required this.contentSource,
    required this.titleId,
    this.mergedId,
    required this.name,
    this.ageRating,
    required this.isAdult,
    required this.videoHost,
    required this.videoUrl,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.isEst,
    this.imageVersion,
  });

  factory OTTResponseV3.fromJson(Map<String, dynamic> json) =>
      _$OTTResponseV3FromJson(json);

  static const toJsonFactory = _$OTTResponseV3ToJson;
  Map<String, dynamic> toJson() => _$OTTResponseV3ToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'isEst', includeIfNull: false)
  final bool? isEst;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$OTTResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OTTResponseV3 &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(
                    other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.isEst, isEst) ||
                const DeepCollectionEquality().equals(other.isEst, isEst)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(isEst) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $OTTResponseV3Extension on OTTResponseV3 {
  OTTResponseV3 copyWith(
      {String? contentType,
      int? contentSource,
      String? titleId,
      String? mergedId,
      String? name,
      int? ageRating,
      bool? isAdult,
      String? videoHost,
      String? videoUrl,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      bool? isEst,
      String? imageVersion}) {
    return OTTResponseV3(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        titleId: titleId ?? this.titleId,
        mergedId: mergedId ?? this.mergedId,
        name: name ?? this.name,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        isEst: isEst ?? this.isEst,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  OTTResponseV3 copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? titleId,
      Wrapped<String?>? mergedId,
      Wrapped<String>? name,
      Wrapped<int?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<bool?>? isEst,
      Wrapped<String?>? imageVersion}) {
    return OTTResponseV3(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        titleId: (titleId != null ? titleId.value : this.titleId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        name: (name != null ? name.value : this.name),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        isEst: (isEst != null ? isEst.value : this.isEst),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRRecommendationResponseV3 {
  PVRRecommendationResponseV3({
    this.mergedId,
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.technicalDuration,
    this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.isRestricted,
    this.series,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.imageVersion,
  });

  factory PVRRecommendationResponseV3.fromJson(Map<String, dynamic> json) =>
      _$PVRRecommendationResponseV3FromJson(json);

  static const toJsonFactory = _$PVRRecommendationResponseV3ToJson;
  Map<String, dynamic> toJson() => _$PVRRecommendationResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$PVRRecommendationResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRRecommendationResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $PVRRecommendationResponseV3Extension on PVRRecommendationResponseV3 {
  PVRRecommendationResponseV3 copyWith(
      {String? mergedId,
      String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      int? technicalDuration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      bool? isRestricted,
      SeriesResponse? series,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      String? imageVersion}) {
    return PVRRecommendationResponseV3(
        mergedId: mergedId ?? this.mergedId,
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  PVRRecommendationResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<String?>? imageVersion}) {
    return PVRRecommendationResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class TopSearchResponseV3 {
  TopSearchResponseV3({
    this.results,
  });

  factory TopSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$TopSearchResponseV3FromJson(json);

  static const toJsonFactory = _$TopSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$TopSearchResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$TopSearchResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopSearchResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $TopSearchResponseV3Extension on TopSearchResponseV3 {
  TopSearchResponseV3 copyWith({List<Object>? results}) {
    return TopSearchResponseV3(results: results ?? this.results);
  }

  TopSearchResponseV3 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return TopSearchResponseV3(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class CollaborativeResponseV3 {
  CollaborativeResponseV3({
    this.results,
    this.type,
  });

  factory CollaborativeResponseV3.fromJson(Map<String, dynamic> json) =>
      _$CollaborativeResponseV3FromJson(json);

  static const toJsonFactory = _$CollaborativeResponseV3ToJson;
  Map<String, dynamic> toJson() => _$CollaborativeResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: collaborativeResponseV3TypeToJson,
    fromJson: collaborativeResponseV3TypeFromJson,
  )
  final enums.CollaborativeResponseV3Type? type;
  static const fromJsonFactory = _$CollaborativeResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CollaborativeResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $CollaborativeResponseV3Extension on CollaborativeResponseV3 {
  CollaborativeResponseV3 copyWith(
      {List<Object>? results, enums.CollaborativeResponseV3Type? type}) {
    return CollaborativeResponseV3(
        results: results ?? this.results, type: type ?? this.type);
  }

  CollaborativeResponseV3 copyWithWrapped(
      {Wrapped<List<Object>?>? results,
      Wrapped<enums.CollaborativeResponseV3Type?>? type}) {
    return CollaborativeResponseV3(
        results: (results != null ? results.value : this.results),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileResponse {
  ProfileResponse({
    this.results,
  });

  factory ProfileResponse.fromJson(Map<String, dynamic> json) =>
      _$ProfileResponseFromJson(json);

  static const toJsonFactory = _$ProfileResponseToJson;
  Map<String, dynamic> toJson() => _$ProfileResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$ProfileResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $ProfileResponseExtension on ProfileResponse {
  ProfileResponse copyWith({List<Object>? results}) {
    return ProfileResponse(results: results ?? this.results);
  }

  ProfileResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return ProfileResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedMultisourceResponseV3 {
  GroupedMultisourceResponseV3({
    this.mergedId,
    required this.groupType,
    required this.id,
    this.name,
    this.channels,
    this.selectedEventId,
    this.series,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
  });

  factory GroupedMultisourceResponseV3.fromJson(Map<String, dynamic> json) =>
      _$GroupedMultisourceResponseV3FromJson(json);

  static const toJsonFactory = _$GroupedMultisourceResponseV3ToJson;
  Map<String, dynamic> toJson() => _$GroupedMultisourceResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <GroupedChannelResponse>[])
  final List<GroupedChannelResponse>? channels;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedMultisourceResponseV3SeriesContentTypeToJson,
    fromJson: groupedMultisourceResponseV3SeriesContentTypeFromJson,
  )
  final enums.GroupedMultisourceResponseV3SeriesContentType? seriesContentType;
  static const fromJsonFactory = _$GroupedMultisourceResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedMultisourceResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      runtimeType.hashCode;
}

extension $GroupedMultisourceResponseV3Extension
    on GroupedMultisourceResponseV3 {
  GroupedMultisourceResponseV3 copyWith(
      {String? mergedId,
      String? groupType,
      String? id,
      String? name,
      List<GroupedChannelResponse>? channels,
      String? selectedEventId,
      SeriesResponse? series,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedMultisourceResponseV3SeriesContentType? seriesContentType}) {
    return GroupedMultisourceResponseV3(
        mergedId: mergedId ?? this.mergedId,
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        series: series ?? this.series,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType);
  }

  GroupedMultisourceResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<List<GroupedChannelResponse>?>? channels,
      Wrapped<String?>? selectedEventId,
      Wrapped<SeriesResponse?>? series,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedMultisourceResponseV3SeriesContentType?>?
          seriesContentType}) {
    return GroupedMultisourceResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        series: (series != null ? series.value : this.series),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedMultisourceResponse {
  GroupedMultisourceResponse({
    this.series,
    required this.groupType,
    required this.id,
    this.name,
    this.channels,
    this.selectedEventId,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
  });

  factory GroupedMultisourceResponse.fromJson(Map<String, dynamic> json) =>
      _$GroupedMultisourceResponseFromJson(json);

  static const toJsonFactory = _$GroupedMultisourceResponseToJson;
  Map<String, dynamic> toJson() => _$GroupedMultisourceResponseToJson(this);

  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <GroupedChannelResponse>[])
  final List<GroupedChannelResponse>? channels;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedMultisourceResponseSeriesContentTypeToJson,
    fromJson: groupedMultisourceResponseSeriesContentTypeFromJson,
  )
  final enums.GroupedMultisourceResponseSeriesContentType? seriesContentType;
  static const fromJsonFactory = _$GroupedMultisourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedMultisourceResponse &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      runtimeType.hashCode;
}

extension $GroupedMultisourceResponseExtension on GroupedMultisourceResponse {
  GroupedMultisourceResponse copyWith(
      {SeriesResponse? series,
      String? groupType,
      String? id,
      String? name,
      List<GroupedChannelResponse>? channels,
      String? selectedEventId,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedMultisourceResponseSeriesContentType? seriesContentType}) {
    return GroupedMultisourceResponse(
        series: series ?? this.series,
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType);
  }

  GroupedMultisourceResponse copyWithWrapped(
      {Wrapped<SeriesResponse?>? series,
      Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<List<GroupedChannelResponse>?>? channels,
      Wrapped<String?>? selectedEventId,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedMultisourceResponseSeriesContentType?>?
          seriesContentType}) {
    return GroupedMultisourceResponse(
        series: (series != null ? series.value : this.series),
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedMultisourceResponseCommon {
  GroupedMultisourceResponseCommon({
    required this.groupType,
    required this.id,
    this.name,
    this.channels,
    this.selectedEventId,
    this.series,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
  });

  factory GroupedMultisourceResponseCommon.fromJson(
          Map<String, dynamic> json) =>
      _$GroupedMultisourceResponseCommonFromJson(json);

  static const toJsonFactory = _$GroupedMultisourceResponseCommonToJson;
  Map<String, dynamic> toJson() =>
      _$GroupedMultisourceResponseCommonToJson(this);

  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <GroupedChannelResponse>[])
  final List<GroupedChannelResponse>? channels;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedMultisourceResponseCommonSeriesContentTypeToJson,
    fromJson: groupedMultisourceResponseCommonSeriesContentTypeFromJson,
  )
  final enums.GroupedMultisourceResponseCommonSeriesContentType?
      seriesContentType;
  static const fromJsonFactory = _$GroupedMultisourceResponseCommonFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedMultisourceResponseCommon &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      runtimeType.hashCode;
}

extension $GroupedMultisourceResponseCommonExtension
    on GroupedMultisourceResponseCommon {
  GroupedMultisourceResponseCommon copyWith(
      {String? groupType,
      String? id,
      String? name,
      List<GroupedChannelResponse>? channels,
      String? selectedEventId,
      SeriesResponse? series,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedMultisourceResponseCommonSeriesContentType?
          seriesContentType}) {
    return GroupedMultisourceResponseCommon(
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        series: series ?? this.series,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType);
  }

  GroupedMultisourceResponseCommon copyWithWrapped(
      {Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<List<GroupedChannelResponse>?>? channels,
      Wrapped<String?>? selectedEventId,
      Wrapped<SeriesResponse?>? series,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedMultisourceResponseCommonSeriesContentType?>?
          seriesContentType}) {
    return GroupedMultisourceResponseCommon(
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        series: (series != null ? series.value : this.series),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedChannelResponse {
  GroupedChannelResponse({
    this.id,
    this.name,
  });

  factory GroupedChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$GroupedChannelResponseFromJson(json);

  static const toJsonFactory = _$GroupedChannelResponseToJson;
  Map<String, dynamic> toJson() => _$GroupedChannelResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$GroupedChannelResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedChannelResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $GroupedChannelResponseExtension on GroupedChannelResponse {
  GroupedChannelResponse copyWith({String? id, String? name}) {
    return GroupedChannelResponse(id: id ?? this.id, name: name ?? this.name);
  }

  GroupedChannelResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<String?>? name}) {
    return GroupedChannelResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedSeriesResponseV3 {
  GroupedSeriesResponseV3({
    this.mergedId,
    required this.groupType,
    required this.id,
    this.name,
    this.channels,
    this.hasInteracted,
    this.selectedEventId,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
    this.episodeCount,
    this.seasonCount,
    this.specialsCount,
    this.isBoxset,
    this.mepSeriesFinale,
    this.premiereAirings,
    this.isSplitProgram,
  });

  factory GroupedSeriesResponseV3.fromJson(Map<String, dynamic> json) =>
      _$GroupedSeriesResponseV3FromJson(json);

  static const toJsonFactory = _$GroupedSeriesResponseV3ToJson;
  Map<String, dynamic> toJson() => _$GroupedSeriesResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <GroupedChannelResponse>[])
  final List<GroupedChannelResponse>? channels;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool? hasInteracted;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedSeriesResponseV3SeriesContentTypeToJson,
    fromJson: groupedSeriesResponseV3SeriesContentTypeFromJson,
  )
  final enums.GroupedSeriesResponseV3SeriesContentType? seriesContentType;
  @JsonKey(name: 'episodeCount', includeIfNull: false)
  final int? episodeCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  static const fromJsonFactory = _$GroupedSeriesResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedSeriesResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)) &&
            (identical(other.episodeCount, episodeCount) ||
                const DeepCollectionEquality()
                    .equals(other.episodeCount, episodeCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)) &&
            (identical(other.isSplitProgram, isSplitProgram) ||
                const DeepCollectionEquality()
                    .equals(other.isSplitProgram, isSplitProgram)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      const DeepCollectionEquality().hash(episodeCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      runtimeType.hashCode;
}

extension $GroupedSeriesResponseV3Extension on GroupedSeriesResponseV3 {
  GroupedSeriesResponseV3 copyWith(
      {String? mergedId,
      String? groupType,
      String? id,
      String? name,
      List<GroupedChannelResponse>? channels,
      bool? hasInteracted,
      String? selectedEventId,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedSeriesResponseV3SeriesContentType? seriesContentType,
      int? episodeCount,
      int? seasonCount,
      int? specialsCount,
      bool? isBoxset,
      String? mepSeriesFinale,
      bool? premiereAirings,
      bool? isSplitProgram}) {
    return GroupedSeriesResponseV3(
        mergedId: mergedId ?? this.mergedId,
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType,
        episodeCount: episodeCount ?? this.episodeCount,
        seasonCount: seasonCount ?? this.seasonCount,
        specialsCount: specialsCount ?? this.specialsCount,
        isBoxset: isBoxset ?? this.isBoxset,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram);
  }

  GroupedSeriesResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<List<GroupedChannelResponse>?>? channels,
      Wrapped<bool?>? hasInteracted,
      Wrapped<String?>? selectedEventId,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedSeriesResponseV3SeriesContentType?>?
          seriesContentType,
      Wrapped<int?>? episodeCount,
      Wrapped<int?>? seasonCount,
      Wrapped<int?>? specialsCount,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings,
      Wrapped<bool?>? isSplitProgram}) {
    return GroupedSeriesResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType),
        episodeCount:
            (episodeCount != null ? episodeCount.value : this.episodeCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedSeriesResponse {
  GroupedSeriesResponse({
    required this.groupType,
    required this.id,
    this.name,
    this.channels,
    this.hasInteracted,
    this.selectedEventId,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
    this.episodeCount,
    this.seasonCount,
    this.specialsCount,
    this.isBoxset,
    this.mepSeriesFinale,
    this.premiereAirings,
    this.isSplitProgram,
  });

  factory GroupedSeriesResponse.fromJson(Map<String, dynamic> json) =>
      _$GroupedSeriesResponseFromJson(json);

  static const toJsonFactory = _$GroupedSeriesResponseToJson;
  Map<String, dynamic> toJson() => _$GroupedSeriesResponseToJson(this);

  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <GroupedChannelResponse>[])
  final List<GroupedChannelResponse>? channels;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool? hasInteracted;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedSeriesResponseSeriesContentTypeToJson,
    fromJson: groupedSeriesResponseSeriesContentTypeFromJson,
  )
  final enums.GroupedSeriesResponseSeriesContentType? seriesContentType;
  @JsonKey(name: 'episodeCount', includeIfNull: false)
  final int? episodeCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  static const fromJsonFactory = _$GroupedSeriesResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedSeriesResponse &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)) &&
            (identical(other.episodeCount, episodeCount) ||
                const DeepCollectionEquality()
                    .equals(other.episodeCount, episodeCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)) &&
            (identical(other.isSplitProgram, isSplitProgram) ||
                const DeepCollectionEquality()
                    .equals(other.isSplitProgram, isSplitProgram)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      const DeepCollectionEquality().hash(episodeCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      runtimeType.hashCode;
}

extension $GroupedSeriesResponseExtension on GroupedSeriesResponse {
  GroupedSeriesResponse copyWith(
      {String? groupType,
      String? id,
      String? name,
      List<GroupedChannelResponse>? channels,
      bool? hasInteracted,
      String? selectedEventId,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedSeriesResponseSeriesContentType? seriesContentType,
      int? episodeCount,
      int? seasonCount,
      int? specialsCount,
      bool? isBoxset,
      String? mepSeriesFinale,
      bool? premiereAirings,
      bool? isSplitProgram}) {
    return GroupedSeriesResponse(
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType,
        episodeCount: episodeCount ?? this.episodeCount,
        seasonCount: seasonCount ?? this.seasonCount,
        specialsCount: specialsCount ?? this.specialsCount,
        isBoxset: isBoxset ?? this.isBoxset,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram);
  }

  GroupedSeriesResponse copyWithWrapped(
      {Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<List<GroupedChannelResponse>?>? channels,
      Wrapped<bool?>? hasInteracted,
      Wrapped<String?>? selectedEventId,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedSeriesResponseSeriesContentType?>? seriesContentType,
      Wrapped<int?>? episodeCount,
      Wrapped<int?>? seasonCount,
      Wrapped<int?>? specialsCount,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings,
      Wrapped<bool?>? isSplitProgram}) {
    return GroupedSeriesResponse(
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType),
        episodeCount:
            (episodeCount != null ? episodeCount.value : this.episodeCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram));
  }
}

@JsonSerializable(explicitToJson: true)
class UserCollaborativeResponse {
  UserCollaborativeResponse({
    this.results,
  });

  factory UserCollaborativeResponse.fromJson(Map<String, dynamic> json) =>
      _$UserCollaborativeResponseFromJson(json);

  static const toJsonFactory = _$UserCollaborativeResponseToJson;
  Map<String, dynamic> toJson() => _$UserCollaborativeResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$UserCollaborativeResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserCollaborativeResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $UserCollaborativeResponseExtension on UserCollaborativeResponse {
  UserCollaborativeResponse copyWith({List<Object>? results}) {
    return UserCollaborativeResponse(results: results ?? this.results);
  }

  UserCollaborativeResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return UserCollaborativeResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class StbSearchResponse {
  StbSearchResponse({
    this.results,
  });

  factory StbSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$StbSearchResponseFromJson(json);

  static const toJsonFactory = _$StbSearchResponseToJson;
  Map<String, dynamic> toJson() => _$StbSearchResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$StbSearchResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StbSearchResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $StbSearchResponseExtension on StbSearchResponse {
  StbSearchResponse copyWith({List<Object>? results}) {
    return StbSearchResponse(results: results ?? this.results);
  }

  StbSearchResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return StbSearchResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponse {
  LTVSearchResponse({
    this.series,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.replayContainsAdult,
    this.replayMinAge,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.replayAvailable,
    this.eventReplay,
  });

  factory LTVSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseFromJson(json);

  static const toJsonFactory = _$LTVSearchResponseToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseToJson(this);

  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  static const fromJsonFactory = _$LTVSearchResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponse &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseExtension on LTVSearchResponse {
  LTVSearchResponse copyWith(
      {SeriesResponse? series,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      bool? replayAvailable,
      EventReplayResponse? eventReplay}) {
    return LTVSearchResponse(
        series: series ?? this.series,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay);
  }

  LTVSearchResponse copyWithWrapped(
      {Wrapped<SeriesResponse?>? series,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay}) {
    return LTVSearchResponse(
        series: (series != null ? series.value : this.series),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponseCommon {
  LTVSearchResponseCommon({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.replayContainsAdult,
    this.replayMinAge,
    this.series,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.replayAvailable,
    this.eventReplay,
  });

  factory LTVSearchResponseCommon.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseCommonFromJson(json);

  static const toJsonFactory = _$LTVSearchResponseCommonToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseCommonToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  static const fromJsonFactory = _$LTVSearchResponseCommonFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponseCommon &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseCommonExtension on LTVSearchResponseCommon {
  LTVSearchResponseCommon copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge,
      SeriesResponse? series,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      bool? replayAvailable,
      EventReplayResponse? eventReplay}) {
    return LTVSearchResponseCommon(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay);
  }

  LTVSearchResponseCommon copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay}) {
    return LTVSearchResponseCommon(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRSearchResponse {
  PVRSearchResponse({
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    required this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.associatedPicture,
    required this.associatedPictureType,
    required this.isRestricted,
    this.series,
    this.eventPremiere,
  });

  factory PVRSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$PVRSearchResponseFromJson(json);

  static const toJsonFactory = _$PVRSearchResponseToJson;
  Map<String, dynamic> toJson() => _$PVRSearchResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  static const fromJsonFactory = _$PVRSearchResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRSearchResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      runtimeType.hashCode;
}

extension $PVRSearchResponseExtension on PVRSearchResponse {
  PVRSearchResponse copyWith(
      {String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isRestricted,
      SeriesResponse? series,
      bool? eventPremiere}) {
    return PVRSearchResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere);
  }

  PVRSearchResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere}) {
    return PVRSearchResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere));
  }
}

@JsonSerializable(explicitToJson: true)
class ApplicationResponse {
  ApplicationResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.appLogo,
  });

  factory ApplicationResponse.fromJson(Map<String, dynamic> json) =>
      _$ApplicationResponseFromJson(json);

  static const toJsonFactory = _$ApplicationResponseToJson;
  Map<String, dynamic> toJson() => _$ApplicationResponseToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'appLogo', includeIfNull: false, defaultValue: '')
  final String? appLogo;
  static const fromJsonFactory = _$ApplicationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ApplicationResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.appLogo, appLogo) ||
                const DeepCollectionEquality().equals(other.appLogo, appLogo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(appLogo) ^
      runtimeType.hashCode;
}

extension $ApplicationResponseExtension on ApplicationResponse {
  ApplicationResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      String? appLogo}) {
    return ApplicationResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        appLogo: appLogo ?? this.appLogo);
  }

  ApplicationResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? appLogo}) {
    return ApplicationResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        appLogo: (appLogo != null ? appLogo.value : this.appLogo));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponse {
  ChannelResponse({
    required this.contentType,
    required this.contentSource,
    this.id,
    this.name,
    this.event,
    required this.associatedPicture,
    required this.associatedPictureType,
  });

  factory ChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseFromJson(json);

  static const toJsonFactory = _$ChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseToJson(this);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'event', includeIfNull: false)
  final ChannelEventResponse? event;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  static const fromJsonFactory = _$ChannelResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.event, event) ||
                const DeepCollectionEquality().equals(other.event, event)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(event) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      runtimeType.hashCode;
}

extension $ChannelResponseExtension on ChannelResponse {
  ChannelResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      ChannelEventResponse? event,
      String? associatedPicture,
      String? associatedPictureType}) {
    return ChannelResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        event: event ?? this.event,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType);
  }

  ChannelResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<ChannelEventResponse?>? event,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType}) {
    return ChannelResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        event: (event != null ? event.value : this.event),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelEventResponse {
  ChannelEventResponse({
    required this.id,
    this.name,
    this.startTime,
    this.endTime,
    this.duration,
    this.ageRating,
    this.isAdult,
  });

  factory ChannelEventResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelEventResponseFromJson(json);

  static const toJsonFactory = _$ChannelEventResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelEventResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  static const fromJsonFactory = _$ChannelEventResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelEventResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality().equals(other.isAdult, isAdult)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      runtimeType.hashCode;
}

extension $ChannelEventResponseExtension on ChannelEventResponse {
  ChannelEventResponse copyWith(
      {String? id,
      String? name,
      String? startTime,
      String? endTime,
      int? duration,
      int? ageRating,
      bool? isAdult}) {
    return ChannelEventResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult);
  }

  ChannelEventResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult}) {
    return ChannelEventResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceSearchResponse {
  VoiceSearchResponse({
    this.results,
  });

  factory VoiceSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$VoiceSearchResponseFromJson(json);

  static const toJsonFactory = _$VoiceSearchResponseToJson;
  Map<String, dynamic> toJson() => _$VoiceSearchResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$VoiceSearchResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoiceSearchResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $VoiceSearchResponseExtension on VoiceSearchResponse {
  VoiceSearchResponse copyWith({List<Object>? results}) {
    return VoiceSearchResponse(results: results ?? this.results);
  }

  VoiceSearchResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return VoiceSearchResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class StbSearchResponseV3 {
  StbSearchResponseV3({
    this.results,
    this.youtube,
    this.suggestions,
  });

  factory StbSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$StbSearchResponseV3FromJson(json);

  static const toJsonFactory = _$StbSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$StbSearchResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  @JsonKey(name: 'youtube', includeIfNull: false)
  final YoutubeResults? youtube;
  @JsonKey(
      name: 'suggestions', includeIfNull: false, defaultValue: <Suggestion>[])
  final List<Suggestion>? suggestions;
  static const fromJsonFactory = _$StbSearchResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StbSearchResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.youtube, youtube) ||
                const DeepCollectionEquality()
                    .equals(other.youtube, youtube)) &&
            (identical(other.suggestions, suggestions) ||
                const DeepCollectionEquality()
                    .equals(other.suggestions, suggestions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(youtube) ^
      const DeepCollectionEquality().hash(suggestions) ^
      runtimeType.hashCode;
}

extension $StbSearchResponseV3Extension on StbSearchResponseV3 {
  StbSearchResponseV3 copyWith(
      {List<Object>? results,
      YoutubeResults? youtube,
      List<Suggestion>? suggestions}) {
    return StbSearchResponseV3(
        results: results ?? this.results,
        youtube: youtube ?? this.youtube,
        suggestions: suggestions ?? this.suggestions);
  }

  StbSearchResponseV3 copyWithWrapped(
      {Wrapped<List<Object>?>? results,
      Wrapped<YoutubeResults?>? youtube,
      Wrapped<List<Suggestion>?>? suggestions}) {
    return StbSearchResponseV3(
        results: (results != null ? results.value : this.results),
        youtube: (youtube != null ? youtube.value : this.youtube),
        suggestions:
            (suggestions != null ? suggestions.value : this.suggestions));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponseV3 {
  LTVSearchResponseV3({
    this.mergedId,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.replayContainsAdult,
    this.replayMinAge,
    this.series,
    this.eventPremiere,
    required this.associatedPicture,
    required this.associatedPictureType,
    this.replayAvailable,
    this.eventReplay,
  });

  factory LTVSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseV3FromJson(json);

  static const toJsonFactory = _$LTVSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  static const fromJsonFactory = _$LTVSearchResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseV3Extension on LTVSearchResponseV3 {
  LTVSearchResponseV3 copyWith(
      {String? mergedId,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge,
      SeriesResponse? series,
      bool? eventPremiere,
      String? associatedPicture,
      String? associatedPictureType,
      bool? replayAvailable,
      EventReplayResponse? eventReplay}) {
    return LTVSearchResponseV3(
        mergedId: mergedId ?? this.mergedId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay);
  }

  LTVSearchResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay}) {
    return LTVSearchResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRSearchResponseV3 {
  PVRSearchResponseV3({
    this.mergedId,
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    required this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.associatedPicture,
    required this.associatedPictureType,
    required this.isRestricted,
    this.series,
    this.eventPremiere,
  });

  factory PVRSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$PVRSearchResponseV3FromJson(json);

  static const toJsonFactory = _$PVRSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$PVRSearchResponseV3ToJson(this);

  @JsonKey(name: 'mergedId', includeIfNull: false)
  final String? mergedId;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String associatedPictureType;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'eventPremiere', includeIfNull: false)
  final bool? eventPremiere;
  static const fromJsonFactory = _$PVRSearchResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRSearchResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.eventPremiere, eventPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.eventPremiere, eventPremiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(eventPremiere) ^
      runtimeType.hashCode;
}

extension $PVRSearchResponseV3Extension on PVRSearchResponseV3 {
  PVRSearchResponseV3 copyWith(
      {String? mergedId,
      String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      int? duration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isRestricted,
      SeriesResponse? series,
      bool? eventPremiere}) {
    return PVRSearchResponseV3(
        mergedId: mergedId ?? this.mergedId,
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series,
        eventPremiere: eventPremiere ?? this.eventPremiere);
  }

  PVRSearchResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<int?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<String>? associatedPicture,
      Wrapped<String>? associatedPictureType,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? eventPremiere}) {
    return PVRSearchResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series),
        eventPremiere:
            (eventPremiere != null ? eventPremiere.value : this.eventPremiere));
  }
}

typedef YoutubeResults = List<YoutubeResults$Item>;

@JsonSerializable(explicitToJson: true)
class YoutubeResults$Item {
  YoutubeResults$Item();

  factory YoutubeResults$Item.fromJson(Map<String, dynamic> json) =>
      _$YoutubeResults$ItemFromJson(json);

  static const toJsonFactory = _$YoutubeResults$ItemToJson;
  Map<String, dynamic> toJson() => _$YoutubeResults$ItemToJson(this);

  static const fromJsonFactory = _$YoutubeResults$ItemFromJson;

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class Suggestion {
  Suggestion({
    required this.title,
  });

  factory Suggestion.fromJson(Map<String, dynamic> json) =>
      _$SuggestionFromJson(json);

  static const toJsonFactory = _$SuggestionToJson;
  Map<String, dynamic> toJson() => _$SuggestionToJson(this);

  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  static const fromJsonFactory = _$SuggestionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Suggestion &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(title) ^ runtimeType.hashCode;
}

extension $SuggestionExtension on Suggestion {
  Suggestion copyWith({String? title}) {
    return Suggestion(title: title ?? this.title);
  }

  Suggestion copyWithWrapped({Wrapped<String>? title}) {
    return Suggestion(title: (title != null ? title.value : this.title));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceSearchResponseV3 {
  VoiceSearchResponseV3({
    this.results,
    this.youtube,
  });

  factory VoiceSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VoiceSearchResponseV3FromJson(json);

  static const toJsonFactory = _$VoiceSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VoiceSearchResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  @JsonKey(name: 'youtube', includeIfNull: false)
  final YoutubeResults? youtube;
  static const fromJsonFactory = _$VoiceSearchResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoiceSearchResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.youtube, youtube) ||
                const DeepCollectionEquality().equals(other.youtube, youtube)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(youtube) ^
      runtimeType.hashCode;
}

extension $VoiceSearchResponseV3Extension on VoiceSearchResponseV3 {
  VoiceSearchResponseV3 copyWith(
      {List<Object>? results, YoutubeResults? youtube}) {
    return VoiceSearchResponseV3(
        results: results ?? this.results, youtube: youtube ?? this.youtube);
  }

  VoiceSearchResponseV3 copyWithWrapped(
      {Wrapped<List<Object>?>? results, Wrapped<YoutubeResults?>? youtube}) {
    return VoiceSearchResponseV3(
        results: (results != null ? results.value : this.results),
        youtube: (youtube != null ? youtube.value : this.youtube));
  }
}

@JsonSerializable(explicitToJson: true)
class GetRecentResponse {
  GetRecentResponse({
    this.results,
  });

  factory GetRecentResponse.fromJson(Map<String, dynamic> json) =>
      _$GetRecentResponseFromJson(json);

  static const toJsonFactory = _$GetRecentResponseToJson;
  Map<String, dynamic> toJson() => _$GetRecentResponseToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Recent>[])
  final List<Recent>? results;
  static const fromJsonFactory = _$GetRecentResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetRecentResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $GetRecentResponseExtension on GetRecentResponse {
  GetRecentResponse copyWith({List<Recent>? results}) {
    return GetRecentResponse(results: results ?? this.results);
  }

  GetRecentResponse copyWithWrapped({Wrapped<List<Recent>?>? results}) {
    return GetRecentResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class Recent {
  Recent({
    required this.id,
    required this.name,
    this.series,
  });

  factory Recent.fromJson(Map<String, dynamic> json) => _$RecentFromJson(json);

  static const toJsonFactory = _$RecentToJson;
  Map<String, dynamic> toJson() => _$RecentToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'series', includeIfNull: false)
  final RecentSeries? series;
  static const fromJsonFactory = _$RecentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Recent &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $RecentExtension on Recent {
  Recent copyWith({String? id, String? name, RecentSeries? series}) {
    return Recent(
        id: id ?? this.id,
        name: name ?? this.name,
        series: series ?? this.series);
  }

  Recent copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<RecentSeries?>? series}) {
    return Recent(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceRecordResponseV3 {
  VoiceRecordResponseV3({
    this.results,
    this.channelIds,
  });

  factory VoiceRecordResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VoiceRecordResponseV3FromJson(json);

  static const toJsonFactory = _$VoiceRecordResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VoiceRecordResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  @JsonKey(name: 'channelIds', includeIfNull: false, defaultValue: '')
  final String? channelIds;
  static const fromJsonFactory = _$VoiceRecordResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoiceRecordResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.channelIds, channelIds) ||
                const DeepCollectionEquality()
                    .equals(other.channelIds, channelIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(channelIds) ^
      runtimeType.hashCode;
}

extension $VoiceRecordResponseV3Extension on VoiceRecordResponseV3 {
  VoiceRecordResponseV3 copyWith({List<Object>? results, String? channelIds}) {
    return VoiceRecordResponseV3(
        results: results ?? this.results,
        channelIds: channelIds ?? this.channelIds);
  }

  VoiceRecordResponseV3 copyWithWrapped(
      {Wrapped<List<Object>?>? results, Wrapped<String?>? channelIds}) {
    return VoiceRecordResponseV3(
        results: (results != null ? results.value : this.results),
        channelIds: (channelIds != null ? channelIds.value : this.channelIds));
  }
}

@JsonSerializable(explicitToJson: true)
class VoicePlayResponseV3 {
  VoicePlayResponseV3({
    this.results,
  });

  factory VoicePlayResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VoicePlayResponseV3FromJson(json);

  static const toJsonFactory = _$VoicePlayResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VoicePlayResponseV3ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$VoicePlayResponseV3FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoicePlayResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $VoicePlayResponseV3Extension on VoicePlayResponseV3 {
  VoicePlayResponseV3 copyWith({List<Object>? results}) {
    return VoicePlayResponseV3(results: results ?? this.results);
  }

  VoicePlayResponseV3 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return VoicePlayResponseV3(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class StbSearchResponseV1 {
  StbSearchResponseV1({
    this.results,
  });

  factory StbSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$StbSearchResponseV1FromJson(json);

  static const toJsonFactory = _$StbSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$StbSearchResponseV1ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$StbSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StbSearchResponseV1 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $StbSearchResponseV1Extension on StbSearchResponseV1 {
  StbSearchResponseV1 copyWith({List<Object>? results}) {
    return StbSearchResponseV1(results: results ?? this.results);
  }

  StbSearchResponseV1 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return StbSearchResponseV1(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class VODSearchResponseV1 {
  VODSearchResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    required this.contentId,
    required this.titleId,
    required this.isViewedCompletely,
    this.minimumAge,
    required this.bookmark,
    this.isAdult,
    this.isReplay,
    this.eventId,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.availabilityStart,
    this.availabilityEnd,
    this.userInteractedWithSeries,
    this.collapseSeries,
    this.collapseInstance,
    required this.product,
    this.hasMultipleProducts,
    this.series,
  });

  factory VODSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$VODSearchResponseV1FromJson(json);

  static const toJsonFactory = _$VODSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$VODSearchResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'isViewedCompletely', includeIfNull: false)
  final bool isViewedCompletely;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String? availabilityEnd;
  @JsonKey(
      name: 'userInteractedWithSeries',
      includeIfNull: false,
      defaultValue: false)
  final bool? userInteractedWithSeries;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'product', includeIfNull: false)
  final ProductResponseV1 product;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesSearchResponseV1? series;
  static const fromJsonFactory = _$VODSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODSearchResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.isViewedCompletely, isViewedCompletely) ||
                const DeepCollectionEquality()
                    .equals(other.isViewedCompletely, isViewedCompletely)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.userInteractedWithSeries, userInteractedWithSeries) ||
                const DeepCollectionEquality().equals(
                    other.userInteractedWithSeries,
                    userInteractedWithSeries)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.product, product) ||
                const DeepCollectionEquality()
                    .equals(other.product, product)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) ||
                const DeepCollectionEquality()
                    .equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(isViewedCompletely) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(userInteractedWithSeries) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(product) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $VODSearchResponseV1Extension on VODSearchResponseV1 {
  VODSearchResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? contentId,
      String? titleId,
      bool? isViewedCompletely,
      String? minimumAge,
      int? bookmark,
      bool? isAdult,
      bool? isReplay,
      String? eventId,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      String? availabilityStart,
      String? availabilityEnd,
      bool? userInteractedWithSeries,
      bool? collapseSeries,
      bool? collapseInstance,
      ProductResponseV1? product,
      bool? hasMultipleProducts,
      SeriesSearchResponseV1? series}) {
    return VODSearchResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        isViewedCompletely: isViewedCompletely ?? this.isViewedCompletely,
        minimumAge: minimumAge ?? this.minimumAge,
        bookmark: bookmark ?? this.bookmark,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        eventId: eventId ?? this.eventId,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        userInteractedWithSeries:
            userInteractedWithSeries ?? this.userInteractedWithSeries,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        product: product ?? this.product,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        series: series ?? this.series);
  }

  VODSearchResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String>? contentId,
      Wrapped<String>? titleId,
      Wrapped<bool>? isViewedCompletely,
      Wrapped<String?>? minimumAge,
      Wrapped<int>? bookmark,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? isReplay,
      Wrapped<String?>? eventId,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? availabilityStart,
      Wrapped<String?>? availabilityEnd,
      Wrapped<bool?>? userInteractedWithSeries,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<ProductResponseV1>? product,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<SeriesSearchResponseV1?>? series}) {
    return VODSearchResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        isViewedCompletely: (isViewedCompletely != null
            ? isViewedCompletely.value
            : this.isViewedCompletely),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        eventId: (eventId != null ? eventId.value : this.eventId),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        userInteractedWithSeries: (userInteractedWithSeries != null
            ? userInteractedWithSeries.value
            : this.userInteractedWithSeries),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        product: (product != null ? product.value : this.product),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class ProductResponseV1 {
  ProductResponseV1({
    this.availabilityStart,
    this.availabilityEnd,
    this.entitlementState,
    this.entitlementEnd,
    this.rentalPeriod,
    this.currency,
    this.offerPrice,
    this.channelId,
  });

  factory ProductResponseV1.fromJson(Map<String, dynamic> json) =>
      _$ProductResponseV1FromJson(json);

  static const toJsonFactory = _$ProductResponseV1ToJson;
  Map<String, dynamic> toJson() => _$ProductResponseV1ToJson(this);

  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String? availabilityEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'offerPrice', includeIfNull: false, defaultValue: '')
  final String? offerPrice;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  static const fromJsonFactory = _$ProductResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductResponseV1 &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.offerPrice, offerPrice) ||
                const DeepCollectionEquality()
                    .equals(other.offerPrice, offerPrice)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(offerPrice) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $ProductResponseV1Extension on ProductResponseV1 {
  ProductResponseV1 copyWith(
      {String? availabilityStart,
      String? availabilityEnd,
      String? entitlementState,
      String? entitlementEnd,
      String? rentalPeriod,
      String? currency,
      String? offerPrice,
      String? channelId}) {
    return ProductResponseV1(
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        currency: currency ?? this.currency,
        offerPrice: offerPrice ?? this.offerPrice,
        channelId: channelId ?? this.channelId);
  }

  ProductResponseV1 copyWithWrapped(
      {Wrapped<String?>? availabilityStart,
      Wrapped<String?>? availabilityEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? rentalPeriod,
      Wrapped<String?>? currency,
      Wrapped<String?>? offerPrice,
      Wrapped<String?>? channelId}) {
    return ProductResponseV1(
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        currency: (currency != null ? currency.value : this.currency),
        offerPrice: (offerPrice != null ? offerPrice.value : this.offerPrice),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesSearchResponseV1 {
  SeriesSearchResponseV1({
    this.seriesId,
    this.episodeName,
    this.episodeNumber,
    this.numberOfEpisodeTitles,
    this.specialsCount,
    this.seasonCount,
    this.seasonName,
    this.seasonNumber,
    this.seriesName,
    this.parentSeriesId,
    this.seriesType,
  });

  factory SeriesSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$SeriesSearchResponseV1FromJson(json);

  static const toJsonFactory = _$SeriesSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$SeriesSearchResponseV1ToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'numberOfEpisodeTitles', includeIfNull: false)
  final int? numberOfEpisodeTitles;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesType', includeIfNull: false, defaultValue: '')
  final String? seriesType;
  static const fromJsonFactory = _$SeriesSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesSearchResponseV1 &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.episodeName, episodeName) ||
                const DeepCollectionEquality()
                    .equals(other.episodeName, episodeName)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.numberOfEpisodeTitles, numberOfEpisodeTitles) ||
                const DeepCollectionEquality().equals(
                    other.numberOfEpisodeTitles, numberOfEpisodeTitles)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesType, seriesType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesType, seriesType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(numberOfEpisodeTitles) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesType) ^
      runtimeType.hashCode;
}

extension $SeriesSearchResponseV1Extension on SeriesSearchResponseV1 {
  SeriesSearchResponseV1 copyWith(
      {String? seriesId,
      String? episodeName,
      int? episodeNumber,
      int? numberOfEpisodeTitles,
      int? specialsCount,
      int? seasonCount,
      String? seasonName,
      int? seasonNumber,
      String? seriesName,
      String? parentSeriesId,
      String? seriesType}) {
    return SeriesSearchResponseV1(
        seriesId: seriesId ?? this.seriesId,
        episodeName: episodeName ?? this.episodeName,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        numberOfEpisodeTitles:
            numberOfEpisodeTitles ?? this.numberOfEpisodeTitles,
        specialsCount: specialsCount ?? this.specialsCount,
        seasonCount: seasonCount ?? this.seasonCount,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        seriesName: seriesName ?? this.seriesName,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesType: seriesType ?? this.seriesType);
  }

  SeriesSearchResponseV1 copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? episodeName,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? numberOfEpisodeTitles,
      Wrapped<int?>? specialsCount,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesType}) {
    return SeriesSearchResponseV1(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        numberOfEpisodeTitles: (numberOfEpisodeTitles != null
            ? numberOfEpisodeTitles.value
            : this.numberOfEpisodeTitles),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesType: (seriesType != null ? seriesType.value : this.seriesType));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponseV1 {
  LTVSearchResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.isAdult,
    this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.series,
  });

  factory LTVSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseV1FromJson(json);

  static const toJsonFactory = _$LTVSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesSearchResponseV1? series;
  static const fromJsonFactory = _$LTVSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseV1Extension on LTVSearchResponseV1 {
  LTVSearchResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      SeriesSearchResponseV1? series}) {
    return LTVSearchResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        series: series ?? this.series);
  }

  LTVSearchResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<SeriesSearchResponseV1?>? series}) {
    return LTVSearchResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRSearchResponseV1 {
  PVRSearchResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.containsAdult,
    this.isAdult,
    required this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.bookmark,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.recordingState,
    this.localRecordingId,
    this.cpeId,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.series,
  });

  factory PVRSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$PVRSearchResponseV1FromJson(json);

  static const toJsonFactory = _$PVRSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$PVRSearchResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: pVRSearchResponseV1RecordingStateToJson,
    fromJson: pVRSearchResponseV1RecordingStateFromJson,
  )
  final enums.PVRSearchResponseV1RecordingState? recordingState;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesSearchResponseV1? series;
  static const fromJsonFactory = _$PVRSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRSearchResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $PVRSearchResponseV1Extension on PVRSearchResponseV1 {
  PVRSearchResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? containsAdult,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      int? bookmark,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      enums.PVRSearchResponseV1RecordingState? recordingState,
      String? localRecordingId,
      String? cpeId,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      SeriesSearchResponseV1? series}) {
    return PVRSearchResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        bookmark: bookmark ?? this.bookmark,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        recordingState: recordingState ?? this.recordingState,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        series: series ?? this.series);
  }

  PVRSearchResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<enums.PVRSearchResponseV1RecordingState?>? recordingState,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<SeriesSearchResponseV1?>? series}) {
    return PVRSearchResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class ApplicationResponseV1 {
  ApplicationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    required this.appId,
    this.appUrl,
    this.image,
  });

  factory ApplicationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$ApplicationResponseV1FromJson(json);

  static const toJsonFactory = _$ApplicationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$ApplicationResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'appId', includeIfNull: false, defaultValue: '')
  final String appId;
  @JsonKey(name: 'appUrl', includeIfNull: false, defaultValue: '')
  final String? appUrl;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$ApplicationResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ApplicationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.appId, appId) ||
                const DeepCollectionEquality().equals(other.appId, appId)) &&
            (identical(other.appUrl, appUrl) ||
                const DeepCollectionEquality().equals(other.appUrl, appUrl)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(appId) ^
      const DeepCollectionEquality().hash(appUrl) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $ApplicationResponseV1Extension on ApplicationResponseV1 {
  ApplicationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? appId,
      String? appUrl,
      String? image}) {
    return ApplicationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        appId: appId ?? this.appId,
        appUrl: appUrl ?? this.appUrl,
        image: image ?? this.image);
  }

  ApplicationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String>? appId,
      Wrapped<String?>? appUrl,
      Wrapped<String?>? image}) {
    return ApplicationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        appId: (appId != null ? appId.value : this.appId),
        appUrl: (appUrl != null ? appUrl.value : this.appUrl),
        image: (image != null ? image.value : this.image));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponseV1 {
  ChannelResponseV1({
    required this.contentSource,
    this.contentType,
    required this.channelName,
    required this.channelId,
    this.eventId,
    this.name,
    this.minimumAge,
    this.isReplay,
    this.isAdult,
    this.associatedPicture,
    this.associatedPictureType,
    this.startTime,
    this.endTime,
  });

  factory ChannelResponseV1.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseV1FromJson(json);

  static const toJsonFactory = _$ChannelResponseV1ToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String channelName;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool? isReplay;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  static const fromJsonFactory = _$ChannelResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality().equals(other.endTime, endTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      runtimeType.hashCode;
}

extension $ChannelResponseV1Extension on ChannelResponseV1 {
  ChannelResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? channelName,
      String? channelId,
      String? eventId,
      String? name,
      String? minimumAge,
      bool? isReplay,
      bool? isAdult,
      String? associatedPicture,
      String? associatedPictureType,
      String? startTime,
      String? endTime}) {
    return ChannelResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        channelName: channelName ?? this.channelName,
        channelId: channelId ?? this.channelId,
        eventId: eventId ?? this.eventId,
        name: name ?? this.name,
        minimumAge: minimumAge ?? this.minimumAge,
        isReplay: isReplay ?? this.isReplay,
        isAdult: isAdult ?? this.isAdult,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime);
  }

  ChannelResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String>? channelName,
      Wrapped<String>? channelId,
      Wrapped<String?>? eventId,
      Wrapped<String?>? name,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isReplay,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime}) {
    return ChannelResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        name: (name != null ? name.value : this.name),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceResponseV1 {
  NuanceResponseV1({
    required this.nluInterpretationResults,
  });

  factory NuanceResponseV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceResponseV1FromJson(json);

  static const toJsonFactory = _$NuanceResponseV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceResponseV1ToJson(this);

  @JsonKey(name: 'nlu_interpretation_results', includeIfNull: false)
  final NuanceInterpretationResultsV1 nluInterpretationResults;
  static const fromJsonFactory = _$NuanceResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceResponseV1 &&
            (identical(
                    other.nluInterpretationResults, nluInterpretationResults) ||
                const DeepCollectionEquality().equals(
                    other.nluInterpretationResults, nluInterpretationResults)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nluInterpretationResults) ^
      runtimeType.hashCode;
}

extension $NuanceResponseV1Extension on NuanceResponseV1 {
  NuanceResponseV1 copyWith(
      {NuanceInterpretationResultsV1? nluInterpretationResults}) {
    return NuanceResponseV1(
        nluInterpretationResults:
            nluInterpretationResults ?? this.nluInterpretationResults);
  }

  NuanceResponseV1 copyWithWrapped(
      {Wrapped<NuanceInterpretationResultsV1>? nluInterpretationResults}) {
    return NuanceResponseV1(
        nluInterpretationResults: (nluInterpretationResults != null
            ? nluInterpretationResults.value
            : this.nluInterpretationResults));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretationResultsV1 {
  NuanceInterpretationResultsV1({
    required this.payload,
  });

  factory NuanceInterpretationResultsV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationResultsV1FromJson(json);

  static const toJsonFactory = _$NuanceInterpretationResultsV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationResultsV1ToJson(this);

  @JsonKey(name: 'payload', includeIfNull: false)
  final NuancePayloadV1 payload;
  static const fromJsonFactory = _$NuanceInterpretationResultsV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretationResultsV1 &&
            (identical(other.payload, payload) ||
                const DeepCollectionEquality().equals(other.payload, payload)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(payload) ^ runtimeType.hashCode;
}

extension $NuanceInterpretationResultsV1Extension
    on NuanceInterpretationResultsV1 {
  NuanceInterpretationResultsV1 copyWith({NuancePayloadV1? payload}) {
    return NuanceInterpretationResultsV1(payload: payload ?? this.payload);
  }

  NuanceInterpretationResultsV1 copyWithWrapped(
      {Wrapped<NuancePayloadV1>? payload}) {
    return NuanceInterpretationResultsV1(
        payload: (payload != null ? payload.value : this.payload));
  }
}

@JsonSerializable(explicitToJson: true)
class NuancePayloadV1 {
  NuancePayloadV1({
    required this.interpretations,
  });

  factory NuancePayloadV1.fromJson(Map<String, dynamic> json) =>
      _$NuancePayloadV1FromJson(json);

  static const toJsonFactory = _$NuancePayloadV1ToJson;
  Map<String, dynamic> toJson() => _$NuancePayloadV1ToJson(this);

  @JsonKey(
      name: 'interpretations',
      includeIfNull: false,
      defaultValue: <NuanceInterpretationsV1>[])
  final List<NuanceInterpretationsV1> interpretations;
  static const fromJsonFactory = _$NuancePayloadV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuancePayloadV1 &&
            (identical(other.interpretations, interpretations) ||
                const DeepCollectionEquality()
                    .equals(other.interpretations, interpretations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(interpretations) ^
      runtimeType.hashCode;
}

extension $NuancePayloadV1Extension on NuancePayloadV1 {
  NuancePayloadV1 copyWith({List<NuanceInterpretationsV1>? interpretations}) {
    return NuancePayloadV1(
        interpretations: interpretations ?? this.interpretations);
  }

  NuancePayloadV1 copyWithWrapped(
      {Wrapped<List<NuanceInterpretationsV1>>? interpretations}) {
    return NuancePayloadV1(
        interpretations: (interpretations != null
            ? interpretations.value
            : this.interpretations));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretationsV1 {
  NuanceInterpretationsV1({
    required this.concepts,
    required this.action,
    required this.literal,
  });

  factory NuanceInterpretationsV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationsV1FromJson(json);

  static const toJsonFactory = _$NuanceInterpretationsV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationsV1ToJson(this);

  @JsonKey(name: 'concepts', includeIfNull: false)
  final NuanceConceptsV1 concepts;
  @JsonKey(name: 'action', includeIfNull: false)
  final NuanceActionV1 action;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  static const fromJsonFactory = _$NuanceInterpretationsV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretationsV1 &&
            (identical(other.concepts, concepts) ||
                const DeepCollectionEquality()
                    .equals(other.concepts, concepts)) &&
            (identical(other.action, action) ||
                const DeepCollectionEquality().equals(other.action, action)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality().equals(other.literal, literal)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(concepts) ^
      const DeepCollectionEquality().hash(action) ^
      const DeepCollectionEquality().hash(literal) ^
      runtimeType.hashCode;
}

extension $NuanceInterpretationsV1Extension on NuanceInterpretationsV1 {
  NuanceInterpretationsV1 copyWith(
      {NuanceConceptsV1? concepts, NuanceActionV1? action, String? literal}) {
    return NuanceInterpretationsV1(
        concepts: concepts ?? this.concepts,
        action: action ?? this.action,
        literal: literal ?? this.literal);
  }

  NuanceInterpretationsV1 copyWithWrapped(
      {Wrapped<NuanceConceptsV1>? concepts,
      Wrapped<NuanceActionV1>? action,
      Wrapped<String>? literal}) {
    return NuanceInterpretationsV1(
        concepts: (concepts != null ? concepts.value : this.concepts),
        action: (action != null ? action.value : this.action),
        literal: (literal != null ? literal.value : this.literal));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConceptsV1 {
  NuanceConceptsV1({
    this.nuanceTvQuery,
    this.nuanceTvMediatype,
    this.nuanceTvModifier,
    this.nuanceTvYear,
    this.nuanceTvGenre,
    this.nuanceTvProvider,
    this.nuanceTvStation,
    this.lgiTvAgeRating,
    this.nuanceCALENDARX,
    this.lgiTvEasterEggSearch,
  });

  factory NuanceConceptsV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptsV1FromJson(json);

  static const toJsonFactory = _$NuanceConceptsV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptsV1ToJson(this);

  @JsonKey(
      name: 'nuance_tv_query',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvQuery;
  @JsonKey(
      name: 'nuance_tv_mediatype',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvMediatype;
  @JsonKey(
      name: 'nuance_tv_modifier',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvModifier;
  @JsonKey(
      name: 'nuance_tv_year',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvYear;
  @JsonKey(
      name: 'nuance_tv_genre',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvGenre;
  @JsonKey(
      name: 'nuance_tv_provider',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvProvider;
  @JsonKey(
      name: 'nuance_tv_station',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvStation;
  @JsonKey(
      name: 'lgi_tv_ageRating',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? lgiTvAgeRating;
  @JsonKey(
      name: 'nuance_CALENDARX',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceCALENDARX;
  @JsonKey(
      name: 'lgi_tv_easter_egg_search',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? lgiTvEasterEggSearch;
  static const fromJsonFactory = _$NuanceConceptsV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConceptsV1 &&
            (identical(other.nuanceTvQuery, nuanceTvQuery) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvQuery, nuanceTvQuery)) &&
            (identical(other.nuanceTvMediatype, nuanceTvMediatype) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvMediatype, nuanceTvMediatype)) &&
            (identical(other.nuanceTvModifier, nuanceTvModifier) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvModifier, nuanceTvModifier)) &&
            (identical(other.nuanceTvYear, nuanceTvYear) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvYear, nuanceTvYear)) &&
            (identical(other.nuanceTvGenre, nuanceTvGenre) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvGenre, nuanceTvGenre)) &&
            (identical(other.nuanceTvProvider, nuanceTvProvider) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvProvider, nuanceTvProvider)) &&
            (identical(other.nuanceTvStation, nuanceTvStation) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvStation, nuanceTvStation)) &&
            (identical(other.lgiTvAgeRating, lgiTvAgeRating) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvAgeRating, lgiTvAgeRating)) &&
            (identical(other.nuanceCALENDARX, nuanceCALENDARX) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDARX, nuanceCALENDARX)) &&
            (identical(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceTvQuery) ^
      const DeepCollectionEquality().hash(nuanceTvMediatype) ^
      const DeepCollectionEquality().hash(nuanceTvModifier) ^
      const DeepCollectionEquality().hash(nuanceTvYear) ^
      const DeepCollectionEquality().hash(nuanceTvGenre) ^
      const DeepCollectionEquality().hash(nuanceTvProvider) ^
      const DeepCollectionEquality().hash(nuanceTvStation) ^
      const DeepCollectionEquality().hash(lgiTvAgeRating) ^
      const DeepCollectionEquality().hash(nuanceCALENDARX) ^
      const DeepCollectionEquality().hash(lgiTvEasterEggSearch) ^
      runtimeType.hashCode;
}

extension $NuanceConceptsV1Extension on NuanceConceptsV1 {
  NuanceConceptsV1 copyWith(
      {List<NuanceConceptV1>? nuanceTvQuery,
      List<NuanceConceptV1>? nuanceTvMediatype,
      List<NuanceConceptV1>? nuanceTvModifier,
      List<NuanceConceptV1>? nuanceTvYear,
      List<NuanceConceptV1>? nuanceTvGenre,
      List<NuanceConceptV1>? nuanceTvProvider,
      List<NuanceConceptV1>? nuanceTvStation,
      List<NuanceConceptV1>? lgiTvAgeRating,
      List<NuanceConceptV1>? nuanceCALENDARX,
      List<NuanceConceptV1>? lgiTvEasterEggSearch}) {
    return NuanceConceptsV1(
        nuanceTvQuery: nuanceTvQuery ?? this.nuanceTvQuery,
        nuanceTvMediatype: nuanceTvMediatype ?? this.nuanceTvMediatype,
        nuanceTvModifier: nuanceTvModifier ?? this.nuanceTvModifier,
        nuanceTvYear: nuanceTvYear ?? this.nuanceTvYear,
        nuanceTvGenre: nuanceTvGenre ?? this.nuanceTvGenre,
        nuanceTvProvider: nuanceTvProvider ?? this.nuanceTvProvider,
        nuanceTvStation: nuanceTvStation ?? this.nuanceTvStation,
        lgiTvAgeRating: lgiTvAgeRating ?? this.lgiTvAgeRating,
        nuanceCALENDARX: nuanceCALENDARX ?? this.nuanceCALENDARX,
        lgiTvEasterEggSearch:
            lgiTvEasterEggSearch ?? this.lgiTvEasterEggSearch);
  }

  NuanceConceptsV1 copyWithWrapped(
      {Wrapped<List<NuanceConceptV1>?>? nuanceTvQuery,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvMediatype,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvModifier,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvYear,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvGenre,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvProvider,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvStation,
      Wrapped<List<NuanceConceptV1>?>? lgiTvAgeRating,
      Wrapped<List<NuanceConceptV1>?>? nuanceCALENDARX,
      Wrapped<List<NuanceConceptV1>?>? lgiTvEasterEggSearch}) {
    return NuanceConceptsV1(
        nuanceTvQuery:
            (nuanceTvQuery != null ? nuanceTvQuery.value : this.nuanceTvQuery),
        nuanceTvMediatype: (nuanceTvMediatype != null
            ? nuanceTvMediatype.value
            : this.nuanceTvMediatype),
        nuanceTvModifier: (nuanceTvModifier != null
            ? nuanceTvModifier.value
            : this.nuanceTvModifier),
        nuanceTvYear:
            (nuanceTvYear != null ? nuanceTvYear.value : this.nuanceTvYear),
        nuanceTvGenre:
            (nuanceTvGenre != null ? nuanceTvGenre.value : this.nuanceTvGenre),
        nuanceTvProvider: (nuanceTvProvider != null
            ? nuanceTvProvider.value
            : this.nuanceTvProvider),
        nuanceTvStation: (nuanceTvStation != null
            ? nuanceTvStation.value
            : this.nuanceTvStation),
        lgiTvAgeRating: (lgiTvAgeRating != null
            ? lgiTvAgeRating.value
            : this.lgiTvAgeRating),
        nuanceCALENDARX: (nuanceCALENDARX != null
            ? nuanceCALENDARX.value
            : this.nuanceCALENDARX),
        lgiTvEasterEggSearch: (lgiTvEasterEggSearch != null
            ? lgiTvEasterEggSearch.value
            : this.lgiTvEasterEggSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConceptV1 {
  NuanceConceptV1({
    required this.value,
    required this.literal,
    required this.ranges,
  });

  factory NuanceConceptV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptV1FromJson(json);

  static const toJsonFactory = _$NuanceConceptV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptV1ToJson(this);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String value;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  @JsonKey(name: 'ranges', includeIfNull: false, defaultValue: <List<int?>>[])
  final List<List<int?>> ranges;
  static const fromJsonFactory = _$NuanceConceptV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConceptV1 &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality()
                    .equals(other.literal, literal)) &&
            (identical(other.ranges, ranges) ||
                const DeepCollectionEquality().equals(other.ranges, ranges)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(literal) ^
      const DeepCollectionEquality().hash(ranges) ^
      runtimeType.hashCode;
}

extension $NuanceConceptV1Extension on NuanceConceptV1 {
  NuanceConceptV1 copyWith(
      {String? value, String? literal, List<List<int?>>? ranges}) {
    return NuanceConceptV1(
        value: value ?? this.value,
        literal: literal ?? this.literal,
        ranges: ranges ?? this.ranges);
  }

  NuanceConceptV1 copyWithWrapped(
      {Wrapped<String>? value,
      Wrapped<String>? literal,
      Wrapped<List<List<int?>>>? ranges}) {
    return NuanceConceptV1(
        value: (value != null ? value.value : this.value),
        literal: (literal != null ? literal.value : this.literal),
        ranges: (ranges != null ? ranges.value : this.ranges));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceActionV1 {
  NuanceActionV1({
    this.intent,
  });

  factory NuanceActionV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceActionV1FromJson(json);

  static const toJsonFactory = _$NuanceActionV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceActionV1ToJson(this);

  @JsonKey(name: 'intent', includeIfNull: false)
  final NuanceIntentV1? intent;
  static const fromJsonFactory = _$NuanceActionV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceActionV1 &&
            (identical(other.intent, intent) ||
                const DeepCollectionEquality().equals(other.intent, intent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intent) ^ runtimeType.hashCode;
}

extension $NuanceActionV1Extension on NuanceActionV1 {
  NuanceActionV1 copyWith({NuanceIntentV1? intent}) {
    return NuanceActionV1(intent: intent ?? this.intent);
  }

  NuanceActionV1 copyWithWrapped({Wrapped<NuanceIntentV1?>? intent}) {
    return NuanceActionV1(
        intent: (intent != null ? intent.value : this.intent));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceIntentV1 {
  NuanceIntentV1({
    this.value,
    this.confidence,
  });

  factory NuanceIntentV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceIntentV1FromJson(json);

  static const toJsonFactory = _$NuanceIntentV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceIntentV1ToJson(this);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  @JsonKey(name: 'confidence', includeIfNull: false)
  final double? confidence;
  static const fromJsonFactory = _$NuanceIntentV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceIntentV1 &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.confidence, confidence) ||
                const DeepCollectionEquality()
                    .equals(other.confidence, confidence)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(confidence) ^
      runtimeType.hashCode;
}

extension $NuanceIntentV1Extension on NuanceIntentV1 {
  NuanceIntentV1 copyWith({String? value, double? confidence}) {
    return NuanceIntentV1(
        value: value ?? this.value, confidence: confidence ?? this.confidence);
  }

  NuanceIntentV1 copyWithWrapped(
      {Wrapped<String?>? value, Wrapped<double?>? confidence}) {
    return NuanceIntentV1(
        value: (value != null ? value.value : this.value),
        confidence: (confidence != null ? confidence.value : this.confidence));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceSearchResponseV1 {
  VoiceSearchResponseV1({
    this.results,
  });

  factory VoiceSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$VoiceSearchResponseV1FromJson(json);

  static const toJsonFactory = _$VoiceSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$VoiceSearchResponseV1ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$VoiceSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoiceSearchResponseV1 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $VoiceSearchResponseV1Extension on VoiceSearchResponseV1 {
  VoiceSearchResponseV1 copyWith({List<Object>? results}) {
    return VoiceSearchResponseV1(results: results ?? this.results);
  }

  VoiceSearchResponseV1 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return VoiceSearchResponseV1(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class TopSearchResponseV1 {
  TopSearchResponseV1({
    this.results,
  });

  factory TopSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$TopSearchResponseV1FromJson(json);

  static const toJsonFactory = _$TopSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$TopSearchResponseV1ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$TopSearchResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopSearchResponseV1 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $TopSearchResponseV1Extension on TopSearchResponseV1 {
  TopSearchResponseV1 copyWith({List<Object>? results}) {
    return TopSearchResponseV1(results: results ?? this.results);
  }

  TopSearchResponseV1 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return TopSearchResponseV1(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVRecommendationResponseV1 {
  LTVRecommendationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.isAdult,
    required this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.series,
  });

  factory LTVRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$LTVRecommendationResponseV1FromJson(json);

  static const toJsonFactory = _$LTVRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$LTVRecommendationResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponseV1? series;
  static const fromJsonFactory = _$LTVRecommendationResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVRecommendationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $LTVRecommendationResponseV1Extension on LTVRecommendationResponseV1 {
  LTVRecommendationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      SeriesRecommendationResponseV1? series}) {
    return LTVRecommendationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        series: series ?? this.series);
  }

  LTVRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<SeriesRecommendationResponseV1?>? series}) {
    return LTVRecommendationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesRecommendationResponseV1 {
  SeriesRecommendationResponseV1({
    this.seriesId,
    this.episodeName,
    this.episodeNumber,
    this.numberOfEpisodeTitles,
    this.specialsCount,
    this.seasonCount,
    this.seasonName,
    this.seasonNumber,
    this.seriesName,
    this.parentSeriesId,
    this.seriesType,
  });

  factory SeriesRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$SeriesRecommendationResponseV1FromJson(json);

  static const toJsonFactory = _$SeriesRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$SeriesRecommendationResponseV1ToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'numberOfEpisodeTitles', includeIfNull: false)
  final int? numberOfEpisodeTitles;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesType', includeIfNull: false, defaultValue: '')
  final String? seriesType;
  static const fromJsonFactory = _$SeriesRecommendationResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesRecommendationResponseV1 &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.episodeName, episodeName) ||
                const DeepCollectionEquality()
                    .equals(other.episodeName, episodeName)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.numberOfEpisodeTitles, numberOfEpisodeTitles) ||
                const DeepCollectionEquality().equals(
                    other.numberOfEpisodeTitles, numberOfEpisodeTitles)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesType, seriesType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesType, seriesType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(numberOfEpisodeTitles) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesType) ^
      runtimeType.hashCode;
}

extension $SeriesRecommendationResponseV1Extension
    on SeriesRecommendationResponseV1 {
  SeriesRecommendationResponseV1 copyWith(
      {String? seriesId,
      String? episodeName,
      int? episodeNumber,
      int? numberOfEpisodeTitles,
      int? specialsCount,
      int? seasonCount,
      String? seasonName,
      int? seasonNumber,
      String? seriesName,
      String? parentSeriesId,
      String? seriesType}) {
    return SeriesRecommendationResponseV1(
        seriesId: seriesId ?? this.seriesId,
        episodeName: episodeName ?? this.episodeName,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        numberOfEpisodeTitles:
            numberOfEpisodeTitles ?? this.numberOfEpisodeTitles,
        specialsCount: specialsCount ?? this.specialsCount,
        seasonCount: seasonCount ?? this.seasonCount,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        seriesName: seriesName ?? this.seriesName,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesType: seriesType ?? this.seriesType);
  }

  SeriesRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? episodeName,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? numberOfEpisodeTitles,
      Wrapped<int?>? specialsCount,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesType}) {
    return SeriesRecommendationResponseV1(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        numberOfEpisodeTitles: (numberOfEpisodeTitles != null
            ? numberOfEpisodeTitles.value
            : this.numberOfEpisodeTitles),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesType: (seriesType != null ? seriesType.value : this.seriesType));
  }
}

@JsonSerializable(explicitToJson: true)
class VODRecommendationResponseV1 {
  VODRecommendationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    required this.contentId,
    required this.titleId,
    required this.isViewedCompletely,
    this.minimumAge,
    required this.bookmark,
    this.isAdult,
    required this.isReplay,
    this.eventId,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.availabilityStart,
    this.availabilityEnd,
    this.userInteractedWithSeries,
    this.collapseSeries,
    this.collapseInstance,
    required this.product,
    this.hasMultipleProducts,
    this.series,
  });

  factory VODRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$VODRecommendationResponseV1FromJson(json);

  static const toJsonFactory = _$VODRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$VODRecommendationResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'isViewedCompletely', includeIfNull: false)
  final bool isViewedCompletely;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'bookmark', includeIfNull: false, defaultValue: '')
  final String bookmark;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String? availabilityEnd;
  @JsonKey(
      name: 'userInteractedWithSeries',
      includeIfNull: false,
      defaultValue: false)
  final bool? userInteractedWithSeries;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'product', includeIfNull: false)
  final ProductResponseV1 product;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponseV1? series;
  static const fromJsonFactory = _$VODRecommendationResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODRecommendationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.isViewedCompletely, isViewedCompletely) ||
                const DeepCollectionEquality()
                    .equals(other.isViewedCompletely, isViewedCompletely)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.userInteractedWithSeries, userInteractedWithSeries) ||
                const DeepCollectionEquality().equals(
                    other.userInteractedWithSeries,
                    userInteractedWithSeries)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.product, product) ||
                const DeepCollectionEquality()
                    .equals(other.product, product)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) ||
                const DeepCollectionEquality()
                    .equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(isViewedCompletely) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(userInteractedWithSeries) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(product) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $VODRecommendationResponseV1Extension on VODRecommendationResponseV1 {
  VODRecommendationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? contentId,
      String? titleId,
      bool? isViewedCompletely,
      String? minimumAge,
      String? bookmark,
      bool? isAdult,
      bool? isReplay,
      String? eventId,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      String? availabilityStart,
      String? availabilityEnd,
      bool? userInteractedWithSeries,
      bool? collapseSeries,
      bool? collapseInstance,
      ProductResponseV1? product,
      bool? hasMultipleProducts,
      SeriesRecommendationResponseV1? series}) {
    return VODRecommendationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        isViewedCompletely: isViewedCompletely ?? this.isViewedCompletely,
        minimumAge: minimumAge ?? this.minimumAge,
        bookmark: bookmark ?? this.bookmark,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        eventId: eventId ?? this.eventId,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        userInteractedWithSeries:
            userInteractedWithSeries ?? this.userInteractedWithSeries,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        product: product ?? this.product,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        series: series ?? this.series);
  }

  VODRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String>? contentId,
      Wrapped<String>? titleId,
      Wrapped<bool>? isViewedCompletely,
      Wrapped<String?>? minimumAge,
      Wrapped<String>? bookmark,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<String?>? eventId,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? availabilityStart,
      Wrapped<String?>? availabilityEnd,
      Wrapped<bool?>? userInteractedWithSeries,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<ProductResponseV1>? product,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<SeriesRecommendationResponseV1?>? series}) {
    return VODRecommendationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        isViewedCompletely: (isViewedCompletely != null
            ? isViewedCompletely.value
            : this.isViewedCompletely),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        eventId: (eventId != null ? eventId.value : this.eventId),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        userInteractedWithSeries: (userInteractedWithSeries != null
            ? userInteractedWithSeries.value
            : this.userInteractedWithSeries),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        product: (product != null ? product.value : this.product),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRRecommendationResponseV1 {
  PVRRecommendationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.containsAdult,
    this.isAdult,
    required this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.bookmark,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.localRecordingId,
    this.cpeId,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.series,
  });

  factory PVRRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$PVRRecommendationResponseV1FromJson(json);

  static const toJsonFactory = _$PVRRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$PVRRecommendationResponseV1ToJson(this);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponseV1? series;
  static const fromJsonFactory = _$PVRRecommendationResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRRecommendationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $PVRRecommendationResponseV1Extension on PVRRecommendationResponseV1 {
  PVRRecommendationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? containsAdult,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      int? bookmark,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      String? localRecordingId,
      String? cpeId,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      SeriesRecommendationResponseV1? series}) {
    return PVRRecommendationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        bookmark: bookmark ?? this.bookmark,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        series: series ?? this.series);
  }

  PVRRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<SeriesRecommendationResponseV1?>? series}) {
    return PVRRecommendationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisResponseV1 {
  MoreLikeThisResponseV1({
    this.results,
  });

  factory MoreLikeThisResponseV1.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisResponseV1FromJson(json);

  static const toJsonFactory = _$MoreLikeThisResponseV1ToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisResponseV1ToJson(this);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$MoreLikeThisResponseV1FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MoreLikeThisResponseV1 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $MoreLikeThisResponseV1Extension on MoreLikeThisResponseV1 {
  MoreLikeThisResponseV1 copyWith({List<Object>? results}) {
    return MoreLikeThisResponseV1(results: results ?? this.results);
  }

  MoreLikeThisResponseV1 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return MoreLikeThisResponseV1(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceResponse {
  NuanceResponse({
    required this.payload,
  });

  factory NuanceResponse.fromJson(Map<String, dynamic> json) =>
      _$NuanceResponseFromJson(json);

  static const toJsonFactory = _$NuanceResponseToJson;
  Map<String, dynamic> toJson() => _$NuanceResponseToJson(this);

  @JsonKey(name: 'payload', includeIfNull: false)
  final NuancePayload payload;
  static const fromJsonFactory = _$NuanceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceResponse &&
            (identical(other.payload, payload) ||
                const DeepCollectionEquality().equals(other.payload, payload)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(payload) ^ runtimeType.hashCode;
}

extension $NuanceResponseExtension on NuanceResponse {
  NuanceResponse copyWith({NuancePayload? payload}) {
    return NuanceResponse(payload: payload ?? this.payload);
  }

  NuanceResponse copyWithWrapped({Wrapped<NuancePayload>? payload}) {
    return NuanceResponse(
        payload: (payload != null ? payload.value : this.payload));
  }
}

@JsonSerializable(explicitToJson: true)
class NuancePayload {
  NuancePayload({
    required this.interpretations,
  });

  factory NuancePayload.fromJson(Map<String, dynamic> json) =>
      _$NuancePayloadFromJson(json);

  static const toJsonFactory = _$NuancePayloadToJson;
  Map<String, dynamic> toJson() => _$NuancePayloadToJson(this);

  @JsonKey(
      name: 'interpretations',
      includeIfNull: false,
      defaultValue: <NuanceInterpretations>[])
  final List<NuanceInterpretations> interpretations;
  static const fromJsonFactory = _$NuancePayloadFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuancePayload &&
            (identical(other.interpretations, interpretations) ||
                const DeepCollectionEquality()
                    .equals(other.interpretations, interpretations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(interpretations) ^
      runtimeType.hashCode;
}

extension $NuancePayloadExtension on NuancePayload {
  NuancePayload copyWith({List<NuanceInterpretations>? interpretations}) {
    return NuancePayload(
        interpretations: interpretations ?? this.interpretations);
  }

  NuancePayload copyWithWrapped(
      {Wrapped<List<NuanceInterpretations>>? interpretations}) {
    return NuancePayload(
        interpretations: (interpretations != null
            ? interpretations.value
            : this.interpretations));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretations {
  NuanceInterpretations({
    required this.concepts,
    this.action,
    required this.literal,
  });

  factory NuanceInterpretations.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationsFromJson(json);

  static const toJsonFactory = _$NuanceInterpretationsToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationsToJson(this);

  @JsonKey(name: 'concepts', includeIfNull: false)
  final NuanceConcepts concepts;
  @JsonKey(name: 'action', includeIfNull: false)
  final NuanceAction? action;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  static const fromJsonFactory = _$NuanceInterpretationsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretations &&
            (identical(other.concepts, concepts) ||
                const DeepCollectionEquality()
                    .equals(other.concepts, concepts)) &&
            (identical(other.action, action) ||
                const DeepCollectionEquality().equals(other.action, action)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality().equals(other.literal, literal)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(concepts) ^
      const DeepCollectionEquality().hash(action) ^
      const DeepCollectionEquality().hash(literal) ^
      runtimeType.hashCode;
}

extension $NuanceInterpretationsExtension on NuanceInterpretations {
  NuanceInterpretations copyWith(
      {NuanceConcepts? concepts, NuanceAction? action, String? literal}) {
    return NuanceInterpretations(
        concepts: concepts ?? this.concepts,
        action: action ?? this.action,
        literal: literal ?? this.literal);
  }

  NuanceInterpretations copyWithWrapped(
      {Wrapped<NuanceConcepts>? concepts,
      Wrapped<NuanceAction?>? action,
      Wrapped<String>? literal}) {
    return NuanceInterpretations(
        concepts: (concepts != null ? concepts.value : this.concepts),
        action: (action != null ? action.value : this.action),
        literal: (literal != null ? literal.value : this.literal));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConcepts {
  NuanceConcepts({
    this.nuanceTvQuery,
    this.nuanceTvMediatype,
    this.nuanceTvModifier,
    this.nuanceTvYear,
    this.nuanceTvGenre,
    this.nuanceTvProvider,
    this.nuanceTvStation,
    this.lgiTvAgeRating,
    this.nuanceCALENDARX,
    this.lgiTvEasterEggSearch,
  });

  factory NuanceConcepts.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptsFromJson(json);

  static const toJsonFactory = _$NuanceConceptsToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptsToJson(this);

  @JsonKey(
      name: 'nuance_tv_query',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvQuery;
  @JsonKey(
      name: 'nuance_tv_mediatype',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvMediatype;
  @JsonKey(
      name: 'nuance_tv_modifier',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvModifier;
  @JsonKey(
      name: 'nuance_tv_year',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvYear;
  @JsonKey(
      name: 'nuance_tv_genre',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvGenre;
  @JsonKey(
      name: 'nuance_tv_provider',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvProvider;
  @JsonKey(
      name: 'nuance_tv_station',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvStation;
  @JsonKey(
      name: 'lgi_tv_age_rating',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? lgiTvAgeRating;
  @JsonKey(
      name: 'nuance_CALENDARX',
      includeIfNull: false,
      defaultValue: <NuanceCalendarXConcept>[])
  final List<NuanceCalendarXConcept>? nuanceCALENDARX;
  @JsonKey(
      name: 'lgi_tv_easter_egg_search',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? lgiTvEasterEggSearch;
  static const fromJsonFactory = _$NuanceConceptsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConcepts &&
            (identical(other.nuanceTvQuery, nuanceTvQuery) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvQuery, nuanceTvQuery)) &&
            (identical(other.nuanceTvMediatype, nuanceTvMediatype) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvMediatype, nuanceTvMediatype)) &&
            (identical(other.nuanceTvModifier, nuanceTvModifier) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvModifier, nuanceTvModifier)) &&
            (identical(other.nuanceTvYear, nuanceTvYear) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvYear, nuanceTvYear)) &&
            (identical(other.nuanceTvGenre, nuanceTvGenre) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvGenre, nuanceTvGenre)) &&
            (identical(other.nuanceTvProvider, nuanceTvProvider) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvProvider, nuanceTvProvider)) &&
            (identical(other.nuanceTvStation, nuanceTvStation) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvStation, nuanceTvStation)) &&
            (identical(other.lgiTvAgeRating, lgiTvAgeRating) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvAgeRating, lgiTvAgeRating)) &&
            (identical(other.nuanceCALENDARX, nuanceCALENDARX) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDARX, nuanceCALENDARX)) &&
            (identical(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceTvQuery) ^
      const DeepCollectionEquality().hash(nuanceTvMediatype) ^
      const DeepCollectionEquality().hash(nuanceTvModifier) ^
      const DeepCollectionEquality().hash(nuanceTvYear) ^
      const DeepCollectionEquality().hash(nuanceTvGenre) ^
      const DeepCollectionEquality().hash(nuanceTvProvider) ^
      const DeepCollectionEquality().hash(nuanceTvStation) ^
      const DeepCollectionEquality().hash(lgiTvAgeRating) ^
      const DeepCollectionEquality().hash(nuanceCALENDARX) ^
      const DeepCollectionEquality().hash(lgiTvEasterEggSearch) ^
      runtimeType.hashCode;
}

extension $NuanceConceptsExtension on NuanceConcepts {
  NuanceConcepts copyWith(
      {List<NuanceConcept>? nuanceTvQuery,
      List<NuanceConcept>? nuanceTvMediatype,
      List<NuanceConcept>? nuanceTvModifier,
      List<NuanceConcept>? nuanceTvYear,
      List<NuanceConcept>? nuanceTvGenre,
      List<NuanceConcept>? nuanceTvProvider,
      List<NuanceConcept>? nuanceTvStation,
      List<NuanceConcept>? lgiTvAgeRating,
      List<NuanceCalendarXConcept>? nuanceCALENDARX,
      List<NuanceConcept>? lgiTvEasterEggSearch}) {
    return NuanceConcepts(
        nuanceTvQuery: nuanceTvQuery ?? this.nuanceTvQuery,
        nuanceTvMediatype: nuanceTvMediatype ?? this.nuanceTvMediatype,
        nuanceTvModifier: nuanceTvModifier ?? this.nuanceTvModifier,
        nuanceTvYear: nuanceTvYear ?? this.nuanceTvYear,
        nuanceTvGenre: nuanceTvGenre ?? this.nuanceTvGenre,
        nuanceTvProvider: nuanceTvProvider ?? this.nuanceTvProvider,
        nuanceTvStation: nuanceTvStation ?? this.nuanceTvStation,
        lgiTvAgeRating: lgiTvAgeRating ?? this.lgiTvAgeRating,
        nuanceCALENDARX: nuanceCALENDARX ?? this.nuanceCALENDARX,
        lgiTvEasterEggSearch:
            lgiTvEasterEggSearch ?? this.lgiTvEasterEggSearch);
  }

  NuanceConcepts copyWithWrapped(
      {Wrapped<List<NuanceConcept>?>? nuanceTvQuery,
      Wrapped<List<NuanceConcept>?>? nuanceTvMediatype,
      Wrapped<List<NuanceConcept>?>? nuanceTvModifier,
      Wrapped<List<NuanceConcept>?>? nuanceTvYear,
      Wrapped<List<NuanceConcept>?>? nuanceTvGenre,
      Wrapped<List<NuanceConcept>?>? nuanceTvProvider,
      Wrapped<List<NuanceConcept>?>? nuanceTvStation,
      Wrapped<List<NuanceConcept>?>? lgiTvAgeRating,
      Wrapped<List<NuanceCalendarXConcept>?>? nuanceCALENDARX,
      Wrapped<List<NuanceConcept>?>? lgiTvEasterEggSearch}) {
    return NuanceConcepts(
        nuanceTvQuery:
            (nuanceTvQuery != null ? nuanceTvQuery.value : this.nuanceTvQuery),
        nuanceTvMediatype: (nuanceTvMediatype != null
            ? nuanceTvMediatype.value
            : this.nuanceTvMediatype),
        nuanceTvModifier: (nuanceTvModifier != null
            ? nuanceTvModifier.value
            : this.nuanceTvModifier),
        nuanceTvYear:
            (nuanceTvYear != null ? nuanceTvYear.value : this.nuanceTvYear),
        nuanceTvGenre:
            (nuanceTvGenre != null ? nuanceTvGenre.value : this.nuanceTvGenre),
        nuanceTvProvider: (nuanceTvProvider != null
            ? nuanceTvProvider.value
            : this.nuanceTvProvider),
        nuanceTvStation: (nuanceTvStation != null
            ? nuanceTvStation.value
            : this.nuanceTvStation),
        lgiTvAgeRating: (lgiTvAgeRating != null
            ? lgiTvAgeRating.value
            : this.lgiTvAgeRating),
        nuanceCALENDARX: (nuanceCALENDARX != null
            ? nuanceCALENDARX.value
            : this.nuanceCALENDARX),
        lgiTvEasterEggSearch: (lgiTvEasterEggSearch != null
            ? lgiTvEasterEggSearch.value
            : this.lgiTvEasterEggSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConcept {
  NuanceConcept({
    this.value,
    this.literal,
    this.ranges,
  });

  factory NuanceConcept.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptFromJson(json);

  static const toJsonFactory = _$NuanceConceptToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptToJson(this);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String? literal;
  @JsonKey(name: 'ranges', includeIfNull: false, defaultValue: <List<int?>>[])
  final List<List<int?>>? ranges;
  static const fromJsonFactory = _$NuanceConceptFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConcept &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality()
                    .equals(other.literal, literal)) &&
            (identical(other.ranges, ranges) ||
                const DeepCollectionEquality().equals(other.ranges, ranges)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(literal) ^
      const DeepCollectionEquality().hash(ranges) ^
      runtimeType.hashCode;
}

extension $NuanceConceptExtension on NuanceConcept {
  NuanceConcept copyWith(
      {String? value, String? literal, List<List<int?>>? ranges}) {
    return NuanceConcept(
        value: value ?? this.value,
        literal: literal ?? this.literal,
        ranges: ranges ?? this.ranges);
  }

  NuanceConcept copyWithWrapped(
      {Wrapped<String?>? value,
      Wrapped<String?>? literal,
      Wrapped<List<List<int?>>?>? ranges}) {
    return NuanceConcept(
        value: (value != null ? value.value : this.value),
        literal: (literal != null ? literal.value : this.literal),
        ranges: (ranges != null ? ranges.value : this.ranges));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceCalendarXConcept {
  NuanceCalendarXConcept({
    this.value,
    this.literal,
    this.ranges,
  });

  factory NuanceCalendarXConcept.fromJson(Map<String, dynamic> json) =>
      _$NuanceCalendarXConceptFromJson(json);

  static const toJsonFactory = _$NuanceCalendarXConceptToJson;
  Map<String, dynamic> toJson() => _$NuanceCalendarXConceptToJson(this);

  @JsonKey(name: 'value', includeIfNull: false)
  final NuanceCalendarX? value;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String? literal;
  @JsonKey(name: 'ranges', includeIfNull: false, defaultValue: <List<int?>>[])
  final List<List<int?>>? ranges;
  static const fromJsonFactory = _$NuanceCalendarXConceptFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceCalendarXConcept &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality()
                    .equals(other.literal, literal)) &&
            (identical(other.ranges, ranges) ||
                const DeepCollectionEquality().equals(other.ranges, ranges)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(literal) ^
      const DeepCollectionEquality().hash(ranges) ^
      runtimeType.hashCode;
}

extension $NuanceCalendarXConceptExtension on NuanceCalendarXConcept {
  NuanceCalendarXConcept copyWith(
      {NuanceCalendarX? value, String? literal, List<List<int?>>? ranges}) {
    return NuanceCalendarXConcept(
        value: value ?? this.value,
        literal: literal ?? this.literal,
        ranges: ranges ?? this.ranges);
  }

  NuanceCalendarXConcept copyWithWrapped(
      {Wrapped<NuanceCalendarX?>? value,
      Wrapped<String?>? literal,
      Wrapped<List<List<int?>>?>? ranges}) {
    return NuanceCalendarXConcept(
        value: (value != null ? value.value : this.value),
        literal: (literal != null ? literal.value : this.literal),
        ranges: (ranges != null ? ranges.value : this.ranges));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceCalendarX {
  NuanceCalendarX({
    this.nuanceCALENDAR,
    this.nuanceCALENDARRANGE,
  });

  factory NuanceCalendarX.fromJson(Map<String, dynamic> json) =>
      _$NuanceCalendarXFromJson(json);

  static const toJsonFactory = _$NuanceCalendarXToJson;
  Map<String, dynamic> toJson() => _$NuanceCalendarXToJson(this);

  @JsonKey(name: 'nuance_CALENDAR', includeIfNull: false)
  final NuanceCalendar? nuanceCALENDAR;
  @JsonKey(name: 'nuance_CALENDAR_RANGE', includeIfNull: false)
  final NuanceCalendarRange? nuanceCALENDARRANGE;
  static const fromJsonFactory = _$NuanceCalendarXFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceCalendarX &&
            (identical(other.nuanceCALENDAR, nuanceCALENDAR) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDAR, nuanceCALENDAR)) &&
            (identical(other.nuanceCALENDARRANGE, nuanceCALENDARRANGE) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDARRANGE, nuanceCALENDARRANGE)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceCALENDAR) ^
      const DeepCollectionEquality().hash(nuanceCALENDARRANGE) ^
      runtimeType.hashCode;
}

extension $NuanceCalendarXExtension on NuanceCalendarX {
  NuanceCalendarX copyWith(
      {NuanceCalendar? nuanceCALENDAR,
      NuanceCalendarRange? nuanceCALENDARRANGE}) {
    return NuanceCalendarX(
        nuanceCALENDAR: nuanceCALENDAR ?? this.nuanceCALENDAR,
        nuanceCALENDARRANGE: nuanceCALENDARRANGE ?? this.nuanceCALENDARRANGE);
  }

  NuanceCalendarX copyWithWrapped(
      {Wrapped<NuanceCalendar?>? nuanceCALENDAR,
      Wrapped<NuanceCalendarRange?>? nuanceCALENDARRANGE}) {
    return NuanceCalendarX(
        nuanceCALENDAR: (nuanceCALENDAR != null
            ? nuanceCALENDAR.value
            : this.nuanceCALENDAR),
        nuanceCALENDARRANGE: (nuanceCALENDARRANGE != null
            ? nuanceCALENDARRANGE.value
            : this.nuanceCALENDARRANGE));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceCalendar {
  NuanceCalendar({
    this.nuanceDATE,
    this.nuanceTIME,
  });

  factory NuanceCalendar.fromJson(Map<String, dynamic> json) =>
      _$NuanceCalendarFromJson(json);

  static const toJsonFactory = _$NuanceCalendarToJson;
  Map<String, dynamic> toJson() => _$NuanceCalendarToJson(this);

  @JsonKey(name: 'nuance_DATE', includeIfNull: false)
  final NuanceDate? nuanceDATE;
  @JsonKey(name: 'nuance_TIME', includeIfNull: false)
  final NuanceTime? nuanceTIME;
  static const fromJsonFactory = _$NuanceCalendarFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceCalendar &&
            (identical(other.nuanceDATE, nuanceDATE) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceDATE, nuanceDATE)) &&
            (identical(other.nuanceTIME, nuanceTIME) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTIME, nuanceTIME)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceDATE) ^
      const DeepCollectionEquality().hash(nuanceTIME) ^
      runtimeType.hashCode;
}

extension $NuanceCalendarExtension on NuanceCalendar {
  NuanceCalendar copyWith({NuanceDate? nuanceDATE, NuanceTime? nuanceTIME}) {
    return NuanceCalendar(
        nuanceDATE: nuanceDATE ?? this.nuanceDATE,
        nuanceTIME: nuanceTIME ?? this.nuanceTIME);
  }

  NuanceCalendar copyWithWrapped(
      {Wrapped<NuanceDate?>? nuanceDATE, Wrapped<NuanceTime?>? nuanceTIME}) {
    return NuanceCalendar(
        nuanceDATE: (nuanceDATE != null ? nuanceDATE.value : this.nuanceDATE),
        nuanceTIME: (nuanceTIME != null ? nuanceTIME.value : this.nuanceTIME));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceDate {
  NuanceDate({
    this.nuanceDATEABS,
    this.nuanceDATEREL,
  });

  factory NuanceDate.fromJson(Map<String, dynamic> json) =>
      _$NuanceDateFromJson(json);

  static const toJsonFactory = _$NuanceDateToJson;
  Map<String, dynamic> toJson() => _$NuanceDateToJson(this);

  @JsonKey(name: 'nuance_DATE_ABS', includeIfNull: false)
  final NuanceAbsoluteDateTime? nuanceDATEABS;
  @JsonKey(name: 'nuance_DATE_REL', includeIfNull: false)
  final NuanceRelativeDateTime? nuanceDATEREL;
  static const fromJsonFactory = _$NuanceDateFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceDate &&
            (identical(other.nuanceDATEABS, nuanceDATEABS) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceDATEABS, nuanceDATEABS)) &&
            (identical(other.nuanceDATEREL, nuanceDATEREL) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceDATEREL, nuanceDATEREL)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceDATEABS) ^
      const DeepCollectionEquality().hash(nuanceDATEREL) ^
      runtimeType.hashCode;
}

extension $NuanceDateExtension on NuanceDate {
  NuanceDate copyWith(
      {NuanceAbsoluteDateTime? nuanceDATEABS,
      NuanceRelativeDateTime? nuanceDATEREL}) {
    return NuanceDate(
        nuanceDATEABS: nuanceDATEABS ?? this.nuanceDATEABS,
        nuanceDATEREL: nuanceDATEREL ?? this.nuanceDATEREL);
  }

  NuanceDate copyWithWrapped(
      {Wrapped<NuanceAbsoluteDateTime?>? nuanceDATEABS,
      Wrapped<NuanceRelativeDateTime?>? nuanceDATEREL}) {
    return NuanceDate(
        nuanceDATEABS:
            (nuanceDATEABS != null ? nuanceDATEABS.value : this.nuanceDATEABS),
        nuanceDATEREL:
            (nuanceDATEREL != null ? nuanceDATEREL.value : this.nuanceDATEREL));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceAbsoluteDateTime {
  NuanceAbsoluteDateTime({
    this.nuanceAMPM,
    this.nuanceHOUR,
    this.nuanceMINUTE,
    this.nuanceDAY,
    this.nuanceMONTH,
    this.nuanceMODIFIER,
  });

  factory NuanceAbsoluteDateTime.fromJson(Map<String, dynamic> json) =>
      _$NuanceAbsoluteDateTimeFromJson(json);

  static const toJsonFactory = _$NuanceAbsoluteDateTimeToJson;
  Map<String, dynamic> toJson() => _$NuanceAbsoluteDateTimeToJson(this);

  @JsonKey(name: 'nuance_AMPM', includeIfNull: false, defaultValue: '')
  final String? nuanceAMPM;
  @JsonKey(name: 'nuance_HOUR', includeIfNull: false)
  final int? nuanceHOUR;
  @JsonKey(name: 'nuance_MINUTE', includeIfNull: false)
  final int? nuanceMINUTE;
  @JsonKey(name: 'nuance_DAY', includeIfNull: false)
  final int? nuanceDAY;
  @JsonKey(name: 'nuance_MONTH', includeIfNull: false)
  final int? nuanceMONTH;
  @JsonKey(name: 'nuance_MODIFIER', includeIfNull: false, defaultValue: '')
  final String? nuanceMODIFIER;
  static const fromJsonFactory = _$NuanceAbsoluteDateTimeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceAbsoluteDateTime &&
            (identical(other.nuanceAMPM, nuanceAMPM) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceAMPM, nuanceAMPM)) &&
            (identical(other.nuanceHOUR, nuanceHOUR) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceHOUR, nuanceHOUR)) &&
            (identical(other.nuanceMINUTE, nuanceMINUTE) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceMINUTE, nuanceMINUTE)) &&
            (identical(other.nuanceDAY, nuanceDAY) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceDAY, nuanceDAY)) &&
            (identical(other.nuanceMONTH, nuanceMONTH) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceMONTH, nuanceMONTH)) &&
            (identical(other.nuanceMODIFIER, nuanceMODIFIER) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceMODIFIER, nuanceMODIFIER)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceAMPM) ^
      const DeepCollectionEquality().hash(nuanceHOUR) ^
      const DeepCollectionEquality().hash(nuanceMINUTE) ^
      const DeepCollectionEquality().hash(nuanceDAY) ^
      const DeepCollectionEquality().hash(nuanceMONTH) ^
      const DeepCollectionEquality().hash(nuanceMODIFIER) ^
      runtimeType.hashCode;
}

extension $NuanceAbsoluteDateTimeExtension on NuanceAbsoluteDateTime {
  NuanceAbsoluteDateTime copyWith(
      {String? nuanceAMPM,
      int? nuanceHOUR,
      int? nuanceMINUTE,
      int? nuanceDAY,
      int? nuanceMONTH,
      String? nuanceMODIFIER}) {
    return NuanceAbsoluteDateTime(
        nuanceAMPM: nuanceAMPM ?? this.nuanceAMPM,
        nuanceHOUR: nuanceHOUR ?? this.nuanceHOUR,
        nuanceMINUTE: nuanceMINUTE ?? this.nuanceMINUTE,
        nuanceDAY: nuanceDAY ?? this.nuanceDAY,
        nuanceMONTH: nuanceMONTH ?? this.nuanceMONTH,
        nuanceMODIFIER: nuanceMODIFIER ?? this.nuanceMODIFIER);
  }

  NuanceAbsoluteDateTime copyWithWrapped(
      {Wrapped<String?>? nuanceAMPM,
      Wrapped<int?>? nuanceHOUR,
      Wrapped<int?>? nuanceMINUTE,
      Wrapped<int?>? nuanceDAY,
      Wrapped<int?>? nuanceMONTH,
      Wrapped<String?>? nuanceMODIFIER}) {
    return NuanceAbsoluteDateTime(
        nuanceAMPM: (nuanceAMPM != null ? nuanceAMPM.value : this.nuanceAMPM),
        nuanceHOUR: (nuanceHOUR != null ? nuanceHOUR.value : this.nuanceHOUR),
        nuanceMINUTE:
            (nuanceMINUTE != null ? nuanceMINUTE.value : this.nuanceMINUTE),
        nuanceDAY: (nuanceDAY != null ? nuanceDAY.value : this.nuanceDAY),
        nuanceMONTH:
            (nuanceMONTH != null ? nuanceMONTH.value : this.nuanceMONTH),
        nuanceMODIFIER: (nuanceMODIFIER != null
            ? nuanceMODIFIER.value
            : this.nuanceMODIFIER));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceRelativeDateTime {
  NuanceRelativeDateTime({
    this.nuanceINCREMENT,
    this.nuanceREFERENCE,
    this.nuanceSTEP,
    this.nuanceDAYOFWEEK,
  });

  factory NuanceRelativeDateTime.fromJson(Map<String, dynamic> json) =>
      _$NuanceRelativeDateTimeFromJson(json);

  static const toJsonFactory = _$NuanceRelativeDateTimeToJson;
  Map<String, dynamic> toJson() => _$NuanceRelativeDateTimeToJson(this);

  @JsonKey(name: 'nuance_INCREMENT', includeIfNull: false)
  final int? nuanceINCREMENT;
  @JsonKey(name: 'nuance_REFERENCE', includeIfNull: false)
  final NuanceDateTimeReference? nuanceREFERENCE;
  @JsonKey(
    name: 'nuance_STEP',
    includeIfNull: false,
    toJson: nuanceRelativeDateTimeNuanceSTEPToJson,
    fromJson: nuanceRelativeDateTimeNuanceSTEPFromJson,
  )
  final enums.NuanceRelativeDateTimeNuanceSTEP? nuanceSTEP;
  @JsonKey(name: 'nuance_DAY_OF_WEEK', includeIfNull: false)
  final int? nuanceDAYOFWEEK;
  static const fromJsonFactory = _$NuanceRelativeDateTimeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceRelativeDateTime &&
            (identical(other.nuanceINCREMENT, nuanceINCREMENT) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceINCREMENT, nuanceINCREMENT)) &&
            (identical(other.nuanceREFERENCE, nuanceREFERENCE) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceREFERENCE, nuanceREFERENCE)) &&
            (identical(other.nuanceSTEP, nuanceSTEP) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceSTEP, nuanceSTEP)) &&
            (identical(other.nuanceDAYOFWEEK, nuanceDAYOFWEEK) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceDAYOFWEEK, nuanceDAYOFWEEK)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceINCREMENT) ^
      const DeepCollectionEquality().hash(nuanceREFERENCE) ^
      const DeepCollectionEquality().hash(nuanceSTEP) ^
      const DeepCollectionEquality().hash(nuanceDAYOFWEEK) ^
      runtimeType.hashCode;
}

extension $NuanceRelativeDateTimeExtension on NuanceRelativeDateTime {
  NuanceRelativeDateTime copyWith(
      {int? nuanceINCREMENT,
      NuanceDateTimeReference? nuanceREFERENCE,
      enums.NuanceRelativeDateTimeNuanceSTEP? nuanceSTEP,
      int? nuanceDAYOFWEEK}) {
    return NuanceRelativeDateTime(
        nuanceINCREMENT: nuanceINCREMENT ?? this.nuanceINCREMENT,
        nuanceREFERENCE: nuanceREFERENCE ?? this.nuanceREFERENCE,
        nuanceSTEP: nuanceSTEP ?? this.nuanceSTEP,
        nuanceDAYOFWEEK: nuanceDAYOFWEEK ?? this.nuanceDAYOFWEEK);
  }

  NuanceRelativeDateTime copyWithWrapped(
      {Wrapped<int?>? nuanceINCREMENT,
      Wrapped<NuanceDateTimeReference?>? nuanceREFERENCE,
      Wrapped<enums.NuanceRelativeDateTimeNuanceSTEP?>? nuanceSTEP,
      Wrapped<int?>? nuanceDAYOFWEEK}) {
    return NuanceRelativeDateTime(
        nuanceINCREMENT: (nuanceINCREMENT != null
            ? nuanceINCREMENT.value
            : this.nuanceINCREMENT),
        nuanceREFERENCE: (nuanceREFERENCE != null
            ? nuanceREFERENCE.value
            : this.nuanceREFERENCE),
        nuanceSTEP: (nuanceSTEP != null ? nuanceSTEP.value : this.nuanceSTEP),
        nuanceDAYOFWEEK: (nuanceDAYOFWEEK != null
            ? nuanceDAYOFWEEK.value
            : this.nuanceDAYOFWEEK));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceDateTimeReference {
  NuanceDateTimeReference({
    this.nuanceDATE,
  });

  factory NuanceDateTimeReference.fromJson(Map<String, dynamic> json) =>
      _$NuanceDateTimeReferenceFromJson(json);

  static const toJsonFactory = _$NuanceDateTimeReferenceToJson;
  Map<String, dynamic> toJson() => _$NuanceDateTimeReferenceToJson(this);

  @JsonKey(name: 'nuance_DATE', includeIfNull: false)
  final NuanceDate? nuanceDATE;
  static const fromJsonFactory = _$NuanceDateTimeReferenceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceDateTimeReference &&
            (identical(other.nuanceDATE, nuanceDATE) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceDATE, nuanceDATE)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceDATE) ^ runtimeType.hashCode;
}

extension $NuanceDateTimeReferenceExtension on NuanceDateTimeReference {
  NuanceDateTimeReference copyWith({NuanceDate? nuanceDATE}) {
    return NuanceDateTimeReference(nuanceDATE: nuanceDATE ?? this.nuanceDATE);
  }

  NuanceDateTimeReference copyWithWrapped({Wrapped<NuanceDate?>? nuanceDATE}) {
    return NuanceDateTimeReference(
        nuanceDATE: (nuanceDATE != null ? nuanceDATE.value : this.nuanceDATE));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceTime {
  NuanceTime({
    this.nuanceTIMEABS,
    this.nuanceTIMEREL,
  });

  factory NuanceTime.fromJson(Map<String, dynamic> json) =>
      _$NuanceTimeFromJson(json);

  static const toJsonFactory = _$NuanceTimeToJson;
  Map<String, dynamic> toJson() => _$NuanceTimeToJson(this);

  @JsonKey(name: 'nuance_TIME_ABS', includeIfNull: false)
  final NuanceAbsoluteDateTime? nuanceTIMEABS;
  @JsonKey(name: 'nuance_TIME_REL', includeIfNull: false)
  final NuanceRelativeDateTime? nuanceTIMEREL;
  static const fromJsonFactory = _$NuanceTimeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceTime &&
            (identical(other.nuanceTIMEABS, nuanceTIMEABS) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTIMEABS, nuanceTIMEABS)) &&
            (identical(other.nuanceTIMEREL, nuanceTIMEREL) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTIMEREL, nuanceTIMEREL)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceTIMEABS) ^
      const DeepCollectionEquality().hash(nuanceTIMEREL) ^
      runtimeType.hashCode;
}

extension $NuanceTimeExtension on NuanceTime {
  NuanceTime copyWith(
      {NuanceAbsoluteDateTime? nuanceTIMEABS,
      NuanceRelativeDateTime? nuanceTIMEREL}) {
    return NuanceTime(
        nuanceTIMEABS: nuanceTIMEABS ?? this.nuanceTIMEABS,
        nuanceTIMEREL: nuanceTIMEREL ?? this.nuanceTIMEREL);
  }

  NuanceTime copyWithWrapped(
      {Wrapped<NuanceAbsoluteDateTime?>? nuanceTIMEABS,
      Wrapped<NuanceRelativeDateTime?>? nuanceTIMEREL}) {
    return NuanceTime(
        nuanceTIMEABS:
            (nuanceTIMEABS != null ? nuanceTIMEABS.value : this.nuanceTIMEABS),
        nuanceTIMEREL:
            (nuanceTIMEREL != null ? nuanceTIMEREL.value : this.nuanceTIMEREL));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceCalendarRange {
  NuanceCalendarRange({
    this.nuanceCALENDARRANGESTART,
    this.nuanceCALENDARRANGEEND,
  });

  factory NuanceCalendarRange.fromJson(Map<String, dynamic> json) =>
      _$NuanceCalendarRangeFromJson(json);

  static const toJsonFactory = _$NuanceCalendarRangeToJson;
  Map<String, dynamic> toJson() => _$NuanceCalendarRangeToJson(this);

  @JsonKey(name: 'nuance_CALENDAR_RANGE_START', includeIfNull: false)
  final NuanceCalendar? nuanceCALENDARRANGESTART;
  @JsonKey(name: 'nuance_CALENDAR_RANGE_END', includeIfNull: false)
  final NuanceCalendar? nuanceCALENDARRANGEEND;
  static const fromJsonFactory = _$NuanceCalendarRangeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceCalendarRange &&
            (identical(
                    other.nuanceCALENDARRANGESTART, nuanceCALENDARRANGESTART) ||
                const DeepCollectionEquality().equals(
                    other.nuanceCALENDARRANGESTART,
                    nuanceCALENDARRANGESTART)) &&
            (identical(other.nuanceCALENDARRANGEEND, nuanceCALENDARRANGEEND) ||
                const DeepCollectionEquality().equals(
                    other.nuanceCALENDARRANGEEND, nuanceCALENDARRANGEEND)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceCALENDARRANGESTART) ^
      const DeepCollectionEquality().hash(nuanceCALENDARRANGEEND) ^
      runtimeType.hashCode;
}

extension $NuanceCalendarRangeExtension on NuanceCalendarRange {
  NuanceCalendarRange copyWith(
      {NuanceCalendar? nuanceCALENDARRANGESTART,
      NuanceCalendar? nuanceCALENDARRANGEEND}) {
    return NuanceCalendarRange(
        nuanceCALENDARRANGESTART:
            nuanceCALENDARRANGESTART ?? this.nuanceCALENDARRANGESTART,
        nuanceCALENDARRANGEEND:
            nuanceCALENDARRANGEEND ?? this.nuanceCALENDARRANGEEND);
  }

  NuanceCalendarRange copyWithWrapped(
      {Wrapped<NuanceCalendar?>? nuanceCALENDARRANGESTART,
      Wrapped<NuanceCalendar?>? nuanceCALENDARRANGEEND}) {
    return NuanceCalendarRange(
        nuanceCALENDARRANGESTART: (nuanceCALENDARRANGESTART != null
            ? nuanceCALENDARRANGESTART.value
            : this.nuanceCALENDARRANGESTART),
        nuanceCALENDARRANGEEND: (nuanceCALENDARRANGEEND != null
            ? nuanceCALENDARRANGEEND.value
            : this.nuanceCALENDARRANGEEND));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceAction {
  NuanceAction({
    this.intent,
  });

  factory NuanceAction.fromJson(Map<String, dynamic> json) =>
      _$NuanceActionFromJson(json);

  static const toJsonFactory = _$NuanceActionToJson;
  Map<String, dynamic> toJson() => _$NuanceActionToJson(this);

  @JsonKey(name: 'intent', includeIfNull: false)
  final NuanceIntent? intent;
  static const fromJsonFactory = _$NuanceActionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceAction &&
            (identical(other.intent, intent) ||
                const DeepCollectionEquality().equals(other.intent, intent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intent) ^ runtimeType.hashCode;
}

extension $NuanceActionExtension on NuanceAction {
  NuanceAction copyWith({NuanceIntent? intent}) {
    return NuanceAction(intent: intent ?? this.intent);
  }

  NuanceAction copyWithWrapped({Wrapped<NuanceIntent?>? intent}) {
    return NuanceAction(intent: (intent != null ? intent.value : this.intent));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceIntent {
  NuanceIntent({
    this.value,
    this.confidence,
  });

  factory NuanceIntent.fromJson(Map<String, dynamic> json) =>
      _$NuanceIntentFromJson(json);

  static const toJsonFactory = _$NuanceIntentToJson;
  Map<String, dynamic> toJson() => _$NuanceIntentToJson(this);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  @JsonKey(name: 'confidence', includeIfNull: false)
  final double? confidence;
  static const fromJsonFactory = _$NuanceIntentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceIntent &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.confidence, confidence) ||
                const DeepCollectionEquality()
                    .equals(other.confidence, confidence)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(confidence) ^
      runtimeType.hashCode;
}

extension $NuanceIntentExtension on NuanceIntent {
  NuanceIntent copyWith({String? value, double? confidence}) {
    return NuanceIntent(
        value: value ?? this.value, confidence: confidence ?? this.confidence);
  }

  NuanceIntent copyWithWrapped(
      {Wrapped<String?>? value, Wrapped<double?>? confidence}) {
    return NuanceIntent(
        value: (value != null ? value.value : this.value),
        confidence: (confidence != null ? confidence.value : this.confidence));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceResponseVoice {
  NuanceResponseVoice({
    required this.payload,
  });

  factory NuanceResponseVoice.fromJson(Map<String, dynamic> json) =>
      _$NuanceResponseVoiceFromJson(json);

  static const toJsonFactory = _$NuanceResponseVoiceToJson;
  Map<String, dynamic> toJson() => _$NuanceResponseVoiceToJson(this);

  @JsonKey(name: 'payload', includeIfNull: false)
  final NuancePayloadVoice payload;
  static const fromJsonFactory = _$NuanceResponseVoiceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceResponseVoice &&
            (identical(other.payload, payload) ||
                const DeepCollectionEquality().equals(other.payload, payload)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(payload) ^ runtimeType.hashCode;
}

extension $NuanceResponseVoiceExtension on NuanceResponseVoice {
  NuanceResponseVoice copyWith({NuancePayloadVoice? payload}) {
    return NuanceResponseVoice(payload: payload ?? this.payload);
  }

  NuanceResponseVoice copyWithWrapped({Wrapped<NuancePayloadVoice>? payload}) {
    return NuanceResponseVoice(
        payload: (payload != null ? payload.value : this.payload));
  }
}

@JsonSerializable(explicitToJson: true)
class NuancePayloadVoice {
  NuancePayloadVoice({
    required this.interpretations,
  });

  factory NuancePayloadVoice.fromJson(Map<String, dynamic> json) =>
      _$NuancePayloadVoiceFromJson(json);

  static const toJsonFactory = _$NuancePayloadVoiceToJson;
  Map<String, dynamic> toJson() => _$NuancePayloadVoiceToJson(this);

  @JsonKey(
      name: 'interpretations',
      includeIfNull: false,
      defaultValue: <NuanceInterpretationsVoice>[])
  final List<NuanceInterpretationsVoice> interpretations;
  static const fromJsonFactory = _$NuancePayloadVoiceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuancePayloadVoice &&
            (identical(other.interpretations, interpretations) ||
                const DeepCollectionEquality()
                    .equals(other.interpretations, interpretations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(interpretations) ^
      runtimeType.hashCode;
}

extension $NuancePayloadVoiceExtension on NuancePayloadVoice {
  NuancePayloadVoice copyWith(
      {List<NuanceInterpretationsVoice>? interpretations}) {
    return NuancePayloadVoice(
        interpretations: interpretations ?? this.interpretations);
  }

  NuancePayloadVoice copyWithWrapped(
      {Wrapped<List<NuanceInterpretationsVoice>>? interpretations}) {
    return NuancePayloadVoice(
        interpretations: (interpretations != null
            ? interpretations.value
            : this.interpretations));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretationsVoice {
  NuanceInterpretationsVoice({
    required this.concepts,
    this.action,
    required this.literal,
  });

  factory NuanceInterpretationsVoice.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationsVoiceFromJson(json);

  static const toJsonFactory = _$NuanceInterpretationsVoiceToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationsVoiceToJson(this);

  @JsonKey(name: 'concepts', includeIfNull: false)
  final NuanceConceptsVoice concepts;
  @JsonKey(name: 'action', includeIfNull: false)
  final NuanceAction? action;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  static const fromJsonFactory = _$NuanceInterpretationsVoiceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretationsVoice &&
            (identical(other.concepts, concepts) ||
                const DeepCollectionEquality()
                    .equals(other.concepts, concepts)) &&
            (identical(other.action, action) ||
                const DeepCollectionEquality().equals(other.action, action)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality().equals(other.literal, literal)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(concepts) ^
      const DeepCollectionEquality().hash(action) ^
      const DeepCollectionEquality().hash(literal) ^
      runtimeType.hashCode;
}

extension $NuanceInterpretationsVoiceExtension on NuanceInterpretationsVoice {
  NuanceInterpretationsVoice copyWith(
      {NuanceConceptsVoice? concepts, NuanceAction? action, String? literal}) {
    return NuanceInterpretationsVoice(
        concepts: concepts ?? this.concepts,
        action: action ?? this.action,
        literal: literal ?? this.literal);
  }

  NuanceInterpretationsVoice copyWithWrapped(
      {Wrapped<NuanceConceptsVoice>? concepts,
      Wrapped<NuanceAction?>? action,
      Wrapped<String>? literal}) {
    return NuanceInterpretationsVoice(
        concepts: (concepts != null ? concepts.value : this.concepts),
        action: (action != null ? action.value : this.action),
        literal: (literal != null ? literal.value : this.literal));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConceptsVoice {
  NuanceConceptsVoice({
    this.lgiTvEasterEggSearch,
    this.nuanceCALENDARX,
    this.nuanceTvGenre,
    this.nuanceTvQuery,
    this.nuanceTvStation,
  });

  factory NuanceConceptsVoice.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptsVoiceFromJson(json);

  static const toJsonFactory = _$NuanceConceptsVoiceToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptsVoiceToJson(this);

  @JsonKey(
      name: 'lgi_tv_easter_egg_search',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? lgiTvEasterEggSearch;
  @JsonKey(
      name: 'nuance_CALENDARX',
      includeIfNull: false,
      defaultValue: <NuanceCalendarXConcept>[])
  final List<NuanceCalendarXConcept>? nuanceCALENDARX;
  @JsonKey(
      name: 'nuance_tv_genre',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvGenre;
  @JsonKey(
      name: 'nuance_tv_query',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvQuery;
  @JsonKey(
      name: 'nuance_tv_station',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvStation;
  static const fromJsonFactory = _$NuanceConceptsVoiceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConceptsVoice &&
            (identical(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch) ||
                const DeepCollectionEquality().equals(
                    other.lgiTvEasterEggSearch, lgiTvEasterEggSearch)) &&
            (identical(other.nuanceCALENDARX, nuanceCALENDARX) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDARX, nuanceCALENDARX)) &&
            (identical(other.nuanceTvGenre, nuanceTvGenre) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvGenre, nuanceTvGenre)) &&
            (identical(other.nuanceTvQuery, nuanceTvQuery) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvQuery, nuanceTvQuery)) &&
            (identical(other.nuanceTvStation, nuanceTvStation) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvStation, nuanceTvStation)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lgiTvEasterEggSearch) ^
      const DeepCollectionEquality().hash(nuanceCALENDARX) ^
      const DeepCollectionEquality().hash(nuanceTvGenre) ^
      const DeepCollectionEquality().hash(nuanceTvQuery) ^
      const DeepCollectionEquality().hash(nuanceTvStation) ^
      runtimeType.hashCode;
}

extension $NuanceConceptsVoiceExtension on NuanceConceptsVoice {
  NuanceConceptsVoice copyWith(
      {List<NuanceConcept>? lgiTvEasterEggSearch,
      List<NuanceCalendarXConcept>? nuanceCALENDARX,
      List<NuanceConcept>? nuanceTvGenre,
      List<NuanceConcept>? nuanceTvQuery,
      List<NuanceConcept>? nuanceTvStation}) {
    return NuanceConceptsVoice(
        lgiTvEasterEggSearch: lgiTvEasterEggSearch ?? this.lgiTvEasterEggSearch,
        nuanceCALENDARX: nuanceCALENDARX ?? this.nuanceCALENDARX,
        nuanceTvGenre: nuanceTvGenre ?? this.nuanceTvGenre,
        nuanceTvQuery: nuanceTvQuery ?? this.nuanceTvQuery,
        nuanceTvStation: nuanceTvStation ?? this.nuanceTvStation);
  }

  NuanceConceptsVoice copyWithWrapped(
      {Wrapped<List<NuanceConcept>?>? lgiTvEasterEggSearch,
      Wrapped<List<NuanceCalendarXConcept>?>? nuanceCALENDARX,
      Wrapped<List<NuanceConcept>?>? nuanceTvGenre,
      Wrapped<List<NuanceConcept>?>? nuanceTvQuery,
      Wrapped<List<NuanceConcept>?>? nuanceTvStation}) {
    return NuanceConceptsVoice(
        lgiTvEasterEggSearch: (lgiTvEasterEggSearch != null
            ? lgiTvEasterEggSearch.value
            : this.lgiTvEasterEggSearch),
        nuanceCALENDARX: (nuanceCALENDARX != null
            ? nuanceCALENDARX.value
            : this.nuanceCALENDARX),
        nuanceTvGenre:
            (nuanceTvGenre != null ? nuanceTvGenre.value : this.nuanceTvGenre),
        nuanceTvQuery:
            (nuanceTvQuery != null ? nuanceTvQuery.value : this.nuanceTvQuery),
        nuanceTvStation: (nuanceTvStation != null
            ? nuanceTvStation.value
            : this.nuanceTvStation));
  }
}

@JsonSerializable(explicitToJson: true)
class RecentSeries {
  RecentSeries({
    this.seriesId,
    this.seriesName,
  });

  factory RecentSeries.fromJson(Map<String, dynamic> json) =>
      _$RecentSeriesFromJson(json);

  static const toJsonFactory = _$RecentSeriesToJson;
  Map<String, dynamic> toJson() => _$RecentSeriesToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  static const fromJsonFactory = _$RecentSeriesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecentSeries &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      runtimeType.hashCode;
}

extension $RecentSeriesExtension on RecentSeries {
  RecentSeries copyWith({String? seriesId, String? seriesName}) {
    return RecentSeries(
        seriesId: seriesId ?? this.seriesId,
        seriesName: seriesName ?? this.seriesName);
  }

  RecentSeries copyWithWrapped(
      {Wrapped<String?>? seriesId, Wrapped<String?>? seriesName}) {
    return RecentSeries(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName));
  }
}

@JsonSerializable(explicitToJson: true)
class LearnAction$RequestBody {
  LearnAction$RequestBody({
    this.profileId,
    this.sharedProfile,
    required this.clientType,
    required this.contentSourceId,
    this.resourceId,
    this.actionId,
    this.actionTime,
    this.subgenre,
    this.features,
  });

  factory LearnAction$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$LearnAction$RequestBodyFromJson(json);

  static const toJsonFactory = _$LearnAction$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$LearnAction$RequestBodyToJson(this);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'sharedProfile', includeIfNull: false)
  final bool? sharedProfile;
  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(name: 'contentSourceId', includeIfNull: false)
  final int contentSourceId;
  @JsonKey(name: 'resourceId', includeIfNull: false, defaultValue: '')
  final String? resourceId;
  @JsonKey(name: 'actionId', includeIfNull: false)
  final int? actionId;
  @JsonKey(name: 'actionTime', includeIfNull: false)
  final int? actionTime;
  @JsonKey(name: 'subgenre', includeIfNull: false, defaultValue: <String>[])
  final List<String>? subgenre;
  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$LearnAction$RequestBodyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LearnAction$RequestBody &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.sharedProfile, sharedProfile) ||
                const DeepCollectionEquality()
                    .equals(other.sharedProfile, sharedProfile)) &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(other.contentSourceId, contentSourceId) ||
                const DeepCollectionEquality()
                    .equals(other.contentSourceId, contentSourceId)) &&
            (identical(other.resourceId, resourceId) ||
                const DeepCollectionEquality()
                    .equals(other.resourceId, resourceId)) &&
            (identical(other.actionId, actionId) ||
                const DeepCollectionEquality()
                    .equals(other.actionId, actionId)) &&
            (identical(other.actionTime, actionTime) ||
                const DeepCollectionEquality()
                    .equals(other.actionTime, actionTime)) &&
            (identical(other.subgenre, subgenre) ||
                const DeepCollectionEquality()
                    .equals(other.subgenre, subgenre)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(sharedProfile) ^
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(contentSourceId) ^
      const DeepCollectionEquality().hash(resourceId) ^
      const DeepCollectionEquality().hash(actionId) ^
      const DeepCollectionEquality().hash(actionTime) ^
      const DeepCollectionEquality().hash(subgenre) ^
      const DeepCollectionEquality().hash(features) ^
      runtimeType.hashCode;
}

extension $LearnAction$RequestBodyExtension on LearnAction$RequestBody {
  LearnAction$RequestBody copyWith(
      {String? profileId,
      bool? sharedProfile,
      String? clientType,
      int? contentSourceId,
      String? resourceId,
      int? actionId,
      int? actionTime,
      List<String>? subgenre,
      List<String>? features}) {
    return LearnAction$RequestBody(
        profileId: profileId ?? this.profileId,
        sharedProfile: sharedProfile ?? this.sharedProfile,
        clientType: clientType ?? this.clientType,
        contentSourceId: contentSourceId ?? this.contentSourceId,
        resourceId: resourceId ?? this.resourceId,
        actionId: actionId ?? this.actionId,
        actionTime: actionTime ?? this.actionTime,
        subgenre: subgenre ?? this.subgenre,
        features: features ?? this.features);
  }

  LearnAction$RequestBody copyWithWrapped(
      {Wrapped<String?>? profileId,
      Wrapped<bool?>? sharedProfile,
      Wrapped<String>? clientType,
      Wrapped<int>? contentSourceId,
      Wrapped<String?>? resourceId,
      Wrapped<int?>? actionId,
      Wrapped<int?>? actionTime,
      Wrapped<List<String>?>? subgenre,
      Wrapped<List<String>?>? features}) {
    return LearnAction$RequestBody(
        profileId: (profileId != null ? profileId.value : this.profileId),
        sharedProfile:
            (sharedProfile != null ? sharedProfile.value : this.sharedProfile),
        clientType: (clientType != null ? clientType.value : this.clientType),
        contentSourceId: (contentSourceId != null
            ? contentSourceId.value
            : this.contentSourceId),
        resourceId: (resourceId != null ? resourceId.value : this.resourceId),
        actionId: (actionId != null ? actionId.value : this.actionId),
        actionTime: (actionTime != null ? actionTime.value : this.actionTime),
        subgenre: (subgenre != null ? subgenre.value : this.subgenre),
        features: (features != null ? features.value : this.features));
  }
}

@JsonSerializable(explicitToJson: true)
class LearnActionV1$RequestBody {
  LearnActionV1$RequestBody({
    required this.profileId,
    this.sharedProfile,
    required this.clientType,
    this.contentSourceId,
    this.resourceId,
    this.actionId,
    this.actionTime,
    this.subgenre,
    this.features,
  });

  factory LearnActionV1$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$LearnActionV1$RequestBodyFromJson(json);

  static const toJsonFactory = _$LearnActionV1$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$LearnActionV1$RequestBodyToJson(this);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'sharedProfile', includeIfNull: false)
  final bool? sharedProfile;
  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(
    name: 'contentSourceId',
    includeIfNull: false,
    toJson: learnActionV1$RequestBodyContentSourceIdToJson,
    fromJson: learnActionV1$RequestBodyContentSourceIdFromJson,
  )
  final enums.LearnActionV1$RequestBodyContentSourceId? contentSourceId;
  @JsonKey(name: 'resourceId', includeIfNull: false, defaultValue: '')
  final String? resourceId;
  @JsonKey(name: 'actionId', includeIfNull: false)
  final int? actionId;
  @JsonKey(name: 'actionTime', includeIfNull: false)
  final int? actionTime;
  @JsonKey(name: 'subgenre', includeIfNull: false, defaultValue: <String>[])
  final List<String>? subgenre;
  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$LearnActionV1$RequestBodyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LearnActionV1$RequestBody &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.sharedProfile, sharedProfile) ||
                const DeepCollectionEquality()
                    .equals(other.sharedProfile, sharedProfile)) &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(other.contentSourceId, contentSourceId) ||
                const DeepCollectionEquality()
                    .equals(other.contentSourceId, contentSourceId)) &&
            (identical(other.resourceId, resourceId) ||
                const DeepCollectionEquality()
                    .equals(other.resourceId, resourceId)) &&
            (identical(other.actionId, actionId) ||
                const DeepCollectionEquality()
                    .equals(other.actionId, actionId)) &&
            (identical(other.actionTime, actionTime) ||
                const DeepCollectionEquality()
                    .equals(other.actionTime, actionTime)) &&
            (identical(other.subgenre, subgenre) ||
                const DeepCollectionEquality()
                    .equals(other.subgenre, subgenre)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(sharedProfile) ^
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(contentSourceId) ^
      const DeepCollectionEquality().hash(resourceId) ^
      const DeepCollectionEquality().hash(actionId) ^
      const DeepCollectionEquality().hash(actionTime) ^
      const DeepCollectionEquality().hash(subgenre) ^
      const DeepCollectionEquality().hash(features) ^
      runtimeType.hashCode;
}

extension $LearnActionV1$RequestBodyExtension on LearnActionV1$RequestBody {
  LearnActionV1$RequestBody copyWith(
      {String? profileId,
      bool? sharedProfile,
      String? clientType,
      enums.LearnActionV1$RequestBodyContentSourceId? contentSourceId,
      String? resourceId,
      int? actionId,
      int? actionTime,
      List<String>? subgenre,
      List<String>? features}) {
    return LearnActionV1$RequestBody(
        profileId: profileId ?? this.profileId,
        sharedProfile: sharedProfile ?? this.sharedProfile,
        clientType: clientType ?? this.clientType,
        contentSourceId: contentSourceId ?? this.contentSourceId,
        resourceId: resourceId ?? this.resourceId,
        actionId: actionId ?? this.actionId,
        actionTime: actionTime ?? this.actionTime,
        subgenre: subgenre ?? this.subgenre,
        features: features ?? this.features);
  }

  LearnActionV1$RequestBody copyWithWrapped(
      {Wrapped<String>? profileId,
      Wrapped<bool?>? sharedProfile,
      Wrapped<String>? clientType,
      Wrapped<enums.LearnActionV1$RequestBodyContentSourceId?>? contentSourceId,
      Wrapped<String?>? resourceId,
      Wrapped<int?>? actionId,
      Wrapped<int?>? actionTime,
      Wrapped<List<String>?>? subgenre,
      Wrapped<List<String>?>? features}) {
    return LearnActionV1$RequestBody(
        profileId: (profileId != null ? profileId.value : this.profileId),
        sharedProfile:
            (sharedProfile != null ? sharedProfile.value : this.sharedProfile),
        clientType: (clientType != null ? clientType.value : this.clientType),
        contentSourceId: (contentSourceId != null
            ? contentSourceId.value
            : this.contentSourceId),
        resourceId: (resourceId != null ? resourceId.value : this.resourceId),
        actionId: (actionId != null ? actionId.value : this.actionId),
        actionTime: (actionTime != null ? actionTime.value : this.actionTime),
        subgenre: (subgenre != null ? subgenre.value : this.subgenre),
        features: (features != null ? features.value : this.features));
  }
}

String? vODResponseProductTypeToJson(
    enums.VODResponseProductType? vODResponseProductType) {
  return vODResponseProductType?.value;
}

enums.VODResponseProductType vODResponseProductTypeFromJson(
  Object? vODResponseProductType, [
  enums.VODResponseProductType? defaultValue,
]) {
  return enums.VODResponseProductType.values
          .firstWhereOrNull((e) => e.value == vODResponseProductType) ??
      defaultValue ??
      enums.VODResponseProductType.swaggerGeneratedUnknown;
}

List<String> vODResponseProductTypeListToJson(
    List<enums.VODResponseProductType>? vODResponseProductType) {
  if (vODResponseProductType == null) {
    return [];
  }

  return vODResponseProductType.map((e) => e.value!).toList();
}

List<enums.VODResponseProductType> vODResponseProductTypeListFromJson(
  List? vODResponseProductType, [
  List<enums.VODResponseProductType>? defaultValue,
]) {
  if (vODResponseProductType == null) {
    return defaultValue ?? [];
  }

  return vODResponseProductType
      .map((e) => vODResponseProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODResponseProductType>? vODResponseProductTypeNullableListFromJson(
  List? vODResponseProductType, [
  List<enums.VODResponseProductType>? defaultValue,
]) {
  if (vODResponseProductType == null) {
    return defaultValue;
  }

  return vODResponseProductType
      .map((e) => vODResponseProductTypeFromJson(e.toString()))
      .toList();
}

String? vODResponseCommonProductTypeToJson(
    enums.VODResponseCommonProductType? vODResponseCommonProductType) {
  return vODResponseCommonProductType?.value;
}

enums.VODResponseCommonProductType vODResponseCommonProductTypeFromJson(
  Object? vODResponseCommonProductType, [
  enums.VODResponseCommonProductType? defaultValue,
]) {
  return enums.VODResponseCommonProductType.values
          .firstWhereOrNull((e) => e.value == vODResponseCommonProductType) ??
      defaultValue ??
      enums.VODResponseCommonProductType.swaggerGeneratedUnknown;
}

List<String> vODResponseCommonProductTypeListToJson(
    List<enums.VODResponseCommonProductType>? vODResponseCommonProductType) {
  if (vODResponseCommonProductType == null) {
    return [];
  }

  return vODResponseCommonProductType.map((e) => e.value!).toList();
}

List<enums.VODResponseCommonProductType>
    vODResponseCommonProductTypeListFromJson(
  List? vODResponseCommonProductType, [
  List<enums.VODResponseCommonProductType>? defaultValue,
]) {
  if (vODResponseCommonProductType == null) {
    return defaultValue ?? [];
  }

  return vODResponseCommonProductType
      .map((e) => vODResponseCommonProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODResponseCommonProductType>?
    vODResponseCommonProductTypeNullableListFromJson(
  List? vODResponseCommonProductType, [
  List<enums.VODResponseCommonProductType>? defaultValue,
]) {
  if (vODResponseCommonProductType == null) {
    return defaultValue;
  }

  return vODResponseCommonProductType
      .map((e) => vODResponseCommonProductTypeFromJson(e.toString()))
      .toList();
}

String? vODResponseV3ProductTypeToJson(
    enums.VODResponseV3ProductType? vODResponseV3ProductType) {
  return vODResponseV3ProductType?.value;
}

enums.VODResponseV3ProductType vODResponseV3ProductTypeFromJson(
  Object? vODResponseV3ProductType, [
  enums.VODResponseV3ProductType? defaultValue,
]) {
  return enums.VODResponseV3ProductType.values
          .firstWhereOrNull((e) => e.value == vODResponseV3ProductType) ??
      defaultValue ??
      enums.VODResponseV3ProductType.swaggerGeneratedUnknown;
}

List<String> vODResponseV3ProductTypeListToJson(
    List<enums.VODResponseV3ProductType>? vODResponseV3ProductType) {
  if (vODResponseV3ProductType == null) {
    return [];
  }

  return vODResponseV3ProductType.map((e) => e.value!).toList();
}

List<enums.VODResponseV3ProductType> vODResponseV3ProductTypeListFromJson(
  List? vODResponseV3ProductType, [
  List<enums.VODResponseV3ProductType>? defaultValue,
]) {
  if (vODResponseV3ProductType == null) {
    return defaultValue ?? [];
  }

  return vODResponseV3ProductType
      .map((e) => vODResponseV3ProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODResponseV3ProductType>?
    vODResponseV3ProductTypeNullableListFromJson(
  List? vODResponseV3ProductType, [
  List<enums.VODResponseV3ProductType>? defaultValue,
]) {
  if (vODResponseV3ProductType == null) {
    return defaultValue;
  }

  return vODResponseV3ProductType
      .map((e) => vODResponseV3ProductTypeFromJson(e.toString()))
      .toList();
}

String? collaborativeResponseV3TypeToJson(
    enums.CollaborativeResponseV3Type? collaborativeResponseV3Type) {
  return collaborativeResponseV3Type?.value;
}

enums.CollaborativeResponseV3Type collaborativeResponseV3TypeFromJson(
  Object? collaborativeResponseV3Type, [
  enums.CollaborativeResponseV3Type? defaultValue,
]) {
  return enums.CollaborativeResponseV3Type.values
          .firstWhereOrNull((e) => e.value == collaborativeResponseV3Type) ??
      defaultValue ??
      enums.CollaborativeResponseV3Type.swaggerGeneratedUnknown;
}

List<String> collaborativeResponseV3TypeListToJson(
    List<enums.CollaborativeResponseV3Type>? collaborativeResponseV3Type) {
  if (collaborativeResponseV3Type == null) {
    return [];
  }

  return collaborativeResponseV3Type.map((e) => e.value!).toList();
}

List<enums.CollaborativeResponseV3Type> collaborativeResponseV3TypeListFromJson(
  List? collaborativeResponseV3Type, [
  List<enums.CollaborativeResponseV3Type>? defaultValue,
]) {
  if (collaborativeResponseV3Type == null) {
    return defaultValue ?? [];
  }

  return collaborativeResponseV3Type
      .map((e) => collaborativeResponseV3TypeFromJson(e.toString()))
      .toList();
}

List<enums.CollaborativeResponseV3Type>?
    collaborativeResponseV3TypeNullableListFromJson(
  List? collaborativeResponseV3Type, [
  List<enums.CollaborativeResponseV3Type>? defaultValue,
]) {
  if (collaborativeResponseV3Type == null) {
    return defaultValue;
  }

  return collaborativeResponseV3Type
      .map((e) => collaborativeResponseV3TypeFromJson(e.toString()))
      .toList();
}

String? groupedMultisourceResponseV3SeriesContentTypeToJson(
    enums.GroupedMultisourceResponseV3SeriesContentType?
        groupedMultisourceResponseV3SeriesContentType) {
  return groupedMultisourceResponseV3SeriesContentType?.value;
}

enums.GroupedMultisourceResponseV3SeriesContentType
    groupedMultisourceResponseV3SeriesContentTypeFromJson(
  Object? groupedMultisourceResponseV3SeriesContentType, [
  enums.GroupedMultisourceResponseV3SeriesContentType? defaultValue,
]) {
  return enums.GroupedMultisourceResponseV3SeriesContentType.values
          .firstWhereOrNull((e) =>
              e.value == groupedMultisourceResponseV3SeriesContentType) ??
      defaultValue ??
      enums.GroupedMultisourceResponseV3SeriesContentType
          .swaggerGeneratedUnknown;
}

List<String> groupedMultisourceResponseV3SeriesContentTypeListToJson(
    List<enums.GroupedMultisourceResponseV3SeriesContentType>?
        groupedMultisourceResponseV3SeriesContentType) {
  if (groupedMultisourceResponseV3SeriesContentType == null) {
    return [];
  }

  return groupedMultisourceResponseV3SeriesContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.GroupedMultisourceResponseV3SeriesContentType>
    groupedMultisourceResponseV3SeriesContentTypeListFromJson(
  List? groupedMultisourceResponseV3SeriesContentType, [
  List<enums.GroupedMultisourceResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseV3SeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedMultisourceResponseV3SeriesContentType
      .map((e) =>
          groupedMultisourceResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedMultisourceResponseV3SeriesContentType>?
    groupedMultisourceResponseV3SeriesContentTypeNullableListFromJson(
  List? groupedMultisourceResponseV3SeriesContentType, [
  List<enums.GroupedMultisourceResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseV3SeriesContentType == null) {
    return defaultValue;
  }

  return groupedMultisourceResponseV3SeriesContentType
      .map((e) =>
          groupedMultisourceResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? groupedMultisourceResponseSeriesContentTypeToJson(
    enums.GroupedMultisourceResponseSeriesContentType?
        groupedMultisourceResponseSeriesContentType) {
  return groupedMultisourceResponseSeriesContentType?.value;
}

enums.GroupedMultisourceResponseSeriesContentType
    groupedMultisourceResponseSeriesContentTypeFromJson(
  Object? groupedMultisourceResponseSeriesContentType, [
  enums.GroupedMultisourceResponseSeriesContentType? defaultValue,
]) {
  return enums.GroupedMultisourceResponseSeriesContentType.values
          .firstWhereOrNull(
              (e) => e.value == groupedMultisourceResponseSeriesContentType) ??
      defaultValue ??
      enums.GroupedMultisourceResponseSeriesContentType.swaggerGeneratedUnknown;
}

List<String> groupedMultisourceResponseSeriesContentTypeListToJson(
    List<enums.GroupedMultisourceResponseSeriesContentType>?
        groupedMultisourceResponseSeriesContentType) {
  if (groupedMultisourceResponseSeriesContentType == null) {
    return [];
  }

  return groupedMultisourceResponseSeriesContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.GroupedMultisourceResponseSeriesContentType>
    groupedMultisourceResponseSeriesContentTypeListFromJson(
  List? groupedMultisourceResponseSeriesContentType, [
  List<enums.GroupedMultisourceResponseSeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseSeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedMultisourceResponseSeriesContentType
      .map((e) =>
          groupedMultisourceResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedMultisourceResponseSeriesContentType>?
    groupedMultisourceResponseSeriesContentTypeNullableListFromJson(
  List? groupedMultisourceResponseSeriesContentType, [
  List<enums.GroupedMultisourceResponseSeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseSeriesContentType == null) {
    return defaultValue;
  }

  return groupedMultisourceResponseSeriesContentType
      .map((e) =>
          groupedMultisourceResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? groupedMultisourceResponseCommonSeriesContentTypeToJson(
    enums.GroupedMultisourceResponseCommonSeriesContentType?
        groupedMultisourceResponseCommonSeriesContentType) {
  return groupedMultisourceResponseCommonSeriesContentType?.value;
}

enums.GroupedMultisourceResponseCommonSeriesContentType
    groupedMultisourceResponseCommonSeriesContentTypeFromJson(
  Object? groupedMultisourceResponseCommonSeriesContentType, [
  enums.GroupedMultisourceResponseCommonSeriesContentType? defaultValue,
]) {
  return enums.GroupedMultisourceResponseCommonSeriesContentType.values
          .firstWhereOrNull((e) =>
              e.value == groupedMultisourceResponseCommonSeriesContentType) ??
      defaultValue ??
      enums.GroupedMultisourceResponseCommonSeriesContentType
          .swaggerGeneratedUnknown;
}

List<String> groupedMultisourceResponseCommonSeriesContentTypeListToJson(
    List<enums.GroupedMultisourceResponseCommonSeriesContentType>?
        groupedMultisourceResponseCommonSeriesContentType) {
  if (groupedMultisourceResponseCommonSeriesContentType == null) {
    return [];
  }

  return groupedMultisourceResponseCommonSeriesContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.GroupedMultisourceResponseCommonSeriesContentType>
    groupedMultisourceResponseCommonSeriesContentTypeListFromJson(
  List? groupedMultisourceResponseCommonSeriesContentType, [
  List<enums.GroupedMultisourceResponseCommonSeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseCommonSeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedMultisourceResponseCommonSeriesContentType
      .map((e) => groupedMultisourceResponseCommonSeriesContentTypeFromJson(
          e.toString()))
      .toList();
}

List<enums.GroupedMultisourceResponseCommonSeriesContentType>?
    groupedMultisourceResponseCommonSeriesContentTypeNullableListFromJson(
  List? groupedMultisourceResponseCommonSeriesContentType, [
  List<enums.GroupedMultisourceResponseCommonSeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseCommonSeriesContentType == null) {
    return defaultValue;
  }

  return groupedMultisourceResponseCommonSeriesContentType
      .map((e) => groupedMultisourceResponseCommonSeriesContentTypeFromJson(
          e.toString()))
      .toList();
}

String? groupedSeriesResponseV3SeriesContentTypeToJson(
    enums.GroupedSeriesResponseV3SeriesContentType?
        groupedSeriesResponseV3SeriesContentType) {
  return groupedSeriesResponseV3SeriesContentType?.value;
}

enums.GroupedSeriesResponseV3SeriesContentType
    groupedSeriesResponseV3SeriesContentTypeFromJson(
  Object? groupedSeriesResponseV3SeriesContentType, [
  enums.GroupedSeriesResponseV3SeriesContentType? defaultValue,
]) {
  return enums.GroupedSeriesResponseV3SeriesContentType.values.firstWhereOrNull(
          (e) => e.value == groupedSeriesResponseV3SeriesContentType) ??
      defaultValue ??
      enums.GroupedSeriesResponseV3SeriesContentType.swaggerGeneratedUnknown;
}

List<String> groupedSeriesResponseV3SeriesContentTypeListToJson(
    List<enums.GroupedSeriesResponseV3SeriesContentType>?
        groupedSeriesResponseV3SeriesContentType) {
  if (groupedSeriesResponseV3SeriesContentType == null) {
    return [];
  }

  return groupedSeriesResponseV3SeriesContentType.map((e) => e.value!).toList();
}

List<enums.GroupedSeriesResponseV3SeriesContentType>
    groupedSeriesResponseV3SeriesContentTypeListFromJson(
  List? groupedSeriesResponseV3SeriesContentType, [
  List<enums.GroupedSeriesResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseV3SeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedSeriesResponseV3SeriesContentType
      .map(
          (e) => groupedSeriesResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedSeriesResponseV3SeriesContentType>?
    groupedSeriesResponseV3SeriesContentTypeNullableListFromJson(
  List? groupedSeriesResponseV3SeriesContentType, [
  List<enums.GroupedSeriesResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseV3SeriesContentType == null) {
    return defaultValue;
  }

  return groupedSeriesResponseV3SeriesContentType
      .map(
          (e) => groupedSeriesResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? groupedSeriesResponseSeriesContentTypeToJson(
    enums.GroupedSeriesResponseSeriesContentType?
        groupedSeriesResponseSeriesContentType) {
  return groupedSeriesResponseSeriesContentType?.value;
}

enums.GroupedSeriesResponseSeriesContentType
    groupedSeriesResponseSeriesContentTypeFromJson(
  Object? groupedSeriesResponseSeriesContentType, [
  enums.GroupedSeriesResponseSeriesContentType? defaultValue,
]) {
  return enums.GroupedSeriesResponseSeriesContentType.values.firstWhereOrNull(
          (e) => e.value == groupedSeriesResponseSeriesContentType) ??
      defaultValue ??
      enums.GroupedSeriesResponseSeriesContentType.swaggerGeneratedUnknown;
}

List<String> groupedSeriesResponseSeriesContentTypeListToJson(
    List<enums.GroupedSeriesResponseSeriesContentType>?
        groupedSeriesResponseSeriesContentType) {
  if (groupedSeriesResponseSeriesContentType == null) {
    return [];
  }

  return groupedSeriesResponseSeriesContentType.map((e) => e.value!).toList();
}

List<enums.GroupedSeriesResponseSeriesContentType>
    groupedSeriesResponseSeriesContentTypeListFromJson(
  List? groupedSeriesResponseSeriesContentType, [
  List<enums.GroupedSeriesResponseSeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseSeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedSeriesResponseSeriesContentType
      .map((e) => groupedSeriesResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedSeriesResponseSeriesContentType>?
    groupedSeriesResponseSeriesContentTypeNullableListFromJson(
  List? groupedSeriesResponseSeriesContentType, [
  List<enums.GroupedSeriesResponseSeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseSeriesContentType == null) {
    return defaultValue;
  }

  return groupedSeriesResponseSeriesContentType
      .map((e) => groupedSeriesResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? pVRSearchResponseV1RecordingStateToJson(
    enums.PVRSearchResponseV1RecordingState?
        pVRSearchResponseV1RecordingState) {
  return pVRSearchResponseV1RecordingState?.value;
}

enums.PVRSearchResponseV1RecordingState
    pVRSearchResponseV1RecordingStateFromJson(
  Object? pVRSearchResponseV1RecordingState, [
  enums.PVRSearchResponseV1RecordingState? defaultValue,
]) {
  return enums.PVRSearchResponseV1RecordingState.values.firstWhereOrNull(
          (e) => e.value == pVRSearchResponseV1RecordingState) ??
      defaultValue ??
      enums.PVRSearchResponseV1RecordingState.swaggerGeneratedUnknown;
}

List<String> pVRSearchResponseV1RecordingStateListToJson(
    List<enums.PVRSearchResponseV1RecordingState>?
        pVRSearchResponseV1RecordingState) {
  if (pVRSearchResponseV1RecordingState == null) {
    return [];
  }

  return pVRSearchResponseV1RecordingState.map((e) => e.value!).toList();
}

List<enums.PVRSearchResponseV1RecordingState>
    pVRSearchResponseV1RecordingStateListFromJson(
  List? pVRSearchResponseV1RecordingState, [
  List<enums.PVRSearchResponseV1RecordingState>? defaultValue,
]) {
  if (pVRSearchResponseV1RecordingState == null) {
    return defaultValue ?? [];
  }

  return pVRSearchResponseV1RecordingState
      .map((e) => pVRSearchResponseV1RecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.PVRSearchResponseV1RecordingState>?
    pVRSearchResponseV1RecordingStateNullableListFromJson(
  List? pVRSearchResponseV1RecordingState, [
  List<enums.PVRSearchResponseV1RecordingState>? defaultValue,
]) {
  if (pVRSearchResponseV1RecordingState == null) {
    return defaultValue;
  }

  return pVRSearchResponseV1RecordingState
      .map((e) => pVRSearchResponseV1RecordingStateFromJson(e.toString()))
      .toList();
}

String? nuanceRelativeDateTimeNuanceSTEPToJson(
    enums.NuanceRelativeDateTimeNuanceSTEP? nuanceRelativeDateTimeNuanceSTEP) {
  return nuanceRelativeDateTimeNuanceSTEP?.value;
}

enums.NuanceRelativeDateTimeNuanceSTEP nuanceRelativeDateTimeNuanceSTEPFromJson(
  Object? nuanceRelativeDateTimeNuanceSTEP, [
  enums.NuanceRelativeDateTimeNuanceSTEP? defaultValue,
]) {
  return enums.NuanceRelativeDateTimeNuanceSTEP.values.firstWhereOrNull(
          (e) => e.value == nuanceRelativeDateTimeNuanceSTEP) ??
      defaultValue ??
      enums.NuanceRelativeDateTimeNuanceSTEP.swaggerGeneratedUnknown;
}

List<String> nuanceRelativeDateTimeNuanceSTEPListToJson(
    List<enums.NuanceRelativeDateTimeNuanceSTEP>?
        nuanceRelativeDateTimeNuanceSTEP) {
  if (nuanceRelativeDateTimeNuanceSTEP == null) {
    return [];
  }

  return nuanceRelativeDateTimeNuanceSTEP.map((e) => e.value!).toList();
}

List<enums.NuanceRelativeDateTimeNuanceSTEP>
    nuanceRelativeDateTimeNuanceSTEPListFromJson(
  List? nuanceRelativeDateTimeNuanceSTEP, [
  List<enums.NuanceRelativeDateTimeNuanceSTEP>? defaultValue,
]) {
  if (nuanceRelativeDateTimeNuanceSTEP == null) {
    return defaultValue ?? [];
  }

  return nuanceRelativeDateTimeNuanceSTEP
      .map((e) => nuanceRelativeDateTimeNuanceSTEPFromJson(e.toString()))
      .toList();
}

List<enums.NuanceRelativeDateTimeNuanceSTEP>?
    nuanceRelativeDateTimeNuanceSTEPNullableListFromJson(
  List? nuanceRelativeDateTimeNuanceSTEP, [
  List<enums.NuanceRelativeDateTimeNuanceSTEP>? defaultValue,
]) {
  if (nuanceRelativeDateTimeNuanceSTEP == null) {
    return defaultValue;
  }

  return nuanceRelativeDateTimeNuanceSTEP
      .map((e) => nuanceRelativeDateTimeNuanceSTEPFromJson(e.toString()))
      .toList();
}

String? resourceContentSourceIdToJson(
    enums.ResourceContentSourceId? resourceContentSourceId) {
  return resourceContentSourceId?.value;
}

enums.ResourceContentSourceId resourceContentSourceIdFromJson(
  Object? resourceContentSourceId, [
  enums.ResourceContentSourceId? defaultValue,
]) {
  return enums.ResourceContentSourceId.values
          .firstWhereOrNull((e) => e.value == resourceContentSourceId) ??
      defaultValue ??
      enums.ResourceContentSourceId.swaggerGeneratedUnknown;
}

List<String> resourceContentSourceIdListToJson(
    List<enums.ResourceContentSourceId>? resourceContentSourceId) {
  if (resourceContentSourceId == null) {
    return [];
  }

  return resourceContentSourceId.map((e) => e.value!).toList();
}

List<enums.ResourceContentSourceId> resourceContentSourceIdListFromJson(
  List? resourceContentSourceId, [
  List<enums.ResourceContentSourceId>? defaultValue,
]) {
  if (resourceContentSourceId == null) {
    return defaultValue ?? [];
  }

  return resourceContentSourceId
      .map((e) => resourceContentSourceIdFromJson(e.toString()))
      .toList();
}

List<enums.ResourceContentSourceId>?
    resourceContentSourceIdNullableListFromJson(
  List? resourceContentSourceId, [
  List<enums.ResourceContentSourceId>? defaultValue,
]) {
  if (resourceContentSourceId == null) {
    return defaultValue;
  }

  return resourceContentSourceId
      .map((e) => resourceContentSourceIdFromJson(e.toString()))
      .toList();
}

String? maxResToJson(enums.MaxRes? maxRes) {
  return maxRes?.value;
}

enums.MaxRes maxResFromJson(
  Object? maxRes, [
  enums.MaxRes? defaultValue,
]) {
  return enums.MaxRes.values.firstWhereOrNull((e) => e.value == maxRes) ??
      defaultValue ??
      enums.MaxRes.swaggerGeneratedUnknown;
}

List<String> maxResListToJson(List<enums.MaxRes>? maxRes) {
  if (maxRes == null) {
    return [];
  }

  return maxRes.map((e) => e.value!).toList();
}

List<enums.MaxRes> maxResListFromJson(
  List? maxRes, [
  List<enums.MaxRes>? defaultValue,
]) {
  if (maxRes == null) {
    return defaultValue ?? [];
  }

  return maxRes.map((e) => maxResFromJson(e.toString())).toList();
}

List<enums.MaxRes>? maxResNullableListFromJson(
  List? maxRes, [
  List<enums.MaxRes>? defaultValue,
]) {
  if (maxRes == null) {
    return defaultValue;
  }

  return maxRes.map((e) => maxResFromJson(e.toString())).toList();
}

String? filterOnDemandToJson(enums.FilterOnDemand? filterOnDemand) {
  return filterOnDemand?.value;
}

enums.FilterOnDemand filterOnDemandFromJson(
  Object? filterOnDemand, [
  enums.FilterOnDemand? defaultValue,
]) {
  return enums.FilterOnDemand.values
          .firstWhereOrNull((e) => e.value == filterOnDemand) ??
      defaultValue ??
      enums.FilterOnDemand.swaggerGeneratedUnknown;
}

List<String> filterOnDemandListToJson(
    List<enums.FilterOnDemand>? filterOnDemand) {
  if (filterOnDemand == null) {
    return [];
  }

  return filterOnDemand.map((e) => e.value!).toList();
}

List<enums.FilterOnDemand> filterOnDemandListFromJson(
  List? filterOnDemand, [
  List<enums.FilterOnDemand>? defaultValue,
]) {
  if (filterOnDemand == null) {
    return defaultValue ?? [];
  }

  return filterOnDemand
      .map((e) => filterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.FilterOnDemand>? filterOnDemandNullableListFromJson(
  List? filterOnDemand, [
  List<enums.FilterOnDemand>? defaultValue,
]) {
  if (filterOnDemand == null) {
    return defaultValue;
  }

  return filterOnDemand
      .map((e) => filterOnDemandFromJson(e.toString()))
      .toList();
}

String? svodFilterOnDemandToJson(enums.SvodFilterOnDemand? svodFilterOnDemand) {
  return svodFilterOnDemand?.value;
}

enums.SvodFilterOnDemand svodFilterOnDemandFromJson(
  Object? svodFilterOnDemand, [
  enums.SvodFilterOnDemand? defaultValue,
]) {
  return enums.SvodFilterOnDemand.values
          .firstWhereOrNull((e) => e.value == svodFilterOnDemand) ??
      defaultValue ??
      enums.SvodFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> svodFilterOnDemandListToJson(
    List<enums.SvodFilterOnDemand>? svodFilterOnDemand) {
  if (svodFilterOnDemand == null) {
    return [];
  }

  return svodFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.SvodFilterOnDemand> svodFilterOnDemandListFromJson(
  List? svodFilterOnDemand, [
  List<enums.SvodFilterOnDemand>? defaultValue,
]) {
  if (svodFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return svodFilterOnDemand
      .map((e) => svodFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.SvodFilterOnDemand>? svodFilterOnDemandNullableListFromJson(
  List? svodFilterOnDemand, [
  List<enums.SvodFilterOnDemand>? defaultValue,
]) {
  if (svodFilterOnDemand == null) {
    return defaultValue;
  }

  return svodFilterOnDemand
      .map((e) => svodFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? resourceContentSourceIdCollaborativeToJson(
    enums.ResourceContentSourceIdCollaborative?
        resourceContentSourceIdCollaborative) {
  return resourceContentSourceIdCollaborative?.value;
}

enums.ResourceContentSourceIdCollaborative
    resourceContentSourceIdCollaborativeFromJson(
  Object? resourceContentSourceIdCollaborative, [
  enums.ResourceContentSourceIdCollaborative? defaultValue,
]) {
  return enums.ResourceContentSourceIdCollaborative.values.firstWhereOrNull(
          (e) => e.value == resourceContentSourceIdCollaborative) ??
      defaultValue ??
      enums.ResourceContentSourceIdCollaborative.swaggerGeneratedUnknown;
}

List<String> resourceContentSourceIdCollaborativeListToJson(
    List<enums.ResourceContentSourceIdCollaborative>?
        resourceContentSourceIdCollaborative) {
  if (resourceContentSourceIdCollaborative == null) {
    return [];
  }

  return resourceContentSourceIdCollaborative.map((e) => e.value!).toList();
}

List<enums.ResourceContentSourceIdCollaborative>
    resourceContentSourceIdCollaborativeListFromJson(
  List? resourceContentSourceIdCollaborative, [
  List<enums.ResourceContentSourceIdCollaborative>? defaultValue,
]) {
  if (resourceContentSourceIdCollaborative == null) {
    return defaultValue ?? [];
  }

  return resourceContentSourceIdCollaborative
      .map((e) => resourceContentSourceIdCollaborativeFromJson(e.toString()))
      .toList();
}

List<enums.ResourceContentSourceIdCollaborative>?
    resourceContentSourceIdCollaborativeNullableListFromJson(
  List? resourceContentSourceIdCollaborative, [
  List<enums.ResourceContentSourceIdCollaborative>? defaultValue,
]) {
  if (resourceContentSourceIdCollaborative == null) {
    return defaultValue;
  }

  return resourceContentSourceIdCollaborative
      .map((e) => resourceContentSourceIdCollaborativeFromJson(e.toString()))
      .toList();
}

String? v2RecommendationsMoreLikeThisGetResourceContentSourceIdToJson(
    enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId?
        v2RecommendationsMoreLikeThisGetResourceContentSourceId) {
  return v2RecommendationsMoreLikeThisGetResourceContentSourceId?.value;
}

enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId
    v2RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
  Object? v2RecommendationsMoreLikeThisGetResourceContentSourceId, [
  enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId? defaultValue,
]) {
  return enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId.values
          .firstWhereOrNull((e) =>
              e.value ==
              v2RecommendationsMoreLikeThisGetResourceContentSourceId) ??
      defaultValue ??
      enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId
          .swaggerGeneratedUnknown;
}

List<String> v2RecommendationsMoreLikeThisGetResourceContentSourceIdListToJson(
    List<enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId>?
        v2RecommendationsMoreLikeThisGetResourceContentSourceId) {
  if (v2RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return [];
  }

  return v2RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) => e.value!)
      .toList();
}

List<enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId>
    v2RecommendationsMoreLikeThisGetResourceContentSourceIdListFromJson(
  List? v2RecommendationsMoreLikeThisGetResourceContentSourceId, [
  List<enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v2RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return defaultValue ?? [];
  }

  return v2RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) =>
          v2RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

List<enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId>?
    v2RecommendationsMoreLikeThisGetResourceContentSourceIdNullableListFromJson(
  List? v2RecommendationsMoreLikeThisGetResourceContentSourceId, [
  List<enums.V2RecommendationsMoreLikeThisGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v2RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return defaultValue;
  }

  return v2RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) =>
          v2RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

String? v2RecommendationsMoreLikeThisGetMaxResToJson(
    enums.V2RecommendationsMoreLikeThisGetMaxRes?
        v2RecommendationsMoreLikeThisGetMaxRes) {
  return v2RecommendationsMoreLikeThisGetMaxRes?.value;
}

enums.V2RecommendationsMoreLikeThisGetMaxRes
    v2RecommendationsMoreLikeThisGetMaxResFromJson(
  Object? v2RecommendationsMoreLikeThisGetMaxRes, [
  enums.V2RecommendationsMoreLikeThisGetMaxRes? defaultValue,
]) {
  return enums.V2RecommendationsMoreLikeThisGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2RecommendationsMoreLikeThisGetMaxRes) ??
      defaultValue ??
      enums.V2RecommendationsMoreLikeThisGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2RecommendationsMoreLikeThisGetMaxResListToJson(
    List<enums.V2RecommendationsMoreLikeThisGetMaxRes>?
        v2RecommendationsMoreLikeThisGetMaxRes) {
  if (v2RecommendationsMoreLikeThisGetMaxRes == null) {
    return [];
  }

  return v2RecommendationsMoreLikeThisGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2RecommendationsMoreLikeThisGetMaxRes>
    v2RecommendationsMoreLikeThisGetMaxResListFromJson(
  List? v2RecommendationsMoreLikeThisGetMaxRes, [
  List<enums.V2RecommendationsMoreLikeThisGetMaxRes>? defaultValue,
]) {
  if (v2RecommendationsMoreLikeThisGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2RecommendationsMoreLikeThisGetMaxRes
      .map((e) => v2RecommendationsMoreLikeThisGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2RecommendationsMoreLikeThisGetMaxRes>?
    v2RecommendationsMoreLikeThisGetMaxResNullableListFromJson(
  List? v2RecommendationsMoreLikeThisGetMaxRes, [
  List<enums.V2RecommendationsMoreLikeThisGetMaxRes>? defaultValue,
]) {
  if (v2RecommendationsMoreLikeThisGetMaxRes == null) {
    return defaultValue;
  }

  return v2RecommendationsMoreLikeThisGetMaxRes
      .map((e) => v2RecommendationsMoreLikeThisGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2RecommendationsTopSearchListGetMaxResToJson(
    enums.V2RecommendationsTopSearchListGetMaxRes?
        v2RecommendationsTopSearchListGetMaxRes) {
  return v2RecommendationsTopSearchListGetMaxRes?.value;
}

enums.V2RecommendationsTopSearchListGetMaxRes
    v2RecommendationsTopSearchListGetMaxResFromJson(
  Object? v2RecommendationsTopSearchListGetMaxRes, [
  enums.V2RecommendationsTopSearchListGetMaxRes? defaultValue,
]) {
  return enums.V2RecommendationsTopSearchListGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2RecommendationsTopSearchListGetMaxRes) ??
      defaultValue ??
      enums.V2RecommendationsTopSearchListGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2RecommendationsTopSearchListGetMaxResListToJson(
    List<enums.V2RecommendationsTopSearchListGetMaxRes>?
        v2RecommendationsTopSearchListGetMaxRes) {
  if (v2RecommendationsTopSearchListGetMaxRes == null) {
    return [];
  }

  return v2RecommendationsTopSearchListGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2RecommendationsTopSearchListGetMaxRes>
    v2RecommendationsTopSearchListGetMaxResListFromJson(
  List? v2RecommendationsTopSearchListGetMaxRes, [
  List<enums.V2RecommendationsTopSearchListGetMaxRes>? defaultValue,
]) {
  if (v2RecommendationsTopSearchListGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2RecommendationsTopSearchListGetMaxRes
      .map((e) => v2RecommendationsTopSearchListGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2RecommendationsTopSearchListGetMaxRes>?
    v2RecommendationsTopSearchListGetMaxResNullableListFromJson(
  List? v2RecommendationsTopSearchListGetMaxRes, [
  List<enums.V2RecommendationsTopSearchListGetMaxRes>? defaultValue,
]) {
  if (v2RecommendationsTopSearchListGetMaxRes == null) {
    return defaultValue;
  }

  return v2RecommendationsTopSearchListGetMaxRes
      .map((e) => v2RecommendationsTopSearchListGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsMoreLikeThisGetResourceContentSourceIdToJson(
    enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId?
        v3RecommendationsMoreLikeThisGetResourceContentSourceId) {
  return v3RecommendationsMoreLikeThisGetResourceContentSourceId?.value;
}

enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId
    v3RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
  Object? v3RecommendationsMoreLikeThisGetResourceContentSourceId, [
  enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId? defaultValue,
]) {
  return enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId.values
          .firstWhereOrNull((e) =>
              e.value ==
              v3RecommendationsMoreLikeThisGetResourceContentSourceId) ??
      defaultValue ??
      enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId
          .swaggerGeneratedUnknown;
}

List<String> v3RecommendationsMoreLikeThisGetResourceContentSourceIdListToJson(
    List<enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId>?
        v3RecommendationsMoreLikeThisGetResourceContentSourceId) {
  if (v3RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return [];
  }

  return v3RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) => e.value!)
      .toList();
}

List<enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId>
    v3RecommendationsMoreLikeThisGetResourceContentSourceIdListFromJson(
  List? v3RecommendationsMoreLikeThisGetResourceContentSourceId, [
  List<enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v3RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) =>
          v3RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

List<enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId>?
    v3RecommendationsMoreLikeThisGetResourceContentSourceIdNullableListFromJson(
  List? v3RecommendationsMoreLikeThisGetResourceContentSourceId, [
  List<enums.V3RecommendationsMoreLikeThisGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v3RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return defaultValue;
  }

  return v3RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) =>
          v3RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

String? v3RecommendationsMoreLikeThisGetMaxResToJson(
    enums.V3RecommendationsMoreLikeThisGetMaxRes?
        v3RecommendationsMoreLikeThisGetMaxRes) {
  return v3RecommendationsMoreLikeThisGetMaxRes?.value;
}

enums.V3RecommendationsMoreLikeThisGetMaxRes
    v3RecommendationsMoreLikeThisGetMaxResFromJson(
  Object? v3RecommendationsMoreLikeThisGetMaxRes, [
  enums.V3RecommendationsMoreLikeThisGetMaxRes? defaultValue,
]) {
  return enums.V3RecommendationsMoreLikeThisGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3RecommendationsMoreLikeThisGetMaxRes) ??
      defaultValue ??
      enums.V3RecommendationsMoreLikeThisGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3RecommendationsMoreLikeThisGetMaxResListToJson(
    List<enums.V3RecommendationsMoreLikeThisGetMaxRes>?
        v3RecommendationsMoreLikeThisGetMaxRes) {
  if (v3RecommendationsMoreLikeThisGetMaxRes == null) {
    return [];
  }

  return v3RecommendationsMoreLikeThisGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3RecommendationsMoreLikeThisGetMaxRes>
    v3RecommendationsMoreLikeThisGetMaxResListFromJson(
  List? v3RecommendationsMoreLikeThisGetMaxRes, [
  List<enums.V3RecommendationsMoreLikeThisGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsMoreLikeThisGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsMoreLikeThisGetMaxRes
      .map((e) => v3RecommendationsMoreLikeThisGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsMoreLikeThisGetMaxRes>?
    v3RecommendationsMoreLikeThisGetMaxResNullableListFromJson(
  List? v3RecommendationsMoreLikeThisGetMaxRes, [
  List<enums.V3RecommendationsMoreLikeThisGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsMoreLikeThisGetMaxRes == null) {
    return defaultValue;
  }

  return v3RecommendationsMoreLikeThisGetMaxRes
      .map((e) => v3RecommendationsMoreLikeThisGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsMoreLikeThisGetFilterOnDemandToJson(
    enums.V3RecommendationsMoreLikeThisGetFilterOnDemand?
        v3RecommendationsMoreLikeThisGetFilterOnDemand) {
  return v3RecommendationsMoreLikeThisGetFilterOnDemand?.value;
}

enums.V3RecommendationsMoreLikeThisGetFilterOnDemand
    v3RecommendationsMoreLikeThisGetFilterOnDemandFromJson(
  Object? v3RecommendationsMoreLikeThisGetFilterOnDemand, [
  enums.V3RecommendationsMoreLikeThisGetFilterOnDemand? defaultValue,
]) {
  return enums.V3RecommendationsMoreLikeThisGetFilterOnDemand.values
          .firstWhereOrNull((e) =>
              e.value == v3RecommendationsMoreLikeThisGetFilterOnDemand) ??
      defaultValue ??
      enums.V3RecommendationsMoreLikeThisGetFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String> v3RecommendationsMoreLikeThisGetFilterOnDemandListToJson(
    List<enums.V3RecommendationsMoreLikeThisGetFilterOnDemand>?
        v3RecommendationsMoreLikeThisGetFilterOnDemand) {
  if (v3RecommendationsMoreLikeThisGetFilterOnDemand == null) {
    return [];
  }

  return v3RecommendationsMoreLikeThisGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.V3RecommendationsMoreLikeThisGetFilterOnDemand>
    v3RecommendationsMoreLikeThisGetFilterOnDemandListFromJson(
  List? v3RecommendationsMoreLikeThisGetFilterOnDemand, [
  List<enums.V3RecommendationsMoreLikeThisGetFilterOnDemand>? defaultValue,
]) {
  if (v3RecommendationsMoreLikeThisGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsMoreLikeThisGetFilterOnDemand
      .map((e) =>
          v3RecommendationsMoreLikeThisGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsMoreLikeThisGetFilterOnDemand>?
    v3RecommendationsMoreLikeThisGetFilterOnDemandNullableListFromJson(
  List? v3RecommendationsMoreLikeThisGetFilterOnDemand, [
  List<enums.V3RecommendationsMoreLikeThisGetFilterOnDemand>? defaultValue,
]) {
  if (v3RecommendationsMoreLikeThisGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3RecommendationsMoreLikeThisGetFilterOnDemand
      .map((e) =>
          v3RecommendationsMoreLikeThisGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsTopSearchListGetMaxResToJson(
    enums.V3RecommendationsTopSearchListGetMaxRes?
        v3RecommendationsTopSearchListGetMaxRes) {
  return v3RecommendationsTopSearchListGetMaxRes?.value;
}

enums.V3RecommendationsTopSearchListGetMaxRes
    v3RecommendationsTopSearchListGetMaxResFromJson(
  Object? v3RecommendationsTopSearchListGetMaxRes, [
  enums.V3RecommendationsTopSearchListGetMaxRes? defaultValue,
]) {
  return enums.V3RecommendationsTopSearchListGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3RecommendationsTopSearchListGetMaxRes) ??
      defaultValue ??
      enums.V3RecommendationsTopSearchListGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3RecommendationsTopSearchListGetMaxResListToJson(
    List<enums.V3RecommendationsTopSearchListGetMaxRes>?
        v3RecommendationsTopSearchListGetMaxRes) {
  if (v3RecommendationsTopSearchListGetMaxRes == null) {
    return [];
  }

  return v3RecommendationsTopSearchListGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3RecommendationsTopSearchListGetMaxRes>
    v3RecommendationsTopSearchListGetMaxResListFromJson(
  List? v3RecommendationsTopSearchListGetMaxRes, [
  List<enums.V3RecommendationsTopSearchListGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsTopSearchListGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsTopSearchListGetMaxRes
      .map((e) => v3RecommendationsTopSearchListGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsTopSearchListGetMaxRes>?
    v3RecommendationsTopSearchListGetMaxResNullableListFromJson(
  List? v3RecommendationsTopSearchListGetMaxRes, [
  List<enums.V3RecommendationsTopSearchListGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsTopSearchListGetMaxRes == null) {
    return defaultValue;
  }

  return v3RecommendationsTopSearchListGetMaxRes
      .map((e) => v3RecommendationsTopSearchListGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsTopSearchListGetFilterOnDemandToJson(
    enums.V3RecommendationsTopSearchListGetFilterOnDemand?
        v3RecommendationsTopSearchListGetFilterOnDemand) {
  return v3RecommendationsTopSearchListGetFilterOnDemand?.value;
}

enums.V3RecommendationsTopSearchListGetFilterOnDemand
    v3RecommendationsTopSearchListGetFilterOnDemandFromJson(
  Object? v3RecommendationsTopSearchListGetFilterOnDemand, [
  enums.V3RecommendationsTopSearchListGetFilterOnDemand? defaultValue,
]) {
  return enums.V3RecommendationsTopSearchListGetFilterOnDemand.values
          .firstWhereOrNull((e) =>
              e.value == v3RecommendationsTopSearchListGetFilterOnDemand) ??
      defaultValue ??
      enums.V3RecommendationsTopSearchListGetFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String> v3RecommendationsTopSearchListGetFilterOnDemandListToJson(
    List<enums.V3RecommendationsTopSearchListGetFilterOnDemand>?
        v3RecommendationsTopSearchListGetFilterOnDemand) {
  if (v3RecommendationsTopSearchListGetFilterOnDemand == null) {
    return [];
  }

  return v3RecommendationsTopSearchListGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.V3RecommendationsTopSearchListGetFilterOnDemand>
    v3RecommendationsTopSearchListGetFilterOnDemandListFromJson(
  List? v3RecommendationsTopSearchListGetFilterOnDemand, [
  List<enums.V3RecommendationsTopSearchListGetFilterOnDemand>? defaultValue,
]) {
  if (v3RecommendationsTopSearchListGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsTopSearchListGetFilterOnDemand
      .map((e) =>
          v3RecommendationsTopSearchListGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsTopSearchListGetFilterOnDemand>?
    v3RecommendationsTopSearchListGetFilterOnDemandNullableListFromJson(
  List? v3RecommendationsTopSearchListGetFilterOnDemand, [
  List<enums.V3RecommendationsTopSearchListGetFilterOnDemand>? defaultValue,
]) {
  if (v3RecommendationsTopSearchListGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3RecommendationsTopSearchListGetFilterOnDemand
      .map((e) =>
          v3RecommendationsTopSearchListGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsCollaborativeGetResourceContentSourceIdToJson(
    enums.V3RecommendationsCollaborativeGetResourceContentSourceId?
        v3RecommendationsCollaborativeGetResourceContentSourceId) {
  return v3RecommendationsCollaborativeGetResourceContentSourceId?.value;
}

enums.V3RecommendationsCollaborativeGetResourceContentSourceId
    v3RecommendationsCollaborativeGetResourceContentSourceIdFromJson(
  Object? v3RecommendationsCollaborativeGetResourceContentSourceId, [
  enums.V3RecommendationsCollaborativeGetResourceContentSourceId? defaultValue,
]) {
  return enums.V3RecommendationsCollaborativeGetResourceContentSourceId.values
          .firstWhereOrNull((e) =>
              e.value ==
              v3RecommendationsCollaborativeGetResourceContentSourceId) ??
      defaultValue ??
      enums.V3RecommendationsCollaborativeGetResourceContentSourceId
          .swaggerGeneratedUnknown;
}

List<String> v3RecommendationsCollaborativeGetResourceContentSourceIdListToJson(
    List<enums.V3RecommendationsCollaborativeGetResourceContentSourceId>?
        v3RecommendationsCollaborativeGetResourceContentSourceId) {
  if (v3RecommendationsCollaborativeGetResourceContentSourceId == null) {
    return [];
  }

  return v3RecommendationsCollaborativeGetResourceContentSourceId
      .map((e) => e.value!)
      .toList();
}

List<enums.V3RecommendationsCollaborativeGetResourceContentSourceId>
    v3RecommendationsCollaborativeGetResourceContentSourceIdListFromJson(
  List? v3RecommendationsCollaborativeGetResourceContentSourceId, [
  List<enums.V3RecommendationsCollaborativeGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v3RecommendationsCollaborativeGetResourceContentSourceId == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsCollaborativeGetResourceContentSourceId
      .map((e) =>
          v3RecommendationsCollaborativeGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

List<enums.V3RecommendationsCollaborativeGetResourceContentSourceId>?
    v3RecommendationsCollaborativeGetResourceContentSourceIdNullableListFromJson(
  List? v3RecommendationsCollaborativeGetResourceContentSourceId, [
  List<enums.V3RecommendationsCollaborativeGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v3RecommendationsCollaborativeGetResourceContentSourceId == null) {
    return defaultValue;
  }

  return v3RecommendationsCollaborativeGetResourceContentSourceId
      .map((e) =>
          v3RecommendationsCollaborativeGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

String? v3RecommendationsCollaborativeGetMaxResToJson(
    enums.V3RecommendationsCollaborativeGetMaxRes?
        v3RecommendationsCollaborativeGetMaxRes) {
  return v3RecommendationsCollaborativeGetMaxRes?.value;
}

enums.V3RecommendationsCollaborativeGetMaxRes
    v3RecommendationsCollaborativeGetMaxResFromJson(
  Object? v3RecommendationsCollaborativeGetMaxRes, [
  enums.V3RecommendationsCollaborativeGetMaxRes? defaultValue,
]) {
  return enums.V3RecommendationsCollaborativeGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3RecommendationsCollaborativeGetMaxRes) ??
      defaultValue ??
      enums.V3RecommendationsCollaborativeGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3RecommendationsCollaborativeGetMaxResListToJson(
    List<enums.V3RecommendationsCollaborativeGetMaxRes>?
        v3RecommendationsCollaborativeGetMaxRes) {
  if (v3RecommendationsCollaborativeGetMaxRes == null) {
    return [];
  }

  return v3RecommendationsCollaborativeGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3RecommendationsCollaborativeGetMaxRes>
    v3RecommendationsCollaborativeGetMaxResListFromJson(
  List? v3RecommendationsCollaborativeGetMaxRes, [
  List<enums.V3RecommendationsCollaborativeGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsCollaborativeGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsCollaborativeGetMaxRes
      .map((e) => v3RecommendationsCollaborativeGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsCollaborativeGetMaxRes>?
    v3RecommendationsCollaborativeGetMaxResNullableListFromJson(
  List? v3RecommendationsCollaborativeGetMaxRes, [
  List<enums.V3RecommendationsCollaborativeGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsCollaborativeGetMaxRes == null) {
    return defaultValue;
  }

  return v3RecommendationsCollaborativeGetMaxRes
      .map((e) => v3RecommendationsCollaborativeGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsCollaborativeGetFilterOnDemandToJson(
    enums.V3RecommendationsCollaborativeGetFilterOnDemand?
        v3RecommendationsCollaborativeGetFilterOnDemand) {
  return v3RecommendationsCollaborativeGetFilterOnDemand?.value;
}

enums.V3RecommendationsCollaborativeGetFilterOnDemand
    v3RecommendationsCollaborativeGetFilterOnDemandFromJson(
  Object? v3RecommendationsCollaborativeGetFilterOnDemand, [
  enums.V3RecommendationsCollaborativeGetFilterOnDemand? defaultValue,
]) {
  return enums.V3RecommendationsCollaborativeGetFilterOnDemand.values
          .firstWhereOrNull((e) =>
              e.value == v3RecommendationsCollaborativeGetFilterOnDemand) ??
      defaultValue ??
      enums.V3RecommendationsCollaborativeGetFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String> v3RecommendationsCollaborativeGetFilterOnDemandListToJson(
    List<enums.V3RecommendationsCollaborativeGetFilterOnDemand>?
        v3RecommendationsCollaborativeGetFilterOnDemand) {
  if (v3RecommendationsCollaborativeGetFilterOnDemand == null) {
    return [];
  }

  return v3RecommendationsCollaborativeGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.V3RecommendationsCollaborativeGetFilterOnDemand>
    v3RecommendationsCollaborativeGetFilterOnDemandListFromJson(
  List? v3RecommendationsCollaborativeGetFilterOnDemand, [
  List<enums.V3RecommendationsCollaborativeGetFilterOnDemand>? defaultValue,
]) {
  if (v3RecommendationsCollaborativeGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsCollaborativeGetFilterOnDemand
      .map((e) =>
          v3RecommendationsCollaborativeGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsCollaborativeGetFilterOnDemand>?
    v3RecommendationsCollaborativeGetFilterOnDemandNullableListFromJson(
  List? v3RecommendationsCollaborativeGetFilterOnDemand, [
  List<enums.V3RecommendationsCollaborativeGetFilterOnDemand>? defaultValue,
]) {
  if (v3RecommendationsCollaborativeGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3RecommendationsCollaborativeGetFilterOnDemand
      .map((e) =>
          v3RecommendationsCollaborativeGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3RecommendationsProfileGetMaxResToJson(
    enums.V3RecommendationsProfileGetMaxRes?
        v3RecommendationsProfileGetMaxRes) {
  return v3RecommendationsProfileGetMaxRes?.value;
}

enums.V3RecommendationsProfileGetMaxRes
    v3RecommendationsProfileGetMaxResFromJson(
  Object? v3RecommendationsProfileGetMaxRes, [
  enums.V3RecommendationsProfileGetMaxRes? defaultValue,
]) {
  return enums.V3RecommendationsProfileGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3RecommendationsProfileGetMaxRes) ??
      defaultValue ??
      enums.V3RecommendationsProfileGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3RecommendationsProfileGetMaxResListToJson(
    List<enums.V3RecommendationsProfileGetMaxRes>?
        v3RecommendationsProfileGetMaxRes) {
  if (v3RecommendationsProfileGetMaxRes == null) {
    return [];
  }

  return v3RecommendationsProfileGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3RecommendationsProfileGetMaxRes>
    v3RecommendationsProfileGetMaxResListFromJson(
  List? v3RecommendationsProfileGetMaxRes, [
  List<enums.V3RecommendationsProfileGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsProfileGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3RecommendationsProfileGetMaxRes
      .map((e) => v3RecommendationsProfileGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3RecommendationsProfileGetMaxRes>?
    v3RecommendationsProfileGetMaxResNullableListFromJson(
  List? v3RecommendationsProfileGetMaxRes, [
  List<enums.V3RecommendationsProfileGetMaxRes>? defaultValue,
]) {
  if (v3RecommendationsProfileGetMaxRes == null) {
    return defaultValue;
  }

  return v3RecommendationsProfileGetMaxRes
      .map((e) => v3RecommendationsProfileGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2SearchContentsGetMaxResToJson(
    enums.V2SearchContentsGetMaxRes? v2SearchContentsGetMaxRes) {
  return v2SearchContentsGetMaxRes?.value;
}

enums.V2SearchContentsGetMaxRes v2SearchContentsGetMaxResFromJson(
  Object? v2SearchContentsGetMaxRes, [
  enums.V2SearchContentsGetMaxRes? defaultValue,
]) {
  return enums.V2SearchContentsGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2SearchContentsGetMaxRes) ??
      defaultValue ??
      enums.V2SearchContentsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2SearchContentsGetMaxResListToJson(
    List<enums.V2SearchContentsGetMaxRes>? v2SearchContentsGetMaxRes) {
  if (v2SearchContentsGetMaxRes == null) {
    return [];
  }

  return v2SearchContentsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2SearchContentsGetMaxRes> v2SearchContentsGetMaxResListFromJson(
  List? v2SearchContentsGetMaxRes, [
  List<enums.V2SearchContentsGetMaxRes>? defaultValue,
]) {
  if (v2SearchContentsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2SearchContentsGetMaxRes
      .map((e) => v2SearchContentsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2SearchContentsGetMaxRes>?
    v2SearchContentsGetMaxResNullableListFromJson(
  List? v2SearchContentsGetMaxRes, [
  List<enums.V2SearchContentsGetMaxRes>? defaultValue,
]) {
  if (v2SearchContentsGetMaxRes == null) {
    return defaultValue;
  }

  return v2SearchContentsGetMaxRes
      .map((e) => v2SearchContentsGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2SearchContentsAnonymousGetMaxResToJson(
    enums.V2SearchContentsAnonymousGetMaxRes?
        v2SearchContentsAnonymousGetMaxRes) {
  return v2SearchContentsAnonymousGetMaxRes?.value;
}

enums.V2SearchContentsAnonymousGetMaxRes
    v2SearchContentsAnonymousGetMaxResFromJson(
  Object? v2SearchContentsAnonymousGetMaxRes, [
  enums.V2SearchContentsAnonymousGetMaxRes? defaultValue,
]) {
  return enums.V2SearchContentsAnonymousGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2SearchContentsAnonymousGetMaxRes) ??
      defaultValue ??
      enums.V2SearchContentsAnonymousGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2SearchContentsAnonymousGetMaxResListToJson(
    List<enums.V2SearchContentsAnonymousGetMaxRes>?
        v2SearchContentsAnonymousGetMaxRes) {
  if (v2SearchContentsAnonymousGetMaxRes == null) {
    return [];
  }

  return v2SearchContentsAnonymousGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2SearchContentsAnonymousGetMaxRes>
    v2SearchContentsAnonymousGetMaxResListFromJson(
  List? v2SearchContentsAnonymousGetMaxRes, [
  List<enums.V2SearchContentsAnonymousGetMaxRes>? defaultValue,
]) {
  if (v2SearchContentsAnonymousGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2SearchContentsAnonymousGetMaxRes
      .map((e) => v2SearchContentsAnonymousGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2SearchContentsAnonymousGetMaxRes>?
    v2SearchContentsAnonymousGetMaxResNullableListFromJson(
  List? v2SearchContentsAnonymousGetMaxRes, [
  List<enums.V2SearchContentsAnonymousGetMaxRes>? defaultValue,
]) {
  if (v2SearchContentsAnonymousGetMaxRes == null) {
    return defaultValue;
  }

  return v2SearchContentsAnonymousGetMaxRes
      .map((e) => v2SearchContentsAnonymousGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2SearchVoicePostMaxResToJson(
    enums.V2SearchVoicePostMaxRes? v2SearchVoicePostMaxRes) {
  return v2SearchVoicePostMaxRes?.value;
}

enums.V2SearchVoicePostMaxRes v2SearchVoicePostMaxResFromJson(
  Object? v2SearchVoicePostMaxRes, [
  enums.V2SearchVoicePostMaxRes? defaultValue,
]) {
  return enums.V2SearchVoicePostMaxRes.values
          .firstWhereOrNull((e) => e.value == v2SearchVoicePostMaxRes) ??
      defaultValue ??
      enums.V2SearchVoicePostMaxRes.swaggerGeneratedUnknown;
}

List<String> v2SearchVoicePostMaxResListToJson(
    List<enums.V2SearchVoicePostMaxRes>? v2SearchVoicePostMaxRes) {
  if (v2SearchVoicePostMaxRes == null) {
    return [];
  }

  return v2SearchVoicePostMaxRes.map((e) => e.value!).toList();
}

List<enums.V2SearchVoicePostMaxRes> v2SearchVoicePostMaxResListFromJson(
  List? v2SearchVoicePostMaxRes, [
  List<enums.V2SearchVoicePostMaxRes>? defaultValue,
]) {
  if (v2SearchVoicePostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2SearchVoicePostMaxRes
      .map((e) => v2SearchVoicePostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2SearchVoicePostMaxRes>?
    v2SearchVoicePostMaxResNullableListFromJson(
  List? v2SearchVoicePostMaxRes, [
  List<enums.V2SearchVoicePostMaxRes>? defaultValue,
]) {
  if (v2SearchVoicePostMaxRes == null) {
    return defaultValue;
  }

  return v2SearchVoicePostMaxRes
      .map((e) => v2SearchVoicePostMaxResFromJson(e.toString()))
      .toList();
}

String? v2SearchVoiceAnonymousPostMaxResToJson(
    enums.V2SearchVoiceAnonymousPostMaxRes? v2SearchVoiceAnonymousPostMaxRes) {
  return v2SearchVoiceAnonymousPostMaxRes?.value;
}

enums.V2SearchVoiceAnonymousPostMaxRes v2SearchVoiceAnonymousPostMaxResFromJson(
  Object? v2SearchVoiceAnonymousPostMaxRes, [
  enums.V2SearchVoiceAnonymousPostMaxRes? defaultValue,
]) {
  return enums.V2SearchVoiceAnonymousPostMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2SearchVoiceAnonymousPostMaxRes) ??
      defaultValue ??
      enums.V2SearchVoiceAnonymousPostMaxRes.swaggerGeneratedUnknown;
}

List<String> v2SearchVoiceAnonymousPostMaxResListToJson(
    List<enums.V2SearchVoiceAnonymousPostMaxRes>?
        v2SearchVoiceAnonymousPostMaxRes) {
  if (v2SearchVoiceAnonymousPostMaxRes == null) {
    return [];
  }

  return v2SearchVoiceAnonymousPostMaxRes.map((e) => e.value!).toList();
}

List<enums.V2SearchVoiceAnonymousPostMaxRes>
    v2SearchVoiceAnonymousPostMaxResListFromJson(
  List? v2SearchVoiceAnonymousPostMaxRes, [
  List<enums.V2SearchVoiceAnonymousPostMaxRes>? defaultValue,
]) {
  if (v2SearchVoiceAnonymousPostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2SearchVoiceAnonymousPostMaxRes
      .map((e) => v2SearchVoiceAnonymousPostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2SearchVoiceAnonymousPostMaxRes>?
    v2SearchVoiceAnonymousPostMaxResNullableListFromJson(
  List? v2SearchVoiceAnonymousPostMaxRes, [
  List<enums.V2SearchVoiceAnonymousPostMaxRes>? defaultValue,
]) {
  if (v2SearchVoiceAnonymousPostMaxRes == null) {
    return defaultValue;
  }

  return v2SearchVoiceAnonymousPostMaxRes
      .map((e) => v2SearchVoiceAnonymousPostMaxResFromJson(e.toString()))
      .toList();
}

String? v3SearchContentsGetMaxResToJson(
    enums.V3SearchContentsGetMaxRes? v3SearchContentsGetMaxRes) {
  return v3SearchContentsGetMaxRes?.value;
}

enums.V3SearchContentsGetMaxRes v3SearchContentsGetMaxResFromJson(
  Object? v3SearchContentsGetMaxRes, [
  enums.V3SearchContentsGetMaxRes? defaultValue,
]) {
  return enums.V3SearchContentsGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3SearchContentsGetMaxRes) ??
      defaultValue ??
      enums.V3SearchContentsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3SearchContentsGetMaxResListToJson(
    List<enums.V3SearchContentsGetMaxRes>? v3SearchContentsGetMaxRes) {
  if (v3SearchContentsGetMaxRes == null) {
    return [];
  }

  return v3SearchContentsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3SearchContentsGetMaxRes> v3SearchContentsGetMaxResListFromJson(
  List? v3SearchContentsGetMaxRes, [
  List<enums.V3SearchContentsGetMaxRes>? defaultValue,
]) {
  if (v3SearchContentsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3SearchContentsGetMaxRes
      .map((e) => v3SearchContentsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3SearchContentsGetMaxRes>?
    v3SearchContentsGetMaxResNullableListFromJson(
  List? v3SearchContentsGetMaxRes, [
  List<enums.V3SearchContentsGetMaxRes>? defaultValue,
]) {
  if (v3SearchContentsGetMaxRes == null) {
    return defaultValue;
  }

  return v3SearchContentsGetMaxRes
      .map((e) => v3SearchContentsGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3SearchContentsGetFilterOnDemandToJson(
    enums.V3SearchContentsGetFilterOnDemand?
        v3SearchContentsGetFilterOnDemand) {
  return v3SearchContentsGetFilterOnDemand?.value;
}

enums.V3SearchContentsGetFilterOnDemand
    v3SearchContentsGetFilterOnDemandFromJson(
  Object? v3SearchContentsGetFilterOnDemand, [
  enums.V3SearchContentsGetFilterOnDemand? defaultValue,
]) {
  return enums.V3SearchContentsGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3SearchContentsGetFilterOnDemand) ??
      defaultValue ??
      enums.V3SearchContentsGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3SearchContentsGetFilterOnDemandListToJson(
    List<enums.V3SearchContentsGetFilterOnDemand>?
        v3SearchContentsGetFilterOnDemand) {
  if (v3SearchContentsGetFilterOnDemand == null) {
    return [];
  }

  return v3SearchContentsGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3SearchContentsGetFilterOnDemand>
    v3SearchContentsGetFilterOnDemandListFromJson(
  List? v3SearchContentsGetFilterOnDemand, [
  List<enums.V3SearchContentsGetFilterOnDemand>? defaultValue,
]) {
  if (v3SearchContentsGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3SearchContentsGetFilterOnDemand
      .map((e) => v3SearchContentsGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3SearchContentsGetFilterOnDemand>?
    v3SearchContentsGetFilterOnDemandNullableListFromJson(
  List? v3SearchContentsGetFilterOnDemand, [
  List<enums.V3SearchContentsGetFilterOnDemand>? defaultValue,
]) {
  if (v3SearchContentsGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3SearchContentsGetFilterOnDemand
      .map((e) => v3SearchContentsGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3SearchContentsAnonymousGetMaxResToJson(
    enums.V3SearchContentsAnonymousGetMaxRes?
        v3SearchContentsAnonymousGetMaxRes) {
  return v3SearchContentsAnonymousGetMaxRes?.value;
}

enums.V3SearchContentsAnonymousGetMaxRes
    v3SearchContentsAnonymousGetMaxResFromJson(
  Object? v3SearchContentsAnonymousGetMaxRes, [
  enums.V3SearchContentsAnonymousGetMaxRes? defaultValue,
]) {
  return enums.V3SearchContentsAnonymousGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3SearchContentsAnonymousGetMaxRes) ??
      defaultValue ??
      enums.V3SearchContentsAnonymousGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3SearchContentsAnonymousGetMaxResListToJson(
    List<enums.V3SearchContentsAnonymousGetMaxRes>?
        v3SearchContentsAnonymousGetMaxRes) {
  if (v3SearchContentsAnonymousGetMaxRes == null) {
    return [];
  }

  return v3SearchContentsAnonymousGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3SearchContentsAnonymousGetMaxRes>
    v3SearchContentsAnonymousGetMaxResListFromJson(
  List? v3SearchContentsAnonymousGetMaxRes, [
  List<enums.V3SearchContentsAnonymousGetMaxRes>? defaultValue,
]) {
  if (v3SearchContentsAnonymousGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3SearchContentsAnonymousGetMaxRes
      .map((e) => v3SearchContentsAnonymousGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3SearchContentsAnonymousGetMaxRes>?
    v3SearchContentsAnonymousGetMaxResNullableListFromJson(
  List? v3SearchContentsAnonymousGetMaxRes, [
  List<enums.V3SearchContentsAnonymousGetMaxRes>? defaultValue,
]) {
  if (v3SearchContentsAnonymousGetMaxRes == null) {
    return defaultValue;
  }

  return v3SearchContentsAnonymousGetMaxRes
      .map((e) => v3SearchContentsAnonymousGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3SearchVoicePostMaxResToJson(
    enums.V3SearchVoicePostMaxRes? v3SearchVoicePostMaxRes) {
  return v3SearchVoicePostMaxRes?.value;
}

enums.V3SearchVoicePostMaxRes v3SearchVoicePostMaxResFromJson(
  Object? v3SearchVoicePostMaxRes, [
  enums.V3SearchVoicePostMaxRes? defaultValue,
]) {
  return enums.V3SearchVoicePostMaxRes.values
          .firstWhereOrNull((e) => e.value == v3SearchVoicePostMaxRes) ??
      defaultValue ??
      enums.V3SearchVoicePostMaxRes.swaggerGeneratedUnknown;
}

List<String> v3SearchVoicePostMaxResListToJson(
    List<enums.V3SearchVoicePostMaxRes>? v3SearchVoicePostMaxRes) {
  if (v3SearchVoicePostMaxRes == null) {
    return [];
  }

  return v3SearchVoicePostMaxRes.map((e) => e.value!).toList();
}

List<enums.V3SearchVoicePostMaxRes> v3SearchVoicePostMaxResListFromJson(
  List? v3SearchVoicePostMaxRes, [
  List<enums.V3SearchVoicePostMaxRes>? defaultValue,
]) {
  if (v3SearchVoicePostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3SearchVoicePostMaxRes
      .map((e) => v3SearchVoicePostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3SearchVoicePostMaxRes>?
    v3SearchVoicePostMaxResNullableListFromJson(
  List? v3SearchVoicePostMaxRes, [
  List<enums.V3SearchVoicePostMaxRes>? defaultValue,
]) {
  if (v3SearchVoicePostMaxRes == null) {
    return defaultValue;
  }

  return v3SearchVoicePostMaxRes
      .map((e) => v3SearchVoicePostMaxResFromJson(e.toString()))
      .toList();
}

String? v3SearchVoicePostFilterOnDemandToJson(
    enums.V3SearchVoicePostFilterOnDemand? v3SearchVoicePostFilterOnDemand) {
  return v3SearchVoicePostFilterOnDemand?.value;
}

enums.V3SearchVoicePostFilterOnDemand v3SearchVoicePostFilterOnDemandFromJson(
  Object? v3SearchVoicePostFilterOnDemand, [
  enums.V3SearchVoicePostFilterOnDemand? defaultValue,
]) {
  return enums.V3SearchVoicePostFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3SearchVoicePostFilterOnDemand) ??
      defaultValue ??
      enums.V3SearchVoicePostFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3SearchVoicePostFilterOnDemandListToJson(
    List<enums.V3SearchVoicePostFilterOnDemand>?
        v3SearchVoicePostFilterOnDemand) {
  if (v3SearchVoicePostFilterOnDemand == null) {
    return [];
  }

  return v3SearchVoicePostFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3SearchVoicePostFilterOnDemand>
    v3SearchVoicePostFilterOnDemandListFromJson(
  List? v3SearchVoicePostFilterOnDemand, [
  List<enums.V3SearchVoicePostFilterOnDemand>? defaultValue,
]) {
  if (v3SearchVoicePostFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3SearchVoicePostFilterOnDemand
      .map((e) => v3SearchVoicePostFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3SearchVoicePostFilterOnDemand>?
    v3SearchVoicePostFilterOnDemandNullableListFromJson(
  List? v3SearchVoicePostFilterOnDemand, [
  List<enums.V3SearchVoicePostFilterOnDemand>? defaultValue,
]) {
  if (v3SearchVoicePostFilterOnDemand == null) {
    return defaultValue;
  }

  return v3SearchVoicePostFilterOnDemand
      .map((e) => v3SearchVoicePostFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3SearchVoiceAnonymousPostMaxResToJson(
    enums.V3SearchVoiceAnonymousPostMaxRes? v3SearchVoiceAnonymousPostMaxRes) {
  return v3SearchVoiceAnonymousPostMaxRes?.value;
}

enums.V3SearchVoiceAnonymousPostMaxRes v3SearchVoiceAnonymousPostMaxResFromJson(
  Object? v3SearchVoiceAnonymousPostMaxRes, [
  enums.V3SearchVoiceAnonymousPostMaxRes? defaultValue,
]) {
  return enums.V3SearchVoiceAnonymousPostMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3SearchVoiceAnonymousPostMaxRes) ??
      defaultValue ??
      enums.V3SearchVoiceAnonymousPostMaxRes.swaggerGeneratedUnknown;
}

List<String> v3SearchVoiceAnonymousPostMaxResListToJson(
    List<enums.V3SearchVoiceAnonymousPostMaxRes>?
        v3SearchVoiceAnonymousPostMaxRes) {
  if (v3SearchVoiceAnonymousPostMaxRes == null) {
    return [];
  }

  return v3SearchVoiceAnonymousPostMaxRes.map((e) => e.value!).toList();
}

List<enums.V3SearchVoiceAnonymousPostMaxRes>
    v3SearchVoiceAnonymousPostMaxResListFromJson(
  List? v3SearchVoiceAnonymousPostMaxRes, [
  List<enums.V3SearchVoiceAnonymousPostMaxRes>? defaultValue,
]) {
  if (v3SearchVoiceAnonymousPostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3SearchVoiceAnonymousPostMaxRes
      .map((e) => v3SearchVoiceAnonymousPostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3SearchVoiceAnonymousPostMaxRes>?
    v3SearchVoiceAnonymousPostMaxResNullableListFromJson(
  List? v3SearchVoiceAnonymousPostMaxRes, [
  List<enums.V3SearchVoiceAnonymousPostMaxRes>? defaultValue,
]) {
  if (v3SearchVoiceAnonymousPostMaxRes == null) {
    return defaultValue;
  }

  return v3SearchVoiceAnonymousPostMaxRes
      .map((e) => v3SearchVoiceAnonymousPostMaxResFromJson(e.toString()))
      .toList();
}

String? v3VoiceRecordPostMaxResToJson(
    enums.V3VoiceRecordPostMaxRes? v3VoiceRecordPostMaxRes) {
  return v3VoiceRecordPostMaxRes?.value;
}

enums.V3VoiceRecordPostMaxRes v3VoiceRecordPostMaxResFromJson(
  Object? v3VoiceRecordPostMaxRes, [
  enums.V3VoiceRecordPostMaxRes? defaultValue,
]) {
  return enums.V3VoiceRecordPostMaxRes.values
          .firstWhereOrNull((e) => e.value == v3VoiceRecordPostMaxRes) ??
      defaultValue ??
      enums.V3VoiceRecordPostMaxRes.swaggerGeneratedUnknown;
}

List<String> v3VoiceRecordPostMaxResListToJson(
    List<enums.V3VoiceRecordPostMaxRes>? v3VoiceRecordPostMaxRes) {
  if (v3VoiceRecordPostMaxRes == null) {
    return [];
  }

  return v3VoiceRecordPostMaxRes.map((e) => e.value!).toList();
}

List<enums.V3VoiceRecordPostMaxRes> v3VoiceRecordPostMaxResListFromJson(
  List? v3VoiceRecordPostMaxRes, [
  List<enums.V3VoiceRecordPostMaxRes>? defaultValue,
]) {
  if (v3VoiceRecordPostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3VoiceRecordPostMaxRes
      .map((e) => v3VoiceRecordPostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3VoiceRecordPostMaxRes>?
    v3VoiceRecordPostMaxResNullableListFromJson(
  List? v3VoiceRecordPostMaxRes, [
  List<enums.V3VoiceRecordPostMaxRes>? defaultValue,
]) {
  if (v3VoiceRecordPostMaxRes == null) {
    return defaultValue;
  }

  return v3VoiceRecordPostMaxRes
      .map((e) => v3VoiceRecordPostMaxResFromJson(e.toString()))
      .toList();
}

String? v3VoicePlayPostMaxResToJson(
    enums.V3VoicePlayPostMaxRes? v3VoicePlayPostMaxRes) {
  return v3VoicePlayPostMaxRes?.value;
}

enums.V3VoicePlayPostMaxRes v3VoicePlayPostMaxResFromJson(
  Object? v3VoicePlayPostMaxRes, [
  enums.V3VoicePlayPostMaxRes? defaultValue,
]) {
  return enums.V3VoicePlayPostMaxRes.values
          .firstWhereOrNull((e) => e.value == v3VoicePlayPostMaxRes) ??
      defaultValue ??
      enums.V3VoicePlayPostMaxRes.swaggerGeneratedUnknown;
}

List<String> v3VoicePlayPostMaxResListToJson(
    List<enums.V3VoicePlayPostMaxRes>? v3VoicePlayPostMaxRes) {
  if (v3VoicePlayPostMaxRes == null) {
    return [];
  }

  return v3VoicePlayPostMaxRes.map((e) => e.value!).toList();
}

List<enums.V3VoicePlayPostMaxRes> v3VoicePlayPostMaxResListFromJson(
  List? v3VoicePlayPostMaxRes, [
  List<enums.V3VoicePlayPostMaxRes>? defaultValue,
]) {
  if (v3VoicePlayPostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3VoicePlayPostMaxRes
      .map((e) => v3VoicePlayPostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3VoicePlayPostMaxRes>? v3VoicePlayPostMaxResNullableListFromJson(
  List? v3VoicePlayPostMaxRes, [
  List<enums.V3VoicePlayPostMaxRes>? defaultValue,
]) {
  if (v3VoicePlayPostMaxRes == null) {
    return defaultValue;
  }

  return v3VoicePlayPostMaxRes
      .map((e) => v3VoicePlayPostMaxResFromJson(e.toString()))
      .toList();
}

String? v1SearchContentsGetMaxResToJson(
    enums.V1SearchContentsGetMaxRes? v1SearchContentsGetMaxRes) {
  return v1SearchContentsGetMaxRes?.value;
}

enums.V1SearchContentsGetMaxRes v1SearchContentsGetMaxResFromJson(
  Object? v1SearchContentsGetMaxRes, [
  enums.V1SearchContentsGetMaxRes? defaultValue,
]) {
  return enums.V1SearchContentsGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v1SearchContentsGetMaxRes) ??
      defaultValue ??
      enums.V1SearchContentsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1SearchContentsGetMaxResListToJson(
    List<enums.V1SearchContentsGetMaxRes>? v1SearchContentsGetMaxRes) {
  if (v1SearchContentsGetMaxRes == null) {
    return [];
  }

  return v1SearchContentsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V1SearchContentsGetMaxRes> v1SearchContentsGetMaxResListFromJson(
  List? v1SearchContentsGetMaxRes, [
  List<enums.V1SearchContentsGetMaxRes>? defaultValue,
]) {
  if (v1SearchContentsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1SearchContentsGetMaxRes
      .map((e) => v1SearchContentsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1SearchContentsGetMaxRes>?
    v1SearchContentsGetMaxResNullableListFromJson(
  List? v1SearchContentsGetMaxRes, [
  List<enums.V1SearchContentsGetMaxRes>? defaultValue,
]) {
  if (v1SearchContentsGetMaxRes == null) {
    return defaultValue;
  }

  return v1SearchContentsGetMaxRes
      .map((e) => v1SearchContentsGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1SearchVoicePostMaxResToJson(
    enums.V1SearchVoicePostMaxRes? v1SearchVoicePostMaxRes) {
  return v1SearchVoicePostMaxRes?.value;
}

enums.V1SearchVoicePostMaxRes v1SearchVoicePostMaxResFromJson(
  Object? v1SearchVoicePostMaxRes, [
  enums.V1SearchVoicePostMaxRes? defaultValue,
]) {
  return enums.V1SearchVoicePostMaxRes.values
          .firstWhereOrNull((e) => e.value == v1SearchVoicePostMaxRes) ??
      defaultValue ??
      enums.V1SearchVoicePostMaxRes.swaggerGeneratedUnknown;
}

List<String> v1SearchVoicePostMaxResListToJson(
    List<enums.V1SearchVoicePostMaxRes>? v1SearchVoicePostMaxRes) {
  if (v1SearchVoicePostMaxRes == null) {
    return [];
  }

  return v1SearchVoicePostMaxRes.map((e) => e.value!).toList();
}

List<enums.V1SearchVoicePostMaxRes> v1SearchVoicePostMaxResListFromJson(
  List? v1SearchVoicePostMaxRes, [
  List<enums.V1SearchVoicePostMaxRes>? defaultValue,
]) {
  if (v1SearchVoicePostMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1SearchVoicePostMaxRes
      .map((e) => v1SearchVoicePostMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1SearchVoicePostMaxRes>?
    v1SearchVoicePostMaxResNullableListFromJson(
  List? v1SearchVoicePostMaxRes, [
  List<enums.V1SearchVoicePostMaxRes>? defaultValue,
]) {
  if (v1SearchVoicePostMaxRes == null) {
    return defaultValue;
  }

  return v1SearchVoicePostMaxRes
      .map((e) => v1SearchVoicePostMaxResFromJson(e.toString()))
      .toList();
}

String? v1RecommendationsMoreLikeThisGetResourceContentSourceIdToJson(
    enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId?
        v1RecommendationsMoreLikeThisGetResourceContentSourceId) {
  return v1RecommendationsMoreLikeThisGetResourceContentSourceId?.value;
}

enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId
    v1RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
  Object? v1RecommendationsMoreLikeThisGetResourceContentSourceId, [
  enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId? defaultValue,
]) {
  return enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId.values
          .firstWhereOrNull((e) =>
              e.value ==
              v1RecommendationsMoreLikeThisGetResourceContentSourceId) ??
      defaultValue ??
      enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId
          .swaggerGeneratedUnknown;
}

List<String> v1RecommendationsMoreLikeThisGetResourceContentSourceIdListToJson(
    List<enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId>?
        v1RecommendationsMoreLikeThisGetResourceContentSourceId) {
  if (v1RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return [];
  }

  return v1RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) => e.value!)
      .toList();
}

List<enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId>
    v1RecommendationsMoreLikeThisGetResourceContentSourceIdListFromJson(
  List? v1RecommendationsMoreLikeThisGetResourceContentSourceId, [
  List<enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v1RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return defaultValue ?? [];
  }

  return v1RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) =>
          v1RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

List<enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId>?
    v1RecommendationsMoreLikeThisGetResourceContentSourceIdNullableListFromJson(
  List? v1RecommendationsMoreLikeThisGetResourceContentSourceId, [
  List<enums.V1RecommendationsMoreLikeThisGetResourceContentSourceId>?
      defaultValue,
]) {
  if (v1RecommendationsMoreLikeThisGetResourceContentSourceId == null) {
    return defaultValue;
  }

  return v1RecommendationsMoreLikeThisGetResourceContentSourceId
      .map((e) =>
          v1RecommendationsMoreLikeThisGetResourceContentSourceIdFromJson(
              e.toString()))
      .toList();
}

int? learnAction$RequestBodyContentSourceIdToJson(
    enums.LearnAction$RequestBodyContentSourceId?
        learnAction$RequestBodyContentSourceId) {
  return learnAction$RequestBodyContentSourceId?.value;
}

enums.LearnAction$RequestBodyContentSourceId
    learnAction$RequestBodyContentSourceIdFromJson(
  Object? learnAction$RequestBodyContentSourceId, [
  enums.LearnAction$RequestBodyContentSourceId? defaultValue,
]) {
  return enums.LearnAction$RequestBodyContentSourceId.values.firstWhereOrNull(
          (e) => e.value == learnAction$RequestBodyContentSourceId) ??
      defaultValue ??
      enums.LearnAction$RequestBodyContentSourceId.swaggerGeneratedUnknown;
}

List<int> learnAction$RequestBodyContentSourceIdListToJson(
    List<enums.LearnAction$RequestBodyContentSourceId>?
        learnAction$RequestBodyContentSourceId) {
  if (learnAction$RequestBodyContentSourceId == null) {
    return [];
  }

  return learnAction$RequestBodyContentSourceId.map((e) => e.value!).toList();
}

List<enums.LearnAction$RequestBodyContentSourceId>
    learnAction$RequestBodyContentSourceIdListFromJson(
  List? learnAction$RequestBodyContentSourceId, [
  List<enums.LearnAction$RequestBodyContentSourceId>? defaultValue,
]) {
  if (learnAction$RequestBodyContentSourceId == null) {
    return defaultValue ?? [];
  }

  return learnAction$RequestBodyContentSourceId
      .map((e) => learnAction$RequestBodyContentSourceIdFromJson(e.toString()))
      .toList();
}

List<enums.LearnAction$RequestBodyContentSourceId>?
    learnAction$RequestBodyContentSourceIdNullableListFromJson(
  List? learnAction$RequestBodyContentSourceId, [
  List<enums.LearnAction$RequestBodyContentSourceId>? defaultValue,
]) {
  if (learnAction$RequestBodyContentSourceId == null) {
    return defaultValue;
  }

  return learnAction$RequestBodyContentSourceId
      .map((e) => learnAction$RequestBodyContentSourceIdFromJson(e.toString()))
      .toList();
}

int? learnAction$RequestBodyActionIdToJson(
    enums.LearnAction$RequestBodyActionId? learnAction$RequestBodyActionId) {
  return learnAction$RequestBodyActionId?.value;
}

enums.LearnAction$RequestBodyActionId learnAction$RequestBodyActionIdFromJson(
  Object? learnAction$RequestBodyActionId, [
  enums.LearnAction$RequestBodyActionId? defaultValue,
]) {
  return enums.LearnAction$RequestBodyActionId.values.firstWhereOrNull(
          (e) => e.value == learnAction$RequestBodyActionId) ??
      defaultValue ??
      enums.LearnAction$RequestBodyActionId.swaggerGeneratedUnknown;
}

List<int> learnAction$RequestBodyActionIdListToJson(
    List<enums.LearnAction$RequestBodyActionId>?
        learnAction$RequestBodyActionId) {
  if (learnAction$RequestBodyActionId == null) {
    return [];
  }

  return learnAction$RequestBodyActionId.map((e) => e.value!).toList();
}

List<enums.LearnAction$RequestBodyActionId>
    learnAction$RequestBodyActionIdListFromJson(
  List? learnAction$RequestBodyActionId, [
  List<enums.LearnAction$RequestBodyActionId>? defaultValue,
]) {
  if (learnAction$RequestBodyActionId == null) {
    return defaultValue ?? [];
  }

  return learnAction$RequestBodyActionId
      .map((e) => learnAction$RequestBodyActionIdFromJson(e.toString()))
      .toList();
}

List<enums.LearnAction$RequestBodyActionId>?
    learnAction$RequestBodyActionIdNullableListFromJson(
  List? learnAction$RequestBodyActionId, [
  List<enums.LearnAction$RequestBodyActionId>? defaultValue,
]) {
  if (learnAction$RequestBodyActionId == null) {
    return defaultValue;
  }

  return learnAction$RequestBodyActionId
      .map((e) => learnAction$RequestBodyActionIdFromJson(e.toString()))
      .toList();
}

String? learnActionV1$RequestBodyContentSourceIdToJson(
    enums.LearnActionV1$RequestBodyContentSourceId?
        learnActionV1$RequestBodyContentSourceId) {
  return learnActionV1$RequestBodyContentSourceId?.value;
}

enums.LearnActionV1$RequestBodyContentSourceId
    learnActionV1$RequestBodyContentSourceIdFromJson(
  Object? learnActionV1$RequestBodyContentSourceId, [
  enums.LearnActionV1$RequestBodyContentSourceId? defaultValue,
]) {
  return enums.LearnActionV1$RequestBodyContentSourceId.values.firstWhereOrNull(
          (e) => e.value == learnActionV1$RequestBodyContentSourceId) ??
      defaultValue ??
      enums.LearnActionV1$RequestBodyContentSourceId.swaggerGeneratedUnknown;
}

List<String> learnActionV1$RequestBodyContentSourceIdListToJson(
    List<enums.LearnActionV1$RequestBodyContentSourceId>?
        learnActionV1$RequestBodyContentSourceId) {
  if (learnActionV1$RequestBodyContentSourceId == null) {
    return [];
  }

  return learnActionV1$RequestBodyContentSourceId.map((e) => e.value!).toList();
}

List<enums.LearnActionV1$RequestBodyContentSourceId>
    learnActionV1$RequestBodyContentSourceIdListFromJson(
  List? learnActionV1$RequestBodyContentSourceId, [
  List<enums.LearnActionV1$RequestBodyContentSourceId>? defaultValue,
]) {
  if (learnActionV1$RequestBodyContentSourceId == null) {
    return defaultValue ?? [];
  }

  return learnActionV1$RequestBodyContentSourceId
      .map(
          (e) => learnActionV1$RequestBodyContentSourceIdFromJson(e.toString()))
      .toList();
}

List<enums.LearnActionV1$RequestBodyContentSourceId>?
    learnActionV1$RequestBodyContentSourceIdNullableListFromJson(
  List? learnActionV1$RequestBodyContentSourceId, [
  List<enums.LearnActionV1$RequestBodyContentSourceId>? defaultValue,
]) {
  if (learnActionV1$RequestBodyContentSourceId == null) {
    return defaultValue;
  }

  return learnActionV1$RequestBodyContentSourceId
      .map(
          (e) => learnActionV1$RequestBodyContentSourceIdFromJson(e.toString()))
      .toList();
}

int? learnActionV1$RequestBodyActionIdToJson(
    enums.LearnActionV1$RequestBodyActionId?
        learnActionV1$RequestBodyActionId) {
  return learnActionV1$RequestBodyActionId?.value;
}

enums.LearnActionV1$RequestBodyActionId
    learnActionV1$RequestBodyActionIdFromJson(
  Object? learnActionV1$RequestBodyActionId, [
  enums.LearnActionV1$RequestBodyActionId? defaultValue,
]) {
  return enums.LearnActionV1$RequestBodyActionId.values.firstWhereOrNull(
          (e) => e.value == learnActionV1$RequestBodyActionId) ??
      defaultValue ??
      enums.LearnActionV1$RequestBodyActionId.swaggerGeneratedUnknown;
}

List<int> learnActionV1$RequestBodyActionIdListToJson(
    List<enums.LearnActionV1$RequestBodyActionId>?
        learnActionV1$RequestBodyActionId) {
  if (learnActionV1$RequestBodyActionId == null) {
    return [];
  }

  return learnActionV1$RequestBodyActionId.map((e) => e.value!).toList();
}

List<enums.LearnActionV1$RequestBodyActionId>
    learnActionV1$RequestBodyActionIdListFromJson(
  List? learnActionV1$RequestBodyActionId, [
  List<enums.LearnActionV1$RequestBodyActionId>? defaultValue,
]) {
  if (learnActionV1$RequestBodyActionId == null) {
    return defaultValue ?? [];
  }

  return learnActionV1$RequestBodyActionId
      .map((e) => learnActionV1$RequestBodyActionIdFromJson(e.toString()))
      .toList();
}

List<enums.LearnActionV1$RequestBodyActionId>?
    learnActionV1$RequestBodyActionIdNullableListFromJson(
  List? learnActionV1$RequestBodyActionId, [
  List<enums.LearnActionV1$RequestBodyActionId>? defaultValue,
]) {
  if (learnActionV1$RequestBodyActionId == null) {
    return defaultValue;
  }

  return learnActionV1$RequestBodyActionId
      .map((e) => learnActionV1$RequestBodyActionIdFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
