// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'one_catalog_service.enums.swagger.dart' as enums;
export 'one_catalog_service.enums.swagger.dart';

part 'one_catalog_service.swagger.chopper.dart';
part 'one_catalog_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class OneCatalogService extends ChopperService {
  static OneCatalogService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$OneCatalogService(client);
    }

    final newClient = ChopperClient(
        services: [_$OneCatalogService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$OneCatalogService(newClient);
  }

  ///Returns programs for which an active TVOD rental exists.
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param count The maximum number of items to return
  ///@param filter Comma separated list of filters. The following values are allowed: nonAdult, adult, downloadable, viewableOnCpe
  ///@param x-dev Device ID
  ///@param x-entitlements-token Entitlement Token
  Future<chopper.Response<FeedComposerResponseForPurchasedProgram>>
      feedComposerV1PurchasedItemsGet({
    String? brandingProviderId,
    enums.FeedComposerV1PurchasedItemsGetEncoding? encoding,
    enums.FeedComposerV1PurchasedItemsGetMaxRes? maxRes,
    required int? count,
    String? filter,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseForPurchasedProgram,
        () => FeedComposerResponseForPurchasedProgram.fromJsonFactory);

    return _feedComposerV1PurchasedItemsGet(
        brandingProviderId: brandingProviderId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        count: count,
        filter: filter,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Returns programs for which an active TVOD rental exists.
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param count The maximum number of items to return
  ///@param filter Comma separated list of filters. The following values are allowed: nonAdult, adult, downloadable, viewableOnCpe
  ///@param x-dev Device ID
  ///@param x-entitlements-token Entitlement Token
  @Get(path: '/feed-composer/v1/purchased-items')
  Future<chopper.Response<FeedComposerResponseForPurchasedProgram>>
      _feedComposerV1PurchasedItemsGet({
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('count')
        required int? count,
    @Query('filter')
        String? filter,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Returns the programs on the requested top list.
  ///@param topListId The id of the toplist
  ///@param count The maximum number of items to return
  ///@param brandingProviderId The (optional) id of the vod branding provider or replay provider whose content should be considered exclusively
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param excludeExternalProviders List of brandingProviderIds to exclude their contents
  ///@param cityId City Identifier of the user.
  Future<chopper.Response<FeedComposerResponse>>
      feedComposerV1TopListTopListIdGet({
    required String? topListId,
    required int? count,
    String? brandingProviderId,
    enums.FeedComposerV1TopListTopListIdGetEncoding? encoding,
    enums.FeedComposerV1TopListTopListIdGetMaxRes? maxRes,
    String? excludeExternalProviders,
    String? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _feedComposerV1TopListTopListIdGet(
        topListId: topListId,
        count: count,
        brandingProviderId: brandingProviderId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeExternalProviders: excludeExternalProviders,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Returns the programs on the requested top list.
  ///@param topListId The id of the toplist
  ///@param count The maximum number of items to return
  ///@param brandingProviderId The (optional) id of the vod branding provider or replay provider whose content should be considered exclusively
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param excludeExternalProviders List of brandingProviderIds to exclude their contents
  ///@param cityId City Identifier of the user.
  @Get(path: '/feed-composer/v1/top-list/{topListId}')
  Future<chopper.Response<FeedComposerResponse>>
      _feedComposerV1TopListTopListIdGet({
    @Path('topListId') required String? topListId,
    @Query('count') required int? count,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('encoding') String? encoding,
    @Query('maxRes') String? maxRes,
    @Query('excludeExternalProviders') String? excludeExternalProviders,
    @Query('cityId') String? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves the main menu (aka vodstructure)
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param fallbackRootId The root link to fallback to
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Structure>> v2VodstructureRootIdGet({
    required String? rootId,
    required String? language,
    String? fallbackRootId,
    enums.V2VodstructureRootIdGetEncoding? encoding,
    enums.V2VodstructureRootIdGetMaxRes? maxRes,
    bool? excludeAdult,
    enums.V2VodstructureRootIdGetFilterOnDemand? filterOnDemand,
    String? featureFlags,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Structure, () => Structure.fromJsonFactory);

    return _v2VodstructureRootIdGet(
        rootId: rootId,
        language: language,
        fallbackRootId: fallbackRootId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        filterOnDemand: filterOnDemand?.value?.toString(),
        featureFlags: featureFlags,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the main menu (aka vodstructure)
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param fallbackRootId The root link to fallback to
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/vodstructure/{rootId}')
  Future<chopper.Response<Structure>> _v2VodstructureRootIdGet({
    @Path('rootId')
        required String? rootId,
    @Query('language')
        required String? language,
    @Query('fallbackRootId')
        String? fallbackRootId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the contextual menu
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Screen>> v2ContextualvodRootIdGet({
    required String? rootId,
    required String? language,
    String? profileId,
    bool? optIn,
    bool? sharedProfile,
    enums.V2ContextualvodRootIdGetEncoding? encoding,
    enums.V2ContextualvodRootIdGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? excludeAdult,
    String? featureFlags,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Screen, () => Screen.fromJsonFactory);

    return _v2ContextualvodRootIdGet(
        rootId: rootId,
        language: language,
        profileId: profileId,
        optIn: optIn,
        sharedProfile: sharedProfile,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the contextual menu
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/contextualvod/{rootId}')
  Future<chopper.Response<Screen>> _v2ContextualvodRootIdGet({
    @Path('rootId')
        required String? rootId,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('optIn')
        bool? optIn,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the rented items
  ///@param language The two character language code
  ///@param pagingOffset The page offset value when paging is used
  ///@param pagingSize The page size when paging is used
  ///@param profileId The user selected profile id
  ///@param isAdult The user setting for adult content
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<RentalScreen>> v2RentalsGet({
    required String? language,
    String? pagingOffset,
    String? pagingSize,
    String? profileId,
    bool? isAdult,
    enums.V2RentalsGetEncoding? encoding,
    enums.V2RentalsGetMaxRes? maxRes,
    int? replayOptedInTime,
    bool? mergingOn,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RentalScreen, () => RentalScreen.fromJsonFactory);

    return _v2RentalsGet(
        language: language,
        pagingOffset: pagingOffset,
        pagingSize: pagingSize,
        profileId: profileId,
        isAdult: isAdult,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the rented items
  ///@param language The two character language code
  ///@param pagingOffset The page offset value when paging is used
  ///@param pagingSize The page size when paging is used
  ///@param profileId The user selected profile id
  ///@param isAdult The user setting for adult content
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/rentals')
  Future<chopper.Response<RentalScreen>> _v2RentalsGet({
    @Query('language')
        required String? language,
    @Query('pagingOffset')
        String? pagingOffset,
    @Query('pagingSize')
        String? pagingSize,
    @Query('profileId')
        String? profileId,
    @Query('isAdult')
        bool? isAdult,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves detailed info for an item
  ///@param crid The asset crid
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Map<String, dynamic>>> v2DetailscreenCridGet({
    required String? crid,
    required String? language,
    String? profileId,
    enums.V2DetailscreenCridGetEncoding? encoding,
    enums.V2DetailscreenCridGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    String? brandingProviderId,
    enums.V2DetailscreenCridGetFilterOnDemand? filterOnDemand,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _v2DetailscreenCridGet(
        crid: crid,
        language: language,
        profileId: profileId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        brandingProviderId: brandingProviderId,
        filterOnDemand: filterOnDemand?.value?.toString(),
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves detailed info for an item
  ///@param crid The asset crid
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/detailscreen/{crid}')
  Future<chopper.Response<Map<String, dynamic>>> _v2DetailscreenCridGet({
    @Path('crid')
        required String? crid,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Returns a list of instances of the given trailer crid
  ///@param trailerCrid The trailer asset crid
  ///@param language The two character language code
  ///@param profileId The user selected profile id, only for logging purposes
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param x-dev Device ID, only for logging purposes
  ///@param x-entitlements-token Token containing entitlements info, only for logging purposes
  Future<chopper.Response<TrailerInfo>> v2TrailerDetailsTrailerCridGet({
    required String? trailerCrid,
    required String? language,
    String? profileId,
    enums.V2TrailerDetailsTrailerCridGetEncoding? encoding,
    enums.V2TrailerDetailsTrailerCridGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TrailerInfo, () => TrailerInfo.fromJsonFactory);

    return _v2TrailerDetailsTrailerCridGet(
        trailerCrid: trailerCrid,
        language: language,
        profileId: profileId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Returns a list of instances of the given trailer crid
  ///@param trailerCrid The trailer asset crid
  ///@param language The two character language code
  ///@param profileId The user selected profile id, only for logging purposes
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param x-dev Device ID, only for logging purposes
  ///@param x-entitlements-token Token containing entitlements info, only for logging purposes
  @Get(path: '/v2/trailerDetails/{trailerCrid}')
  Future<chopper.Response<TrailerInfo>> _v2TrailerDetailsTrailerCridGet({
    @Path('trailerCrid')
        required String? trailerCrid,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the options for a grid screen
  ///@param crid The grid screen id
  ///@param language The two character language code
  ///@param genreCrid To indicate if GenreCategoryLink is configured
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<GridOptions>> v2GridoptionsCridGet({
    required String? crid,
    required String? language,
    bool? genreCrid,
    enums.V2GridoptionsCridGetEncoding? encoding,
    enums.V2GridoptionsCridGetMaxRes? maxRes,
    String? cityId,
    bool? onlyGoPlayable,
    enums.V2GridoptionsCridGetFilterOnDemand? filterOnDemand,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridOptions, () => GridOptions.fromJsonFactory);

    return _v2GridoptionsCridGet(
        crid: crid,
        language: language,
        genreCrid: genreCrid,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        onlyGoPlayable: onlyGoPlayable,
        filterOnDemand: filterOnDemand?.value?.toString(),
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the options for a grid screen
  ///@param crid The grid screen id
  ///@param language The two character language code
  ///@param genreCrid To indicate if GenreCategoryLink is configured
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/gridoptions/{crid}')
  Future<chopper.Response<GridOptions>> _v2GridoptionsCridGet({
    @Path('crid')
        required String? crid,
    @Query('language')
        required String? language,
    @Query('genreCrid')
        bool? genreCrid,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves a grid screen with items
  ///@param rootId The root logical key of soft link
  ///@param screenId The grid screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param sortType The sort order for assets
  ///@param sortDirection The sort direction
  ///@param filterType The associated filter type
  ///@param pagingOffset The page offset value when paging is used
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param goDownloadable Only return downloadable items
  ///@param onlyGoPlayable Only return Go playable items
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<GridScreen>> v2GridscreenRootIdScreenIdGet({
    required String? rootId,
    required String? screenId,
    required String? language,
    String? profileId,
    enums.V2GridscreenRootIdScreenIdGetSortType? sortType,
    enums.V2GridscreenRootIdScreenIdGetSortDirection? sortDirection,
    enums.V2GridscreenRootIdScreenIdGetFilterType? filterType,
    String? pagingOffset,
    enums.V2GridscreenRootIdScreenIdGetEncoding? encoding,
    enums.V2GridscreenRootIdScreenIdGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    bool? goDownloadable,
    bool? onlyGoPlayable,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? excludeAdult,
    enums.V2GridscreenRootIdScreenIdGetFilterOnDemand? filterOnDemand,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GridScreen, () => GridScreen.fromJsonFactory);

    return _v2GridscreenRootIdScreenIdGet(
        rootId: rootId,
        screenId: screenId,
        language: language,
        profileId: profileId,
        sortType: sortType?.value?.toString(),
        sortDirection: sortDirection?.value?.toString(),
        filterType: filterType?.value?.toString(),
        pagingOffset: pagingOffset,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        goDownloadable: goDownloadable,
        onlyGoPlayable: onlyGoPlayable,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        excludeAdult: excludeAdult,
        filterOnDemand: filterOnDemand?.value?.toString(),
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a grid screen with items
  ///@param rootId The root logical key of soft link
  ///@param screenId The grid screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param sortType The sort order for assets
  ///@param sortDirection The sort direction
  ///@param filterType The associated filter type
  ///@param pagingOffset The page offset value when paging is used
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param goDownloadable Only return downloadable items
  ///@param onlyGoPlayable Only return Go playable items
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/gridscreen/{rootId}/{screenId}')
  Future<chopper.Response<GridScreen>> _v2GridscreenRootIdScreenIdGet({
    @Path('rootId')
        required String? rootId,
    @Path('screenId')
        required String? screenId,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('sortType')
        String? sortType,
    @Query('sortDirection')
        String? sortDirection,
    @Query('filterType')
        String? filterType,
    @Query('pagingOffset')
        String? pagingOffset,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('goDownloadable')
        bool? goDownloadable,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the next episode
  ///@param language The two character language code
  ///@param episodeId The id of episode
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  Future<chopper.Response<NextEpisode>> v2NextepisodeGet({
    required String? language,
    required String? episodeId,
    enums.V2NextepisodeGetEncoding? encoding,
    enums.V2NextepisodeGetMaxRes? maxRes,
    String? includeExternalProvider,
    String? brandingProviderId,
    enums.V2NextepisodeGetFilterOnDemand? filterOnDemand,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NextEpisode, () => NextEpisode.fromJsonFactory);

    return _v2NextepisodeGet(
        language: language,
        episodeId: episodeId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        brandingProviderId: brandingProviderId,
        filterOnDemand: filterOnDemand?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Retrieves the next episode
  ///@param language The two character language code
  ///@param episodeId The id of episode
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  @Get(path: '/v2/nextepisode')
  Future<chopper.Response<NextEpisode>> _v2NextepisodeGet({
    @Query('language') required String? language,
    @Query('episodeId') required String? episodeId,
    @Query('encoding') String? encoding,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('filterOnDemand') String? filterOnDemand,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves a tile screen with items
  ///@param rootId The root logical key of soft link
  ///@param screenId The tile screen id
  ///@param language The two character language code
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<TileScreen>> v2TilescreenRootIdScreenIdGet({
    required String? rootId,
    required String? screenId,
    required String? language,
    enums.V2TilescreenRootIdScreenIdGetEncoding? encoding,
    enums.V2TilescreenRootIdScreenIdGetMaxRes? maxRes,
    bool? excludeAdult,
    String? featureFlags,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TileScreen, () => TileScreen.fromJsonFactory);

    return _v2TilescreenRootIdScreenIdGet(
        rootId: rootId,
        screenId: screenId,
        language: language,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a tile screen with items
  ///@param rootId The root logical key of soft link
  ///@param screenId The tile screen id
  ///@param language The two character language code
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/tilescreen/{rootId}/{screenId}')
  Future<chopper.Response<TileScreen>> _v2TilescreenRootIdScreenIdGet({
    @Path('rootId')
        required String? rootId,
    @Path('screenId')
        required String? screenId,
    @Query('language')
        required String? language,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves a vod screen
  ///@param rootId The root logical key of soft link
  ///@param crid The screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Screen>> v2VodscreenRootIdCridGet({
    required String? rootId,
    required String? crid,
    required String? language,
    String? profileId,
    bool? optIn,
    bool? sharedProfile,
    enums.V2VodscreenRootIdCridGetEncoding? encoding,
    enums.V2VodscreenRootIdCridGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? excludeAdult,
    bool? onlyGoPlayable,
    enums.V2VodscreenRootIdCridGetFilterOnDemand? filterOnDemand,
    String? featureFlags,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Screen, () => Screen.fromJsonFactory);

    return _v2VodscreenRootIdCridGet(
        rootId: rootId,
        crid: crid,
        language: language,
        profileId: profileId,
        optIn: optIn,
        sharedProfile: sharedProfile,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        excludeAdult: excludeAdult,
        onlyGoPlayable: onlyGoPlayable,
        filterOnDemand: filterOnDemand?.value?.toString(),
        featureFlags: featureFlags,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a vod screen
  ///@param rootId The root logical key of soft link
  ///@param crid The screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/vodscreen/{rootId}/{crid}')
  Future<chopper.Response<Screen>> _v2VodscreenRootIdCridGet({
    @Path('rootId')
        required String? rootId,
    @Path('crid')
        required String? crid,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('optIn')
        bool? optIn,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the vodstructure for a crid
  ///@param rootId The root logical key of soft link
  ///@param crid The crid associated with the structure
  ///@param language The two character language code
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Structure>> v2VodstructureRootIdCridGet({
    required String? rootId,
    required String? crid,
    required String? language,
    enums.V2VodstructureRootIdCridGetEncoding? encoding,
    enums.V2VodstructureRootIdCridGetMaxRes? maxRes,
    bool? excludeAdult,
    String? featureFlags,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Structure, () => Structure.fromJsonFactory);

    return _v2VodstructureRootIdCridGet(
        rootId: rootId,
        crid: crid,
        language: language,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the vodstructure for a crid
  ///@param rootId The root logical key of soft link
  ///@param crid The crid associated with the structure
  ///@param language The two character language code
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v2/vodstructure/{rootId}/{crid}')
  Future<chopper.Response<Structure>> _v2VodstructureRootIdCridGet({
    @Path('rootId')
        required String? rootId,
    @Path('crid')
        required String? crid,
    @Query('language')
        required String? language,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the person details for a person ID
  ///@param personId The person ID to retrieve the person details
  ///@param language The two character language code
  Future<chopper.Response<PersonDetail>> v2PersondetailPersonIdGet({
    required String? personId,
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PersonDetail, () => PersonDetail.fromJsonFactory);

    return _v2PersondetailPersonIdGet(
        personId: personId, language: language, cacheControl: cacheControl);
  }

  ///Retrieves the person details for a person ID
  ///@param personId The person ID to retrieve the person details
  ///@param language The two character language code
  @Get(path: '/v2/persondetail/{personId}')
  Future<chopper.Response<PersonDetail>> _v2PersondetailPersonIdGet({
    @Path('personId') required String? personId,
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves a collection screen
  ///@param id Collection screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param amazonRecommendations Comma Separated Values of the series and title ids for amazon content
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Screen>> v3CollectionsScreenIdGet({
    required String? id,
    required String? language,
    String? profileId,
    bool? optIn,
    bool? sharedProfile,
    enums.V3CollectionsScreenIdGetEncoding? encoding,
    enums.V3CollectionsScreenIdGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? excludeAdult,
    bool? onlyGoPlayable,
    enums.V3CollectionsScreenIdGetFilterOnDemand? filterOnDemand,
    String? featureFlags,
    String? amazonRecommendations,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Screen, () => Screen.fromJsonFactory);

    return _v3CollectionsScreenIdGet(
        id: id,
        language: language,
        profileId: profileId,
        optIn: optIn,
        sharedProfile: sharedProfile,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        excludeAdult: excludeAdult,
        onlyGoPlayable: onlyGoPlayable,
        filterOnDemand: filterOnDemand?.value?.toString(),
        featureFlags: featureFlags,
        amazonRecommendations: amazonRecommendations,
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a collection screen
  ///@param id Collection screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param amazonRecommendations Comma Separated Values of the series and title ids for amazon content
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/collections-screen/{id}')
  Future<chopper.Response<Screen>> _v3CollectionsScreenIdGet({
    @Path('id')
        required String? id,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('optIn')
        bool? optIn,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('featureFlags')
        String? featureFlags,
    @Query('amazonRecommendations')
        String? amazonRecommendations,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the contextual menu
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Screen>> v3ContextualvodRootIdGet({
    required String? rootId,
    required String? language,
    String? profileId,
    bool? optIn,
    bool? sharedProfile,
    enums.V3ContextualvodRootIdGetEncoding? encoding,
    enums.V3ContextualvodRootIdGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? excludeAdult,
    String? featureFlags,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Screen, () => Screen.fromJsonFactory);

    return _v3ContextualvodRootIdGet(
        rootId: rootId,
        language: language,
        profileId: profileId,
        optIn: optIn,
        sharedProfile: sharedProfile,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the contextual menu
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param optIn The user setting for personalized recommendations
  ///@param sharedProfile Indicator of a shared profile (default) or a personal one
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/contextualvod/{rootId}')
  Future<chopper.Response<Screen>> _v3ContextualvodRootIdGet({
    @Path('rootId')
        required String? rootId,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('optIn')
        bool? optIn,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves detailed info for a VoD asset
  ///@param id The asset id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<DetailScreen>> v3DetailsScreenIdGet({
    required String? id,
    required String? language,
    String? profileId,
    enums.V3DetailsScreenIdGetEncoding? encoding,
    enums.V3DetailsScreenIdGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    String? brandingProviderId,
    enums.V3DetailsScreenIdGetFilterOnDemand? filterOnDemand,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DetailScreen, () => DetailScreen.fromJsonFactory);

    return _v3DetailsScreenIdGet(
        id: id,
        language: language,
        profileId: profileId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        brandingProviderId: brandingProviderId,
        filterOnDemand: filterOnDemand?.value?.toString(),
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves detailed info for a VoD asset
  ///@param id The asset id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/details-screen/{id}')
  Future<chopper.Response<DetailScreen>> _v3DetailsScreenIdGet({
    @Path('id')
        required String? id,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the options for a grid screen
  ///@param id The grid screen id
  ///@param language The two character language code
  ///@param type The type of grid screen
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<GridOptions>> v3GridOptionsIdGet({
    required String? id,
    required String? language,
    enums.V3GridOptionsIdGetType? type,
    enums.V3GridOptionsIdGetEncoding? encoding,
    enums.V3GridOptionsIdGetMaxRes? maxRes,
    String? cityId,
    bool? onlyGoPlayable,
    enums.V3GridOptionsIdGetFilterOnDemand? filterOnDemand,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridOptions, () => GridOptions.fromJsonFactory);

    return _v3GridOptionsIdGet(
        id: id,
        language: language,
        type: type?.value?.toString(),
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        onlyGoPlayable: onlyGoPlayable,
        filterOnDemand: filterOnDemand?.value?.toString(),
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the options for a grid screen
  ///@param id The grid screen id
  ///@param language The two character language code
  ///@param type The type of grid screen
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param onlyGoPlayable Only return Go playable items
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/grid-options/{id}')
  Future<chopper.Response<GridOptions>> _v3GridOptionsIdGet({
    @Path('id')
        required String? id,
    @Query('language')
        required String? language,
    @Query('type')
        String? type,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves a grid screen with items
  ///@param id The grid screen id
  ///@param language The two character language code
  ///@param type The type of grid screen
  ///@param profileId The user selected profile id
  ///@param sortType The sort order for assets
  ///@param sortDirection The sort direction
  ///@param filterType The associated filter type
  ///@param pagingOffset The page offset value when paging is used. The value should be 0 or more.
  ///@param pagingSize The page size when paging is used. The value should be 1 or more.
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param goDownloadable Only return downloadable items
  ///@param onlyGoPlayable Only return Go playable items
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<GridScreen>> v3GridScreenIdGet({
    required String? id,
    required String? language,
    enums.V3GridScreenIdGetType? type,
    String? profileId,
    enums.V3GridScreenIdGetSortType? sortType,
    enums.V3GridScreenIdGetSortDirection? sortDirection,
    enums.V3GridScreenIdGetFilterType? filterType,
    String? pagingOffset,
    String? pagingSize,
    enums.V3GridScreenIdGetEncoding? encoding,
    enums.V3GridScreenIdGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    bool? goDownloadable,
    bool? onlyGoPlayable,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? excludeAdult,
    enums.V3GridScreenIdGetFilterOnDemand? filterOnDemand,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GridScreen, () => GridScreen.fromJsonFactory);

    return _v3GridScreenIdGet(
        id: id,
        language: language,
        type: type?.value?.toString(),
        profileId: profileId,
        sortType: sortType?.value?.toString(),
        sortDirection: sortDirection?.value?.toString(),
        filterType: filterType?.value?.toString(),
        pagingOffset: pagingOffset,
        pagingSize: pagingSize,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        goDownloadable: goDownloadable,
        onlyGoPlayable: onlyGoPlayable,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        excludeAdult: excludeAdult,
        filterOnDemand: filterOnDemand?.value?.toString(),
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a grid screen with items
  ///@param id The grid screen id
  ///@param language The two character language code
  ///@param type The type of grid screen
  ///@param profileId The user selected profile id
  ///@param sortType The sort order for assets
  ///@param sortDirection The sort direction
  ///@param filterType The associated filter type
  ///@param pagingOffset The page offset value when paging is used. The value should be 0 or more.
  ///@param pagingSize The page size when paging is used. The value should be 1 or more.
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param goDownloadable Only return downloadable items
  ///@param onlyGoPlayable Only return Go playable items
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/grid-screen/{id}')
  Future<chopper.Response<GridScreen>> _v3GridScreenIdGet({
    @Path('id')
        required String? id,
    @Query('language')
        required String? language,
    @Query('type')
        String? type,
    @Query('profileId')
        String? profileId,
    @Query('sortType')
        String? sortType,
    @Query('sortDirection')
        String? sortDirection,
    @Query('filterType')
        String? filterType,
    @Query('pagingOffset')
        String? pagingOffset,
    @Query('pagingSize')
        String? pagingSize,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('goDownloadable')
        bool? goDownloadable,
    @Query('onlyGoPlayable')
        bool? onlyGoPlayable,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the next episode
  ///@param language The two character language code
  ///@param episodeId The id of episode
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  Future<chopper.Response<NextEpisode>> v3NextepisodeGet({
    required String? language,
    required String? episodeId,
    enums.V3NextepisodeGetEncoding? encoding,
    enums.V3NextepisodeGetMaxRes? maxRes,
    String? includeExternalProvider,
    String? brandingProviderId,
    enums.V3NextepisodeGetFilterOnDemand? filterOnDemand,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NextEpisode, () => NextEpisode.fromJsonFactory);

    return _v3NextepisodeGet(
        language: language,
        episodeId: episodeId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        brandingProviderId: brandingProviderId,
        filterOnDemand: filterOnDemand?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Retrieves the next episode
  ///@param language The two character language code
  ///@param episodeId The id of episode
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param brandingProviderId Filter content to a certain BrandingProvider
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  @Get(path: '/v3/nextepisode')
  Future<chopper.Response<NextEpisode>> _v3NextepisodeGet({
    @Query('language') required String? language,
    @Query('episodeId') required String? episodeId,
    @Query('encoding') String? encoding,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('filterOnDemand') String? filterOnDemand,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves the rented items
  ///@param language The two character language code
  ///@param pagingOffset The page offset value when paging is used
  ///@param pagingSize The page size when paging is used
  ///@param profileId The user selected profile id
  ///@param isAdult The user setting for adult content
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<RentalScreen>> v3RentalsGet({
    required String? language,
    String? pagingOffset,
    String? pagingSize,
    String? profileId,
    bool? isAdult,
    enums.V3RentalsGetEncoding? encoding,
    enums.V3RentalsGetMaxRes? maxRes,
    int? replayOptedInTime,
    bool? mergingOn,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RentalScreen, () => RentalScreen.fromJsonFactory);

    return _v3RentalsGet(
        language: language,
        pagingOffset: pagingOffset,
        pagingSize: pagingSize,
        profileId: profileId,
        isAdult: isAdult,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the rented items
  ///@param language The two character language code
  ///@param pagingOffset The page offset value when paging is used
  ///@param pagingSize The page size when paging is used
  ///@param profileId The user selected profile id
  ///@param isAdult The user setting for adult content
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param replayOptedInTime Parameter to pass on to the picker service for season count calculation.
  ///@param mergingOn Parameter to indicate whether season count merging has to be done by picker service.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/rentals')
  Future<chopper.Response<RentalScreen>> _v3RentalsGet({
    @Query('language')
        required String? language,
    @Query('pagingOffset')
        String? pagingOffset,
    @Query('pagingSize')
        String? pagingSize,
    @Query('profileId')
        String? profileId,
    @Query('isAdult')
        bool? isAdult,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the main menu (aka vodstructure)
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param menu type of the menu structure to be retrieved
  ///@param fallbackRootId The root link to fallback to
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Structure>> v3StructureRootIdGet({
    required String? rootId,
    required String? language,
    enums.V3StructureRootIdGetMenu? menu,
    String? fallbackRootId,
    enums.V3StructureRootIdGetEncoding? encoding,
    enums.V3StructureRootIdGetMaxRes? maxRes,
    bool? excludeAdult,
    enums.V3StructureRootIdGetFilterOnDemand? filterOnDemand,
    String? featureFlags,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Structure, () => Structure.fromJsonFactory);

    return _v3StructureRootIdGet(
        rootId: rootId,
        language: language,
        menu: menu?.value?.toString(),
        fallbackRootId: fallbackRootId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        filterOnDemand: filterOnDemand?.value?.toString(),
        featureFlags: featureFlags,
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the main menu (aka vodstructure)
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param menu type of the menu structure to be retrieved
  ///@param fallbackRootId The root link to fallback to
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param filterOnDemand Removes TVoD related content if this parameter is used with value svod
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/structure/{rootId}')
  Future<chopper.Response<Structure>> _v3StructureRootIdGet({
    @Path('rootId')
        required String? rootId,
    @Query('language')
        required String? language,
    @Query('menu')
        String? menu,
    @Query('fallbackRootId')
        String? fallbackRootId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('featureFlags')
        String? featureFlags,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves the vodstructure for a crid
  ///@param rootId The root logical key of soft link
  ///@param id The id associated with the structure
  ///@param language The two character language code
  ///@param menu type of the menu structure to be retrieved
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<Structure>> v3StructureRootIdIdGet({
    required String? rootId,
    required String? id,
    required String? language,
    enums.V3StructureRootIdIdGetMenu? menu,
    enums.V3StructureRootIdIdGetEncoding? encoding,
    enums.V3StructureRootIdIdGetMaxRes? maxRes,
    bool? excludeAdult,
    String? featureFlags,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Structure, () => Structure.fromJsonFactory);

    return _v3StructureRootIdIdGet(
        rootId: rootId,
        id: id,
        language: language,
        menu: menu?.value?.toString(),
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves the vodstructure for a crid
  ///@param rootId The root logical key of soft link
  ///@param id The id associated with the structure
  ///@param language The two character language code
  ///@param menu type of the menu structure to be retrieved
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/structure/{rootId}/{id}')
  Future<chopper.Response<Structure>> _v3StructureRootIdIdGet({
    @Path('rootId')
        required String? rootId,
    @Path('id')
        required String? id,
    @Query('language')
        required String? language,
    @Query('menu')
        String? menu,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves a tile link that matches given channel id
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param channelId The id of the channel
  ///@param replayProviderId The id of the replay provider.
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param cityId City Identifier of the user.
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<TileItem>> v3TileLinkRootIdGet({
    required String? rootId,
    required String? language,
    required String? channelId,
    String? replayProviderId,
    enums.V3TileLinkRootIdGetEncoding? encoding,
    enums.V3TileLinkRootIdGetMaxRes? maxRes,
    bool? excludeAdult,
    String? featureFlags,
    String? cityId,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TileItem, () => TileItem.fromJsonFactory);

    return _v3TileLinkRootIdGet(
        rootId: rootId,
        language: language,
        channelId: channelId,
        replayProviderId: replayProviderId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        cityId: cityId,
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a tile link that matches given channel id
  ///@param rootId The root logical key of soft link
  ///@param language The two character language code
  ///@param channelId The id of the channel
  ///@param replayProviderId The id of the replay provider.
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param cityId City Identifier of the user.
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/tile-link/{rootId}')
  Future<chopper.Response<TileItem>> _v3TileLinkRootIdGet({
    @Path('rootId')
        required String? rootId,
    @Query('language')
        required String? language,
    @Query('channelId')
        required String? channelId,
    @Query('replayProviderId')
        String? replayProviderId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Query('cityId')
        String? cityId,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves a tile screen with items
  ///@param id The tile screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param cityId City Identifier of the user.
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<TileScreen>> v3TilesScreenIdGet({
    required String? id,
    required String? language,
    required String? profileId,
    String? cityId,
    enums.V3TilesScreenIdGetEncoding? encoding,
    enums.V3TilesScreenIdGetMaxRes? maxRes,
    bool? excludeAdult,
    String? featureFlags,
    int? entityVersion,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TileScreen, () => TileScreen.fromJsonFactory);

    return _v3TilesScreenIdGet(
        id: id,
        language: language,
        profileId: profileId,
        cityId: cityId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        featureFlags: featureFlags,
        entityVersion: entityVersion,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Retrieves a tile screen with items
  ///@param id The tile screen id
  ///@param language The two character language code
  ///@param profileId The user selected profile id
  ///@param cityId City Identifier of the user.
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult
  ///@param featureFlags Comma Separated Values of the features that clients supports
  ///@param entityVersion The maximum version of UI elements which are supported by the client.
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v3/tiles-screen/{id}')
  Future<chopper.Response<TileScreen>> _v3TilesScreenIdGet({
    @Path('id')
        required String? id,
    @Query('language')
        required String? language,
    @Query('profileId')
        required String? profileId,
    @Query('cityId')
        String? cityId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('featureFlags')
        String? featureFlags,
    @Query('entityVersion')
        int? entityVersion,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Returns a list of instances of the given trailer crid
  ///@param trailerCrid The trailer asset crid
  ///@param language The two character language code
  ///@param profileId The user selected profile id, only for logging purposes
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param x-dev Device ID, only for logging purposes
  ///@param x-entitlements-token Token containing entitlements info, only for logging purposes
  Future<chopper.Response<TrailerInfo>> v3TrailerDetailsTrailerCridGet({
    required String? trailerCrid,
    required String? language,
    String? profileId,
    enums.V3TrailerDetailsTrailerCridGetEncoding? encoding,
    enums.V3TrailerDetailsTrailerCridGetMaxRes? maxRes,
    String? cityId,
    String? includeExternalProvider,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TrailerInfo, () => TrailerInfo.fromJsonFactory);

    return _v3TrailerDetailsTrailerCridGet(
        trailerCrid: trailerCrid,
        language: language,
        profileId: profileId,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Returns a list of instances of the given trailer crid
  ///@param trailerCrid The trailer asset crid
  ///@param language The two character language code
  ///@param profileId The user selected profile id, only for logging purposes
  ///@param encoding Supported encoding type for content instance selection
  ///@param maxRes The maximum resolution supported for content instance selection
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  ///@param x-dev Device ID, only for logging purposes
  ///@param x-entitlements-token Token containing entitlements info, only for logging purposes
  @Get(path: '/v3/trailerDetails/{trailerCrid}')
  Future<chopper.Response<TrailerInfo>> _v3TrailerDetailsTrailerCridGet({
    @Path('trailerCrid')
        required String? trailerCrid,
    @Query('language')
        required String? language,
    @Query('profileId')
        String? profileId,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        String? cityId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Exclusive endpoint returning feeds items for a given feedId exclusively OTT catalog
  ///@param feedId identifier of the editorial feed or external managed feed
  ///@param language The two character language code
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult. For external feed items this flag will not be applied as the metadata is unknown
  ///@param count The maximum number of items to return in range 0-500. Defaults to 12 if not supplied. If the count exceeds the value 500, then a count of 500 will be used.
  ///@param cityId City Identifier of the user.
  ///@param amazonRecommendations Comma Separated Values of the series and title ids for amazon content
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  Future<chopper.Response<FeedResponse>> v1FeedFeedIdGet({
    required String? feedId,
    required String? language,
    enums.V1FeedFeedIdGetEncoding? encoding,
    enums.V1FeedFeedIdGetMaxRes? maxRes,
    bool? excludeAdult,
    int? count,
    required String? cityId,
    String? amazonRecommendations,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedResponse, () => FeedResponse.fromJsonFactory);

    return _v1FeedFeedIdGet(
        feedId: feedId,
        language: language,
        encoding: encoding?.value?.toString(),
        maxRes: maxRes?.value?.toString(),
        excludeAdult: excludeAdult,
        count: count,
        cityId: cityId,
        amazonRecommendations: amazonRecommendations,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Exclusive endpoint returning feeds items for a given feedId exclusively OTT catalog
  ///@param feedId identifier of the editorial feed or external managed feed
  ///@param language The two character language code
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param excludeAdult boolean flag when set to true indicating to remove any content that is adult. For external feed items this flag will not be applied as the metadata is unknown
  ///@param count The maximum number of items to return in range 0-500. Defaults to 12 if not supplied. If the count exceeds the value 500, then a count of 500 will be used.
  ///@param cityId City Identifier of the user.
  ///@param amazonRecommendations Comma Separated Values of the series and title ids for amazon content
  ///@param x-dev Device ID
  ///@param x-entitlements-token Token containing entitlements info
  @Get(path: '/v1/feed/{feedId}')
  Future<chopper.Response<FeedResponse>> _v1FeedFeedIdGet({
    @Path('feedId')
        required String? feedId,
    @Query('language')
        required String? language,
    @Query('encoding')
        String? encoding,
    @Query('maxRes')
        String? maxRes,
    @Query('excludeAdult')
        bool? excludeAdult,
    @Query('count')
        int? count,
    @Query('cityId')
        required String? cityId,
    @Query('amazonRecommendations')
        String? amazonRecommendations,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves an editorial feed with sorted items
  ///@param categoryId The crid of the editorial category
  ///@param language The two character language code
  ///@param sortType The sort order for assets
  ///@param sortDirection The sort direction
  ///@param pagingOffset The page offset, integer >= 0
  ///@param pagingSize The page size, integer >= 1
  ///@param filters Comma separated filters, eg. 'downloadable'
  ///@param maxRes Max resolution supported by the CPE, eg. '4K'
  ///@param onlyGoPlayable When set to true only return titles/shows with an available OTT content
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  Future<chopper.Response<EditorialFeed>> hzngoV1EditorialFeedCategoryIdGet({
    required String? categoryId,
    required String? language,
    required enums.HzngoV1EditorialFeedCategoryIdGetSortType? sortType,
    required enums.HzngoV1EditorialFeedCategoryIdGetSortDirection?
        sortDirection,
    String? pagingOffset,
    String? pagingSize,
    String? filters,
    String? maxRes,
    bool? onlyGoPlayable,
    String? cityId,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EditorialFeed, () => EditorialFeed.fromJsonFactory);

    return _hzngoV1EditorialFeedCategoryIdGet(
        categoryId: categoryId,
        language: language,
        sortType: sortType?.value?.toString(),
        sortDirection: sortDirection?.value?.toString(),
        pagingOffset: pagingOffset,
        pagingSize: pagingSize,
        filters: filters,
        maxRes: maxRes,
        onlyGoPlayable: onlyGoPlayable,
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///Retrieves an editorial feed with sorted items
  ///@param categoryId The crid of the editorial category
  ///@param language The two character language code
  ///@param sortType The sort order for assets
  ///@param sortDirection The sort direction
  ///@param pagingOffset The page offset, integer >= 0
  ///@param pagingSize The page size, integer >= 1
  ///@param filters Comma separated filters, eg. 'downloadable'
  ///@param maxRes Max resolution supported by the CPE, eg. '4K'
  ///@param onlyGoPlayable When set to true only return titles/shows with an available OTT content
  ///@param cityId City Identifier of the user.
  ///@param includeExternalProvider If present, the contents from the 'external provider(s)' are included in the results. Value can be a comma separated list.
  @Get(path: '/hzngo/v1/editorialFeed/{categoryId}')
  Future<chopper.Response<EditorialFeed>> _hzngoV1EditorialFeedCategoryIdGet({
    @Path('categoryId') required String? categoryId,
    @Query('language') required String? language,
    @Query('sortType') required String? sortType,
    @Query('sortDirection') required String? sortDirection,
    @Query('pagingOffset') String? pagingOffset,
    @Query('pagingSize') String? pagingSize,
    @Query('filters') String? filters,
    @Query('maxRes') String? maxRes,
    @Query('onlyGoPlayable') bool? onlyGoPlayable,
    @Query('cityId') String? cityId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves a list of genres related to that crid
  ///@param crid The crid of the item
  ///@param language The two character language code
  Future<chopper.Response<GenreListResponse>> hzngoV1FeedGenreListCridGet({
    required String? crid,
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GenreListResponse, () => GenreListResponse.fromJsonFactory);

    return _hzngoV1FeedGenreListCridGet(
        crid: crid, language: language, cacheControl: cacheControl);
  }

  ///Retrieves a list of genres related to that crid
  ///@param crid The crid of the item
  ///@param language The two character language code
  @Get(path: '/hzngo/v1/feedGenreList/{crid}')
  Future<chopper.Response<GenreListResponse>> _hzngoV1FeedGenreListCridGet({
    @Path('crid') required String? crid,
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param goPlayable
  ///@param nrOfCandidates
  ///@param sharedProfile Flag to determine call mode to RENG / DS service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param filterOnDemand Filter TVOD/SVOD content
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  ///@param useSeriesLogic flag to enable series recommendations instead of episode recommendations
  ///@param x-dev
  ///@param x-entitlements-token
  Future<chopper.Response<Aspot>>
      phsV1CustomersCustomerIdProfilesProfileIdASpotGet({
    required String? customerId,
    required String? profileId,
    String? language,
    String? cpeId,
    String? clientType,
    String? maxRes,
    int? cityId,
    String? replayOptInDate,
    bool? goPlayable,
    int? nrOfCandidates,
    bool? sharedProfile,
    bool? optIn,
    String? version,
    String? featureFlags,
    enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand?
        filterOnDemand,
    String? includeExternalProvider,
    bool? useSeriesLogic,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Aspot, () => Aspot.fromJsonFactory);

    return _phsV1CustomersCustomerIdProfilesProfileIdASpotGet(
        customerId: customerId,
        profileId: profileId,
        language: language,
        cpeId: cpeId,
        clientType: clientType,
        maxRes: maxRes,
        cityId: cityId,
        replayOptInDate: replayOptInDate,
        goPlayable: goPlayable,
        nrOfCandidates: nrOfCandidates,
        sharedProfile: sharedProfile,
        optIn: optIn,
        version: version,
        featureFlags: featureFlags,
        filterOnDemand: filterOnDemand?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        useSeriesLogic: useSeriesLogic,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param goPlayable
  ///@param nrOfCandidates
  ///@param sharedProfile Flag to determine call mode to RENG / DS service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param filterOnDemand Filter TVOD/SVOD content
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  ///@param useSeriesLogic flag to enable series recommendations instead of episode recommendations
  ///@param x-dev
  ///@param x-entitlements-token
  @Get(path: '/phs/v1/customers/{customerId}/profiles/{profileId}/a-spot')
  Future<chopper.Response<Aspot>>
      _phsV1CustomersCustomerIdProfilesProfileIdASpotGet({
    @Path('customerId')
        required String? customerId,
    @Path('profileId')
        required String? profileId,
    @Query('language')
        String? language,
    @Query('cpeId')
        String? cpeId,
    @Query('clientType')
        String? clientType,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptInDate')
        String? replayOptInDate,
    @Query('goPlayable')
        bool? goPlayable,
    @Query('nrOfCandidates')
        int? nrOfCandidates,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('optIn')
        bool? optIn,
    @Query('version')
        String? version,
    @Query('featureFlags')
        String? featureFlags,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('useSeriesLogic')
        bool? useSeriesLogic,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param goPlayable
  ///@param limit Max amount of aspot items to be returned
  ///@param sharedProfile Flag to determine call mode to RENG / DS service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param filterOnDemand Filter TVOD/SVOD content
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  ///@param useSeriesLogic flag to enable series recommendations instead of episode recommendations
  ///@param x-dev
  ///@param x-entitlements-token
  Future<chopper.Response<List<Aspot>>>
      phsV1CustomersCustomerIdProfilesProfileIdASpotsGet({
    required String? customerId,
    required String? profileId,
    String? language,
    String? cpeId,
    String? clientType,
    String? maxRes,
    int? cityId,
    String? replayOptInDate,
    bool? goPlayable,
    int? limit,
    bool? sharedProfile,
    bool? optIn,
    String? version,
    String? featureFlags,
    enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand?
        filterOnDemand,
    String? includeExternalProvider,
    bool? useSeriesLogic,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Aspot, () => Aspot.fromJsonFactory);

    return _phsV1CustomersCustomerIdProfilesProfileIdASpotsGet(
        customerId: customerId,
        profileId: profileId,
        language: language,
        cpeId: cpeId,
        clientType: clientType,
        maxRes: maxRes,
        cityId: cityId,
        replayOptInDate: replayOptInDate,
        goPlayable: goPlayable,
        limit: limit,
        sharedProfile: sharedProfile,
        optIn: optIn,
        version: version,
        featureFlags: featureFlags,
        filterOnDemand: filterOnDemand?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        useSeriesLogic: useSeriesLogic,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param goPlayable
  ///@param limit Max amount of aspot items to be returned
  ///@param sharedProfile Flag to determine call mode to RENG / DS service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param filterOnDemand Filter TVOD/SVOD content
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  ///@param useSeriesLogic flag to enable series recommendations instead of episode recommendations
  ///@param x-dev
  ///@param x-entitlements-token
  @Get(path: '/phs/v1/customers/{customerId}/profiles/{profileId}/a-spots')
  Future<chopper.Response<List<Aspot>>>
      _phsV1CustomersCustomerIdProfilesProfileIdASpotsGet({
    @Path('customerId')
        required String? customerId,
    @Path('profileId')
        required String? profileId,
    @Query('language')
        String? language,
    @Query('cpeId')
        String? cpeId,
    @Query('clientType')
        String? clientType,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptInDate')
        String? replayOptInDate,
    @Query('goPlayable')
        bool? goPlayable,
    @Query('limit')
        int? limit,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('optIn')
        bool? optIn,
    @Query('version')
        String? version,
    @Query('featureFlags')
        String? featureFlags,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('useSeriesLogic')
        bool? useSeriesLogic,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param goPlayable
  ///@param recentlyUsedApps Comma seperated list of OTT appid's to be returned to the client. Ex.: com.libertyglobal.app.amazon,com.libertyglobal.app.netflix
  ///@param sharedProfile Flag to determine call mode to RENG / DS service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param id Comma seperated list of collection id's to be returned to the client. Ex.: rented-with-continue-watching-id,rented-id
  ///@param appid Comma seperated list of OTT appid's to be returned to the client. Ex.: com.libertyglobal.app.primevideo,com.libertyglobal.app.netflix
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param filterOnDemand Filter TVOD/SVOD content
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  ///@param productClass An identifier for the client device, making the request. For HZNGO Clients: Orion-DASH, Orion-HLS | For CPE Clients: EOSSTB, EOS2STB, HZNSTB, APLSTB
  ///@param replicationToken replication token used for recordings
  ///@param useSeriesLogic flag to enable series recommendations instead of episode recommendations
  ///@param amazonBookmarks Amazon specific external bookmarks list for continue watching
  ///@param amazonRecommendations Personalised list of recommendations from Amazon
  ///@param x-dev
  ///@param x-entitlements-token
  Future<chopper.Response<Screen>>
      phsV1CustomersCustomerIdProfilesProfileIdScreenGet({
    required String? customerId,
    required String? profileId,
    String? language,
    String? cpeId,
    String? clientType,
    String? maxRes,
    int? cityId,
    String? replayOptInDate,
    bool? goPlayable,
    String? recentlyUsedApps,
    bool? sharedProfile,
    String? id,
    String? appid,
    bool? optIn,
    String? version,
    String? featureFlags,
    enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand?
        filterOnDemand,
    String? includeExternalProvider,
    String? productClass,
    String? replicationToken,
    bool? useSeriesLogic,
    String? amazonBookmarks,
    String? amazonRecommendations,
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Screen, () => Screen.fromJsonFactory);

    return _phsV1CustomersCustomerIdProfilesProfileIdScreenGet(
        customerId: customerId,
        profileId: profileId,
        language: language,
        cpeId: cpeId,
        clientType: clientType,
        maxRes: maxRes,
        cityId: cityId,
        replayOptInDate: replayOptInDate,
        goPlayable: goPlayable,
        recentlyUsedApps: recentlyUsedApps,
        sharedProfile: sharedProfile,
        id: id,
        appid: appid,
        optIn: optIn,
        version: version,
        featureFlags: featureFlags,
        filterOnDemand: filterOnDemand?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        productClass: productClass,
        replicationToken: replicationToken,
        useSeriesLogic: useSeriesLogic,
        amazonBookmarks: amazonBookmarks,
        amazonRecommendations: amazonRecommendations,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param goPlayable
  ///@param recentlyUsedApps Comma seperated list of OTT appid's to be returned to the client. Ex.: com.libertyglobal.app.amazon,com.libertyglobal.app.netflix
  ///@param sharedProfile Flag to determine call mode to RENG / DS service - when true or absent: subscriber mode is used, when false: user mode is used
  ///@param id Comma seperated list of collection id's to be returned to the client. Ex.: rented-with-continue-watching-id,rented-id
  ///@param appid Comma seperated list of OTT appid's to be returned to the client. Ex.: com.libertyglobal.app.primevideo,com.libertyglobal.app.netflix
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param filterOnDemand Filter TVOD/SVOD content
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  ///@param productClass An identifier for the client device, making the request. For HZNGO Clients: Orion-DASH, Orion-HLS | For CPE Clients: EOSSTB, EOS2STB, HZNSTB, APLSTB
  ///@param replicationToken replication token used for recordings
  ///@param useSeriesLogic flag to enable series recommendations instead of episode recommendations
  ///@param amazonBookmarks Amazon specific external bookmarks list for continue watching
  ///@param amazonRecommendations Personalised list of recommendations from Amazon
  ///@param x-dev
  ///@param x-entitlements-token
  @Get(path: '/phs/v1/customers/{customerId}/profiles/{profileId}/screen')
  Future<chopper.Response<Screen>>
      _phsV1CustomersCustomerIdProfilesProfileIdScreenGet({
    @Path('customerId')
        required String? customerId,
    @Path('profileId')
        required String? profileId,
    @Query('language')
        String? language,
    @Query('cpeId')
        String? cpeId,
    @Query('clientType')
        String? clientType,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptInDate')
        String? replayOptInDate,
    @Query('goPlayable')
        bool? goPlayable,
    @Query('recentlyUsedApps')
        String? recentlyUsedApps,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('id')
        String? id,
    @Query('appid')
        String? appid,
    @Query('optIn')
        bool? optIn,
    @Query('version')
        String? version,
    @Query('featureFlags')
        String? featureFlags,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('productClass')
        String? productClass,
    @Query('replicationToken')
        String? replicationToken,
    @Query('useSeriesLogic')
        bool? useSeriesLogic,
    @Query('amazonBookmarks')
        String? amazonBookmarks,
    @Query('amazonRecommendations')
        String? amazonRecommendations,
    @Header('x-dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param x-entitlements-token
  Future<chopper.Response<Structure>>
      phsV1CustomersCustomerIdProfilesProfileIdStructureGet({
    required String? customerId,
    required String? profileId,
    String? language,
    String? clientType,
    bool? optIn,
    String? version,
    String? featureFlags,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Structure, () => Structure.fromJsonFactory);

    return _phsV1CustomersCustomerIdProfilesProfileIdStructureGet(
        customerId: customerId,
        profileId: profileId,
        language: language,
        clientType: clientType,
        optIn: optIn,
        version: version,
        featureFlags: featureFlags,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param customerId CustomerId with country code (eg: 'C001869_pl')
  ///@param profileId
  ///@param language
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param x-entitlements-token
  @Get(path: '/phs/v1/customers/{customerId}/profiles/{profileId}/structure')
  Future<chopper.Response<Structure>>
      _phsV1CustomersCustomerIdProfilesProfileIdStructureGet({
    @Path('customerId')
        required String? customerId,
    @Path('profileId')
        required String? profileId,
    @Query('language')
        String? language,
    @Query('clientType')
        String? clientType,
    @Query('optIn')
        bool? optIn,
    @Query('version')
        String? version,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param profileId
  ///@param language
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param x-entitlements-token
  Future<chopper.Response<Structure>> phsV1StructureGet({
    String? profileId,
    String? language,
    String? clientType,
    bool? optIn,
    String? version,
    String? featureFlags,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Structure, () => Structure.fromJsonFactory);

    return _phsV1StructureGet(
        profileId: profileId,
        language: language,
        clientType: clientType,
        optIn: optIn,
        version: version,
        featureFlags: featureFlags,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param profileId
  ///@param language
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param optIn
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param x-entitlements-token
  @Get(path: '/phs/v1/structure')
  Future<chopper.Response<Structure>> _phsV1StructureGet({
    @Query('profileId')
        String? profileId,
    @Query('language')
        String? language,
    @Query('clientType')
        String? clientType,
    @Query('optIn')
        bool? optIn,
    @Query('version')
        String? version,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///
  ///@param profileId
  ///@param language
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param productClass An identifier for the client device, making the request. For HZNGO Clients: Orion-DASH, Orion-HLS | For CPE Clients: EOSSTB, EOS2STB, HZNSTB, APLSTB
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param x-entitlements-token
  ///@param User-Agent Custom HTTP header containing the customers userAgent.
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  Future<chopper.Response<TopShelf>> phsV1TopshelfGet({
    String? profileId,
    String? language,
    String? clientType,
    String? maxRes,
    required int? cityId,
    required String? productClass,
    String? version,
    String? featureFlags,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TopShelf, () => TopShelf.fromJsonFactory);

    return _phsV1TopshelfGet(
        profileId: profileId,
        language: language,
        clientType: clientType,
        maxRes: maxRes,
        cityId: cityId,
        productClass: productClass,
        version: version,
        featureFlags: featureFlags,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///
  ///@param profileId
  ///@param language
  ///@param clientType Available values: STB-EOS, HZNGO, HZNGO-WEB, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param productClass An identifier for the client device, making the request. For HZNGO Clients: Orion-DASH, Orion-HLS | For CPE Clients: EOSSTB, EOS2STB, HZNSTB, APLSTB
  ///@param version
  ///@param featureFlags Comma seperated list of feature flags. Currently client_mobile is supported
  ///@param x-entitlements-token
  ///@param User-Agent Custom HTTP header containing the customers userAgent.
  ///@param includeExternalProvider Comma seperated list of branding provider Ids. Ex.: provider-AMAZON, provider-BBC,provider-STV,provider-MY5, provider-DISNEYPLUS
  @Get(path: '/phs/v1/topshelf')
  Future<chopper.Response<TopShelf>> _phsV1TopshelfGet({
    @Query('profileId')
        String? profileId,
    @Query('language')
        String? language,
    @Query('clientType')
        String? clientType,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        required int? cityId,
    @Query('productClass')
        required String? productClass,
    @Query('version')
        String? version,
    @Query('featureFlags')
        String? featureFlags,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Header('Cache-Control')
        String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class CustomerAccessError {
  CustomerAccessError({
    this.errorMessage,
  });

  factory CustomerAccessError.fromJson(Map<String, dynamic> json) =>
      _$CustomerAccessErrorFromJson(json);

  static const toJsonFactory = _$CustomerAccessErrorToJson;
  Map<String, dynamic> toJson() => _$CustomerAccessErrorToJson(this);

  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  static const fromJsonFactory = _$CustomerAccessErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerAccessError &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errorMessage) ^ runtimeType.hashCode;
}

extension $CustomerAccessErrorExtension on CustomerAccessError {
  CustomerAccessError copyWith({String? errorMessage}) {
    return CustomerAccessError(errorMessage: errorMessage ?? this.errorMessage);
  }

  CustomerAccessError copyWithWrapped({Wrapped<String?>? errorMessage}) {
    return CustomerAccessError(
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage));
  }
}

@JsonSerializable(explicitToJson: true)
class Program {
  Program({
    this.crid,
    this.type,
  });

  factory Program.fromJson(Map<String, dynamic> json) =>
      _$ProgramFromJson(json);

  static const toJsonFactory = _$ProgramToJson;
  Map<String, dynamic> toJson() => _$ProgramToJson(this);

  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: programTypeToJson,
    fromJson: programTypeFromJson,
  )
  final enums.ProgramType? type;
  static const fromJsonFactory = _$ProgramFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Program &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ProgramExtension on Program {
  Program copyWith({String? crid, enums.ProgramType? type}) {
    return Program(crid: crid ?? this.crid, type: type ?? this.type);
  }

  Program copyWithWrapped(
      {Wrapped<String?>? crid, Wrapped<enums.ProgramType?>? type}) {
    return Program(
        crid: (crid != null ? crid.value : this.crid),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class Show {
  Show({
    this.crid,
    this.type,
  });

  factory Show.fromJson(Map<String, dynamic> json) => _$ShowFromJson(json);

  static const toJsonFactory = _$ShowToJson;
  Map<String, dynamic> toJson() => _$ShowToJson(this);

  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: showTypeToJson,
    fromJson: showTypeFromJson,
  )
  final enums.ShowType? type;
  static const fromJsonFactory = _$ShowFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Show &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ShowExtension on Show {
  Show copyWith({String? crid, enums.ShowType? type}) {
    return Show(crid: crid ?? this.crid, type: type ?? this.type);
  }

  Show copyWithWrapped(
      {Wrapped<String?>? crid, Wrapped<enums.ShowType?>? type}) {
    return Show(
        crid: (crid != null ? crid.value : this.crid),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class Title {
  Title({
    this.crid,
    this.type,
  });

  factory Title.fromJson(Map<String, dynamic> json) => _$TitleFromJson(json);

  static const toJsonFactory = _$TitleToJson;
  Map<String, dynamic> toJson() => _$TitleToJson(this);

  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: titleTypeToJson,
    fromJson: titleTypeFromJson,
  )
  final enums.TitleType? type;
  static const fromJsonFactory = _$TitleFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Title &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $TitleExtension on Title {
  Title copyWith({String? crid, enums.TitleType? type}) {
    return Title(crid: crid ?? this.crid, type: type ?? this.type);
  }

  Title copyWithWrapped(
      {Wrapped<String?>? crid, Wrapped<enums.TitleType?>? type}) {
    return Title(
        crid: (crid != null ? crid.value : this.crid),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponse {
  FeedComposerResponse({
    this.programs,
  });

  factory FeedComposerResponse.fromJson(Map<String, dynamic> json) =>
      _$FeedComposerResponseFromJson(json);

  static const toJsonFactory = _$FeedComposerResponseToJson;
  Map<String, dynamic> toJson() => _$FeedComposerResponseToJson(this);

  @JsonKey(name: 'programs', includeIfNull: false, defaultValue: <Program>[])
  final List<Program>? programs;
  static const fromJsonFactory = _$FeedComposerResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponse &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(programs) ^ runtimeType.hashCode;
}

extension $FeedComposerResponseExtension on FeedComposerResponse {
  FeedComposerResponse copyWith({List<Program>? programs}) {
    return FeedComposerResponse(programs: programs ?? this.programs);
  }

  FeedComposerResponse copyWithWrapped({Wrapped<List<Program>?>? programs}) {
    return FeedComposerResponse(
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponseForPurchasedProgram {
  FeedComposerResponseForPurchasedProgram({
    this.programs,
  });

  factory FeedComposerResponseForPurchasedProgram.fromJson(
          Map<String, dynamic> json) =>
      _$FeedComposerResponseForPurchasedProgramFromJson(json);

  static const toJsonFactory = _$FeedComposerResponseForPurchasedProgramToJson;
  Map<String, dynamic> toJson() =>
      _$FeedComposerResponseForPurchasedProgramToJson(this);

  @JsonKey(
      name: 'programs',
      includeIfNull: false,
      defaultValue: <PurchasedProgram>[])
  final List<PurchasedProgram>? programs;
  static const fromJsonFactory =
      _$FeedComposerResponseForPurchasedProgramFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponseForPurchasedProgram &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(programs) ^ runtimeType.hashCode;
}

extension $FeedComposerResponseForPurchasedProgramExtension
    on FeedComposerResponseForPurchasedProgram {
  FeedComposerResponseForPurchasedProgram copyWith(
      {List<PurchasedProgram>? programs}) {
    return FeedComposerResponseForPurchasedProgram(
        programs: programs ?? this.programs);
  }

  FeedComposerResponseForPurchasedProgram copyWithWrapped(
      {Wrapped<List<PurchasedProgram>?>? programs}) {
    return FeedComposerResponseForPurchasedProgram(
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchasedProgram {
  PurchasedProgram({
    this.crid,
    this.type,
    this.brandingProviderId,
    this.productId,
  });

  factory PurchasedProgram.fromJson(Map<String, dynamic> json) =>
      _$PurchasedProgramFromJson(json);

  static const toJsonFactory = _$PurchasedProgramToJson;
  Map<String, dynamic> toJson() => _$PurchasedProgramToJson(this);

  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: purchasedProgramTypeToJson,
    fromJson: purchasedProgramTypeFromJson,
  )
  final enums.PurchasedProgramType? type;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String? productId;
  static const fromJsonFactory = _$PurchasedProgramFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchasedProgram &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(productId) ^
      runtimeType.hashCode;
}

extension $PurchasedProgramExtension on PurchasedProgram {
  PurchasedProgram copyWith(
      {String? crid,
      enums.PurchasedProgramType? type,
      String? brandingProviderId,
      String? productId}) {
    return PurchasedProgram(
        crid: crid ?? this.crid,
        type: type ?? this.type,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        productId: productId ?? this.productId);
  }

  PurchasedProgram copyWithWrapped(
      {Wrapped<String?>? crid,
      Wrapped<enums.PurchasedProgramType?>? type,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? productId}) {
    return PurchasedProgram(
        crid: (crid != null ? crid.value : this.crid),
        type: (type != null ? type.value : this.type),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        productId: (productId != null ? productId.value : this.productId));
  }
}

@JsonSerializable(explicitToJson: true)
class ASpot {
  ASpot({
    this.id,
    this.mergedId,
    this.title,
    this.isAdult,
    this.imageVersion,
    this.screenLayout,
    this.type,
    this.assetType,
    this.brandingProviderId,
    this.channelId,
    this.eventId,
    this.background,
    this.treatment,
    this.gridLink,
    this.synopsis,
    this.isBoxset,
    this.isSplitProgram,
  });

  factory ASpot.fromJson(Map<String, dynamic> json) => _$ASpotFromJson(json);

  static const toJsonFactory = _$ASpotToJson;
  Map<String, dynamic> toJson() => _$ASpotToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: aSpotTypeToJson,
    fromJson: aSpotTypeFromJson,
  )
  final enums.ASpotType? type;
  @JsonKey(
    name: 'assetType',
    includeIfNull: false,
    toJson: aSpotAssetTypeToJson,
    fromJson: aSpotAssetTypeFromJson,
  )
  final enums.ASpotAssetType? assetType;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String? background;
  @JsonKey(name: 'treatment', includeIfNull: false, defaultValue: '')
  final String? treatment;
  @JsonKey(name: 'gridLink', includeIfNull: false)
  final GridLink? gridLink;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  static const fromJsonFactory = _$ASpotFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ASpot &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.screenLayout, screenLayout) ||
                const DeepCollectionEquality()
                    .equals(other.screenLayout, screenLayout)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.assetType, assetType) ||
                const DeepCollectionEquality()
                    .equals(other.assetType, assetType)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.treatment, treatment) ||
                const DeepCollectionEquality()
                    .equals(other.treatment, treatment)) &&
            (identical(other.gridLink, gridLink) ||
                const DeepCollectionEquality()
                    .equals(other.gridLink, gridLink)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.isSplitProgram, isSplitProgram) ||
                const DeepCollectionEquality()
                    .equals(other.isSplitProgram, isSplitProgram)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(assetType) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(treatment) ^
      const DeepCollectionEquality().hash(gridLink) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      runtimeType.hashCode;
}

extension $ASpotExtension on ASpot {
  ASpot copyWith(
      {String? id,
      String? mergedId,
      String? title,
      bool? isAdult,
      String? imageVersion,
      String? screenLayout,
      enums.ASpotType? type,
      enums.ASpotAssetType? assetType,
      String? brandingProviderId,
      String? channelId,
      String? eventId,
      String? background,
      String? treatment,
      GridLink? gridLink,
      String? synopsis,
      bool? isBoxset,
      bool? isSplitProgram}) {
    return ASpot(
        id: id ?? this.id,
        mergedId: mergedId ?? this.mergedId,
        title: title ?? this.title,
        isAdult: isAdult ?? this.isAdult,
        imageVersion: imageVersion ?? this.imageVersion,
        screenLayout: screenLayout ?? this.screenLayout,
        type: type ?? this.type,
        assetType: assetType ?? this.assetType,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        channelId: channelId ?? this.channelId,
        eventId: eventId ?? this.eventId,
        background: background ?? this.background,
        treatment: treatment ?? this.treatment,
        gridLink: gridLink ?? this.gridLink,
        synopsis: synopsis ?? this.synopsis,
        isBoxset: isBoxset ?? this.isBoxset,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram);
  }

  ASpot copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? mergedId,
      Wrapped<String?>? title,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? screenLayout,
      Wrapped<enums.ASpotType?>? type,
      Wrapped<enums.ASpotAssetType?>? assetType,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? channelId,
      Wrapped<String?>? eventId,
      Wrapped<String?>? background,
      Wrapped<String?>? treatment,
      Wrapped<GridLink?>? gridLink,
      Wrapped<String?>? synopsis,
      Wrapped<bool?>? isBoxset,
      Wrapped<bool?>? isSplitProgram}) {
    return ASpot(
        id: (id != null ? id.value : this.id),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        title: (title != null ? title.value : this.title),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        type: (type != null ? type.value : this.type),
        assetType: (assetType != null ? assetType.value : this.assetType),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        background: (background != null ? background.value : this.background),
        treatment: (treatment != null ? treatment.value : this.treatment),
        gridLink: (gridLink != null ? gridLink.value : this.gridLink),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram));
  }
}

@JsonSerializable(explicitToJson: true)
class Collection {
  Collection({
    this.id,
    this.title,
    this.ordinal,
    this.type,
    this.isAdult,
    this.collectionLayout,
    this.contentType,
    this.totalCount,
    this.appLink,
    this.gridLink,
    this.collectionTheme,
    this.items,
    this.subcollections,
  });

  factory Collection.fromJson(Map<String, dynamic> json) =>
      _$CollectionFromJson(json);

  static const toJsonFactory = _$CollectionToJson;
  Map<String, dynamic> toJson() => _$CollectionToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'ordinal', includeIfNull: false)
  final int? ordinal;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'collectionLayout', includeIfNull: false, defaultValue: '')
  final String? collectionLayout;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'totalCount', includeIfNull: false)
  final int? totalCount;
  @JsonKey(name: 'appLink', includeIfNull: false)
  final AppLink? appLink;
  @JsonKey(name: 'gridLink', includeIfNull: false)
  final GridLink? gridLink;
  @JsonKey(name: 'collectionTheme', includeIfNull: false)
  final CollectionTheme? collectionTheme;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <Item>[])
  final List<Item>? items;
  @JsonKey(
      name: 'subcollections',
      includeIfNull: false,
      defaultValue: <Collection>[])
  final List<Collection>? subcollections;
  static const fromJsonFactory = _$CollectionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Collection &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.ordinal, ordinal) ||
                const DeepCollectionEquality()
                    .equals(other.ordinal, ordinal)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.collectionLayout, collectionLayout) ||
                const DeepCollectionEquality()
                    .equals(other.collectionLayout, collectionLayout)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.totalCount, totalCount) ||
                const DeepCollectionEquality()
                    .equals(other.totalCount, totalCount)) &&
            (identical(other.appLink, appLink) ||
                const DeepCollectionEquality()
                    .equals(other.appLink, appLink)) &&
            (identical(other.gridLink, gridLink) ||
                const DeepCollectionEquality()
                    .equals(other.gridLink, gridLink)) &&
            (identical(other.collectionTheme, collectionTheme) ||
                const DeepCollectionEquality()
                    .equals(other.collectionTheme, collectionTheme)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)) &&
            (identical(other.subcollections, subcollections) ||
                const DeepCollectionEquality()
                    .equals(other.subcollections, subcollections)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(ordinal) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(collectionLayout) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(totalCount) ^
      const DeepCollectionEquality().hash(appLink) ^
      const DeepCollectionEquality().hash(gridLink) ^
      const DeepCollectionEquality().hash(collectionTheme) ^
      const DeepCollectionEquality().hash(items) ^
      const DeepCollectionEquality().hash(subcollections) ^
      runtimeType.hashCode;
}

extension $CollectionExtension on Collection {
  Collection copyWith(
      {String? id,
      String? title,
      int? ordinal,
      String? type,
      bool? isAdult,
      String? collectionLayout,
      String? contentType,
      int? totalCount,
      AppLink? appLink,
      GridLink? gridLink,
      CollectionTheme? collectionTheme,
      List<Item>? items,
      List<Collection>? subcollections}) {
    return Collection(
        id: id ?? this.id,
        title: title ?? this.title,
        ordinal: ordinal ?? this.ordinal,
        type: type ?? this.type,
        isAdult: isAdult ?? this.isAdult,
        collectionLayout: collectionLayout ?? this.collectionLayout,
        contentType: contentType ?? this.contentType,
        totalCount: totalCount ?? this.totalCount,
        appLink: appLink ?? this.appLink,
        gridLink: gridLink ?? this.gridLink,
        collectionTheme: collectionTheme ?? this.collectionTheme,
        items: items ?? this.items,
        subcollections: subcollections ?? this.subcollections);
  }

  Collection copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<int?>? ordinal,
      Wrapped<String?>? type,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? collectionLayout,
      Wrapped<String?>? contentType,
      Wrapped<int?>? totalCount,
      Wrapped<AppLink?>? appLink,
      Wrapped<GridLink?>? gridLink,
      Wrapped<CollectionTheme?>? collectionTheme,
      Wrapped<List<Item>?>? items,
      Wrapped<List<Collection>?>? subcollections}) {
    return Collection(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        ordinal: (ordinal != null ? ordinal.value : this.ordinal),
        type: (type != null ? type.value : this.type),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        collectionLayout: (collectionLayout != null
            ? collectionLayout.value
            : this.collectionLayout),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        totalCount: (totalCount != null ? totalCount.value : this.totalCount),
        appLink: (appLink != null ? appLink.value : this.appLink),
        gridLink: (gridLink != null ? gridLink.value : this.gridLink),
        collectionTheme: (collectionTheme != null
            ? collectionTheme.value
            : this.collectionTheme),
        items: (items != null ? items.value : this.items),
        subcollections: (subcollections != null
            ? subcollections.value
            : this.subcollections));
  }
}

@JsonSerializable(explicitToJson: true)
class AppLink {
  AppLink({
    this.id,
  });

  factory AppLink.fromJson(Map<String, dynamic> json) =>
      _$AppLinkFromJson(json);

  static const toJsonFactory = _$AppLinkToJson;
  Map<String, dynamic> toJson() => _$AppLinkToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$AppLinkFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AppLink &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $AppLinkExtension on AppLink {
  AppLink copyWith({String? id}) {
    return AppLink(id: id ?? this.id);
  }

  AppLink copyWithWrapped({Wrapped<String?>? id}) {
    return AppLink(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class GridLink {
  GridLink({
    this.id,
    this.sectionId,
    this.screenId,
    this.type,
    this.softLinkType,
    this.title,
    this.theme,
    this.replayScreen,
  });

  factory GridLink.fromJson(Map<String, dynamic> json) =>
      _$GridLinkFromJson(json);

  static const toJsonFactory = _$GridLinkToJson;
  Map<String, dynamic> toJson() => _$GridLinkToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'sectionId', includeIfNull: false, defaultValue: '')
  final String? sectionId;
  @JsonKey(name: 'screenId', includeIfNull: false, defaultValue: '')
  final String? screenId;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'softLinkType', includeIfNull: false, defaultValue: '')
  final String? softLinkType;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'theme', includeIfNull: false)
  final Theme? theme;
  @JsonKey(name: 'replayScreen', includeIfNull: false)
  final ReplayScreen? replayScreen;
  static const fromJsonFactory = _$GridLinkFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridLink &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.sectionId, sectionId) ||
                const DeepCollectionEquality()
                    .equals(other.sectionId, sectionId)) &&
            (identical(other.screenId, screenId) ||
                const DeepCollectionEquality()
                    .equals(other.screenId, screenId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.softLinkType, softLinkType) ||
                const DeepCollectionEquality()
                    .equals(other.softLinkType, softLinkType)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.theme, theme) ||
                const DeepCollectionEquality().equals(other.theme, theme)) &&
            (identical(other.replayScreen, replayScreen) ||
                const DeepCollectionEquality()
                    .equals(other.replayScreen, replayScreen)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(sectionId) ^
      const DeepCollectionEquality().hash(screenId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(softLinkType) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(theme) ^
      const DeepCollectionEquality().hash(replayScreen) ^
      runtimeType.hashCode;
}

extension $GridLinkExtension on GridLink {
  GridLink copyWith(
      {String? id,
      String? sectionId,
      String? screenId,
      String? type,
      String? softLinkType,
      String? title,
      Theme? theme,
      ReplayScreen? replayScreen}) {
    return GridLink(
        id: id ?? this.id,
        sectionId: sectionId ?? this.sectionId,
        screenId: screenId ?? this.screenId,
        type: type ?? this.type,
        softLinkType: softLinkType ?? this.softLinkType,
        title: title ?? this.title,
        theme: theme ?? this.theme,
        replayScreen: replayScreen ?? this.replayScreen);
  }

  GridLink copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? sectionId,
      Wrapped<String?>? screenId,
      Wrapped<String?>? type,
      Wrapped<String?>? softLinkType,
      Wrapped<String?>? title,
      Wrapped<Theme?>? theme,
      Wrapped<ReplayScreen?>? replayScreen}) {
    return GridLink(
        id: (id != null ? id.value : this.id),
        sectionId: (sectionId != null ? sectionId.value : this.sectionId),
        screenId: (screenId != null ? screenId.value : this.screenId),
        type: (type != null ? type.value : this.type),
        softLinkType:
            (softLinkType != null ? softLinkType.value : this.softLinkType),
        title: (title != null ? title.value : this.title),
        theme: (theme != null ? theme.value : this.theme),
        replayScreen:
            (replayScreen != null ? replayScreen.value : this.replayScreen));
  }
}

@JsonSerializable(explicitToJson: true)
class CollectionTheme {
  CollectionTheme({
    this.backgroundColor,
    this.showProviderLogo,
    this.showTileLogo,
  });

  factory CollectionTheme.fromJson(Map<String, dynamic> json) =>
      _$CollectionThemeFromJson(json);

  static const toJsonFactory = _$CollectionThemeToJson;
  Map<String, dynamic> toJson() => _$CollectionThemeToJson(this);

  @JsonKey(name: 'backgroundColor', includeIfNull: false, defaultValue: '')
  final String? backgroundColor;
  @JsonKey(name: 'showProviderLogo', includeIfNull: false)
  final bool? showProviderLogo;
  @JsonKey(name: 'showTileLogo', includeIfNull: false)
  final bool? showTileLogo;
  static const fromJsonFactory = _$CollectionThemeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CollectionTheme &&
            (identical(other.backgroundColor, backgroundColor) ||
                const DeepCollectionEquality()
                    .equals(other.backgroundColor, backgroundColor)) &&
            (identical(other.showProviderLogo, showProviderLogo) ||
                const DeepCollectionEquality()
                    .equals(other.showProviderLogo, showProviderLogo)) &&
            (identical(other.showTileLogo, showTileLogo) ||
                const DeepCollectionEquality()
                    .equals(other.showTileLogo, showTileLogo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(backgroundColor) ^
      const DeepCollectionEquality().hash(showProviderLogo) ^
      const DeepCollectionEquality().hash(showTileLogo) ^
      runtimeType.hashCode;
}

extension $CollectionThemeExtension on CollectionTheme {
  CollectionTheme copyWith(
      {String? backgroundColor, bool? showProviderLogo, bool? showTileLogo}) {
    return CollectionTheme(
        backgroundColor: backgroundColor ?? this.backgroundColor,
        showProviderLogo: showProviderLogo ?? this.showProviderLogo,
        showTileLogo: showTileLogo ?? this.showTileLogo);
  }

  CollectionTheme copyWithWrapped(
      {Wrapped<String?>? backgroundColor,
      Wrapped<bool?>? showProviderLogo,
      Wrapped<bool?>? showTileLogo}) {
    return CollectionTheme(
        backgroundColor: (backgroundColor != null
            ? backgroundColor.value
            : this.backgroundColor),
        showProviderLogo: (showProviderLogo != null
            ? showProviderLogo.value
            : this.showProviderLogo),
        showTileLogo:
            (showTileLogo != null ? showTileLogo.value : this.showTileLogo));
  }
}

@JsonSerializable(explicitToJson: true)
class Hotlinks {
  Hotlinks({
    this.rentScreen,
    this.adultRentScreen,
    this.mainMenuPromo,
  });

  factory Hotlinks.fromJson(Map<String, dynamic> json) =>
      _$HotlinksFromJson(json);

  static const toJsonFactory = _$HotlinksToJson;
  Map<String, dynamic> toJson() => _$HotlinksToJson(this);

  @JsonKey(name: 'rentScreen', includeIfNull: false)
  final Screen? rentScreen;
  @JsonKey(name: 'adultRentScreen', includeIfNull: false)
  final Screen? adultRentScreen;
  @JsonKey(name: 'mainMenuPromo', includeIfNull: false)
  final Screen? mainMenuPromo;
  static const fromJsonFactory = _$HotlinksFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Hotlinks &&
            (identical(other.rentScreen, rentScreen) ||
                const DeepCollectionEquality()
                    .equals(other.rentScreen, rentScreen)) &&
            (identical(other.adultRentScreen, adultRentScreen) ||
                const DeepCollectionEquality()
                    .equals(other.adultRentScreen, adultRentScreen)) &&
            (identical(other.mainMenuPromo, mainMenuPromo) ||
                const DeepCollectionEquality()
                    .equals(other.mainMenuPromo, mainMenuPromo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rentScreen) ^
      const DeepCollectionEquality().hash(adultRentScreen) ^
      const DeepCollectionEquality().hash(mainMenuPromo) ^
      runtimeType.hashCode;
}

extension $HotlinksExtension on Hotlinks {
  Hotlinks copyWith(
      {Screen? rentScreen, Screen? adultRentScreen, Screen? mainMenuPromo}) {
    return Hotlinks(
        rentScreen: rentScreen ?? this.rentScreen,
        adultRentScreen: adultRentScreen ?? this.adultRentScreen,
        mainMenuPromo: mainMenuPromo ?? this.mainMenuPromo);
  }

  Hotlinks copyWithWrapped(
      {Wrapped<Screen?>? rentScreen,
      Wrapped<Screen?>? adultRentScreen,
      Wrapped<Screen?>? mainMenuPromo}) {
    return Hotlinks(
        rentScreen: (rentScreen != null ? rentScreen.value : this.rentScreen),
        adultRentScreen: (adultRentScreen != null
            ? adultRentScreen.value
            : this.adultRentScreen),
        mainMenuPromo:
            (mainMenuPromo != null ? mainMenuPromo.value : this.mainMenuPromo));
  }
}

@JsonSerializable(explicitToJson: true)
class Item {
  Item({
    this.id,
    this.mergedId,
    this.type,
    this.assetType,
    this.title,
    this.subTitle,
    this.ordinal,
    this.isAdult,
    this.ageRating,
    this.duration,
    this.image,
    this.price,
    this.priceDisplay,
    this.minPrice,
    this.minPriceDisplay,
    this.seriesId,
    this.seriesTitle,
    this.seasonId,
    this.season,
    this.seasonCount,
    this.episode,
    this.gridLink,
    this.userInteractedWithSeries,
    this.bookmark,
    this.tvodEntitlementEnd,
    this.broadcastDate,
    this.brandingProviderId,
    this.channelId,
    this.eventId,
    this.channelName,
    this.screenLayout,
    this.promoVideoUrl,
    this.promoVideoEndImage,
    this.promoVideoEndText,
    this.isBoxset,
    this.isSplitProgram,
    this.goPlayable,
    this.appDeepLink,
    this.minResolution,
    this.imageVersion,
  });

  factory Item.fromJson(Map<String, dynamic> json) => _$ItemFromJson(json);

  static const toJsonFactory = _$ItemToJson;
  Map<String, dynamic> toJson() => _$ItemToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: itemTypeToJson,
    fromJson: itemTypeFromJson,
  )
  final enums.ItemType? type;
  @JsonKey(
    name: 'assetType',
    includeIfNull: false,
    toJson: itemAssetTypeToJson,
    fromJson: itemAssetTypeFromJson,
  )
  final enums.ItemAssetType? assetType;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'subTitle', includeIfNull: false, defaultValue: '')
  final String? subTitle;
  @JsonKey(name: 'ordinal', includeIfNull: false)
  final int? ordinal;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesTitle', includeIfNull: false, defaultValue: '')
  final String? seriesTitle;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'season', includeIfNull: false, defaultValue: '')
  final String? season;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'episode', includeIfNull: false, defaultValue: '')
  final String? episode;
  @JsonKey(name: 'gridLink', includeIfNull: false)
  final GridLink? gridLink;
  @JsonKey(name: 'userInteractedWithSeries', includeIfNull: false)
  final bool? userInteractedWithSeries;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'tvodEntitlementEnd', includeIfNull: false)
  final DateTime? tvodEntitlementEnd;
  @JsonKey(name: 'broadcastDate', includeIfNull: false)
  final DateTime? broadcastDate;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'promoVideoUrl', includeIfNull: false, defaultValue: '')
  final String? promoVideoUrl;
  @JsonKey(name: 'promoVideoEndImage', includeIfNull: false, defaultValue: '')
  final String? promoVideoEndImage;
  @JsonKey(name: 'promoVideoEndText', includeIfNull: false, defaultValue: '')
  final String? promoVideoEndText;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'goPlayable', includeIfNull: false)
  final bool? goPlayable;
  @JsonKey(name: 'appDeepLink', includeIfNull: false, defaultValue: '')
  final String? appDeepLink;
  @JsonKey(
    name: 'minResolution',
    includeIfNull: false,
    toJson: itemMinResolutionToJson,
    fromJson: itemMinResolutionFromJson,
  )
  final enums.ItemMinResolution? minResolution;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$ItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Item &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.assetType, assetType) ||
                const DeepCollectionEquality()
                    .equals(other.assetType, assetType)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.subTitle, subTitle) ||
                const DeepCollectionEquality()
                    .equals(other.subTitle, subTitle)) &&
            (identical(other.ordinal, ordinal) ||
                const DeepCollectionEquality()
                    .equals(other.ordinal, ordinal)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesTitle, seriesTitle) ||
                const DeepCollectionEquality()
                    .equals(other.seriesTitle, seriesTitle)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.gridLink, gridLink) ||
                const DeepCollectionEquality()
                    .equals(other.gridLink, gridLink)) &&
            (identical(other.userInteractedWithSeries, userInteractedWithSeries) ||
                const DeepCollectionEquality().equals(
                    other.userInteractedWithSeries,
                    userInteractedWithSeries)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality().equals(other.bookmark, bookmark)) &&
            (identical(other.tvodEntitlementEnd, tvodEntitlementEnd) || const DeepCollectionEquality().equals(other.tvodEntitlementEnd, tvodEntitlementEnd)) &&
            (identical(other.broadcastDate, broadcastDate) || const DeepCollectionEquality().equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.brandingProviderId, brandingProviderId) || const DeepCollectionEquality().equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.channelId, channelId) || const DeepCollectionEquality().equals(other.channelId, channelId)) &&
            (identical(other.eventId, eventId) || const DeepCollectionEquality().equals(other.eventId, eventId)) &&
            (identical(other.channelName, channelName) || const DeepCollectionEquality().equals(other.channelName, channelName)) &&
            (identical(other.screenLayout, screenLayout) || const DeepCollectionEquality().equals(other.screenLayout, screenLayout)) &&
            (identical(other.promoVideoUrl, promoVideoUrl) || const DeepCollectionEquality().equals(other.promoVideoUrl, promoVideoUrl)) &&
            (identical(other.promoVideoEndImage, promoVideoEndImage) || const DeepCollectionEquality().equals(other.promoVideoEndImage, promoVideoEndImage)) &&
            (identical(other.promoVideoEndText, promoVideoEndText) || const DeepCollectionEquality().equals(other.promoVideoEndText, promoVideoEndText)) &&
            (identical(other.isBoxset, isBoxset) || const DeepCollectionEquality().equals(other.isBoxset, isBoxset)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.goPlayable, goPlayable) || const DeepCollectionEquality().equals(other.goPlayable, goPlayable)) &&
            (identical(other.appDeepLink, appDeepLink) || const DeepCollectionEquality().equals(other.appDeepLink, appDeepLink)) &&
            (identical(other.minResolution, minResolution) || const DeepCollectionEquality().equals(other.minResolution, minResolution)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(assetType) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(subTitle) ^
      const DeepCollectionEquality().hash(ordinal) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesTitle) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(gridLink) ^
      const DeepCollectionEquality().hash(userInteractedWithSeries) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(tvodEntitlementEnd) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(promoVideoUrl) ^
      const DeepCollectionEquality().hash(promoVideoEndImage) ^
      const DeepCollectionEquality().hash(promoVideoEndText) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(goPlayable) ^
      const DeepCollectionEquality().hash(appDeepLink) ^
      const DeepCollectionEquality().hash(minResolution) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $ItemExtension on Item {
  Item copyWith(
      {String? id,
      String? mergedId,
      enums.ItemType? type,
      enums.ItemAssetType? assetType,
      String? title,
      String? subTitle,
      int? ordinal,
      bool? isAdult,
      String? ageRating,
      int? duration,
      String? image,
      String? price,
      String? priceDisplay,
      String? minPrice,
      String? minPriceDisplay,
      String? seriesId,
      String? seriesTitle,
      String? seasonId,
      String? season,
      int? seasonCount,
      String? episode,
      GridLink? gridLink,
      bool? userInteractedWithSeries,
      int? bookmark,
      DateTime? tvodEntitlementEnd,
      DateTime? broadcastDate,
      String? brandingProviderId,
      String? channelId,
      String? eventId,
      String? channelName,
      String? screenLayout,
      String? promoVideoUrl,
      String? promoVideoEndImage,
      String? promoVideoEndText,
      bool? isBoxset,
      bool? isSplitProgram,
      bool? goPlayable,
      String? appDeepLink,
      enums.ItemMinResolution? minResolution,
      String? imageVersion}) {
    return Item(
        id: id ?? this.id,
        mergedId: mergedId ?? this.mergedId,
        type: type ?? this.type,
        assetType: assetType ?? this.assetType,
        title: title ?? this.title,
        subTitle: subTitle ?? this.subTitle,
        ordinal: ordinal ?? this.ordinal,
        isAdult: isAdult ?? this.isAdult,
        ageRating: ageRating ?? this.ageRating,
        duration: duration ?? this.duration,
        image: image ?? this.image,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        seriesId: seriesId ?? this.seriesId,
        seriesTitle: seriesTitle ?? this.seriesTitle,
        seasonId: seasonId ?? this.seasonId,
        season: season ?? this.season,
        seasonCount: seasonCount ?? this.seasonCount,
        episode: episode ?? this.episode,
        gridLink: gridLink ?? this.gridLink,
        userInteractedWithSeries:
            userInteractedWithSeries ?? this.userInteractedWithSeries,
        bookmark: bookmark ?? this.bookmark,
        tvodEntitlementEnd: tvodEntitlementEnd ?? this.tvodEntitlementEnd,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        channelId: channelId ?? this.channelId,
        eventId: eventId ?? this.eventId,
        channelName: channelName ?? this.channelName,
        screenLayout: screenLayout ?? this.screenLayout,
        promoVideoUrl: promoVideoUrl ?? this.promoVideoUrl,
        promoVideoEndImage: promoVideoEndImage ?? this.promoVideoEndImage,
        promoVideoEndText: promoVideoEndText ?? this.promoVideoEndText,
        isBoxset: isBoxset ?? this.isBoxset,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        goPlayable: goPlayable ?? this.goPlayable,
        appDeepLink: appDeepLink ?? this.appDeepLink,
        minResolution: minResolution ?? this.minResolution,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  Item copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? mergedId,
      Wrapped<enums.ItemType?>? type,
      Wrapped<enums.ItemAssetType?>? assetType,
      Wrapped<String?>? title,
      Wrapped<String?>? subTitle,
      Wrapped<int?>? ordinal,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? ageRating,
      Wrapped<int?>? duration,
      Wrapped<String?>? image,
      Wrapped<String?>? price,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? seriesTitle,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? season,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? episode,
      Wrapped<GridLink?>? gridLink,
      Wrapped<bool?>? userInteractedWithSeries,
      Wrapped<int?>? bookmark,
      Wrapped<DateTime?>? tvodEntitlementEnd,
      Wrapped<DateTime?>? broadcastDate,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? channelId,
      Wrapped<String?>? eventId,
      Wrapped<String?>? channelName,
      Wrapped<String?>? screenLayout,
      Wrapped<String?>? promoVideoUrl,
      Wrapped<String?>? promoVideoEndImage,
      Wrapped<String?>? promoVideoEndText,
      Wrapped<bool?>? isBoxset,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<bool?>? goPlayable,
      Wrapped<String?>? appDeepLink,
      Wrapped<enums.ItemMinResolution?>? minResolution,
      Wrapped<String?>? imageVersion}) {
    return Item(
        id: (id != null ? id.value : this.id),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        type: (type != null ? type.value : this.type),
        assetType: (assetType != null ? assetType.value : this.assetType),
        title: (title != null ? title.value : this.title),
        subTitle: (subTitle != null ? subTitle.value : this.subTitle),
        ordinal: (ordinal != null ? ordinal.value : this.ordinal),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        duration: (duration != null ? duration.value : this.duration),
        image: (image != null ? image.value : this.image),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesTitle:
            (seriesTitle != null ? seriesTitle.value : this.seriesTitle),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        season: (season != null ? season.value : this.season),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        episode: (episode != null ? episode.value : this.episode),
        gridLink: (gridLink != null ? gridLink.value : this.gridLink),
        userInteractedWithSeries: (userInteractedWithSeries != null
            ? userInteractedWithSeries.value
            : this.userInteractedWithSeries),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        tvodEntitlementEnd: (tvodEntitlementEnd != null
            ? tvodEntitlementEnd.value
            : this.tvodEntitlementEnd),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        promoVideoUrl:
            (promoVideoUrl != null ? promoVideoUrl.value : this.promoVideoUrl),
        promoVideoEndImage: (promoVideoEndImage != null
            ? promoVideoEndImage.value
            : this.promoVideoEndImage),
        promoVideoEndText: (promoVideoEndText != null
            ? promoVideoEndText.value
            : this.promoVideoEndText),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        goPlayable: (goPlayable != null ? goPlayable.value : this.goPlayable),
        appDeepLink:
            (appDeepLink != null ? appDeepLink.value : this.appDeepLink),
        minResolution:
            (minResolution != null ? minResolution.value : this.minResolution),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayScreen {
  ReplayScreen({
    this.id,
    this.showNetworkDropdown,
    this.showChannelDropdown,
    this.showDayDropdown,
    this.showGenreDropdown,
    this.showSortingDropdown,
    this.sorting,
    this.replayProviderId,
    this.channelId,
    this.replayGenreId,
    this.dayStart,
  });

  factory ReplayScreen.fromJson(Map<String, dynamic> json) =>
      _$ReplayScreenFromJson(json);

  static const toJsonFactory = _$ReplayScreenToJson;
  Map<String, dynamic> toJson() => _$ReplayScreenToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'showNetworkDropdown', includeIfNull: false)
  final bool? showNetworkDropdown;
  @JsonKey(name: 'showChannelDropdown', includeIfNull: false)
  final bool? showChannelDropdown;
  @JsonKey(name: 'showDayDropdown', includeIfNull: false)
  final bool? showDayDropdown;
  @JsonKey(name: 'showGenreDropdown', includeIfNull: false)
  final bool? showGenreDropdown;
  @JsonKey(name: 'showSortingDropdown', includeIfNull: false)
  final bool? showSortingDropdown;
  @JsonKey(name: 'sorting', includeIfNull: false, defaultValue: '')
  final String? sorting;
  @JsonKey(name: 'replayProviderId', includeIfNull: false, defaultValue: '')
  final String? replayProviderId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'replayGenreId', includeIfNull: false, defaultValue: '')
  final String? replayGenreId;
  @JsonKey(name: 'dayStart', includeIfNull: false, defaultValue: '')
  final String? dayStart;
  static const fromJsonFactory = _$ReplayScreenFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayScreen &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.showNetworkDropdown, showNetworkDropdown) ||
                const DeepCollectionEquality()
                    .equals(other.showNetworkDropdown, showNetworkDropdown)) &&
            (identical(other.showChannelDropdown, showChannelDropdown) ||
                const DeepCollectionEquality()
                    .equals(other.showChannelDropdown, showChannelDropdown)) &&
            (identical(other.showDayDropdown, showDayDropdown) ||
                const DeepCollectionEquality()
                    .equals(other.showDayDropdown, showDayDropdown)) &&
            (identical(other.showGenreDropdown, showGenreDropdown) ||
                const DeepCollectionEquality()
                    .equals(other.showGenreDropdown, showGenreDropdown)) &&
            (identical(other.showSortingDropdown, showSortingDropdown) ||
                const DeepCollectionEquality()
                    .equals(other.showSortingDropdown, showSortingDropdown)) &&
            (identical(other.sorting, sorting) ||
                const DeepCollectionEquality()
                    .equals(other.sorting, sorting)) &&
            (identical(other.replayProviderId, replayProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.replayProviderId, replayProviderId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.replayGenreId, replayGenreId) ||
                const DeepCollectionEquality()
                    .equals(other.replayGenreId, replayGenreId)) &&
            (identical(other.dayStart, dayStart) ||
                const DeepCollectionEquality()
                    .equals(other.dayStart, dayStart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(showNetworkDropdown) ^
      const DeepCollectionEquality().hash(showChannelDropdown) ^
      const DeepCollectionEquality().hash(showDayDropdown) ^
      const DeepCollectionEquality().hash(showGenreDropdown) ^
      const DeepCollectionEquality().hash(showSortingDropdown) ^
      const DeepCollectionEquality().hash(sorting) ^
      const DeepCollectionEquality().hash(replayProviderId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(replayGenreId) ^
      const DeepCollectionEquality().hash(dayStart) ^
      runtimeType.hashCode;
}

extension $ReplayScreenExtension on ReplayScreen {
  ReplayScreen copyWith(
      {String? id,
      bool? showNetworkDropdown,
      bool? showChannelDropdown,
      bool? showDayDropdown,
      bool? showGenreDropdown,
      bool? showSortingDropdown,
      String? sorting,
      String? replayProviderId,
      String? channelId,
      String? replayGenreId,
      String? dayStart}) {
    return ReplayScreen(
        id: id ?? this.id,
        showNetworkDropdown: showNetworkDropdown ?? this.showNetworkDropdown,
        showChannelDropdown: showChannelDropdown ?? this.showChannelDropdown,
        showDayDropdown: showDayDropdown ?? this.showDayDropdown,
        showGenreDropdown: showGenreDropdown ?? this.showGenreDropdown,
        showSortingDropdown: showSortingDropdown ?? this.showSortingDropdown,
        sorting: sorting ?? this.sorting,
        replayProviderId: replayProviderId ?? this.replayProviderId,
        channelId: channelId ?? this.channelId,
        replayGenreId: replayGenreId ?? this.replayGenreId,
        dayStart: dayStart ?? this.dayStart);
  }

  ReplayScreen copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<bool?>? showNetworkDropdown,
      Wrapped<bool?>? showChannelDropdown,
      Wrapped<bool?>? showDayDropdown,
      Wrapped<bool?>? showGenreDropdown,
      Wrapped<bool?>? showSortingDropdown,
      Wrapped<String?>? sorting,
      Wrapped<String?>? replayProviderId,
      Wrapped<String?>? channelId,
      Wrapped<String?>? replayGenreId,
      Wrapped<String?>? dayStart}) {
    return ReplayScreen(
        id: (id != null ? id.value : this.id),
        showNetworkDropdown: (showNetworkDropdown != null
            ? showNetworkDropdown.value
            : this.showNetworkDropdown),
        showChannelDropdown: (showChannelDropdown != null
            ? showChannelDropdown.value
            : this.showChannelDropdown),
        showDayDropdown: (showDayDropdown != null
            ? showDayDropdown.value
            : this.showDayDropdown),
        showGenreDropdown: (showGenreDropdown != null
            ? showGenreDropdown.value
            : this.showGenreDropdown),
        showSortingDropdown: (showSortingDropdown != null
            ? showSortingDropdown.value
            : this.showSortingDropdown),
        sorting: (sorting != null ? sorting.value : this.sorting),
        replayProviderId: (replayProviderId != null
            ? replayProviderId.value
            : this.replayProviderId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        replayGenreId:
            (replayGenreId != null ? replayGenreId.value : this.replayGenreId),
        dayStart: (dayStart != null ? dayStart.value : this.dayStart));
  }
}

@JsonSerializable(explicitToJson: true)
class Screen {
  Screen({
    this.id,
    this.structureId,
    this.title,
    this.ordinal,
    this.isAdult,
    this.screenLayout,
    this.theme,
    this.image,
    this.abTestGroup,
    this.brandingProviderId,
    this.isBoxset,
    this.aspot,
    this.collections,
  });

  factory Screen.fromJson(Map<String, dynamic> json) => _$ScreenFromJson(json);

  static const toJsonFactory = _$ScreenToJson;
  Map<String, dynamic> toJson() => _$ScreenToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'structureId', includeIfNull: false, defaultValue: '')
  final String? structureId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'ordinal', includeIfNull: false)
  final int? ordinal;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'theme', includeIfNull: false)
  final Theme? theme;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'abTestGroup', includeIfNull: false, defaultValue: '')
  final String? abTestGroup;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'aspot', includeIfNull: false)
  final ASpot? aspot;
  @JsonKey(
      name: 'collections', includeIfNull: false, defaultValue: <Collection>[])
  final List<Collection>? collections;
  static const fromJsonFactory = _$ScreenFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Screen &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.structureId, structureId) ||
                const DeepCollectionEquality()
                    .equals(other.structureId, structureId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.ordinal, ordinal) ||
                const DeepCollectionEquality()
                    .equals(other.ordinal, ordinal)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.screenLayout, screenLayout) ||
                const DeepCollectionEquality()
                    .equals(other.screenLayout, screenLayout)) &&
            (identical(other.theme, theme) ||
                const DeepCollectionEquality().equals(other.theme, theme)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.abTestGroup, abTestGroup) ||
                const DeepCollectionEquality()
                    .equals(other.abTestGroup, abTestGroup)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.aspot, aspot) ||
                const DeepCollectionEquality().equals(other.aspot, aspot)) &&
            (identical(other.collections, collections) ||
                const DeepCollectionEquality()
                    .equals(other.collections, collections)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(structureId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(ordinal) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(theme) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(abTestGroup) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(aspot) ^
      const DeepCollectionEquality().hash(collections) ^
      runtimeType.hashCode;
}

extension $ScreenExtension on Screen {
  Screen copyWith(
      {String? id,
      String? structureId,
      String? title,
      int? ordinal,
      bool? isAdult,
      String? screenLayout,
      Theme? theme,
      String? image,
      String? abTestGroup,
      String? brandingProviderId,
      bool? isBoxset,
      ASpot? aspot,
      List<Collection>? collections}) {
    return Screen(
        id: id ?? this.id,
        structureId: structureId ?? this.structureId,
        title: title ?? this.title,
        ordinal: ordinal ?? this.ordinal,
        isAdult: isAdult ?? this.isAdult,
        screenLayout: screenLayout ?? this.screenLayout,
        theme: theme ?? this.theme,
        image: image ?? this.image,
        abTestGroup: abTestGroup ?? this.abTestGroup,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        isBoxset: isBoxset ?? this.isBoxset,
        aspot: aspot ?? this.aspot,
        collections: collections ?? this.collections);
  }

  Screen copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? structureId,
      Wrapped<String?>? title,
      Wrapped<int?>? ordinal,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? screenLayout,
      Wrapped<Theme?>? theme,
      Wrapped<String?>? image,
      Wrapped<String?>? abTestGroup,
      Wrapped<String?>? brandingProviderId,
      Wrapped<bool?>? isBoxset,
      Wrapped<ASpot?>? aspot,
      Wrapped<List<Collection>?>? collections}) {
    return Screen(
        id: (id != null ? id.value : this.id),
        structureId:
            (structureId != null ? structureId.value : this.structureId),
        title: (title != null ? title.value : this.title),
        ordinal: (ordinal != null ? ordinal.value : this.ordinal),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        theme: (theme != null ? theme.value : this.theme),
        image: (image != null ? image.value : this.image),
        abTestGroup:
            (abTestGroup != null ? abTestGroup.value : this.abTestGroup),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        aspot: (aspot != null ? aspot.value : this.aspot),
        collections:
            (collections != null ? collections.value : this.collections));
  }
}

@JsonSerializable(explicitToJson: true)
class Structure {
  Structure({
    this.rootId,
    this.id,
    this.title,
    this.theme,
    this.screens,
    this.hotlinks,
  });

  factory Structure.fromJson(Map<String, dynamic> json) =>
      _$StructureFromJson(json);

  static const toJsonFactory = _$StructureToJson;
  Map<String, dynamic> toJson() => _$StructureToJson(this);

  @JsonKey(name: 'rootId', includeIfNull: false, defaultValue: '')
  final String? rootId;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'theme', includeIfNull: false)
  final Theme? theme;
  @JsonKey(name: 'screens', includeIfNull: false, defaultValue: <Screen>[])
  final List<Screen>? screens;
  @JsonKey(name: 'hotlinks', includeIfNull: false)
  final Hotlinks? hotlinks;
  static const fromJsonFactory = _$StructureFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Structure &&
            (identical(other.rootId, rootId) ||
                const DeepCollectionEquality().equals(other.rootId, rootId)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.theme, theme) ||
                const DeepCollectionEquality().equals(other.theme, theme)) &&
            (identical(other.screens, screens) ||
                const DeepCollectionEquality()
                    .equals(other.screens, screens)) &&
            (identical(other.hotlinks, hotlinks) ||
                const DeepCollectionEquality()
                    .equals(other.hotlinks, hotlinks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rootId) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(theme) ^
      const DeepCollectionEquality().hash(screens) ^
      const DeepCollectionEquality().hash(hotlinks) ^
      runtimeType.hashCode;
}

extension $StructureExtension on Structure {
  Structure copyWith(
      {String? rootId,
      String? id,
      String? title,
      Theme? theme,
      List<Screen>? screens,
      Hotlinks? hotlinks}) {
    return Structure(
        rootId: rootId ?? this.rootId,
        id: id ?? this.id,
        title: title ?? this.title,
        theme: theme ?? this.theme,
        screens: screens ?? this.screens,
        hotlinks: hotlinks ?? this.hotlinks);
  }

  Structure copyWithWrapped(
      {Wrapped<String?>? rootId,
      Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<Theme?>? theme,
      Wrapped<List<Screen>?>? screens,
      Wrapped<Hotlinks?>? hotlinks}) {
    return Structure(
        rootId: (rootId != null ? rootId.value : this.rootId),
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        theme: (theme != null ? theme.value : this.theme),
        screens: (screens != null ? screens.value : this.screens),
        hotlinks: (hotlinks != null ? hotlinks.value : this.hotlinks));
  }
}

@JsonSerializable(explicitToJson: true)
class Theme {
  Theme({
    this.name,
    this.background,
    this.aspotBackground,
    this.logoFocused,
    this.logoNonfocused,
    this.editorialImage,
    this.brandLogoImage,
    this.channelLogoUrl,
  });

  factory Theme.fromJson(Map<String, dynamic> json) => _$ThemeFromJson(json);

  static const toJsonFactory = _$ThemeToJson;
  Map<String, dynamic> toJson() => _$ThemeToJson(this);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String? background;
  @JsonKey(name: 'aspotBackground', includeIfNull: false, defaultValue: '')
  final String? aspotBackground;
  @JsonKey(name: 'logoFocused', includeIfNull: false, defaultValue: '')
  final String? logoFocused;
  @JsonKey(name: 'logoNonfocused', includeIfNull: false, defaultValue: '')
  final String? logoNonfocused;
  @JsonKey(name: 'editorialImage', includeIfNull: false, defaultValue: '')
  final String? editorialImage;
  @JsonKey(name: 'brandLogoImage', includeIfNull: false, defaultValue: '')
  final String? brandLogoImage;
  @JsonKey(name: 'channelLogoUrl', includeIfNull: false, defaultValue: '')
  final String? channelLogoUrl;
  static const fromJsonFactory = _$ThemeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Theme &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.aspotBackground, aspotBackground) ||
                const DeepCollectionEquality()
                    .equals(other.aspotBackground, aspotBackground)) &&
            (identical(other.logoFocused, logoFocused) ||
                const DeepCollectionEquality()
                    .equals(other.logoFocused, logoFocused)) &&
            (identical(other.logoNonfocused, logoNonfocused) ||
                const DeepCollectionEquality()
                    .equals(other.logoNonfocused, logoNonfocused)) &&
            (identical(other.editorialImage, editorialImage) ||
                const DeepCollectionEquality()
                    .equals(other.editorialImage, editorialImage)) &&
            (identical(other.brandLogoImage, brandLogoImage) ||
                const DeepCollectionEquality()
                    .equals(other.brandLogoImage, brandLogoImage)) &&
            (identical(other.channelLogoUrl, channelLogoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.channelLogoUrl, channelLogoUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(aspotBackground) ^
      const DeepCollectionEquality().hash(logoFocused) ^
      const DeepCollectionEquality().hash(logoNonfocused) ^
      const DeepCollectionEquality().hash(editorialImage) ^
      const DeepCollectionEquality().hash(brandLogoImage) ^
      const DeepCollectionEquality().hash(channelLogoUrl) ^
      runtimeType.hashCode;
}

extension $ThemeExtension on Theme {
  Theme copyWith(
      {String? name,
      String? background,
      String? aspotBackground,
      String? logoFocused,
      String? logoNonfocused,
      String? editorialImage,
      String? brandLogoImage,
      String? channelLogoUrl}) {
    return Theme(
        name: name ?? this.name,
        background: background ?? this.background,
        aspotBackground: aspotBackground ?? this.aspotBackground,
        logoFocused: logoFocused ?? this.logoFocused,
        logoNonfocused: logoNonfocused ?? this.logoNonfocused,
        editorialImage: editorialImage ?? this.editorialImage,
        brandLogoImage: brandLogoImage ?? this.brandLogoImage,
        channelLogoUrl: channelLogoUrl ?? this.channelLogoUrl);
  }

  Theme copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<String?>? background,
      Wrapped<String?>? aspotBackground,
      Wrapped<String?>? logoFocused,
      Wrapped<String?>? logoNonfocused,
      Wrapped<String?>? editorialImage,
      Wrapped<String?>? brandLogoImage,
      Wrapped<String?>? channelLogoUrl}) {
    return Theme(
        name: (name != null ? name.value : this.name),
        background: (background != null ? background.value : this.background),
        aspotBackground: (aspotBackground != null
            ? aspotBackground.value
            : this.aspotBackground),
        logoFocused:
            (logoFocused != null ? logoFocused.value : this.logoFocused),
        logoNonfocused: (logoNonfocused != null
            ? logoNonfocused.value
            : this.logoNonfocused),
        editorialImage: (editorialImage != null
            ? editorialImage.value
            : this.editorialImage),
        brandLogoImage: (brandLogoImage != null
            ? brandLogoImage.value
            : this.brandLogoImage),
        channelLogoUrl: (channelLogoUrl != null
            ? channelLogoUrl.value
            : this.channelLogoUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class RentalScreen {
  RentalScreen({
    this.hasAdultRentals,
    this.id,
    this.title,
    this.screenLayout,
    this.isAdult,
    this.background,
    this.logoThumbnail,
    this.brandingProviderId,
    this.indexStart,
    this.itemCount,
    this.totalCount,
    this.items,
  });

  factory RentalScreen.fromJson(Map<String, dynamic> json) =>
      _$RentalScreenFromJson(json);

  static const toJsonFactory = _$RentalScreenToJson;
  Map<String, dynamic> toJson() => _$RentalScreenToJson(this);

  @JsonKey(name: 'hasAdultRentals', includeIfNull: false)
  final bool? hasAdultRentals;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String? background;
  @JsonKey(name: 'logoThumbnail', includeIfNull: false, defaultValue: '')
  final String? logoThumbnail;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'indexStart', includeIfNull: false)
  final int? indexStart;
  @JsonKey(name: 'itemCount', includeIfNull: false)
  final int? itemCount;
  @JsonKey(name: 'totalCount', includeIfNull: false)
  final int? totalCount;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <Item>[])
  final List<Item>? items;
  static const fromJsonFactory = _$RentalScreenFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RentalScreen &&
            (identical(other.hasAdultRentals, hasAdultRentals) ||
                const DeepCollectionEquality()
                    .equals(other.hasAdultRentals, hasAdultRentals)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.screenLayout, screenLayout) ||
                const DeepCollectionEquality()
                    .equals(other.screenLayout, screenLayout)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.logoThumbnail, logoThumbnail) ||
                const DeepCollectionEquality()
                    .equals(other.logoThumbnail, logoThumbnail)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.indexStart, indexStart) ||
                const DeepCollectionEquality()
                    .equals(other.indexStart, indexStart)) &&
            (identical(other.itemCount, itemCount) ||
                const DeepCollectionEquality()
                    .equals(other.itemCount, itemCount)) &&
            (identical(other.totalCount, totalCount) ||
                const DeepCollectionEquality()
                    .equals(other.totalCount, totalCount)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(hasAdultRentals) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(logoThumbnail) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(indexStart) ^
      const DeepCollectionEquality().hash(itemCount) ^
      const DeepCollectionEquality().hash(totalCount) ^
      const DeepCollectionEquality().hash(items) ^
      runtimeType.hashCode;
}

extension $RentalScreenExtension on RentalScreen {
  RentalScreen copyWith(
      {bool? hasAdultRentals,
      String? id,
      String? title,
      String? screenLayout,
      bool? isAdult,
      String? background,
      String? logoThumbnail,
      String? brandingProviderId,
      int? indexStart,
      int? itemCount,
      int? totalCount,
      List<Item>? items}) {
    return RentalScreen(
        hasAdultRentals: hasAdultRentals ?? this.hasAdultRentals,
        id: id ?? this.id,
        title: title ?? this.title,
        screenLayout: screenLayout ?? this.screenLayout,
        isAdult: isAdult ?? this.isAdult,
        background: background ?? this.background,
        logoThumbnail: logoThumbnail ?? this.logoThumbnail,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        indexStart: indexStart ?? this.indexStart,
        itemCount: itemCount ?? this.itemCount,
        totalCount: totalCount ?? this.totalCount,
        items: items ?? this.items);
  }

  RentalScreen copyWithWrapped(
      {Wrapped<bool?>? hasAdultRentals,
      Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? screenLayout,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? background,
      Wrapped<String?>? logoThumbnail,
      Wrapped<String?>? brandingProviderId,
      Wrapped<int?>? indexStart,
      Wrapped<int?>? itemCount,
      Wrapped<int?>? totalCount,
      Wrapped<List<Item>?>? items}) {
    return RentalScreen(
        hasAdultRentals: (hasAdultRentals != null
            ? hasAdultRentals.value
            : this.hasAdultRentals),
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        background: (background != null ? background.value : this.background),
        logoThumbnail:
            (logoThumbnail != null ? logoThumbnail.value : this.logoThumbnail),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        indexStart: (indexStart != null ? indexStart.value : this.indexStart),
        itemCount: (itemCount != null ? itemCount.value : this.itemCount),
        totalCount: (totalCount != null ? totalCount.value : this.totalCount),
        items: (items != null ? items.value : this.items));
  }
}

@JsonSerializable(explicitToJson: true)
class CastAndCrew {
  CastAndCrew({
    this.id,
    this.name,
    this.role,
    this.image,
  });

  factory CastAndCrew.fromJson(Map<String, dynamic> json) =>
      _$CastAndCrewFromJson(json);

  static const toJsonFactory = _$CastAndCrewToJson;
  Map<String, dynamic> toJson() => _$CastAndCrewToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'role', includeIfNull: false, defaultValue: '')
  final String? role;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$CastAndCrewFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CastAndCrew &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.role, role) ||
                const DeepCollectionEquality().equals(other.role, role)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(role) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $CastAndCrewExtension on CastAndCrew {
  CastAndCrew copyWith(
      {String? id, String? name, String? role, String? image}) {
    return CastAndCrew(
        id: id ?? this.id,
        name: name ?? this.name,
        role: role ?? this.role,
        image: image ?? this.image);
  }

  CastAndCrew copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? role,
      Wrapped<String?>? image}) {
    return CastAndCrew(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        role: (role != null ? role.value : this.role),
        image: (image != null ? image.value : this.image));
  }
}

@JsonSerializable(explicitToJson: true)
class TrailerInfo {
  TrailerInfo({
    this.id,
    this.title,
    this.duration,
    this.synopsis,
    this.parentTitleId,
    this.instances,
  });

  factory TrailerInfo.fromJson(Map<String, dynamic> json) =>
      _$TrailerInfoFromJson(json);

  static const toJsonFactory = _$TrailerInfoToJson;
  Map<String, dynamic> toJson() => _$TrailerInfoToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'parentTitleId', includeIfNull: false, defaultValue: '')
  final String? parentTitleId;
  @JsonKey(
      name: 'instances',
      includeIfNull: false,
      defaultValue: <TrailerInstance>[])
  final List<TrailerInstance>? instances;
  static const fromJsonFactory = _$TrailerInfoFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TrailerInfo &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.parentTitleId, parentTitleId) ||
                const DeepCollectionEquality()
                    .equals(other.parentTitleId, parentTitleId)) &&
            (identical(other.instances, instances) ||
                const DeepCollectionEquality()
                    .equals(other.instances, instances)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(parentTitleId) ^
      const DeepCollectionEquality().hash(instances) ^
      runtimeType.hashCode;
}

extension $TrailerInfoExtension on TrailerInfo {
  TrailerInfo copyWith(
      {String? id,
      String? title,
      int? duration,
      String? synopsis,
      String? parentTitleId,
      List<TrailerInstance>? instances}) {
    return TrailerInfo(
        id: id ?? this.id,
        title: title ?? this.title,
        duration: duration ?? this.duration,
        synopsis: synopsis ?? this.synopsis,
        parentTitleId: parentTitleId ?? this.parentTitleId,
        instances: instances ?? this.instances);
  }

  TrailerInfo copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<int?>? duration,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? parentTitleId,
      Wrapped<List<TrailerInstance>?>? instances}) {
    return TrailerInfo(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        duration: (duration != null ? duration.value : this.duration),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        parentTitleId:
            (parentTitleId != null ? parentTitleId.value : this.parentTitleId),
        instances: (instances != null ? instances.value : this.instances));
  }
}

@JsonSerializable(explicitToJson: true)
class DetailScreen {
  DetailScreen({
    this.id,
    this.mergedId,
    this.imageVersion,
    this.type,
    this.assetType,
    this.title,
    this.subTitle,
    this.ordinal,
    this.isPreview,
    this.parentTitleId,
    this.isAdult,
    this.ageRating,
    this.duration,
    this.image,
    this.price,
    this.priceDisplay,
    this.minPrice,
    this.minPriceDisplay,
    this.seriesId,
    this.seriesTitle,
    this.seasonId,
    this.season,
    this.episode,
    this.gridLink,
    this.userInteractedWithSeries,
    this.bookmark,
    this.tvodEntitlementEnd,
    this.broadcastDate,
    this.channelName,
    this.screenLayout,
    this.totalEpisodes,
    this.parentalGuidanceText,
    this.onWatchlist,
    this.genres,
    this.synopsis,
    this.longSynopsis,
    this.audioLanguages,
    this.signLanguages,
    this.country,
    this.subtitles,
    this.supplementalAudioDescriptions,
    this.icons,
    this.trailers,
    this.trailerInfo,
    this.castAndCrew,
    this.castCollection,
    this.crewCollection,
    this.instances,
    this.prodYear,
    this.seasonCount,
    this.promoVideoUrl,
    this.promoVideoEndImage,
    this.promoVideoEndText,
    this.minResolution,
    this.isBoxset,
    this.goPlayable,
    this.brandingProviderId,
    this.sources,
  });

  factory DetailScreen.fromJson(Map<String, dynamic> json) =>
      _$DetailScreenFromJson(json);

  static const toJsonFactory = _$DetailScreenToJson;
  Map<String, dynamic> toJson() => _$DetailScreenToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: detailScreenTypeToJson,
    fromJson: detailScreenTypeFromJson,
  )
  final enums.DetailScreenType? type;
  @JsonKey(
    name: 'assetType',
    includeIfNull: false,
    toJson: detailScreenAssetTypeToJson,
    fromJson: detailScreenAssetTypeFromJson,
  )
  final enums.DetailScreenAssetType? assetType;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'subTitle', includeIfNull: false, defaultValue: '')
  final String? subTitle;
  @JsonKey(name: 'ordinal', includeIfNull: false)
  final int? ordinal;
  @JsonKey(name: 'isPreview', includeIfNull: false)
  final bool? isPreview;
  @JsonKey(name: 'parentTitleId', includeIfNull: false, defaultValue: '')
  final String? parentTitleId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesTitle', includeIfNull: false, defaultValue: '')
  final String? seriesTitle;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'season', includeIfNull: false, defaultValue: '')
  final String? season;
  @JsonKey(name: 'episode', includeIfNull: false, defaultValue: '')
  final String? episode;
  @JsonKey(name: 'gridLink', includeIfNull: false)
  final GridLink? gridLink;
  @JsonKey(name: 'userInteractedWithSeries', includeIfNull: false)
  final bool? userInteractedWithSeries;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'tvodEntitlementEnd', includeIfNull: false)
  final DateTime? tvodEntitlementEnd;
  @JsonKey(name: 'broadcastDate', includeIfNull: false)
  final DateTime? broadcastDate;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'totalEpisodes', includeIfNull: false)
  final int? totalEpisodes;
  @JsonKey(name: 'parentalGuidanceText', includeIfNull: false, defaultValue: '')
  final String? parentalGuidanceText;
  @JsonKey(name: 'onWatchlist', includeIfNull: false)
  final bool? onWatchlist;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'longSynopsis', includeIfNull: false, defaultValue: '')
  final String? longSynopsis;
  @JsonKey(
      name: 'audioLanguages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? audioLanguages;
  @JsonKey(
      name: 'signLanguages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? signLanguages;
  @JsonKey(name: 'country', includeIfNull: false, defaultValue: <String>[])
  final List<String>? country;
  @JsonKey(name: 'subtitles', includeIfNull: false, defaultValue: <String>[])
  final List<String>? subtitles;
  @JsonKey(
      name: 'supplementalAudioDescriptions',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? supplementalAudioDescriptions;
  @JsonKey(name: 'icons', includeIfNull: false, defaultValue: <String>[])
  final List<String>? icons;
  @JsonKey(name: 'trailers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? trailers;
  @JsonKey(
      name: 'trailerInfo', includeIfNull: false, defaultValue: <TrailerInfo>[])
  final List<TrailerInfo>? trailerInfo;
  @JsonKey(
      name: 'castAndCrew', includeIfNull: false, defaultValue: <CastAndCrew>[])
  final List<CastAndCrew>? castAndCrew;
  @JsonKey(
      name: 'castCollection',
      includeIfNull: false,
      defaultValue: <CastAndCrew>[])
  final List<CastAndCrew>? castCollection;
  @JsonKey(
      name: 'crewCollection',
      includeIfNull: false,
      defaultValue: <CastAndCrew>[])
  final List<CastAndCrew>? crewCollection;
  @JsonKey(name: 'instances', includeIfNull: false, defaultValue: <Instance>[])
  final List<Instance>? instances;
  @JsonKey(name: 'prodYear', includeIfNull: false, defaultValue: '')
  final String? prodYear;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'promoVideoUrl', includeIfNull: false, defaultValue: '')
  final String? promoVideoUrl;
  @JsonKey(name: 'promoVideoEndImage', includeIfNull: false, defaultValue: '')
  final String? promoVideoEndImage;
  @JsonKey(name: 'promoVideoEndText', includeIfNull: false, defaultValue: '')
  final String? promoVideoEndText;
  @JsonKey(
    name: 'minResolution',
    includeIfNull: false,
    toJson: detailScreenMinResolutionToJson,
    fromJson: detailScreenMinResolutionFromJson,
  )
  final enums.DetailScreenMinResolution? minResolution;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'goPlayable', includeIfNull: false)
  final bool? goPlayable;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'sources', includeIfNull: false, defaultValue: <SourceExt>[])
  final List<SourceExt>? sources;
  static const fromJsonFactory = _$DetailScreenFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DetailScreen &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.assetType, assetType) ||
                const DeepCollectionEquality()
                    .equals(other.assetType, assetType)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.subTitle, subTitle) ||
                const DeepCollectionEquality()
                    .equals(other.subTitle, subTitle)) &&
            (identical(other.ordinal, ordinal) ||
                const DeepCollectionEquality()
                    .equals(other.ordinal, ordinal)) &&
            (identical(other.isPreview, isPreview) ||
                const DeepCollectionEquality()
                    .equals(other.isPreview, isPreview)) &&
            (identical(other.parentTitleId, parentTitleId) ||
                const DeepCollectionEquality()
                    .equals(other.parentTitleId, parentTitleId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesTitle, seriesTitle) ||
                const DeepCollectionEquality()
                    .equals(other.seriesTitle, seriesTitle)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.gridLink, gridLink) ||
                const DeepCollectionEquality()
                    .equals(other.gridLink, gridLink)) &&
            (identical(other.userInteractedWithSeries, userInteractedWithSeries) ||
                const DeepCollectionEquality().equals(other.userInteractedWithSeries, userInteractedWithSeries)) &&
            (identical(other.bookmark, bookmark) || const DeepCollectionEquality().equals(other.bookmark, bookmark)) &&
            (identical(other.tvodEntitlementEnd, tvodEntitlementEnd) || const DeepCollectionEquality().equals(other.tvodEntitlementEnd, tvodEntitlementEnd)) &&
            (identical(other.broadcastDate, broadcastDate) || const DeepCollectionEquality().equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.channelName, channelName) || const DeepCollectionEquality().equals(other.channelName, channelName)) &&
            (identical(other.screenLayout, screenLayout) || const DeepCollectionEquality().equals(other.screenLayout, screenLayout)) &&
            (identical(other.totalEpisodes, totalEpisodes) || const DeepCollectionEquality().equals(other.totalEpisodes, totalEpisodes)) &&
            (identical(other.parentalGuidanceText, parentalGuidanceText) || const DeepCollectionEquality().equals(other.parentalGuidanceText, parentalGuidanceText)) &&
            (identical(other.onWatchlist, onWatchlist) || const DeepCollectionEquality().equals(other.onWatchlist, onWatchlist)) &&
            (identical(other.genres, genres) || const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.synopsis, synopsis) || const DeepCollectionEquality().equals(other.synopsis, synopsis)) &&
            (identical(other.longSynopsis, longSynopsis) || const DeepCollectionEquality().equals(other.longSynopsis, longSynopsis)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.country, country) || const DeepCollectionEquality().equals(other.country, country)) &&
            (identical(other.subtitles, subtitles) || const DeepCollectionEquality().equals(other.subtitles, subtitles)) &&
            (identical(other.supplementalAudioDescriptions, supplementalAudioDescriptions) || const DeepCollectionEquality().equals(other.supplementalAudioDescriptions, supplementalAudioDescriptions)) &&
            (identical(other.icons, icons) || const DeepCollectionEquality().equals(other.icons, icons)) &&
            (identical(other.trailers, trailers) || const DeepCollectionEquality().equals(other.trailers, trailers)) &&
            (identical(other.trailerInfo, trailerInfo) || const DeepCollectionEquality().equals(other.trailerInfo, trailerInfo)) &&
            (identical(other.castAndCrew, castAndCrew) || const DeepCollectionEquality().equals(other.castAndCrew, castAndCrew)) &&
            (identical(other.castCollection, castCollection) || const DeepCollectionEquality().equals(other.castCollection, castCollection)) &&
            (identical(other.crewCollection, crewCollection) || const DeepCollectionEquality().equals(other.crewCollection, crewCollection)) &&
            (identical(other.instances, instances) || const DeepCollectionEquality().equals(other.instances, instances)) &&
            (identical(other.prodYear, prodYear) || const DeepCollectionEquality().equals(other.prodYear, prodYear)) &&
            (identical(other.seasonCount, seasonCount) || const DeepCollectionEquality().equals(other.seasonCount, seasonCount)) &&
            (identical(other.promoVideoUrl, promoVideoUrl) || const DeepCollectionEquality().equals(other.promoVideoUrl, promoVideoUrl)) &&
            (identical(other.promoVideoEndImage, promoVideoEndImage) || const DeepCollectionEquality().equals(other.promoVideoEndImage, promoVideoEndImage)) &&
            (identical(other.promoVideoEndText, promoVideoEndText) || const DeepCollectionEquality().equals(other.promoVideoEndText, promoVideoEndText)) &&
            (identical(other.minResolution, minResolution) || const DeepCollectionEquality().equals(other.minResolution, minResolution)) &&
            (identical(other.isBoxset, isBoxset) || const DeepCollectionEquality().equals(other.isBoxset, isBoxset)) &&
            (identical(other.goPlayable, goPlayable) || const DeepCollectionEquality().equals(other.goPlayable, goPlayable)) &&
            (identical(other.brandingProviderId, brandingProviderId) || const DeepCollectionEquality().equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.sources, sources) || const DeepCollectionEquality().equals(other.sources, sources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(assetType) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(subTitle) ^
      const DeepCollectionEquality().hash(ordinal) ^
      const DeepCollectionEquality().hash(isPreview) ^
      const DeepCollectionEquality().hash(parentTitleId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesTitle) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(gridLink) ^
      const DeepCollectionEquality().hash(userInteractedWithSeries) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(tvodEntitlementEnd) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(totalEpisodes) ^
      const DeepCollectionEquality().hash(parentalGuidanceText) ^
      const DeepCollectionEquality().hash(onWatchlist) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(longSynopsis) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(country) ^
      const DeepCollectionEquality().hash(subtitles) ^
      const DeepCollectionEquality().hash(supplementalAudioDescriptions) ^
      const DeepCollectionEquality().hash(icons) ^
      const DeepCollectionEquality().hash(trailers) ^
      const DeepCollectionEquality().hash(trailerInfo) ^
      const DeepCollectionEquality().hash(castAndCrew) ^
      const DeepCollectionEquality().hash(castCollection) ^
      const DeepCollectionEquality().hash(crewCollection) ^
      const DeepCollectionEquality().hash(instances) ^
      const DeepCollectionEquality().hash(prodYear) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(promoVideoUrl) ^
      const DeepCollectionEquality().hash(promoVideoEndImage) ^
      const DeepCollectionEquality().hash(promoVideoEndText) ^
      const DeepCollectionEquality().hash(minResolution) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(goPlayable) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(sources) ^
      runtimeType.hashCode;
}

extension $DetailScreenExtension on DetailScreen {
  DetailScreen copyWith(
      {String? id,
      String? mergedId,
      String? imageVersion,
      enums.DetailScreenType? type,
      enums.DetailScreenAssetType? assetType,
      String? title,
      String? subTitle,
      int? ordinal,
      bool? isPreview,
      String? parentTitleId,
      bool? isAdult,
      String? ageRating,
      int? duration,
      String? image,
      String? price,
      String? priceDisplay,
      String? minPrice,
      String? minPriceDisplay,
      String? seriesId,
      String? seriesTitle,
      String? seasonId,
      String? season,
      String? episode,
      GridLink? gridLink,
      bool? userInteractedWithSeries,
      int? bookmark,
      DateTime? tvodEntitlementEnd,
      DateTime? broadcastDate,
      String? channelName,
      String? screenLayout,
      int? totalEpisodes,
      String? parentalGuidanceText,
      bool? onWatchlist,
      List<String>? genres,
      String? synopsis,
      String? longSynopsis,
      List<String>? audioLanguages,
      List<String>? signLanguages,
      List<String>? country,
      List<String>? subtitles,
      List<String>? supplementalAudioDescriptions,
      List<String>? icons,
      List<String>? trailers,
      List<TrailerInfo>? trailerInfo,
      List<CastAndCrew>? castAndCrew,
      List<CastAndCrew>? castCollection,
      List<CastAndCrew>? crewCollection,
      List<Instance>? instances,
      String? prodYear,
      int? seasonCount,
      String? promoVideoUrl,
      String? promoVideoEndImage,
      String? promoVideoEndText,
      enums.DetailScreenMinResolution? minResolution,
      bool? isBoxset,
      bool? goPlayable,
      String? brandingProviderId,
      List<SourceExt>? sources}) {
    return DetailScreen(
        id: id ?? this.id,
        mergedId: mergedId ?? this.mergedId,
        imageVersion: imageVersion ?? this.imageVersion,
        type: type ?? this.type,
        assetType: assetType ?? this.assetType,
        title: title ?? this.title,
        subTitle: subTitle ?? this.subTitle,
        ordinal: ordinal ?? this.ordinal,
        isPreview: isPreview ?? this.isPreview,
        parentTitleId: parentTitleId ?? this.parentTitleId,
        isAdult: isAdult ?? this.isAdult,
        ageRating: ageRating ?? this.ageRating,
        duration: duration ?? this.duration,
        image: image ?? this.image,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        seriesId: seriesId ?? this.seriesId,
        seriesTitle: seriesTitle ?? this.seriesTitle,
        seasonId: seasonId ?? this.seasonId,
        season: season ?? this.season,
        episode: episode ?? this.episode,
        gridLink: gridLink ?? this.gridLink,
        userInteractedWithSeries:
            userInteractedWithSeries ?? this.userInteractedWithSeries,
        bookmark: bookmark ?? this.bookmark,
        tvodEntitlementEnd: tvodEntitlementEnd ?? this.tvodEntitlementEnd,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        channelName: channelName ?? this.channelName,
        screenLayout: screenLayout ?? this.screenLayout,
        totalEpisodes: totalEpisodes ?? this.totalEpisodes,
        parentalGuidanceText: parentalGuidanceText ?? this.parentalGuidanceText,
        onWatchlist: onWatchlist ?? this.onWatchlist,
        genres: genres ?? this.genres,
        synopsis: synopsis ?? this.synopsis,
        longSynopsis: longSynopsis ?? this.longSynopsis,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        country: country ?? this.country,
        subtitles: subtitles ?? this.subtitles,
        supplementalAudioDescriptions:
            supplementalAudioDescriptions ?? this.supplementalAudioDescriptions,
        icons: icons ?? this.icons,
        trailers: trailers ?? this.trailers,
        trailerInfo: trailerInfo ?? this.trailerInfo,
        castAndCrew: castAndCrew ?? this.castAndCrew,
        castCollection: castCollection ?? this.castCollection,
        crewCollection: crewCollection ?? this.crewCollection,
        instances: instances ?? this.instances,
        prodYear: prodYear ?? this.prodYear,
        seasonCount: seasonCount ?? this.seasonCount,
        promoVideoUrl: promoVideoUrl ?? this.promoVideoUrl,
        promoVideoEndImage: promoVideoEndImage ?? this.promoVideoEndImage,
        promoVideoEndText: promoVideoEndText ?? this.promoVideoEndText,
        minResolution: minResolution ?? this.minResolution,
        isBoxset: isBoxset ?? this.isBoxset,
        goPlayable: goPlayable ?? this.goPlayable,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        sources: sources ?? this.sources);
  }

  DetailScreen copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? mergedId,
      Wrapped<String?>? imageVersion,
      Wrapped<enums.DetailScreenType?>? type,
      Wrapped<enums.DetailScreenAssetType?>? assetType,
      Wrapped<String?>? title,
      Wrapped<String?>? subTitle,
      Wrapped<int?>? ordinal,
      Wrapped<bool?>? isPreview,
      Wrapped<String?>? parentTitleId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? ageRating,
      Wrapped<int?>? duration,
      Wrapped<String?>? image,
      Wrapped<String?>? price,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? seriesTitle,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? season,
      Wrapped<String?>? episode,
      Wrapped<GridLink?>? gridLink,
      Wrapped<bool?>? userInteractedWithSeries,
      Wrapped<int?>? bookmark,
      Wrapped<DateTime?>? tvodEntitlementEnd,
      Wrapped<DateTime?>? broadcastDate,
      Wrapped<String?>? channelName,
      Wrapped<String?>? screenLayout,
      Wrapped<int?>? totalEpisodes,
      Wrapped<String?>? parentalGuidanceText,
      Wrapped<bool?>? onWatchlist,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? longSynopsis,
      Wrapped<List<String>?>? audioLanguages,
      Wrapped<List<String>?>? signLanguages,
      Wrapped<List<String>?>? country,
      Wrapped<List<String>?>? subtitles,
      Wrapped<List<String>?>? supplementalAudioDescriptions,
      Wrapped<List<String>?>? icons,
      Wrapped<List<String>?>? trailers,
      Wrapped<List<TrailerInfo>?>? trailerInfo,
      Wrapped<List<CastAndCrew>?>? castAndCrew,
      Wrapped<List<CastAndCrew>?>? castCollection,
      Wrapped<List<CastAndCrew>?>? crewCollection,
      Wrapped<List<Instance>?>? instances,
      Wrapped<String?>? prodYear,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? promoVideoUrl,
      Wrapped<String?>? promoVideoEndImage,
      Wrapped<String?>? promoVideoEndText,
      Wrapped<enums.DetailScreenMinResolution?>? minResolution,
      Wrapped<bool?>? isBoxset,
      Wrapped<bool?>? goPlayable,
      Wrapped<String?>? brandingProviderId,
      Wrapped<List<SourceExt>?>? sources}) {
    return DetailScreen(
        id: (id != null ? id.value : this.id),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        type: (type != null ? type.value : this.type),
        assetType: (assetType != null ? assetType.value : this.assetType),
        title: (title != null ? title.value : this.title),
        subTitle: (subTitle != null ? subTitle.value : this.subTitle),
        ordinal: (ordinal != null ? ordinal.value : this.ordinal),
        isPreview: (isPreview != null ? isPreview.value : this.isPreview),
        parentTitleId:
            (parentTitleId != null ? parentTitleId.value : this.parentTitleId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        duration: (duration != null ? duration.value : this.duration),
        image: (image != null ? image.value : this.image),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesTitle:
            (seriesTitle != null ? seriesTitle.value : this.seriesTitle),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        season: (season != null ? season.value : this.season),
        episode: (episode != null ? episode.value : this.episode),
        gridLink: (gridLink != null ? gridLink.value : this.gridLink),
        userInteractedWithSeries: (userInteractedWithSeries != null
            ? userInteractedWithSeries.value
            : this.userInteractedWithSeries),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        tvodEntitlementEnd: (tvodEntitlementEnd != null
            ? tvodEntitlementEnd.value
            : this.tvodEntitlementEnd),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        totalEpisodes:
            (totalEpisodes != null ? totalEpisodes.value : this.totalEpisodes),
        parentalGuidanceText: (parentalGuidanceText != null
            ? parentalGuidanceText.value
            : this.parentalGuidanceText),
        onWatchlist:
            (onWatchlist != null ? onWatchlist.value : this.onWatchlist),
        genres: (genres != null ? genres.value : this.genres),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        longSynopsis:
            (longSynopsis != null ? longSynopsis.value : this.longSynopsis),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        country: (country != null ? country.value : this.country),
        subtitles: (subtitles != null ? subtitles.value : this.subtitles),
        supplementalAudioDescriptions: (supplementalAudioDescriptions != null
            ? supplementalAudioDescriptions.value
            : this.supplementalAudioDescriptions),
        icons: (icons != null ? icons.value : this.icons),
        trailers: (trailers != null ? trailers.value : this.trailers),
        trailerInfo:
            (trailerInfo != null ? trailerInfo.value : this.trailerInfo),
        castAndCrew:
            (castAndCrew != null ? castAndCrew.value : this.castAndCrew),
        castCollection: (castCollection != null
            ? castCollection.value
            : this.castCollection),
        crewCollection: (crewCollection != null
            ? crewCollection.value
            : this.crewCollection),
        instances: (instances != null ? instances.value : this.instances),
        prodYear: (prodYear != null ? prodYear.value : this.prodYear),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        promoVideoUrl:
            (promoVideoUrl != null ? promoVideoUrl.value : this.promoVideoUrl),
        promoVideoEndImage: (promoVideoEndImage != null
            ? promoVideoEndImage.value
            : this.promoVideoEndImage),
        promoVideoEndText: (promoVideoEndText != null
            ? promoVideoEndText.value
            : this.promoVideoEndText),
        minResolution:
            (minResolution != null ? minResolution.value : this.minResolution),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        goPlayable: (goPlayable != null ? goPlayable.value : this.goPlayable),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        sources: (sources != null ? sources.value : this.sources));
  }
}

@JsonSerializable(explicitToJson: true)
class EstInstanceData {
  EstInstanceData({
    this.minPriceDisplay,
    this.currency,
    this.videoHost,
    this.videoUrl,
  });

  factory EstInstanceData.fromJson(Map<String, dynamic> json) =>
      _$EstInstanceDataFromJson(json);

  static const toJsonFactory = _$EstInstanceDataToJson;
  Map<String, dynamic> toJson() => _$EstInstanceDataToJson(this);

  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String? videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String? videoUrl;
  static const fromJsonFactory = _$EstInstanceDataFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstInstanceData &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      runtimeType.hashCode;
}

extension $EstInstanceDataExtension on EstInstanceData {
  EstInstanceData copyWith(
      {String? minPriceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl}) {
    return EstInstanceData(
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl);
  }

  EstInstanceData copyWithWrapped(
      {Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? currency,
      Wrapped<String?>? videoHost,
      Wrapped<String?>? videoUrl}) {
    return EstInstanceData(
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class TrailerInstance {
  TrailerInstance({
    this.id,
    this.resolution,
    this.goPlayable,
    this.brandingProviderId,
  });

  factory TrailerInstance.fromJson(Map<String, dynamic> json) =>
      _$TrailerInstanceFromJson(json);

  static const toJsonFactory = _$TrailerInstanceToJson;
  Map<String, dynamic> toJson() => _$TrailerInstanceToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'goPlayable', includeIfNull: false)
  final bool? goPlayable;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  static const fromJsonFactory = _$TrailerInstanceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TrailerInstance &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.goPlayable, goPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.goPlayable, goPlayable)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(goPlayable) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      runtimeType.hashCode;
}

extension $TrailerInstanceExtension on TrailerInstance {
  TrailerInstance copyWith(
      {String? id,
      String? resolution,
      bool? goPlayable,
      String? brandingProviderId}) {
    return TrailerInstance(
        id: id ?? this.id,
        resolution: resolution ?? this.resolution,
        goPlayable: goPlayable ?? this.goPlayable,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId);
  }

  TrailerInstance copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? resolution,
      Wrapped<bool?>? goPlayable,
      Wrapped<String?>? brandingProviderId}) {
    return TrailerInstance(
        id: (id != null ? id.value : this.id),
        resolution: (resolution != null ? resolution.value : this.resolution),
        goPlayable: (goPlayable != null ? goPlayable.value : this.goPlayable),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId));
  }
}

@JsonSerializable(explicitToJson: true)
class Instance {
  Instance({
    this.id,
    this.resolution,
    this.isDolby,
    this.audioLang,
    this.subtitles,
    this.supplementalAudioDescriptions,
    this.signLanguages,
    this.availabilityStart,
    this.availabilityEnd,
    this.startIntroTime,
    this.endIntroTime,
    this.est,
    this.broadcastDate,
    this.broadcaster,
    this.brandingProviderId,
    this.isVodOttOnlyPurchasable,
    this.channelName,
    this.endCreditsTimestamp,
    this.goPlayable,
    this.goDownloadable,
    this.isAdEnabled,
    this.isA2AEnabled,
    this.download,
    this.playbackOptinRequired,
    this.advertisingOptInModal,
    this.advertisingUpgradeButton,
    this.upgradeDeeplink,
    this.supportedExternalStreamingProtocols,
    this.offers,
  });

  factory Instance.fromJson(Map<String, dynamic> json) =>
      _$InstanceFromJson(json);

  static const toJsonFactory = _$InstanceToJson;
  Map<String, dynamic> toJson() => _$InstanceToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'isDolby', includeIfNull: false)
  final bool? isDolby;
  @JsonKey(name: 'audioLang', includeIfNull: false, defaultValue: '')
  final String? audioLang;
  @JsonKey(name: 'subtitles', includeIfNull: false, defaultValue: '')
  final String? subtitles;
  @JsonKey(
      name: 'supplementalAudioDescriptions',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? supplementalAudioDescriptions;
  @JsonKey(
      name: 'signLanguages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? signLanguages;
  @JsonKey(name: 'availabilityStart', includeIfNull: false)
  final DateTime? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false)
  final DateTime? availabilityEnd;
  @JsonKey(name: 'startIntroTime', includeIfNull: false)
  final int? startIntroTime;
  @JsonKey(name: 'endIntroTime', includeIfNull: false)
  final int? endIntroTime;
  @JsonKey(name: 'est', includeIfNull: false)
  final EstInstanceData? est;
  @JsonKey(name: 'broadcastDate', includeIfNull: false)
  final DateTime? broadcastDate;
  @JsonKey(name: 'broadcaster', includeIfNull: false, defaultValue: '')
  final String? broadcaster;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'isVodOttOnlyPurchasable', includeIfNull: false)
  final bool? isVodOttOnlyPurchasable;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'endCreditsTimestamp', includeIfNull: false)
  final int? endCreditsTimestamp;
  @JsonKey(name: 'goPlayable', includeIfNull: false)
  final bool? goPlayable;
  @JsonKey(name: 'goDownloadable', includeIfNull: false)
  final bool? goDownloadable;
  @JsonKey(name: 'isAdEnabled', includeIfNull: false)
  final bool? isAdEnabled;
  @JsonKey(name: 'isA2AEnabled', includeIfNull: false)
  final bool? isA2AEnabled;
  @JsonKey(name: 'download', includeIfNull: false)
  final Download? download;
  @JsonKey(
      name: 'playbackOptinRequired',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? playbackOptinRequired;
  @JsonKey(name: 'advertisingOptInModal', includeIfNull: false)
  final int? advertisingOptInModal;
  @JsonKey(name: 'advertisingUpgradeButton', includeIfNull: false)
  final bool? advertisingUpgradeButton;
  @JsonKey(name: 'upgradeDeeplink', includeIfNull: false, defaultValue: '')
  final String? upgradeDeeplink;
  @JsonKey(
      name: 'supportedExternalStreamingProtocols',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? supportedExternalStreamingProtocols;
  @JsonKey(name: 'offers', includeIfNull: false, defaultValue: <Offer>[])
  final List<Offer>? offers;
  static const fromJsonFactory = _$InstanceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Instance &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.isDolby, isDolby) ||
                const DeepCollectionEquality()
                    .equals(other.isDolby, isDolby)) &&
            (identical(other.audioLang, audioLang) ||
                const DeepCollectionEquality()
                    .equals(other.audioLang, audioLang)) &&
            (identical(other.subtitles, subtitles) ||
                const DeepCollectionEquality()
                    .equals(other.subtitles, subtitles)) &&
            (identical(other.supplementalAudioDescriptions, supplementalAudioDescriptions) ||
                const DeepCollectionEquality().equals(
                    other.supplementalAudioDescriptions,
                    supplementalAudioDescriptions)) &&
            (identical(other.signLanguages, signLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.signLanguages, signLanguages)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.startIntroTime, startIntroTime) ||
                const DeepCollectionEquality()
                    .equals(other.startIntroTime, startIntroTime)) &&
            (identical(other.endIntroTime, endIntroTime) ||
                const DeepCollectionEquality()
                    .equals(other.endIntroTime, endIntroTime)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.broadcaster, broadcaster) ||
                const DeepCollectionEquality()
                    .equals(other.broadcaster, broadcaster)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.isVodOttOnlyPurchasable, isVodOttOnlyPurchasable) ||
                const DeepCollectionEquality().equals(
                    other.isVodOttOnlyPurchasable, isVodOttOnlyPurchasable)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.endCreditsTimestamp, endCreditsTimestamp) ||
                const DeepCollectionEquality()
                    .equals(other.endCreditsTimestamp, endCreditsTimestamp)) &&
            (identical(other.goPlayable, goPlayable) || const DeepCollectionEquality().equals(other.goPlayable, goPlayable)) &&
            (identical(other.goDownloadable, goDownloadable) || const DeepCollectionEquality().equals(other.goDownloadable, goDownloadable)) &&
            (identical(other.isAdEnabled, isAdEnabled) || const DeepCollectionEquality().equals(other.isAdEnabled, isAdEnabled)) &&
            (identical(other.isA2AEnabled, isA2AEnabled) || const DeepCollectionEquality().equals(other.isA2AEnabled, isA2AEnabled)) &&
            (identical(other.download, download) || const DeepCollectionEquality().equals(other.download, download)) &&
            (identical(other.playbackOptinRequired, playbackOptinRequired) || const DeepCollectionEquality().equals(other.playbackOptinRequired, playbackOptinRequired)) &&
            (identical(other.advertisingOptInModal, advertisingOptInModal) || const DeepCollectionEquality().equals(other.advertisingOptInModal, advertisingOptInModal)) &&
            (identical(other.advertisingUpgradeButton, advertisingUpgradeButton) || const DeepCollectionEquality().equals(other.advertisingUpgradeButton, advertisingUpgradeButton)) &&
            (identical(other.upgradeDeeplink, upgradeDeeplink) || const DeepCollectionEquality().equals(other.upgradeDeeplink, upgradeDeeplink)) &&
            (identical(other.supportedExternalStreamingProtocols, supportedExternalStreamingProtocols) || const DeepCollectionEquality().equals(other.supportedExternalStreamingProtocols, supportedExternalStreamingProtocols)) &&
            (identical(other.offers, offers) || const DeepCollectionEquality().equals(other.offers, offers)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(isDolby) ^
      const DeepCollectionEquality().hash(audioLang) ^
      const DeepCollectionEquality().hash(subtitles) ^
      const DeepCollectionEquality().hash(supplementalAudioDescriptions) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(startIntroTime) ^
      const DeepCollectionEquality().hash(endIntroTime) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(broadcaster) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(isVodOttOnlyPurchasable) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(endCreditsTimestamp) ^
      const DeepCollectionEquality().hash(goPlayable) ^
      const DeepCollectionEquality().hash(goDownloadable) ^
      const DeepCollectionEquality().hash(isAdEnabled) ^
      const DeepCollectionEquality().hash(isA2AEnabled) ^
      const DeepCollectionEquality().hash(download) ^
      const DeepCollectionEquality().hash(playbackOptinRequired) ^
      const DeepCollectionEquality().hash(advertisingOptInModal) ^
      const DeepCollectionEquality().hash(advertisingUpgradeButton) ^
      const DeepCollectionEquality().hash(upgradeDeeplink) ^
      const DeepCollectionEquality().hash(supportedExternalStreamingProtocols) ^
      const DeepCollectionEquality().hash(offers) ^
      runtimeType.hashCode;
}

extension $InstanceExtension on Instance {
  Instance copyWith(
      {String? id,
      String? resolution,
      bool? isDolby,
      String? audioLang,
      String? subtitles,
      List<String>? supplementalAudioDescriptions,
      List<String>? signLanguages,
      DateTime? availabilityStart,
      DateTime? availabilityEnd,
      int? startIntroTime,
      int? endIntroTime,
      EstInstanceData? est,
      DateTime? broadcastDate,
      String? broadcaster,
      String? brandingProviderId,
      bool? isVodOttOnlyPurchasable,
      String? channelName,
      int? endCreditsTimestamp,
      bool? goPlayable,
      bool? goDownloadable,
      bool? isAdEnabled,
      bool? isA2AEnabled,
      Download? download,
      List<String>? playbackOptinRequired,
      int? advertisingOptInModal,
      bool? advertisingUpgradeButton,
      String? upgradeDeeplink,
      List<String>? supportedExternalStreamingProtocols,
      List<Offer>? offers}) {
    return Instance(
        id: id ?? this.id,
        resolution: resolution ?? this.resolution,
        isDolby: isDolby ?? this.isDolby,
        audioLang: audioLang ?? this.audioLang,
        subtitles: subtitles ?? this.subtitles,
        supplementalAudioDescriptions:
            supplementalAudioDescriptions ?? this.supplementalAudioDescriptions,
        signLanguages: signLanguages ?? this.signLanguages,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        startIntroTime: startIntroTime ?? this.startIntroTime,
        endIntroTime: endIntroTime ?? this.endIntroTime,
        est: est ?? this.est,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        broadcaster: broadcaster ?? this.broadcaster,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        isVodOttOnlyPurchasable:
            isVodOttOnlyPurchasable ?? this.isVodOttOnlyPurchasable,
        channelName: channelName ?? this.channelName,
        endCreditsTimestamp: endCreditsTimestamp ?? this.endCreditsTimestamp,
        goPlayable: goPlayable ?? this.goPlayable,
        goDownloadable: goDownloadable ?? this.goDownloadable,
        isAdEnabled: isAdEnabled ?? this.isAdEnabled,
        isA2AEnabled: isA2AEnabled ?? this.isA2AEnabled,
        download: download ?? this.download,
        playbackOptinRequired:
            playbackOptinRequired ?? this.playbackOptinRequired,
        advertisingOptInModal:
            advertisingOptInModal ?? this.advertisingOptInModal,
        advertisingUpgradeButton:
            advertisingUpgradeButton ?? this.advertisingUpgradeButton,
        upgradeDeeplink: upgradeDeeplink ?? this.upgradeDeeplink,
        supportedExternalStreamingProtocols:
            supportedExternalStreamingProtocols ??
                this.supportedExternalStreamingProtocols,
        offers: offers ?? this.offers);
  }

  Instance copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? resolution,
      Wrapped<bool?>? isDolby,
      Wrapped<String?>? audioLang,
      Wrapped<String?>? subtitles,
      Wrapped<List<String>?>? supplementalAudioDescriptions,
      Wrapped<List<String>?>? signLanguages,
      Wrapped<DateTime?>? availabilityStart,
      Wrapped<DateTime?>? availabilityEnd,
      Wrapped<int?>? startIntroTime,
      Wrapped<int?>? endIntroTime,
      Wrapped<EstInstanceData?>? est,
      Wrapped<DateTime?>? broadcastDate,
      Wrapped<String?>? broadcaster,
      Wrapped<String?>? brandingProviderId,
      Wrapped<bool?>? isVodOttOnlyPurchasable,
      Wrapped<String?>? channelName,
      Wrapped<int?>? endCreditsTimestamp,
      Wrapped<bool?>? goPlayable,
      Wrapped<bool?>? goDownloadable,
      Wrapped<bool?>? isAdEnabled,
      Wrapped<bool?>? isA2AEnabled,
      Wrapped<Download?>? download,
      Wrapped<List<String>?>? playbackOptinRequired,
      Wrapped<int?>? advertisingOptInModal,
      Wrapped<bool?>? advertisingUpgradeButton,
      Wrapped<String?>? upgradeDeeplink,
      Wrapped<List<String>?>? supportedExternalStreamingProtocols,
      Wrapped<List<Offer>?>? offers}) {
    return Instance(
        id: (id != null ? id.value : this.id),
        resolution: (resolution != null ? resolution.value : this.resolution),
        isDolby: (isDolby != null ? isDolby.value : this.isDolby),
        audioLang: (audioLang != null ? audioLang.value : this.audioLang),
        subtitles: (subtitles != null ? subtitles.value : this.subtitles),
        supplementalAudioDescriptions: (supplementalAudioDescriptions != null
            ? supplementalAudioDescriptions.value
            : this.supplementalAudioDescriptions),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        startIntroTime: (startIntroTime != null
            ? startIntroTime.value
            : this.startIntroTime),
        endIntroTime:
            (endIntroTime != null ? endIntroTime.value : this.endIntroTime),
        est: (est != null ? est.value : this.est),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        broadcaster:
            (broadcaster != null ? broadcaster.value : this.broadcaster),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        isVodOttOnlyPurchasable: (isVodOttOnlyPurchasable != null
            ? isVodOttOnlyPurchasable.value
            : this.isVodOttOnlyPurchasable),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        endCreditsTimestamp: (endCreditsTimestamp != null
            ? endCreditsTimestamp.value
            : this.endCreditsTimestamp),
        goPlayable: (goPlayable != null ? goPlayable.value : this.goPlayable),
        goDownloadable: (goDownloadable != null
            ? goDownloadable.value
            : this.goDownloadable),
        isAdEnabled:
            (isAdEnabled != null ? isAdEnabled.value : this.isAdEnabled),
        isA2AEnabled:
            (isA2AEnabled != null ? isA2AEnabled.value : this.isA2AEnabled),
        download: (download != null ? download.value : this.download),
        playbackOptinRequired: (playbackOptinRequired != null
            ? playbackOptinRequired.value
            : this.playbackOptinRequired),
        advertisingOptInModal: (advertisingOptInModal != null
            ? advertisingOptInModal.value
            : this.advertisingOptInModal),
        advertisingUpgradeButton: (advertisingUpgradeButton != null
            ? advertisingUpgradeButton.value
            : this.advertisingUpgradeButton),
        upgradeDeeplink: (upgradeDeeplink != null
            ? upgradeDeeplink.value
            : this.upgradeDeeplink),
        supportedExternalStreamingProtocols:
            (supportedExternalStreamingProtocols != null
                ? supportedExternalStreamingProtocols.value
                : this.supportedExternalStreamingProtocols),
        offers: (offers != null ? offers.value : this.offers));
  }
}

@JsonSerializable(explicitToJson: true)
class Download {
  Download({
    this.expirySecondsAfterDownload,
    this.expirySecondsAfterPlay,
    this.lastAvailabilty,
    this.maxDownloads,
  });

  factory Download.fromJson(Map<String, dynamic> json) =>
      _$DownloadFromJson(json);

  static const toJsonFactory = _$DownloadToJson;
  Map<String, dynamic> toJson() => _$DownloadToJson(this);

  @JsonKey(name: 'expirySecondsAfterDownload', includeIfNull: false)
  final double? expirySecondsAfterDownload;
  @JsonKey(name: 'expirySecondsAfterPlay', includeIfNull: false)
  final double? expirySecondsAfterPlay;
  @JsonKey(name: 'lastAvailabilty', includeIfNull: false)
  final DateTime? lastAvailabilty;
  @JsonKey(name: 'maxDownloads', includeIfNull: false)
  final double? maxDownloads;
  static const fromJsonFactory = _$DownloadFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Download &&
            (identical(other.expirySecondsAfterDownload,
                    expirySecondsAfterDownload) ||
                const DeepCollectionEquality().equals(
                    other.expirySecondsAfterDownload,
                    expirySecondsAfterDownload)) &&
            (identical(other.expirySecondsAfterPlay, expirySecondsAfterPlay) ||
                const DeepCollectionEquality().equals(
                    other.expirySecondsAfterPlay, expirySecondsAfterPlay)) &&
            (identical(other.lastAvailabilty, lastAvailabilty) ||
                const DeepCollectionEquality()
                    .equals(other.lastAvailabilty, lastAvailabilty)) &&
            (identical(other.maxDownloads, maxDownloads) ||
                const DeepCollectionEquality()
                    .equals(other.maxDownloads, maxDownloads)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(expirySecondsAfterDownload) ^
      const DeepCollectionEquality().hash(expirySecondsAfterPlay) ^
      const DeepCollectionEquality().hash(lastAvailabilty) ^
      const DeepCollectionEquality().hash(maxDownloads) ^
      runtimeType.hashCode;
}

extension $DownloadExtension on Download {
  Download copyWith(
      {double? expirySecondsAfterDownload,
      double? expirySecondsAfterPlay,
      DateTime? lastAvailabilty,
      double? maxDownloads}) {
    return Download(
        expirySecondsAfterDownload:
            expirySecondsAfterDownload ?? this.expirySecondsAfterDownload,
        expirySecondsAfterPlay:
            expirySecondsAfterPlay ?? this.expirySecondsAfterPlay,
        lastAvailabilty: lastAvailabilty ?? this.lastAvailabilty,
        maxDownloads: maxDownloads ?? this.maxDownloads);
  }

  Download copyWithWrapped(
      {Wrapped<double?>? expirySecondsAfterDownload,
      Wrapped<double?>? expirySecondsAfterPlay,
      Wrapped<DateTime?>? lastAvailabilty,
      Wrapped<double?>? maxDownloads}) {
    return Download(
        expirySecondsAfterDownload: (expirySecondsAfterDownload != null
            ? expirySecondsAfterDownload.value
            : this.expirySecondsAfterDownload),
        expirySecondsAfterPlay: (expirySecondsAfterPlay != null
            ? expirySecondsAfterPlay.value
            : this.expirySecondsAfterPlay),
        lastAvailabilty: (lastAvailabilty != null
            ? lastAvailabilty.value
            : this.lastAvailabilty),
        maxDownloads:
            (maxDownloads != null ? maxDownloads.value : this.maxDownloads));
  }
}

@JsonSerializable(explicitToJson: true)
class Offer {
  Offer({
    this.id,
    this.entitled,
    this.offerId,
    this.name,
    this.type,
    this.titleCount,
    this.price,
    this.priceDisplay,
    this.currency,
    this.period,
    this.entitlementEnd,
    this.image,
    this.edsProductId,
    this.relationAvailabilityStart,
    this.relationAvailabilityEnd,
  });

  factory Offer.fromJson(Map<String, dynamic> json) => _$OfferFromJson(json);

  static const toJsonFactory = _$OfferToJson;
  Map<String, dynamic> toJson() => _$OfferToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'entitled', includeIfNull: false)
  final bool? entitled;
  @JsonKey(name: 'offerId', includeIfNull: false, defaultValue: '')
  final String? offerId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'titleCount', includeIfNull: false)
  final int? titleCount;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'period', includeIfNull: false)
  final int? period;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'edsProductId', includeIfNull: false, defaultValue: '')
  final String? edsProductId;
  @JsonKey(name: 'relationAvailabilityStart', includeIfNull: false)
  final DateTime? relationAvailabilityStart;
  @JsonKey(name: 'relationAvailabilityEnd', includeIfNull: false)
  final DateTime? relationAvailabilityEnd;
  static const fromJsonFactory = _$OfferFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Offer &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.entitled, entitled) ||
                const DeepCollectionEquality()
                    .equals(other.entitled, entitled)) &&
            (identical(other.offerId, offerId) ||
                const DeepCollectionEquality()
                    .equals(other.offerId, offerId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.titleCount, titleCount) ||
                const DeepCollectionEquality()
                    .equals(other.titleCount, titleCount)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.period, period) ||
                const DeepCollectionEquality().equals(other.period, period)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.edsProductId, edsProductId) ||
                const DeepCollectionEquality()
                    .equals(other.edsProductId, edsProductId)) &&
            (identical(other.relationAvailabilityStart,
                    relationAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.relationAvailabilityStart,
                    relationAvailabilityStart)) &&
            (identical(
                    other.relationAvailabilityEnd, relationAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.relationAvailabilityEnd, relationAvailabilityEnd)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(entitled) ^
      const DeepCollectionEquality().hash(offerId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(titleCount) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(period) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(edsProductId) ^
      const DeepCollectionEquality().hash(relationAvailabilityStart) ^
      const DeepCollectionEquality().hash(relationAvailabilityEnd) ^
      runtimeType.hashCode;
}

extension $OfferExtension on Offer {
  Offer copyWith(
      {String? id,
      bool? entitled,
      String? offerId,
      String? name,
      String? type,
      int? titleCount,
      String? price,
      String? priceDisplay,
      String? currency,
      int? period,
      DateTime? entitlementEnd,
      String? image,
      String? edsProductId,
      DateTime? relationAvailabilityStart,
      DateTime? relationAvailabilityEnd}) {
    return Offer(
        id: id ?? this.id,
        entitled: entitled ?? this.entitled,
        offerId: offerId ?? this.offerId,
        name: name ?? this.name,
        type: type ?? this.type,
        titleCount: titleCount ?? this.titleCount,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        currency: currency ?? this.currency,
        period: period ?? this.period,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        image: image ?? this.image,
        edsProductId: edsProductId ?? this.edsProductId,
        relationAvailabilityStart:
            relationAvailabilityStart ?? this.relationAvailabilityStart,
        relationAvailabilityEnd:
            relationAvailabilityEnd ?? this.relationAvailabilityEnd);
  }

  Offer copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<bool?>? entitled,
      Wrapped<String?>? offerId,
      Wrapped<String?>? name,
      Wrapped<String?>? type,
      Wrapped<int?>? titleCount,
      Wrapped<String?>? price,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? currency,
      Wrapped<int?>? period,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<String?>? image,
      Wrapped<String?>? edsProductId,
      Wrapped<DateTime?>? relationAvailabilityStart,
      Wrapped<DateTime?>? relationAvailabilityEnd}) {
    return Offer(
        id: (id != null ? id.value : this.id),
        entitled: (entitled != null ? entitled.value : this.entitled),
        offerId: (offerId != null ? offerId.value : this.offerId),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        titleCount: (titleCount != null ? titleCount.value : this.titleCount),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        period: (period != null ? period.value : this.period),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        image: (image != null ? image.value : this.image),
        edsProductId:
            (edsProductId != null ? edsProductId.value : this.edsProductId),
        relationAvailabilityStart: (relationAvailabilityStart != null
            ? relationAvailabilityStart.value
            : this.relationAvailabilityStart),
        relationAvailabilityEnd: (relationAvailabilityEnd != null
            ? relationAvailabilityEnd.value
            : this.relationAvailabilityEnd));
  }
}

@JsonSerializable(explicitToJson: true)
class OttSource {
  OttSource({
    this.id,
    this.titleId,
    this.minPriceDisplay,
    this.currency,
    this.videoHost,
    this.videoUrl,
    this.isEST,
    this.brandingProviderId,
    this.goPlayable,
    this.goDownloadable,
  });

  factory OttSource.fromJson(Map<String, dynamic> json) =>
      _$OttSourceFromJson(json);

  static const toJsonFactory = _$OttSourceToJson;
  Map<String, dynamic> toJson() => _$OttSourceToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String? videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String? videoUrl;
  @JsonKey(name: 'isEST', includeIfNull: false)
  final bool? isEST;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'goPlayable', includeIfNull: false)
  final bool? goPlayable;
  @JsonKey(name: 'goDownloadable', includeIfNull: false)
  final bool? goDownloadable;
  static const fromJsonFactory = _$OttSourceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OttSource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.isEST, isEST) ||
                const DeepCollectionEquality().equals(other.isEST, isEST)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.goPlayable, goPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.goPlayable, goPlayable)) &&
            (identical(other.goDownloadable, goDownloadable) ||
                const DeepCollectionEquality()
                    .equals(other.goDownloadable, goDownloadable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(isEST) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(goPlayable) ^
      const DeepCollectionEquality().hash(goDownloadable) ^
      runtimeType.hashCode;
}

extension $OttSourceExtension on OttSource {
  OttSource copyWith(
      {String? id,
      String? titleId,
      String? minPriceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl,
      bool? isEST,
      String? brandingProviderId,
      bool? goPlayable,
      bool? goDownloadable}) {
    return OttSource(
        id: id ?? this.id,
        titleId: titleId ?? this.titleId,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        isEST: isEST ?? this.isEST,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        goPlayable: goPlayable ?? this.goPlayable,
        goDownloadable: goDownloadable ?? this.goDownloadable);
  }

  OttSource copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? titleId,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? currency,
      Wrapped<String?>? videoHost,
      Wrapped<String?>? videoUrl,
      Wrapped<bool?>? isEST,
      Wrapped<String?>? brandingProviderId,
      Wrapped<bool?>? goPlayable,
      Wrapped<bool?>? goDownloadable}) {
    return OttSource(
        id: (id != null ? id.value : this.id),
        titleId: (titleId != null ? titleId.value : this.titleId),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        isEST: (isEST != null ? isEST.value : this.isEST),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        goPlayable: (goPlayable != null ? goPlayable.value : this.goPlayable),
        goDownloadable: (goDownloadable != null
            ? goDownloadable.value
            : this.goDownloadable));
  }
}

@JsonSerializable(explicitToJson: true)
class SourceExt {
  SourceExt({
    this.sourceType,
    this.source,
  });

  factory SourceExt.fromJson(Map<String, dynamic> json) =>
      _$SourceExtFromJson(json);

  static const toJsonFactory = _$SourceExtToJson;
  Map<String, dynamic> toJson() => _$SourceExtToJson(this);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceExtSourceTypeToJson,
    fromJson: sourceExtSourceTypeFromJson,
  )
  final enums.SourceExtSourceType? sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final OttSource? source;
  static const fromJsonFactory = _$SourceExtFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SourceExt &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $SourceExtExtension on SourceExt {
  SourceExt copyWith(
      {enums.SourceExtSourceType? sourceType, OttSource? source}) {
    return SourceExt(
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  SourceExt copyWithWrapped(
      {Wrapped<enums.SourceExtSourceType?>? sourceType,
      Wrapped<OttSource?>? source}) {
    return SourceExt(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class SourceOtt {
  SourceOtt({
    this.source,
    this.sourceType,
  });

  factory SourceOtt.fromJson(Map<String, dynamic> json) =>
      _$SourceOttFromJson(json);

  static const toJsonFactory = _$SourceOttToJson;
  Map<String, dynamic> toJson() => _$SourceOttToJson(this);

  @JsonKey(name: 'source', includeIfNull: false)
  final OttSource? source;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceOttSourceTypeToJson,
    fromJson: sourceOttSourceTypeFromJson,
  )
  final enums.SourceOttSourceType? sourceType;
  static const fromJsonFactory = _$SourceOttFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SourceOtt &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(sourceType) ^
      runtimeType.hashCode;
}

extension $SourceOttExtension on SourceOtt {
  SourceOtt copyWith(
      {OttSource? source, enums.SourceOttSourceType? sourceType}) {
    return SourceOtt(
        source: source ?? this.source,
        sourceType: sourceType ?? this.sourceType);
  }

  SourceOtt copyWithWrapped(
      {Wrapped<OttSource?>? source,
      Wrapped<enums.SourceOttSourceType?>? sourceType}) {
    return SourceOtt(
        source: (source != null ? source.value : this.source),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType));
  }
}

@JsonSerializable(explicitToJson: true)
class GridFilterOption {
  GridFilterOption({
    this.name,
    this.crid,
    this.titlesCount,
    this.seriesCount,
    this.isAdult,
  });

  factory GridFilterOption.fromJson(Map<String, dynamic> json) =>
      _$GridFilterOptionFromJson(json);

  static const toJsonFactory = _$GridFilterOptionToJson;
  Map<String, dynamic> toJson() => _$GridFilterOptionToJson(this);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(name: 'titlesCount', includeIfNull: false)
  final int? titlesCount;
  @JsonKey(name: 'seriesCount', includeIfNull: false)
  final int? seriesCount;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  static const fromJsonFactory = _$GridFilterOptionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridFilterOption &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.titlesCount, titlesCount) ||
                const DeepCollectionEquality()
                    .equals(other.titlesCount, titlesCount)) &&
            (identical(other.seriesCount, seriesCount) ||
                const DeepCollectionEquality()
                    .equals(other.seriesCount, seriesCount)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality().equals(other.isAdult, isAdult)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(titlesCount) ^
      const DeepCollectionEquality().hash(seriesCount) ^
      const DeepCollectionEquality().hash(isAdult) ^
      runtimeType.hashCode;
}

extension $GridFilterOptionExtension on GridFilterOption {
  GridFilterOption copyWith(
      {String? name,
      String? crid,
      int? titlesCount,
      int? seriesCount,
      bool? isAdult}) {
    return GridFilterOption(
        name: name ?? this.name,
        crid: crid ?? this.crid,
        titlesCount: titlesCount ?? this.titlesCount,
        seriesCount: seriesCount ?? this.seriesCount,
        isAdult: isAdult ?? this.isAdult);
  }

  GridFilterOption copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<String?>? crid,
      Wrapped<int?>? titlesCount,
      Wrapped<int?>? seriesCount,
      Wrapped<bool?>? isAdult}) {
    return GridFilterOption(
        name: (name != null ? name.value : this.name),
        crid: (crid != null ? crid.value : this.crid),
        titlesCount:
            (titlesCount != null ? titlesCount.value : this.titlesCount),
        seriesCount:
            (seriesCount != null ? seriesCount.value : this.seriesCount),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult));
  }
}

@JsonSerializable(explicitToJson: true)
class GridFilterOptions {
  GridFilterOptions({
    this.newArrivals,
    this.lastChance,
    this.goDownloadable,
    this.genres,
  });

  factory GridFilterOptions.fromJson(Map<String, dynamic> json) =>
      _$GridFilterOptionsFromJson(json);

  static const toJsonFactory = _$GridFilterOptionsToJson;
  Map<String, dynamic> toJson() => _$GridFilterOptionsToJson(this);

  @JsonKey(name: 'newArrivals', includeIfNull: false)
  final bool? newArrivals;
  @JsonKey(name: 'lastChance', includeIfNull: false)
  final bool? lastChance;
  @JsonKey(name: 'goDownloadable', includeIfNull: false)
  final bool? goDownloadable;
  @JsonKey(
      name: 'genres', includeIfNull: false, defaultValue: <GridFilterOption>[])
  final List<GridFilterOption>? genres;
  static const fromJsonFactory = _$GridFilterOptionsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridFilterOptions &&
            (identical(other.newArrivals, newArrivals) ||
                const DeepCollectionEquality()
                    .equals(other.newArrivals, newArrivals)) &&
            (identical(other.lastChance, lastChance) ||
                const DeepCollectionEquality()
                    .equals(other.lastChance, lastChance)) &&
            (identical(other.goDownloadable, goDownloadable) ||
                const DeepCollectionEquality()
                    .equals(other.goDownloadable, goDownloadable)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(newArrivals) ^
      const DeepCollectionEquality().hash(lastChance) ^
      const DeepCollectionEquality().hash(goDownloadable) ^
      const DeepCollectionEquality().hash(genres) ^
      runtimeType.hashCode;
}

extension $GridFilterOptionsExtension on GridFilterOptions {
  GridFilterOptions copyWith(
      {bool? newArrivals,
      bool? lastChance,
      bool? goDownloadable,
      List<GridFilterOption>? genres}) {
    return GridFilterOptions(
        newArrivals: newArrivals ?? this.newArrivals,
        lastChance: lastChance ?? this.lastChance,
        goDownloadable: goDownloadable ?? this.goDownloadable,
        genres: genres ?? this.genres);
  }

  GridFilterOptions copyWithWrapped(
      {Wrapped<bool?>? newArrivals,
      Wrapped<bool?>? lastChance,
      Wrapped<bool?>? goDownloadable,
      Wrapped<List<GridFilterOption>?>? genres}) {
    return GridFilterOptions(
        newArrivals:
            (newArrivals != null ? newArrivals.value : this.newArrivals),
        lastChance: (lastChance != null ? lastChance.value : this.lastChance),
        goDownloadable: (goDownloadable != null
            ? goDownloadable.value
            : this.goDownloadable),
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class GridOptions {
  GridOptions({
    this.id,
    this.titlesCount,
    this.seriesCount,
    this.isAdult,
    this.filterOptions,
    this.sortOptions,
  });

  factory GridOptions.fromJson(Map<String, dynamic> json) =>
      _$GridOptionsFromJson(json);

  static const toJsonFactory = _$GridOptionsToJson;
  Map<String, dynamic> toJson() => _$GridOptionsToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'titlesCount', includeIfNull: false)
  final int? titlesCount;
  @JsonKey(name: 'seriesCount', includeIfNull: false)
  final int? seriesCount;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'filterOptions', includeIfNull: false)
  final GridFilterOptions? filterOptions;
  @JsonKey(name: 'sortOptions', includeIfNull: false)
  final GridSortOptions? sortOptions;
  static const fromJsonFactory = _$GridOptionsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridOptions &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.titlesCount, titlesCount) ||
                const DeepCollectionEquality()
                    .equals(other.titlesCount, titlesCount)) &&
            (identical(other.seriesCount, seriesCount) ||
                const DeepCollectionEquality()
                    .equals(other.seriesCount, seriesCount)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.filterOptions, filterOptions) ||
                const DeepCollectionEquality()
                    .equals(other.filterOptions, filterOptions)) &&
            (identical(other.sortOptions, sortOptions) ||
                const DeepCollectionEquality()
                    .equals(other.sortOptions, sortOptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(titlesCount) ^
      const DeepCollectionEquality().hash(seriesCount) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(filterOptions) ^
      const DeepCollectionEquality().hash(sortOptions) ^
      runtimeType.hashCode;
}

extension $GridOptionsExtension on GridOptions {
  GridOptions copyWith(
      {String? id,
      int? titlesCount,
      int? seriesCount,
      bool? isAdult,
      GridFilterOptions? filterOptions,
      GridSortOptions? sortOptions}) {
    return GridOptions(
        id: id ?? this.id,
        titlesCount: titlesCount ?? this.titlesCount,
        seriesCount: seriesCount ?? this.seriesCount,
        isAdult: isAdult ?? this.isAdult,
        filterOptions: filterOptions ?? this.filterOptions,
        sortOptions: sortOptions ?? this.sortOptions);
  }

  GridOptions copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<int?>? titlesCount,
      Wrapped<int?>? seriesCount,
      Wrapped<bool?>? isAdult,
      Wrapped<GridFilterOptions?>? filterOptions,
      Wrapped<GridSortOptions?>? sortOptions}) {
    return GridOptions(
        id: (id != null ? id.value : this.id),
        titlesCount:
            (titlesCount != null ? titlesCount.value : this.titlesCount),
        seriesCount:
            (seriesCount != null ? seriesCount.value : this.seriesCount),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        filterOptions:
            (filterOptions != null ? filterOptions.value : this.filterOptions),
        sortOptions:
            (sortOptions != null ? sortOptions.value : this.sortOptions));
  }
}

@JsonSerializable(explicitToJson: true)
class GridSortOptions {
  GridSortOptions({
    this.broadcastDate,
  });

  factory GridSortOptions.fromJson(Map<String, dynamic> json) =>
      _$GridSortOptionsFromJson(json);

  static const toJsonFactory = _$GridSortOptionsToJson;
  Map<String, dynamic> toJson() => _$GridSortOptionsToJson(this);

  @JsonKey(name: 'broadcastDate', includeIfNull: false)
  final bool? broadcastDate;
  static const fromJsonFactory = _$GridSortOptionsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridSortOptions &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(broadcastDate) ^ runtimeType.hashCode;
}

extension $GridSortOptionsExtension on GridSortOptions {
  GridSortOptions copyWith({bool? broadcastDate}) {
    return GridSortOptions(broadcastDate: broadcastDate ?? this.broadcastDate);
  }

  GridSortOptions copyWithWrapped({Wrapped<bool?>? broadcastDate}) {
    return GridSortOptions(
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate));
  }
}

@JsonSerializable(explicitToJson: true)
class GridScreen {
  GridScreen({
    this.id,
    this.title,
    this.screenLayout,
    this.isAdult,
    this.background,
    this.brandLogoImage,
    this.channelLogoUrl,
    this.editorialImageUrl,
    this.logoThumbnail,
    this.brandingProviderId,
    this.indexStart,
    this.itemCount,
    this.totalCount,
    this.items,
  });

  factory GridScreen.fromJson(Map<String, dynamic> json) =>
      _$GridScreenFromJson(json);

  static const toJsonFactory = _$GridScreenToJson;
  Map<String, dynamic> toJson() => _$GridScreenToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String? background;
  @JsonKey(name: 'brandLogoImage', includeIfNull: false, defaultValue: '')
  final String? brandLogoImage;
  @JsonKey(name: 'channelLogoUrl', includeIfNull: false, defaultValue: '')
  final String? channelLogoUrl;
  @JsonKey(name: 'editorialImageUrl', includeIfNull: false, defaultValue: '')
  final String? editorialImageUrl;
  @JsonKey(name: 'logoThumbnail', includeIfNull: false, defaultValue: '')
  final String? logoThumbnail;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'indexStart', includeIfNull: false)
  final int? indexStart;
  @JsonKey(name: 'itemCount', includeIfNull: false)
  final int? itemCount;
  @JsonKey(name: 'totalCount', includeIfNull: false)
  final int? totalCount;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <Item>[])
  final List<Item>? items;
  static const fromJsonFactory = _$GridScreenFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridScreen &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.screenLayout, screenLayout) ||
                const DeepCollectionEquality()
                    .equals(other.screenLayout, screenLayout)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.brandLogoImage, brandLogoImage) ||
                const DeepCollectionEquality()
                    .equals(other.brandLogoImage, brandLogoImage)) &&
            (identical(other.channelLogoUrl, channelLogoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.channelLogoUrl, channelLogoUrl)) &&
            (identical(other.editorialImageUrl, editorialImageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.editorialImageUrl, editorialImageUrl)) &&
            (identical(other.logoThumbnail, logoThumbnail) ||
                const DeepCollectionEquality()
                    .equals(other.logoThumbnail, logoThumbnail)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.indexStart, indexStart) ||
                const DeepCollectionEquality()
                    .equals(other.indexStart, indexStart)) &&
            (identical(other.itemCount, itemCount) ||
                const DeepCollectionEquality()
                    .equals(other.itemCount, itemCount)) &&
            (identical(other.totalCount, totalCount) ||
                const DeepCollectionEquality()
                    .equals(other.totalCount, totalCount)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(brandLogoImage) ^
      const DeepCollectionEquality().hash(channelLogoUrl) ^
      const DeepCollectionEquality().hash(editorialImageUrl) ^
      const DeepCollectionEquality().hash(logoThumbnail) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(indexStart) ^
      const DeepCollectionEquality().hash(itemCount) ^
      const DeepCollectionEquality().hash(totalCount) ^
      const DeepCollectionEquality().hash(items) ^
      runtimeType.hashCode;
}

extension $GridScreenExtension on GridScreen {
  GridScreen copyWith(
      {String? id,
      String? title,
      String? screenLayout,
      bool? isAdult,
      String? background,
      String? brandLogoImage,
      String? channelLogoUrl,
      String? editorialImageUrl,
      String? logoThumbnail,
      String? brandingProviderId,
      int? indexStart,
      int? itemCount,
      int? totalCount,
      List<Item>? items}) {
    return GridScreen(
        id: id ?? this.id,
        title: title ?? this.title,
        screenLayout: screenLayout ?? this.screenLayout,
        isAdult: isAdult ?? this.isAdult,
        background: background ?? this.background,
        brandLogoImage: brandLogoImage ?? this.brandLogoImage,
        channelLogoUrl: channelLogoUrl ?? this.channelLogoUrl,
        editorialImageUrl: editorialImageUrl ?? this.editorialImageUrl,
        logoThumbnail: logoThumbnail ?? this.logoThumbnail,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        indexStart: indexStart ?? this.indexStart,
        itemCount: itemCount ?? this.itemCount,
        totalCount: totalCount ?? this.totalCount,
        items: items ?? this.items);
  }

  GridScreen copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? screenLayout,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? background,
      Wrapped<String?>? brandLogoImage,
      Wrapped<String?>? channelLogoUrl,
      Wrapped<String?>? editorialImageUrl,
      Wrapped<String?>? logoThumbnail,
      Wrapped<String?>? brandingProviderId,
      Wrapped<int?>? indexStart,
      Wrapped<int?>? itemCount,
      Wrapped<int?>? totalCount,
      Wrapped<List<Item>?>? items}) {
    return GridScreen(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        background: (background != null ? background.value : this.background),
        brandLogoImage: (brandLogoImage != null
            ? brandLogoImage.value
            : this.brandLogoImage),
        channelLogoUrl: (channelLogoUrl != null
            ? channelLogoUrl.value
            : this.channelLogoUrl),
        editorialImageUrl: (editorialImageUrl != null
            ? editorialImageUrl.value
            : this.editorialImageUrl),
        logoThumbnail:
            (logoThumbnail != null ? logoThumbnail.value : this.logoThumbnail),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        indexStart: (indexStart != null ? indexStart.value : this.indexStart),
        itemCount: (itemCount != null ? itemCount.value : this.itemCount),
        totalCount: (totalCount != null ? totalCount.value : this.totalCount),
        items: (items != null ? items.value : this.items));
  }
}

@JsonSerializable(explicitToJson: true)
class NextEpisode {
  NextEpisode({
    this.nextEpisode,
  });

  factory NextEpisode.fromJson(Map<String, dynamic> json) =>
      _$NextEpisodeFromJson(json);

  static const toJsonFactory = _$NextEpisodeToJson;
  Map<String, dynamic> toJson() => _$NextEpisodeToJson(this);

  @JsonKey(name: 'nextEpisode', includeIfNull: false, defaultValue: '')
  final String? nextEpisode;
  static const fromJsonFactory = _$NextEpisodeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NextEpisode &&
            (identical(other.nextEpisode, nextEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.nextEpisode, nextEpisode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nextEpisode) ^ runtimeType.hashCode;
}

extension $NextEpisodeExtension on NextEpisode {
  NextEpisode copyWith({String? nextEpisode}) {
    return NextEpisode(nextEpisode: nextEpisode ?? this.nextEpisode);
  }

  NextEpisode copyWithWrapped({Wrapped<String?>? nextEpisode}) {
    return NextEpisode(
        nextEpisode:
            (nextEpisode != null ? nextEpisode.value : this.nextEpisode));
  }
}

@JsonSerializable(explicitToJson: true)
class TileItem {
  TileItem({
    this.id,
    this.title,
    this.image,
    this.screenLayout,
    this.contentType,
    this.isAdult,
    this.gridLink,
  });

  factory TileItem.fromJson(Map<String, dynamic> json) =>
      _$TileItemFromJson(json);

  static const toJsonFactory = _$TileItemToJson;
  Map<String, dynamic> toJson() => _$TileItemToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'gridLink', includeIfNull: false)
  final GridLink? gridLink;
  static const fromJsonFactory = _$TileItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.screenLayout, screenLayout) ||
                const DeepCollectionEquality()
                    .equals(other.screenLayout, screenLayout)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.gridLink, gridLink) ||
                const DeepCollectionEquality()
                    .equals(other.gridLink, gridLink)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(gridLink) ^
      runtimeType.hashCode;
}

extension $TileItemExtension on TileItem {
  TileItem copyWith(
      {String? id,
      String? title,
      String? image,
      String? screenLayout,
      String? contentType,
      bool? isAdult,
      GridLink? gridLink}) {
    return TileItem(
        id: id ?? this.id,
        title: title ?? this.title,
        image: image ?? this.image,
        screenLayout: screenLayout ?? this.screenLayout,
        contentType: contentType ?? this.contentType,
        isAdult: isAdult ?? this.isAdult,
        gridLink: gridLink ?? this.gridLink);
  }

  TileItem copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? image,
      Wrapped<String?>? screenLayout,
      Wrapped<String?>? contentType,
      Wrapped<bool?>? isAdult,
      Wrapped<GridLink?>? gridLink}) {
    return TileItem(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        image: (image != null ? image.value : this.image),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        gridLink: (gridLink != null ? gridLink.value : this.gridLink));
  }
}

@JsonSerializable(explicitToJson: true)
class TileScreen {
  TileScreen({
    this.id,
    this.title,
    this.screenLayout,
    this.isAdult,
    this.background,
    this.logoThumbnail,
    this.brandingProviderId,
    this.items,
  });

  factory TileScreen.fromJson(Map<String, dynamic> json) =>
      _$TileScreenFromJson(json);

  static const toJsonFactory = _$TileScreenToJson;
  Map<String, dynamic> toJson() => _$TileScreenToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'screenLayout', includeIfNull: false, defaultValue: '')
  final String? screenLayout;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String? background;
  @JsonKey(name: 'logoThumbnail', includeIfNull: false, defaultValue: '')
  final String? logoThumbnail;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <TileItem>[])
  final List<TileItem>? items;
  static const fromJsonFactory = _$TileScreenFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileScreen &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.screenLayout, screenLayout) ||
                const DeepCollectionEquality()
                    .equals(other.screenLayout, screenLayout)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.logoThumbnail, logoThumbnail) ||
                const DeepCollectionEquality()
                    .equals(other.logoThumbnail, logoThumbnail)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(screenLayout) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(logoThumbnail) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(items) ^
      runtimeType.hashCode;
}

extension $TileScreenExtension on TileScreen {
  TileScreen copyWith(
      {String? id,
      String? title,
      String? screenLayout,
      bool? isAdult,
      String? background,
      String? logoThumbnail,
      String? brandingProviderId,
      List<TileItem>? items}) {
    return TileScreen(
        id: id ?? this.id,
        title: title ?? this.title,
        screenLayout: screenLayout ?? this.screenLayout,
        isAdult: isAdult ?? this.isAdult,
        background: background ?? this.background,
        logoThumbnail: logoThumbnail ?? this.logoThumbnail,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        items: items ?? this.items);
  }

  TileScreen copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? screenLayout,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? background,
      Wrapped<String?>? logoThumbnail,
      Wrapped<String?>? brandingProviderId,
      Wrapped<List<TileItem>?>? items}) {
    return TileScreen(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        screenLayout:
            (screenLayout != null ? screenLayout.value : this.screenLayout),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        background: (background != null ? background.value : this.background),
        logoThumbnail:
            (logoThumbnail != null ? logoThumbnail.value : this.logoThumbnail),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        items: (items != null ? items.value : this.items));
  }
}

@JsonSerializable(explicitToJson: true)
class PersonDetail {
  PersonDetail({
    this.id,
    this.name,
    this.dateOfBirth,
    this.placeOfBirth,
    this.synopsis,
    this.image,
  });

  factory PersonDetail.fromJson(Map<String, dynamic> json) =>
      _$PersonDetailFromJson(json);

  static const toJsonFactory = _$PersonDetailToJson;
  Map<String, dynamic> toJson() => _$PersonDetailToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'dateOfBirth', includeIfNull: false, defaultValue: '')
  final String? dateOfBirth;
  @JsonKey(name: 'placeOfBirth', includeIfNull: false, defaultValue: '')
  final String? placeOfBirth;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$PersonDetailFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PersonDetail &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.dateOfBirth, dateOfBirth) ||
                const DeepCollectionEquality()
                    .equals(other.dateOfBirth, dateOfBirth)) &&
            (identical(other.placeOfBirth, placeOfBirth) ||
                const DeepCollectionEquality()
                    .equals(other.placeOfBirth, placeOfBirth)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(dateOfBirth) ^
      const DeepCollectionEquality().hash(placeOfBirth) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $PersonDetailExtension on PersonDetail {
  PersonDetail copyWith(
      {String? id,
      String? name,
      String? dateOfBirth,
      String? placeOfBirth,
      String? synopsis,
      String? image}) {
    return PersonDetail(
        id: id ?? this.id,
        name: name ?? this.name,
        dateOfBirth: dateOfBirth ?? this.dateOfBirth,
        placeOfBirth: placeOfBirth ?? this.placeOfBirth,
        synopsis: synopsis ?? this.synopsis,
        image: image ?? this.image);
  }

  PersonDetail copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? dateOfBirth,
      Wrapped<String?>? placeOfBirth,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? image}) {
    return PersonDetail(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        dateOfBirth:
            (dateOfBirth != null ? dateOfBirth.value : this.dateOfBirth),
        placeOfBirth:
            (placeOfBirth != null ? placeOfBirth.value : this.placeOfBirth),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        image: (image != null ? image.value : this.image));
  }
}

@JsonSerializable(explicitToJson: true)
class AZJump {
  AZJump({
    this.undefinedParameter,
    this.a,
    this.b,
    this.c,
    this.d,
    this.e,
    this.f,
    this.g,
    this.h,
    this.i,
    this.j,
    this.k,
    this.l,
    this.m,
    this.n,
    this.o,
    this.p,
    this.q,
    this.r,
    this.s,
    this.t,
    this.u,
    this.v,
    this.w,
    this.x,
    this.y,
    this.z,
  });

  factory AZJump.fromJson(Map<String, dynamic> json) => _$AZJumpFromJson(json);

  static const toJsonFactory = _$AZJumpToJson;
  Map<String, dynamic> toJson() => _$AZJumpToJson(this);

  @JsonKey(name: '#', includeIfNull: false)
  final int? undefinedParameter;
  @JsonKey(name: 'A', includeIfNull: false)
  final int? a;
  @JsonKey(name: 'B', includeIfNull: false)
  final int? b;
  @JsonKey(name: 'C', includeIfNull: false)
  final int? c;
  @JsonKey(name: 'D', includeIfNull: false)
  final int? d;
  @JsonKey(name: 'E', includeIfNull: false)
  final int? e;
  @JsonKey(name: 'F', includeIfNull: false)
  final int? f;
  @JsonKey(name: 'G', includeIfNull: false)
  final int? g;
  @JsonKey(name: 'H', includeIfNull: false)
  final int? h;
  @JsonKey(name: 'I', includeIfNull: false)
  final int? i;
  @JsonKey(name: 'J', includeIfNull: false)
  final int? j;
  @JsonKey(name: 'K', includeIfNull: false)
  final int? k;
  @JsonKey(name: 'L', includeIfNull: false)
  final int? l;
  @JsonKey(name: 'M', includeIfNull: false)
  final int? m;
  @JsonKey(name: 'N', includeIfNull: false)
  final int? n;
  @JsonKey(name: 'O', includeIfNull: false)
  final int? o;
  @JsonKey(name: 'P', includeIfNull: false)
  final int? p;
  @JsonKey(name: 'Q', includeIfNull: false)
  final int? q;
  @JsonKey(name: 'R', includeIfNull: false)
  final int? r;
  @JsonKey(name: 'S', includeIfNull: false)
  final int? s;
  @JsonKey(name: 'T', includeIfNull: false)
  final int? t;
  @JsonKey(name: 'U', includeIfNull: false)
  final int? u;
  @JsonKey(name: 'V', includeIfNull: false)
  final int? v;
  @JsonKey(name: 'W', includeIfNull: false)
  final int? w;
  @JsonKey(name: 'X', includeIfNull: false)
  final int? x;
  @JsonKey(name: 'Y', includeIfNull: false)
  final int? y;
  @JsonKey(name: 'Z', includeIfNull: false)
  final int? z;
  static const fromJsonFactory = _$AZJumpFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AZJump &&
            (identical(other.undefinedParameter, undefinedParameter) ||
                const DeepCollectionEquality()
                    .equals(other.undefinedParameter, undefinedParameter)) &&
            (identical(other.a, a) ||
                const DeepCollectionEquality().equals(other.a, a)) &&
            (identical(other.b, b) ||
                const DeepCollectionEquality().equals(other.b, b)) &&
            (identical(other.c, c) ||
                const DeepCollectionEquality().equals(other.c, c)) &&
            (identical(other.d, d) ||
                const DeepCollectionEquality().equals(other.d, d)) &&
            (identical(other.e, e) ||
                const DeepCollectionEquality().equals(other.e, e)) &&
            (identical(other.f, f) ||
                const DeepCollectionEquality().equals(other.f, f)) &&
            (identical(other.g, g) ||
                const DeepCollectionEquality().equals(other.g, g)) &&
            (identical(other.h, h) ||
                const DeepCollectionEquality().equals(other.h, h)) &&
            (identical(other.i, i) ||
                const DeepCollectionEquality().equals(other.i, i)) &&
            (identical(other.j, j) ||
                const DeepCollectionEquality().equals(other.j, j)) &&
            (identical(other.k, k) ||
                const DeepCollectionEquality().equals(other.k, k)) &&
            (identical(other.l, l) ||
                const DeepCollectionEquality().equals(other.l, l)) &&
            (identical(other.m, m) ||
                const DeepCollectionEquality().equals(other.m, m)) &&
            (identical(other.n, n) ||
                const DeepCollectionEquality().equals(other.n, n)) &&
            (identical(other.o, o) ||
                const DeepCollectionEquality().equals(other.o, o)) &&
            (identical(other.p, p) ||
                const DeepCollectionEquality().equals(other.p, p)) &&
            (identical(other.q, q) ||
                const DeepCollectionEquality().equals(other.q, q)) &&
            (identical(other.r, r) ||
                const DeepCollectionEquality().equals(other.r, r)) &&
            (identical(other.s, s) ||
                const DeepCollectionEquality().equals(other.s, s)) &&
            (identical(other.t, t) ||
                const DeepCollectionEquality().equals(other.t, t)) &&
            (identical(other.u, u) ||
                const DeepCollectionEquality().equals(other.u, u)) &&
            (identical(other.v, v) ||
                const DeepCollectionEquality().equals(other.v, v)) &&
            (identical(other.w, w) ||
                const DeepCollectionEquality().equals(other.w, w)) &&
            (identical(other.x, x) ||
                const DeepCollectionEquality().equals(other.x, x)) &&
            (identical(other.y, y) ||
                const DeepCollectionEquality().equals(other.y, y)) &&
            (identical(other.z, z) ||
                const DeepCollectionEquality().equals(other.z, z)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(undefinedParameter) ^
      const DeepCollectionEquality().hash(a) ^
      const DeepCollectionEquality().hash(b) ^
      const DeepCollectionEquality().hash(c) ^
      const DeepCollectionEquality().hash(d) ^
      const DeepCollectionEquality().hash(e) ^
      const DeepCollectionEquality().hash(f) ^
      const DeepCollectionEquality().hash(g) ^
      const DeepCollectionEquality().hash(h) ^
      const DeepCollectionEquality().hash(i) ^
      const DeepCollectionEquality().hash(j) ^
      const DeepCollectionEquality().hash(k) ^
      const DeepCollectionEquality().hash(l) ^
      const DeepCollectionEquality().hash(m) ^
      const DeepCollectionEquality().hash(n) ^
      const DeepCollectionEquality().hash(o) ^
      const DeepCollectionEquality().hash(p) ^
      const DeepCollectionEquality().hash(q) ^
      const DeepCollectionEquality().hash(r) ^
      const DeepCollectionEquality().hash(s) ^
      const DeepCollectionEquality().hash(t) ^
      const DeepCollectionEquality().hash(u) ^
      const DeepCollectionEquality().hash(v) ^
      const DeepCollectionEquality().hash(w) ^
      const DeepCollectionEquality().hash(x) ^
      const DeepCollectionEquality().hash(y) ^
      const DeepCollectionEquality().hash(z) ^
      runtimeType.hashCode;
}

extension $AZJumpExtension on AZJump {
  AZJump copyWith(
      {int? undefinedParameter,
      int? a,
      int? b,
      int? c,
      int? d,
      int? e,
      int? f,
      int? g,
      int? h,
      int? i,
      int? j,
      int? k,
      int? l,
      int? m,
      int? n,
      int? o,
      int? p,
      int? q,
      int? r,
      int? s,
      int? t,
      int? u,
      int? v,
      int? w,
      int? x,
      int? y,
      int? z}) {
    return AZJump(
        undefinedParameter: undefinedParameter ?? this.undefinedParameter,
        a: a ?? this.a,
        b: b ?? this.b,
        c: c ?? this.c,
        d: d ?? this.d,
        e: e ?? this.e,
        f: f ?? this.f,
        g: g ?? this.g,
        h: h ?? this.h,
        i: i ?? this.i,
        j: j ?? this.j,
        k: k ?? this.k,
        l: l ?? this.l,
        m: m ?? this.m,
        n: n ?? this.n,
        o: o ?? this.o,
        p: p ?? this.p,
        q: q ?? this.q,
        r: r ?? this.r,
        s: s ?? this.s,
        t: t ?? this.t,
        u: u ?? this.u,
        v: v ?? this.v,
        w: w ?? this.w,
        x: x ?? this.x,
        y: y ?? this.y,
        z: z ?? this.z);
  }

  AZJump copyWithWrapped(
      {Wrapped<int?>? undefinedParameter,
      Wrapped<int?>? a,
      Wrapped<int?>? b,
      Wrapped<int?>? c,
      Wrapped<int?>? d,
      Wrapped<int?>? e,
      Wrapped<int?>? f,
      Wrapped<int?>? g,
      Wrapped<int?>? h,
      Wrapped<int?>? i,
      Wrapped<int?>? j,
      Wrapped<int?>? k,
      Wrapped<int?>? l,
      Wrapped<int?>? m,
      Wrapped<int?>? n,
      Wrapped<int?>? o,
      Wrapped<int?>? p,
      Wrapped<int?>? q,
      Wrapped<int?>? r,
      Wrapped<int?>? s,
      Wrapped<int?>? t,
      Wrapped<int?>? u,
      Wrapped<int?>? v,
      Wrapped<int?>? w,
      Wrapped<int?>? x,
      Wrapped<int?>? y,
      Wrapped<int?>? z}) {
    return AZJump(
        undefinedParameter: (undefinedParameter != null
            ? undefinedParameter.value
            : this.undefinedParameter),
        a: (a != null ? a.value : this.a),
        b: (b != null ? b.value : this.b),
        c: (c != null ? c.value : this.c),
        d: (d != null ? d.value : this.d),
        e: (e != null ? e.value : this.e),
        f: (f != null ? f.value : this.f),
        g: (g != null ? g.value : this.g),
        h: (h != null ? h.value : this.h),
        i: (i != null ? i.value : this.i),
        j: (j != null ? j.value : this.j),
        k: (k != null ? k.value : this.k),
        l: (l != null ? l.value : this.l),
        m: (m != null ? m.value : this.m),
        n: (n != null ? n.value : this.n),
        o: (o != null ? o.value : this.o),
        p: (p != null ? p.value : this.p),
        q: (q != null ? q.value : this.q),
        r: (r != null ? r.value : this.r),
        s: (s != null ? s.value : this.s),
        t: (t != null ? t.value : this.t),
        u: (u != null ? u.value : this.u),
        v: (v != null ? v.value : this.v),
        w: (w != null ? w.value : this.w),
        x: (x != null ? x.value : this.x),
        y: (y != null ? y.value : this.y),
        z: (z != null ? z.value : this.z));
  }
}

@JsonSerializable(explicitToJson: true)
class EditorialFeed {
  EditorialFeed({
    this.id,
    this.language,
    this.indexStart,
    this.sortType,
    this.sortDirection,
    this.itemCount,
    this.totalCount,
    this.items,
    this.azjump,
    this.filters,
  });

  factory EditorialFeed.fromJson(Map<String, dynamic> json) =>
      _$EditorialFeedFromJson(json);

  static const toJsonFactory = _$EditorialFeedToJson;
  Map<String, dynamic> toJson() => _$EditorialFeedToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  @JsonKey(name: 'indexStart', includeIfNull: false)
  final int? indexStart;
  @JsonKey(name: 'sortType', includeIfNull: false, defaultValue: '')
  final String? sortType;
  @JsonKey(name: 'sortDirection', includeIfNull: false, defaultValue: '')
  final String? sortDirection;
  @JsonKey(name: 'itemCount', includeIfNull: false)
  final int? itemCount;
  @JsonKey(name: 'totalCount', includeIfNull: false)
  final int? totalCount;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <FeedItem>[])
  final List<FeedItem>? items;
  @JsonKey(name: 'azjump', includeIfNull: false)
  final AZJump? azjump;
  @JsonKey(name: 'filters', includeIfNull: false, defaultValue: <String>[])
  final List<String>? filters;
  static const fromJsonFactory = _$EditorialFeedFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EditorialFeed &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.indexStart, indexStart) ||
                const DeepCollectionEquality()
                    .equals(other.indexStart, indexStart)) &&
            (identical(other.sortType, sortType) ||
                const DeepCollectionEquality()
                    .equals(other.sortType, sortType)) &&
            (identical(other.sortDirection, sortDirection) ||
                const DeepCollectionEquality()
                    .equals(other.sortDirection, sortDirection)) &&
            (identical(other.itemCount, itemCount) ||
                const DeepCollectionEquality()
                    .equals(other.itemCount, itemCount)) &&
            (identical(other.totalCount, totalCount) ||
                const DeepCollectionEquality()
                    .equals(other.totalCount, totalCount)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)) &&
            (identical(other.azjump, azjump) ||
                const DeepCollectionEquality().equals(other.azjump, azjump)) &&
            (identical(other.filters, filters) ||
                const DeepCollectionEquality().equals(other.filters, filters)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(indexStart) ^
      const DeepCollectionEquality().hash(sortType) ^
      const DeepCollectionEquality().hash(sortDirection) ^
      const DeepCollectionEquality().hash(itemCount) ^
      const DeepCollectionEquality().hash(totalCount) ^
      const DeepCollectionEquality().hash(items) ^
      const DeepCollectionEquality().hash(azjump) ^
      const DeepCollectionEquality().hash(filters) ^
      runtimeType.hashCode;
}

extension $EditorialFeedExtension on EditorialFeed {
  EditorialFeed copyWith(
      {String? id,
      String? language,
      int? indexStart,
      String? sortType,
      String? sortDirection,
      int? itemCount,
      int? totalCount,
      List<FeedItem>? items,
      AZJump? azjump,
      List<String>? filters}) {
    return EditorialFeed(
        id: id ?? this.id,
        language: language ?? this.language,
        indexStart: indexStart ?? this.indexStart,
        sortType: sortType ?? this.sortType,
        sortDirection: sortDirection ?? this.sortDirection,
        itemCount: itemCount ?? this.itemCount,
        totalCount: totalCount ?? this.totalCount,
        items: items ?? this.items,
        azjump: azjump ?? this.azjump,
        filters: filters ?? this.filters);
  }

  EditorialFeed copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? language,
      Wrapped<int?>? indexStart,
      Wrapped<String?>? sortType,
      Wrapped<String?>? sortDirection,
      Wrapped<int?>? itemCount,
      Wrapped<int?>? totalCount,
      Wrapped<List<FeedItem>?>? items,
      Wrapped<AZJump?>? azjump,
      Wrapped<List<String>?>? filters}) {
    return EditorialFeed(
        id: (id != null ? id.value : this.id),
        language: (language != null ? language.value : this.language),
        indexStart: (indexStart != null ? indexStart.value : this.indexStart),
        sortType: (sortType != null ? sortType.value : this.sortType),
        sortDirection:
            (sortDirection != null ? sortDirection.value : this.sortDirection),
        itemCount: (itemCount != null ? itemCount.value : this.itemCount),
        totalCount: (totalCount != null ? totalCount.value : this.totalCount),
        items: (items != null ? items.value : this.items),
        azjump: (azjump != null ? azjump.value : this.azjump),
        filters: (filters != null ? filters.value : this.filters));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedItem {
  FeedItem({
    this.id,
  });

  factory FeedItem.fromJson(Map<String, dynamic> json) =>
      _$FeedItemFromJson(json);

  static const toJsonFactory = _$FeedItemToJson;
  Map<String, dynamic> toJson() => _$FeedItemToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$FeedItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $FeedItemExtension on FeedItem {
  FeedItem copyWith({String? id}) {
    return FeedItem(id: id ?? this.id);
  }

  FeedItem copyWithWrapped({Wrapped<String?>? id}) {
    return FeedItem(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    this.name,
    this.crid,
    this.titlesCount,
    this.seriesCount,
    this.isAdult,
    this.image,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(name: 'titlesCount', includeIfNull: false)
  final int? titlesCount;
  @JsonKey(name: 'seriesCount', includeIfNull: false)
  final int? seriesCount;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$GenreFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.titlesCount, titlesCount) ||
                const DeepCollectionEquality()
                    .equals(other.titlesCount, titlesCount)) &&
            (identical(other.seriesCount, seriesCount) ||
                const DeepCollectionEquality()
                    .equals(other.seriesCount, seriesCount)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(titlesCount) ^
      const DeepCollectionEquality().hash(seriesCount) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith(
      {String? name,
      String? crid,
      int? titlesCount,
      int? seriesCount,
      bool? isAdult,
      String? image}) {
    return Genre(
        name: name ?? this.name,
        crid: crid ?? this.crid,
        titlesCount: titlesCount ?? this.titlesCount,
        seriesCount: seriesCount ?? this.seriesCount,
        isAdult: isAdult ?? this.isAdult,
        image: image ?? this.image);
  }

  Genre copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<String?>? crid,
      Wrapped<int?>? titlesCount,
      Wrapped<int?>? seriesCount,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? image}) {
    return Genre(
        name: (name != null ? name.value : this.name),
        crid: (crid != null ? crid.value : this.crid),
        titlesCount:
            (titlesCount != null ? titlesCount.value : this.titlesCount),
        seriesCount:
            (seriesCount != null ? seriesCount.value : this.seriesCount),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        image: (image != null ? image.value : this.image));
  }
}

@JsonSerializable(explicitToJson: true)
class GenreListResponse {
  GenreListResponse({
    this.id,
    this.genres,
  });

  factory GenreListResponse.fromJson(Map<String, dynamic> json) =>
      _$GenreListResponseFromJson(json);

  static const toJsonFactory = _$GenreListResponseToJson;
  Map<String, dynamic> toJson() => _$GenreListResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <Genre>[])
  final List<Genre>? genres;
  static const fromJsonFactory = _$GenreListResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenreListResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(genres) ^
      runtimeType.hashCode;
}

extension $GenreListResponseExtension on GenreListResponse {
  GenreListResponse copyWith({String? id, List<Genre>? genres}) {
    return GenreListResponse(id: id ?? this.id, genres: genres ?? this.genres);
  }

  GenreListResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<List<Genre>?>? genres}) {
    return GenreListResponse(
        id: (id != null ? id.value : this.id),
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedResponse {
  FeedResponse({
    this.id,
    this.feedType,
    this.metadata,
    this.name,
    this.isAdult,
    this.brandingProviderId,
    this.appId,
    this.items,
  });

  factory FeedResponse.fromJson(Map<String, dynamic> json) =>
      _$FeedResponseFromJson(json);

  static const toJsonFactory = _$FeedResponseToJson;
  Map<String, dynamic> toJson() => _$FeedResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'feedType',
    includeIfNull: false,
    toJson: feedResponseFeedTypeToJson,
    fromJson: feedResponseFeedTypeFromJson,
  )
  final enums.FeedResponseFeedType? feedType;
  @JsonKey(
    name: 'metadata',
    includeIfNull: false,
    toJson: feedResponseMetadataToJson,
    fromJson: feedResponseMetadataFromJson,
  )
  final enums.FeedResponseMetadata? metadata;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'appId', includeIfNull: false, defaultValue: '')
  final String? appId;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <Item>[])
  final List<Item>? items;
  static const fromJsonFactory = _$FeedResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.feedType, feedType) ||
                const DeepCollectionEquality()
                    .equals(other.feedType, feedType)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.appId, appId) ||
                const DeepCollectionEquality().equals(other.appId, appId)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(feedType) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(appId) ^
      const DeepCollectionEquality().hash(items) ^
      runtimeType.hashCode;
}

extension $FeedResponseExtension on FeedResponse {
  FeedResponse copyWith(
      {String? id,
      enums.FeedResponseFeedType? feedType,
      enums.FeedResponseMetadata? metadata,
      String? name,
      bool? isAdult,
      String? brandingProviderId,
      String? appId,
      List<Item>? items}) {
    return FeedResponse(
        id: id ?? this.id,
        feedType: feedType ?? this.feedType,
        metadata: metadata ?? this.metadata,
        name: name ?? this.name,
        isAdult: isAdult ?? this.isAdult,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        appId: appId ?? this.appId,
        items: items ?? this.items);
  }

  FeedResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<enums.FeedResponseFeedType?>? feedType,
      Wrapped<enums.FeedResponseMetadata?>? metadata,
      Wrapped<String?>? name,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? appId,
      Wrapped<List<Item>?>? items}) {
    return FeedResponse(
        id: (id != null ? id.value : this.id),
        feedType: (feedType != null ? feedType.value : this.feedType),
        metadata: (metadata != null ? metadata.value : this.metadata),
        name: (name != null ? name.value : this.name),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        appId: (appId != null ? appId.value : this.appId),
        items: (items != null ? items.value : this.items));
  }
}

@JsonSerializable(explicitToJson: true)
class Aspot {
  Aspot({
    this.id,
    this.type,
    this.isBoxset,
    this.brandingProviderId,
    this.imageVersion,
    this.seriesId,
    this.title,
    this.yearOfProduction,
    this.genres,
    this.subType,
    this.seasonCount,
    this.channelId,
    this.entitlementState,
    this.startTime,
    this.endTime,
    this.earliestBroadcastStartTime,
  });

  factory Aspot.fromJson(Map<String, dynamic> json) => _$AspotFromJson(json);

  static const toJsonFactory = _$AspotToJson;
  Map<String, dynamic> toJson() => _$AspotToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'yearOfProduction', includeIfNull: false, defaultValue: '')
  final String? yearOfProduction;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(
    name: 'subType',
    includeIfNull: false,
    toJson: aspotSubTypeToJson,
    fromJson: aspotSubTypeFromJson,
  )
  final enums.AspotSubType? subType;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(
    name: 'entitlementState',
    includeIfNull: false,
    toJson: aspotEntitlementStateToJson,
    fromJson: aspotEntitlementStateFromJson,
  )
  final enums.AspotEntitlementState? entitlementState;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'earliestBroadcastStartTime', includeIfNull: false)
  final DateTime? earliestBroadcastStartTime;
  static const fromJsonFactory = _$AspotFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Aspot &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.yearOfProduction, yearOfProduction) ||
                const DeepCollectionEquality()
                    .equals(other.yearOfProduction, yearOfProduction)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.subType, subType) ||
                const DeepCollectionEquality()
                    .equals(other.subType, subType)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.earliestBroadcastStartTime,
                    earliestBroadcastStartTime) ||
                const DeepCollectionEquality().equals(
                    other.earliestBroadcastStartTime,
                    earliestBroadcastStartTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(yearOfProduction) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(subType) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(earliestBroadcastStartTime) ^
      runtimeType.hashCode;
}

extension $AspotExtension on Aspot {
  Aspot copyWith(
      {String? id,
      String? type,
      bool? isBoxset,
      String? brandingProviderId,
      String? imageVersion,
      String? seriesId,
      String? title,
      String? yearOfProduction,
      List<String>? genres,
      enums.AspotSubType? subType,
      int? seasonCount,
      String? channelId,
      enums.AspotEntitlementState? entitlementState,
      DateTime? startTime,
      DateTime? endTime,
      DateTime? earliestBroadcastStartTime}) {
    return Aspot(
        id: id ?? this.id,
        type: type ?? this.type,
        isBoxset: isBoxset ?? this.isBoxset,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        imageVersion: imageVersion ?? this.imageVersion,
        seriesId: seriesId ?? this.seriesId,
        title: title ?? this.title,
        yearOfProduction: yearOfProduction ?? this.yearOfProduction,
        genres: genres ?? this.genres,
        subType: subType ?? this.subType,
        seasonCount: seasonCount ?? this.seasonCount,
        channelId: channelId ?? this.channelId,
        entitlementState: entitlementState ?? this.entitlementState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        earliestBroadcastStartTime:
            earliestBroadcastStartTime ?? this.earliestBroadcastStartTime);
  }

  Aspot copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? title,
      Wrapped<String?>? yearOfProduction,
      Wrapped<List<String>?>? genres,
      Wrapped<enums.AspotSubType?>? subType,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? channelId,
      Wrapped<enums.AspotEntitlementState?>? entitlementState,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<DateTime?>? earliestBroadcastStartTime}) {
    return Aspot(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        title: (title != null ? title.value : this.title),
        yearOfProduction: (yearOfProduction != null
            ? yearOfProduction.value
            : this.yearOfProduction),
        genres: (genres != null ? genres.value : this.genres),
        subType: (subType != null ? subType.value : this.subType),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        channelId: (channelId != null ? channelId.value : this.channelId),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        earliestBroadcastStartTime: (earliestBroadcastStartTime != null
            ? earliestBroadcastStartTime.value
            : this.earliestBroadcastStartTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenCollection {
  ScreenCollection({
    required this.id,
    this.title,
    required this.type,
    this.layout,
    this.items,
    this.subcollections,
  });

  factory ScreenCollection.fromJson(Map<String, dynamic> json) =>
      _$ScreenCollectionFromJson(json);

  static const toJsonFactory = _$ScreenCollectionToJson;
  Map<String, dynamic> toJson() => _$ScreenCollectionToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(
    name: 'layout',
    includeIfNull: false,
    toJson: screenCollectionLayoutToJson,
    fromJson: screenCollectionLayoutFromJson,
  )
  final enums.ScreenCollectionLayout? layout;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <ScreenItem>[])
  final List<ScreenItem>? items;
  @JsonKey(
      name: 'subcollections',
      includeIfNull: false,
      defaultValue: <ScreenSubcollection>[])
  final List<ScreenSubcollection>? subcollections;
  static const fromJsonFactory = _$ScreenCollectionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenCollection &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.layout, layout) ||
                const DeepCollectionEquality().equals(other.layout, layout)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)) &&
            (identical(other.subcollections, subcollections) ||
                const DeepCollectionEquality()
                    .equals(other.subcollections, subcollections)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(layout) ^
      const DeepCollectionEquality().hash(items) ^
      const DeepCollectionEquality().hash(subcollections) ^
      runtimeType.hashCode;
}

extension $ScreenCollectionExtension on ScreenCollection {
  ScreenCollection copyWith(
      {String? id,
      String? title,
      String? type,
      enums.ScreenCollectionLayout? layout,
      List<ScreenItem>? items,
      List<ScreenSubcollection>? subcollections}) {
    return ScreenCollection(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        layout: layout ?? this.layout,
        items: items ?? this.items,
        subcollections: subcollections ?? this.subcollections);
  }

  ScreenCollection copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? title,
      Wrapped<String>? type,
      Wrapped<enums.ScreenCollectionLayout?>? layout,
      Wrapped<List<ScreenItem>?>? items,
      Wrapped<List<ScreenSubcollection>?>? subcollections}) {
    return ScreenCollection(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        layout: (layout != null ? layout.value : this.layout),
        items: (items != null ? items.value : this.items),
        subcollections: (subcollections != null
            ? subcollections.value
            : this.subcollections));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenSubcollection {
  ScreenSubcollection({
    required this.id,
    required this.title,
    required this.type,
    this.lastInteracted,
    this.items,
  });

  factory ScreenSubcollection.fromJson(Map<String, dynamic> json) =>
      _$ScreenSubcollectionFromJson(json);

  static const toJsonFactory = _$ScreenSubcollectionToJson;
  Map<String, dynamic> toJson() => _$ScreenSubcollectionToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'lastInteracted', includeIfNull: false)
  final DateTime? lastInteracted;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <ScreenItem>[])
  final List<ScreenItem>? items;
  static const fromJsonFactory = _$ScreenSubcollectionFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenSubcollection &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.lastInteracted, lastInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.lastInteracted, lastInteracted)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(lastInteracted) ^
      const DeepCollectionEquality().hash(items) ^
      runtimeType.hashCode;
}

extension $ScreenSubcollectionExtension on ScreenSubcollection {
  ScreenSubcollection copyWith(
      {String? id,
      String? title,
      String? type,
      DateTime? lastInteracted,
      List<ScreenItem>? items}) {
    return ScreenSubcollection(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        lastInteracted: lastInteracted ?? this.lastInteracted,
        items: items ?? this.items);
  }

  ScreenSubcollection copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<String>? type,
      Wrapped<DateTime?>? lastInteracted,
      Wrapped<List<ScreenItem>?>? items}) {
    return ScreenSubcollection(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        lastInteracted: (lastInteracted != null
            ? lastInteracted.value
            : this.lastInteracted),
        items: (items != null ? items.value : this.items));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenItem {
  ScreenItem({
    this.id,
    this.title,
    this.type,
    this.brandingProviderId,
    this.subType,
    this.ageRating,
    this.channelId,
    this.startTime,
    this.endTime,
    this.duration,
    this.bookmark,
    this.priceDisplay,
    this.minPriceDisplay,
    this.tvodEntitlementEnd,
    this.entitlementEnd,
    this.isRemoved,
    this.isExpired,
    this.isBoxset,
    this.seasonNumber,
    this.episodeNumber,
    this.recordingState,
    this.seasonCount,
    this.expirationDate,
    this.earliestBroadcastStartTime,
    this.isPurchased,
    this.seriesId,
    this.rootId,
    this.providerId,
    this.interacted,
    this.image,
    this.externalAppId,
    this.externalAppDeepLink,
    this.imageVersion,
    this.entitlementState,
    this.goPlayable,
    this.episodeName,
    this.url,
    this.mostRelevantEpisode,
    this.isSplitProgram,
    this.shortDescription,
    this.genres,
    this.fromRemoteBookmark,
  });

  factory ScreenItem.fromJson(Map<String, dynamic> json) =>
      _$ScreenItemFromJson(json);

  static const toJsonFactory = _$ScreenItemToJson;
  Map<String, dynamic> toJson() => _$ScreenItemToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(
    name: 'subType',
    includeIfNull: false,
    toJson: screenItemSubTypeToJson,
    fromJson: screenItemSubTypeFromJson,
  )
  final enums.ScreenItemSubType? subType;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'tvodEntitlementEnd', includeIfNull: false)
  final DateTime? tvodEntitlementEnd;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'isRemoved', includeIfNull: false)
  final bool? isRemoved;
  @JsonKey(name: 'isExpired', includeIfNull: false)
  final bool? isExpired;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'recordingState', includeIfNull: false, defaultValue: '')
  final String? recordingState;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'earliestBroadcastStartTime', includeIfNull: false)
  final DateTime? earliestBroadcastStartTime;
  @JsonKey(name: 'isPurchased', includeIfNull: false)
  final bool? isPurchased;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'rootId', includeIfNull: false, defaultValue: '')
  final String? rootId;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'interacted', includeIfNull: false)
  final bool? interacted;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'externalAppId', includeIfNull: false, defaultValue: '')
  final String? externalAppId;
  @JsonKey(name: 'externalAppDeepLink', includeIfNull: false, defaultValue: '')
  final String? externalAppDeepLink;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(
    name: 'entitlementState',
    includeIfNull: false,
    toJson: screenItemEntitlementStateToJson,
    fromJson: screenItemEntitlementStateFromJson,
  )
  final enums.ScreenItemEntitlementState? entitlementState;
  @JsonKey(name: 'goPlayable', includeIfNull: false)
  final bool? goPlayable;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false, defaultValue: '')
  final String? mostRelevantEpisode;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'fromRemoteBookmark', includeIfNull: false)
  final bool? fromRemoteBookmark;
  static const fromJsonFactory = _$ScreenItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.subType, subType) ||
                const DeepCollectionEquality()
                    .equals(other.subType, subType)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.tvodEntitlementEnd, tvodEntitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.tvodEntitlementEnd, tvodEntitlementEnd)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.isRemoved, isRemoved) ||
                const DeepCollectionEquality()
                    .equals(other.isRemoved, isRemoved)) &&
            (identical(other.isExpired, isExpired) ||
                const DeepCollectionEquality()
                    .equals(other.isExpired, isExpired)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.earliestBroadcastStartTime, earliestBroadcastStartTime) || const DeepCollectionEquality().equals(other.earliestBroadcastStartTime, earliestBroadcastStartTime)) &&
            (identical(other.isPurchased, isPurchased) || const DeepCollectionEquality().equals(other.isPurchased, isPurchased)) &&
            (identical(other.seriesId, seriesId) || const DeepCollectionEquality().equals(other.seriesId, seriesId)) &&
            (identical(other.rootId, rootId) || const DeepCollectionEquality().equals(other.rootId, rootId)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)) &&
            (identical(other.interacted, interacted) || const DeepCollectionEquality().equals(other.interacted, interacted)) &&
            (identical(other.image, image) || const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.externalAppId, externalAppId) || const DeepCollectionEquality().equals(other.externalAppId, externalAppId)) &&
            (identical(other.externalAppDeepLink, externalAppDeepLink) || const DeepCollectionEquality().equals(other.externalAppDeepLink, externalAppDeepLink)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.entitlementState, entitlementState) || const DeepCollectionEquality().equals(other.entitlementState, entitlementState)) &&
            (identical(other.goPlayable, goPlayable) || const DeepCollectionEquality().equals(other.goPlayable, goPlayable)) &&
            (identical(other.episodeName, episodeName) || const DeepCollectionEquality().equals(other.episodeName, episodeName)) &&
            (identical(other.url, url) || const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) || const DeepCollectionEquality().equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.shortDescription, shortDescription) || const DeepCollectionEquality().equals(other.shortDescription, shortDescription)) &&
            (identical(other.genres, genres) || const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.fromRemoteBookmark, fromRemoteBookmark) || const DeepCollectionEquality().equals(other.fromRemoteBookmark, fromRemoteBookmark)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(subType) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(tvodEntitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(isRemoved) ^
      const DeepCollectionEquality().hash(isExpired) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(earliestBroadcastStartTime) ^
      const DeepCollectionEquality().hash(isPurchased) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(rootId) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(interacted) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(externalAppId) ^
      const DeepCollectionEquality().hash(externalAppDeepLink) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(goPlayable) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(fromRemoteBookmark) ^
      runtimeType.hashCode;
}

extension $ScreenItemExtension on ScreenItem {
  ScreenItem copyWith(
      {String? id,
      String? title,
      String? type,
      String? brandingProviderId,
      enums.ScreenItemSubType? subType,
      String? ageRating,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      int? duration,
      int? bookmark,
      String? priceDisplay,
      String? minPriceDisplay,
      DateTime? tvodEntitlementEnd,
      DateTime? entitlementEnd,
      bool? isRemoved,
      bool? isExpired,
      bool? isBoxset,
      int? seasonNumber,
      int? episodeNumber,
      String? recordingState,
      int? seasonCount,
      DateTime? expirationDate,
      DateTime? earliestBroadcastStartTime,
      bool? isPurchased,
      String? seriesId,
      String? rootId,
      String? providerId,
      bool? interacted,
      String? image,
      String? externalAppId,
      String? externalAppDeepLink,
      String? imageVersion,
      enums.ScreenItemEntitlementState? entitlementState,
      bool? goPlayable,
      String? episodeName,
      String? url,
      String? mostRelevantEpisode,
      bool? isSplitProgram,
      String? shortDescription,
      List<String>? genres,
      bool? fromRemoteBookmark}) {
    return ScreenItem(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        subType: subType ?? this.subType,
        ageRating: ageRating ?? this.ageRating,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        bookmark: bookmark ?? this.bookmark,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        tvodEntitlementEnd: tvodEntitlementEnd ?? this.tvodEntitlementEnd,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        isRemoved: isRemoved ?? this.isRemoved,
        isExpired: isExpired ?? this.isExpired,
        isBoxset: isBoxset ?? this.isBoxset,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        recordingState: recordingState ?? this.recordingState,
        seasonCount: seasonCount ?? this.seasonCount,
        expirationDate: expirationDate ?? this.expirationDate,
        earliestBroadcastStartTime:
            earliestBroadcastStartTime ?? this.earliestBroadcastStartTime,
        isPurchased: isPurchased ?? this.isPurchased,
        seriesId: seriesId ?? this.seriesId,
        rootId: rootId ?? this.rootId,
        providerId: providerId ?? this.providerId,
        interacted: interacted ?? this.interacted,
        image: image ?? this.image,
        externalAppId: externalAppId ?? this.externalAppId,
        externalAppDeepLink: externalAppDeepLink ?? this.externalAppDeepLink,
        imageVersion: imageVersion ?? this.imageVersion,
        entitlementState: entitlementState ?? this.entitlementState,
        goPlayable: goPlayable ?? this.goPlayable,
        episodeName: episodeName ?? this.episodeName,
        url: url ?? this.url,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        shortDescription: shortDescription ?? this.shortDescription,
        genres: genres ?? this.genres,
        fromRemoteBookmark: fromRemoteBookmark ?? this.fromRemoteBookmark);
  }

  ScreenItem copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? type,
      Wrapped<String?>? brandingProviderId,
      Wrapped<enums.ScreenItemSubType?>? subType,
      Wrapped<String?>? ageRating,
      Wrapped<String?>? channelId,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<DateTime?>? tvodEntitlementEnd,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<bool?>? isRemoved,
      Wrapped<bool?>? isExpired,
      Wrapped<bool?>? isBoxset,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? recordingState,
      Wrapped<int?>? seasonCount,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<DateTime?>? earliestBroadcastStartTime,
      Wrapped<bool?>? isPurchased,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? rootId,
      Wrapped<String?>? providerId,
      Wrapped<bool?>? interacted,
      Wrapped<String?>? image,
      Wrapped<String?>? externalAppId,
      Wrapped<String?>? externalAppDeepLink,
      Wrapped<String?>? imageVersion,
      Wrapped<enums.ScreenItemEntitlementState?>? entitlementState,
      Wrapped<bool?>? goPlayable,
      Wrapped<String?>? episodeName,
      Wrapped<String?>? url,
      Wrapped<String?>? mostRelevantEpisode,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<String?>? shortDescription,
      Wrapped<List<String>?>? genres,
      Wrapped<bool?>? fromRemoteBookmark}) {
    return ScreenItem(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        subType: (subType != null ? subType.value : this.subType),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        tvodEntitlementEnd: (tvodEntitlementEnd != null
            ? tvodEntitlementEnd.value
            : this.tvodEntitlementEnd),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        isRemoved: (isRemoved != null ? isRemoved.value : this.isRemoved),
        isExpired: (isExpired != null ? isExpired.value : this.isExpired),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        earliestBroadcastStartTime: (earliestBroadcastStartTime != null
            ? earliestBroadcastStartTime.value
            : this.earliestBroadcastStartTime),
        isPurchased:
            (isPurchased != null ? isPurchased.value : this.isPurchased),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        rootId: (rootId != null ? rootId.value : this.rootId),
        providerId: (providerId != null ? providerId.value : this.providerId),
        interacted: (interacted != null ? interacted.value : this.interacted),
        image: (image != null ? image.value : this.image),
        externalAppId:
            (externalAppId != null ? externalAppId.value : this.externalAppId),
        externalAppDeepLink: (externalAppDeepLink != null
            ? externalAppDeepLink.value
            : this.externalAppDeepLink),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        goPlayable: (goPlayable != null ? goPlayable.value : this.goPlayable),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        url: (url != null ? url.value : this.url),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        genres: (genres != null ? genres.value : this.genres),
        fromRemoteBookmark: (fromRemoteBookmark != null
            ? fromRemoteBookmark.value
            : this.fromRemoteBookmark));
  }
}

@JsonSerializable(explicitToJson: true)
class TopShelf {
  TopShelf({
    required this.collections,
  });

  factory TopShelf.fromJson(Map<String, dynamic> json) =>
      _$TopShelfFromJson(json);

  static const toJsonFactory = _$TopShelfToJson;
  Map<String, dynamic> toJson() => _$TopShelfToJson(this);

  @JsonKey(
      name: 'collections',
      includeIfNull: false,
      defaultValue: <ScreenCollection>[])
  final List<ScreenCollection> collections;
  static const fromJsonFactory = _$TopShelfFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopShelf &&
            (identical(other.collections, collections) ||
                const DeepCollectionEquality()
                    .equals(other.collections, collections)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(collections) ^ runtimeType.hashCode;
}

extension $TopShelfExtension on TopShelf {
  TopShelf copyWith({List<ScreenCollection>? collections}) {
    return TopShelf(collections: collections ?? this.collections);
  }

  TopShelf copyWithWrapped({Wrapped<List<ScreenCollection>>? collections}) {
    return TopShelf(
        collections:
            (collections != null ? collections.value : this.collections));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error?>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    this.httpStatusCode,
    this.statusCode,
    this.message,
    this.details,
    this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int? httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int?>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String?>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? programTypeToJson(enums.ProgramType? programType) {
  return programType?.value;
}

enums.ProgramType programTypeFromJson(
  Object? programType, [
  enums.ProgramType? defaultValue,
]) {
  return enums.ProgramType.values
          .firstWhereOrNull((e) => e.value == programType) ??
      defaultValue ??
      enums.ProgramType.swaggerGeneratedUnknown;
}

List<String> programTypeListToJson(List<enums.ProgramType>? programType) {
  if (programType == null) {
    return [];
  }

  return programType.map((e) => e.value!).toList();
}

List<enums.ProgramType> programTypeListFromJson(
  List? programType, [
  List<enums.ProgramType>? defaultValue,
]) {
  if (programType == null) {
    return defaultValue ?? [];
  }

  return programType.map((e) => programTypeFromJson(e.toString())).toList();
}

List<enums.ProgramType>? programTypeNullableListFromJson(
  List? programType, [
  List<enums.ProgramType>? defaultValue,
]) {
  if (programType == null) {
    return defaultValue;
  }

  return programType.map((e) => programTypeFromJson(e.toString())).toList();
}

String? showTypeToJson(enums.ShowType? showType) {
  return showType?.value;
}

enums.ShowType showTypeFromJson(
  Object? showType, [
  enums.ShowType? defaultValue,
]) {
  return enums.ShowType.values.firstWhereOrNull((e) => e.value == showType) ??
      defaultValue ??
      enums.ShowType.swaggerGeneratedUnknown;
}

List<String> showTypeListToJson(List<enums.ShowType>? showType) {
  if (showType == null) {
    return [];
  }

  return showType.map((e) => e.value!).toList();
}

List<enums.ShowType> showTypeListFromJson(
  List? showType, [
  List<enums.ShowType>? defaultValue,
]) {
  if (showType == null) {
    return defaultValue ?? [];
  }

  return showType.map((e) => showTypeFromJson(e.toString())).toList();
}

List<enums.ShowType>? showTypeNullableListFromJson(
  List? showType, [
  List<enums.ShowType>? defaultValue,
]) {
  if (showType == null) {
    return defaultValue;
  }

  return showType.map((e) => showTypeFromJson(e.toString())).toList();
}

String? titleTypeToJson(enums.TitleType? titleType) {
  return titleType?.value;
}

enums.TitleType titleTypeFromJson(
  Object? titleType, [
  enums.TitleType? defaultValue,
]) {
  return enums.TitleType.values.firstWhereOrNull((e) => e.value == titleType) ??
      defaultValue ??
      enums.TitleType.swaggerGeneratedUnknown;
}

List<String> titleTypeListToJson(List<enums.TitleType>? titleType) {
  if (titleType == null) {
    return [];
  }

  return titleType.map((e) => e.value!).toList();
}

List<enums.TitleType> titleTypeListFromJson(
  List? titleType, [
  List<enums.TitleType>? defaultValue,
]) {
  if (titleType == null) {
    return defaultValue ?? [];
  }

  return titleType.map((e) => titleTypeFromJson(e.toString())).toList();
}

List<enums.TitleType>? titleTypeNullableListFromJson(
  List? titleType, [
  List<enums.TitleType>? defaultValue,
]) {
  if (titleType == null) {
    return defaultValue;
  }

  return titleType.map((e) => titleTypeFromJson(e.toString())).toList();
}

String? purchasedProgramTypeToJson(
    enums.PurchasedProgramType? purchasedProgramType) {
  return purchasedProgramType?.value;
}

enums.PurchasedProgramType purchasedProgramTypeFromJson(
  Object? purchasedProgramType, [
  enums.PurchasedProgramType? defaultValue,
]) {
  return enums.PurchasedProgramType.values
          .firstWhereOrNull((e) => e.value == purchasedProgramType) ??
      defaultValue ??
      enums.PurchasedProgramType.swaggerGeneratedUnknown;
}

List<String> purchasedProgramTypeListToJson(
    List<enums.PurchasedProgramType>? purchasedProgramType) {
  if (purchasedProgramType == null) {
    return [];
  }

  return purchasedProgramType.map((e) => e.value!).toList();
}

List<enums.PurchasedProgramType> purchasedProgramTypeListFromJson(
  List? purchasedProgramType, [
  List<enums.PurchasedProgramType>? defaultValue,
]) {
  if (purchasedProgramType == null) {
    return defaultValue ?? [];
  }

  return purchasedProgramType
      .map((e) => purchasedProgramTypeFromJson(e.toString()))
      .toList();
}

List<enums.PurchasedProgramType>? purchasedProgramTypeNullableListFromJson(
  List? purchasedProgramType, [
  List<enums.PurchasedProgramType>? defaultValue,
]) {
  if (purchasedProgramType == null) {
    return defaultValue;
  }

  return purchasedProgramType
      .map((e) => purchasedProgramTypeFromJson(e.toString()))
      .toList();
}

String? aSpotTypeToJson(enums.ASpotType? aSpotType) {
  return aSpotType?.value;
}

enums.ASpotType aSpotTypeFromJson(
  Object? aSpotType, [
  enums.ASpotType? defaultValue,
]) {
  return enums.ASpotType.values.firstWhereOrNull((e) => e.value == aSpotType) ??
      defaultValue ??
      enums.ASpotType.swaggerGeneratedUnknown;
}

List<String> aSpotTypeListToJson(List<enums.ASpotType>? aSpotType) {
  if (aSpotType == null) {
    return [];
  }

  return aSpotType.map((e) => e.value!).toList();
}

List<enums.ASpotType> aSpotTypeListFromJson(
  List? aSpotType, [
  List<enums.ASpotType>? defaultValue,
]) {
  if (aSpotType == null) {
    return defaultValue ?? [];
  }

  return aSpotType.map((e) => aSpotTypeFromJson(e.toString())).toList();
}

List<enums.ASpotType>? aSpotTypeNullableListFromJson(
  List? aSpotType, [
  List<enums.ASpotType>? defaultValue,
]) {
  if (aSpotType == null) {
    return defaultValue;
  }

  return aSpotType.map((e) => aSpotTypeFromJson(e.toString())).toList();
}

String? aSpotAssetTypeToJson(enums.ASpotAssetType? aSpotAssetType) {
  return aSpotAssetType?.value;
}

enums.ASpotAssetType aSpotAssetTypeFromJson(
  Object? aSpotAssetType, [
  enums.ASpotAssetType? defaultValue,
]) {
  return enums.ASpotAssetType.values
          .firstWhereOrNull((e) => e.value == aSpotAssetType) ??
      defaultValue ??
      enums.ASpotAssetType.swaggerGeneratedUnknown;
}

List<String> aSpotAssetTypeListToJson(
    List<enums.ASpotAssetType>? aSpotAssetType) {
  if (aSpotAssetType == null) {
    return [];
  }

  return aSpotAssetType.map((e) => e.value!).toList();
}

List<enums.ASpotAssetType> aSpotAssetTypeListFromJson(
  List? aSpotAssetType, [
  List<enums.ASpotAssetType>? defaultValue,
]) {
  if (aSpotAssetType == null) {
    return defaultValue ?? [];
  }

  return aSpotAssetType
      .map((e) => aSpotAssetTypeFromJson(e.toString()))
      .toList();
}

List<enums.ASpotAssetType>? aSpotAssetTypeNullableListFromJson(
  List? aSpotAssetType, [
  List<enums.ASpotAssetType>? defaultValue,
]) {
  if (aSpotAssetType == null) {
    return defaultValue;
  }

  return aSpotAssetType
      .map((e) => aSpotAssetTypeFromJson(e.toString()))
      .toList();
}

String? itemTypeToJson(enums.ItemType? itemType) {
  return itemType?.value;
}

enums.ItemType itemTypeFromJson(
  Object? itemType, [
  enums.ItemType? defaultValue,
]) {
  return enums.ItemType.values.firstWhereOrNull((e) => e.value == itemType) ??
      defaultValue ??
      enums.ItemType.swaggerGeneratedUnknown;
}

List<String> itemTypeListToJson(List<enums.ItemType>? itemType) {
  if (itemType == null) {
    return [];
  }

  return itemType.map((e) => e.value!).toList();
}

List<enums.ItemType> itemTypeListFromJson(
  List? itemType, [
  List<enums.ItemType>? defaultValue,
]) {
  if (itemType == null) {
    return defaultValue ?? [];
  }

  return itemType.map((e) => itemTypeFromJson(e.toString())).toList();
}

List<enums.ItemType>? itemTypeNullableListFromJson(
  List? itemType, [
  List<enums.ItemType>? defaultValue,
]) {
  if (itemType == null) {
    return defaultValue;
  }

  return itemType.map((e) => itemTypeFromJson(e.toString())).toList();
}

String? itemAssetTypeToJson(enums.ItemAssetType? itemAssetType) {
  return itemAssetType?.value;
}

enums.ItemAssetType itemAssetTypeFromJson(
  Object? itemAssetType, [
  enums.ItemAssetType? defaultValue,
]) {
  return enums.ItemAssetType.values
          .firstWhereOrNull((e) => e.value == itemAssetType) ??
      defaultValue ??
      enums.ItemAssetType.swaggerGeneratedUnknown;
}

List<String> itemAssetTypeListToJson(List<enums.ItemAssetType>? itemAssetType) {
  if (itemAssetType == null) {
    return [];
  }

  return itemAssetType.map((e) => e.value!).toList();
}

List<enums.ItemAssetType> itemAssetTypeListFromJson(
  List? itemAssetType, [
  List<enums.ItemAssetType>? defaultValue,
]) {
  if (itemAssetType == null) {
    return defaultValue ?? [];
  }

  return itemAssetType.map((e) => itemAssetTypeFromJson(e.toString())).toList();
}

List<enums.ItemAssetType>? itemAssetTypeNullableListFromJson(
  List? itemAssetType, [
  List<enums.ItemAssetType>? defaultValue,
]) {
  if (itemAssetType == null) {
    return defaultValue;
  }

  return itemAssetType.map((e) => itemAssetTypeFromJson(e.toString())).toList();
}

String? itemMinResolutionToJson(enums.ItemMinResolution? itemMinResolution) {
  return itemMinResolution?.value;
}

enums.ItemMinResolution itemMinResolutionFromJson(
  Object? itemMinResolution, [
  enums.ItemMinResolution? defaultValue,
]) {
  return enums.ItemMinResolution.values
          .firstWhereOrNull((e) => e.value == itemMinResolution) ??
      defaultValue ??
      enums.ItemMinResolution.swaggerGeneratedUnknown;
}

List<String> itemMinResolutionListToJson(
    List<enums.ItemMinResolution>? itemMinResolution) {
  if (itemMinResolution == null) {
    return [];
  }

  return itemMinResolution.map((e) => e.value!).toList();
}

List<enums.ItemMinResolution> itemMinResolutionListFromJson(
  List? itemMinResolution, [
  List<enums.ItemMinResolution>? defaultValue,
]) {
  if (itemMinResolution == null) {
    return defaultValue ?? [];
  }

  return itemMinResolution
      .map((e) => itemMinResolutionFromJson(e.toString()))
      .toList();
}

List<enums.ItemMinResolution>? itemMinResolutionNullableListFromJson(
  List? itemMinResolution, [
  List<enums.ItemMinResolution>? defaultValue,
]) {
  if (itemMinResolution == null) {
    return defaultValue;
  }

  return itemMinResolution
      .map((e) => itemMinResolutionFromJson(e.toString()))
      .toList();
}

String? detailScreenTypeToJson(enums.DetailScreenType? detailScreenType) {
  return detailScreenType?.value;
}

enums.DetailScreenType detailScreenTypeFromJson(
  Object? detailScreenType, [
  enums.DetailScreenType? defaultValue,
]) {
  return enums.DetailScreenType.values
          .firstWhereOrNull((e) => e.value == detailScreenType) ??
      defaultValue ??
      enums.DetailScreenType.swaggerGeneratedUnknown;
}

List<String> detailScreenTypeListToJson(
    List<enums.DetailScreenType>? detailScreenType) {
  if (detailScreenType == null) {
    return [];
  }

  return detailScreenType.map((e) => e.value!).toList();
}

List<enums.DetailScreenType> detailScreenTypeListFromJson(
  List? detailScreenType, [
  List<enums.DetailScreenType>? defaultValue,
]) {
  if (detailScreenType == null) {
    return defaultValue ?? [];
  }

  return detailScreenType
      .map((e) => detailScreenTypeFromJson(e.toString()))
      .toList();
}

List<enums.DetailScreenType>? detailScreenTypeNullableListFromJson(
  List? detailScreenType, [
  List<enums.DetailScreenType>? defaultValue,
]) {
  if (detailScreenType == null) {
    return defaultValue;
  }

  return detailScreenType
      .map((e) => detailScreenTypeFromJson(e.toString()))
      .toList();
}

String? detailScreenAssetTypeToJson(
    enums.DetailScreenAssetType? detailScreenAssetType) {
  return detailScreenAssetType?.value;
}

enums.DetailScreenAssetType detailScreenAssetTypeFromJson(
  Object? detailScreenAssetType, [
  enums.DetailScreenAssetType? defaultValue,
]) {
  return enums.DetailScreenAssetType.values
          .firstWhereOrNull((e) => e.value == detailScreenAssetType) ??
      defaultValue ??
      enums.DetailScreenAssetType.swaggerGeneratedUnknown;
}

List<String> detailScreenAssetTypeListToJson(
    List<enums.DetailScreenAssetType>? detailScreenAssetType) {
  if (detailScreenAssetType == null) {
    return [];
  }

  return detailScreenAssetType.map((e) => e.value!).toList();
}

List<enums.DetailScreenAssetType> detailScreenAssetTypeListFromJson(
  List? detailScreenAssetType, [
  List<enums.DetailScreenAssetType>? defaultValue,
]) {
  if (detailScreenAssetType == null) {
    return defaultValue ?? [];
  }

  return detailScreenAssetType
      .map((e) => detailScreenAssetTypeFromJson(e.toString()))
      .toList();
}

List<enums.DetailScreenAssetType>? detailScreenAssetTypeNullableListFromJson(
  List? detailScreenAssetType, [
  List<enums.DetailScreenAssetType>? defaultValue,
]) {
  if (detailScreenAssetType == null) {
    return defaultValue;
  }

  return detailScreenAssetType
      .map((e) => detailScreenAssetTypeFromJson(e.toString()))
      .toList();
}

String? detailScreenMinResolutionToJson(
    enums.DetailScreenMinResolution? detailScreenMinResolution) {
  return detailScreenMinResolution?.value;
}

enums.DetailScreenMinResolution detailScreenMinResolutionFromJson(
  Object? detailScreenMinResolution, [
  enums.DetailScreenMinResolution? defaultValue,
]) {
  return enums.DetailScreenMinResolution.values
          .firstWhereOrNull((e) => e.value == detailScreenMinResolution) ??
      defaultValue ??
      enums.DetailScreenMinResolution.swaggerGeneratedUnknown;
}

List<String> detailScreenMinResolutionListToJson(
    List<enums.DetailScreenMinResolution>? detailScreenMinResolution) {
  if (detailScreenMinResolution == null) {
    return [];
  }

  return detailScreenMinResolution.map((e) => e.value!).toList();
}

List<enums.DetailScreenMinResolution> detailScreenMinResolutionListFromJson(
  List? detailScreenMinResolution, [
  List<enums.DetailScreenMinResolution>? defaultValue,
]) {
  if (detailScreenMinResolution == null) {
    return defaultValue ?? [];
  }

  return detailScreenMinResolution
      .map((e) => detailScreenMinResolutionFromJson(e.toString()))
      .toList();
}

List<enums.DetailScreenMinResolution>?
    detailScreenMinResolutionNullableListFromJson(
  List? detailScreenMinResolution, [
  List<enums.DetailScreenMinResolution>? defaultValue,
]) {
  if (detailScreenMinResolution == null) {
    return defaultValue;
  }

  return detailScreenMinResolution
      .map((e) => detailScreenMinResolutionFromJson(e.toString()))
      .toList();
}

String? sourceExtSourceTypeToJson(
    enums.SourceExtSourceType? sourceExtSourceType) {
  return sourceExtSourceType?.value;
}

enums.SourceExtSourceType sourceExtSourceTypeFromJson(
  Object? sourceExtSourceType, [
  enums.SourceExtSourceType? defaultValue,
]) {
  return enums.SourceExtSourceType.values
          .firstWhereOrNull((e) => e.value == sourceExtSourceType) ??
      defaultValue ??
      enums.SourceExtSourceType.swaggerGeneratedUnknown;
}

List<String> sourceExtSourceTypeListToJson(
    List<enums.SourceExtSourceType>? sourceExtSourceType) {
  if (sourceExtSourceType == null) {
    return [];
  }

  return sourceExtSourceType.map((e) => e.value!).toList();
}

List<enums.SourceExtSourceType> sourceExtSourceTypeListFromJson(
  List? sourceExtSourceType, [
  List<enums.SourceExtSourceType>? defaultValue,
]) {
  if (sourceExtSourceType == null) {
    return defaultValue ?? [];
  }

  return sourceExtSourceType
      .map((e) => sourceExtSourceTypeFromJson(e.toString()))
      .toList();
}

List<enums.SourceExtSourceType>? sourceExtSourceTypeNullableListFromJson(
  List? sourceExtSourceType, [
  List<enums.SourceExtSourceType>? defaultValue,
]) {
  if (sourceExtSourceType == null) {
    return defaultValue;
  }

  return sourceExtSourceType
      .map((e) => sourceExtSourceTypeFromJson(e.toString()))
      .toList();
}

String? sourceOttSourceTypeToJson(
    enums.SourceOttSourceType? sourceOttSourceType) {
  return sourceOttSourceType?.value;
}

enums.SourceOttSourceType sourceOttSourceTypeFromJson(
  Object? sourceOttSourceType, [
  enums.SourceOttSourceType? defaultValue,
]) {
  return enums.SourceOttSourceType.values
          .firstWhereOrNull((e) => e.value == sourceOttSourceType) ??
      defaultValue ??
      enums.SourceOttSourceType.swaggerGeneratedUnknown;
}

List<String> sourceOttSourceTypeListToJson(
    List<enums.SourceOttSourceType>? sourceOttSourceType) {
  if (sourceOttSourceType == null) {
    return [];
  }

  return sourceOttSourceType.map((e) => e.value!).toList();
}

List<enums.SourceOttSourceType> sourceOttSourceTypeListFromJson(
  List? sourceOttSourceType, [
  List<enums.SourceOttSourceType>? defaultValue,
]) {
  if (sourceOttSourceType == null) {
    return defaultValue ?? [];
  }

  return sourceOttSourceType
      .map((e) => sourceOttSourceTypeFromJson(e.toString()))
      .toList();
}

List<enums.SourceOttSourceType>? sourceOttSourceTypeNullableListFromJson(
  List? sourceOttSourceType, [
  List<enums.SourceOttSourceType>? defaultValue,
]) {
  if (sourceOttSourceType == null) {
    return defaultValue;
  }

  return sourceOttSourceType
      .map((e) => sourceOttSourceTypeFromJson(e.toString()))
      .toList();
}

String? feedResponseFeedTypeToJson(
    enums.FeedResponseFeedType? feedResponseFeedType) {
  return feedResponseFeedType?.value;
}

enums.FeedResponseFeedType feedResponseFeedTypeFromJson(
  Object? feedResponseFeedType, [
  enums.FeedResponseFeedType? defaultValue,
]) {
  return enums.FeedResponseFeedType.values
          .firstWhereOrNull((e) => e.value == feedResponseFeedType) ??
      defaultValue ??
      enums.FeedResponseFeedType.swaggerGeneratedUnknown;
}

List<String> feedResponseFeedTypeListToJson(
    List<enums.FeedResponseFeedType>? feedResponseFeedType) {
  if (feedResponseFeedType == null) {
    return [];
  }

  return feedResponseFeedType.map((e) => e.value!).toList();
}

List<enums.FeedResponseFeedType> feedResponseFeedTypeListFromJson(
  List? feedResponseFeedType, [
  List<enums.FeedResponseFeedType>? defaultValue,
]) {
  if (feedResponseFeedType == null) {
    return defaultValue ?? [];
  }

  return feedResponseFeedType
      .map((e) => feedResponseFeedTypeFromJson(e.toString()))
      .toList();
}

List<enums.FeedResponseFeedType>? feedResponseFeedTypeNullableListFromJson(
  List? feedResponseFeedType, [
  List<enums.FeedResponseFeedType>? defaultValue,
]) {
  if (feedResponseFeedType == null) {
    return defaultValue;
  }

  return feedResponseFeedType
      .map((e) => feedResponseFeedTypeFromJson(e.toString()))
      .toList();
}

String? feedResponseMetadataToJson(
    enums.FeedResponseMetadata? feedResponseMetadata) {
  return feedResponseMetadata?.value;
}

enums.FeedResponseMetadata feedResponseMetadataFromJson(
  Object? feedResponseMetadata, [
  enums.FeedResponseMetadata? defaultValue,
]) {
  return enums.FeedResponseMetadata.values
          .firstWhereOrNull((e) => e.value == feedResponseMetadata) ??
      defaultValue ??
      enums.FeedResponseMetadata.swaggerGeneratedUnknown;
}

List<String> feedResponseMetadataListToJson(
    List<enums.FeedResponseMetadata>? feedResponseMetadata) {
  if (feedResponseMetadata == null) {
    return [];
  }

  return feedResponseMetadata.map((e) => e.value!).toList();
}

List<enums.FeedResponseMetadata> feedResponseMetadataListFromJson(
  List? feedResponseMetadata, [
  List<enums.FeedResponseMetadata>? defaultValue,
]) {
  if (feedResponseMetadata == null) {
    return defaultValue ?? [];
  }

  return feedResponseMetadata
      .map((e) => feedResponseMetadataFromJson(e.toString()))
      .toList();
}

List<enums.FeedResponseMetadata>? feedResponseMetadataNullableListFromJson(
  List? feedResponseMetadata, [
  List<enums.FeedResponseMetadata>? defaultValue,
]) {
  if (feedResponseMetadata == null) {
    return defaultValue;
  }

  return feedResponseMetadata
      .map((e) => feedResponseMetadataFromJson(e.toString()))
      .toList();
}

String? aspotSubTypeToJson(enums.AspotSubType? aspotSubType) {
  return aspotSubType?.value;
}

enums.AspotSubType aspotSubTypeFromJson(
  Object? aspotSubType, [
  enums.AspotSubType? defaultValue,
]) {
  return enums.AspotSubType.values
          .firstWhereOrNull((e) => e.value == aspotSubType) ??
      defaultValue ??
      enums.AspotSubType.swaggerGeneratedUnknown;
}

List<String> aspotSubTypeListToJson(List<enums.AspotSubType>? aspotSubType) {
  if (aspotSubType == null) {
    return [];
  }

  return aspotSubType.map((e) => e.value!).toList();
}

List<enums.AspotSubType> aspotSubTypeListFromJson(
  List? aspotSubType, [
  List<enums.AspotSubType>? defaultValue,
]) {
  if (aspotSubType == null) {
    return defaultValue ?? [];
  }

  return aspotSubType.map((e) => aspotSubTypeFromJson(e.toString())).toList();
}

List<enums.AspotSubType>? aspotSubTypeNullableListFromJson(
  List? aspotSubType, [
  List<enums.AspotSubType>? defaultValue,
]) {
  if (aspotSubType == null) {
    return defaultValue;
  }

  return aspotSubType.map((e) => aspotSubTypeFromJson(e.toString())).toList();
}

String? aspotEntitlementStateToJson(
    enums.AspotEntitlementState? aspotEntitlementState) {
  return aspotEntitlementState?.value;
}

enums.AspotEntitlementState aspotEntitlementStateFromJson(
  Object? aspotEntitlementState, [
  enums.AspotEntitlementState? defaultValue,
]) {
  return enums.AspotEntitlementState.values
          .firstWhereOrNull((e) => e.value == aspotEntitlementState) ??
      defaultValue ??
      enums.AspotEntitlementState.swaggerGeneratedUnknown;
}

List<String> aspotEntitlementStateListToJson(
    List<enums.AspotEntitlementState>? aspotEntitlementState) {
  if (aspotEntitlementState == null) {
    return [];
  }

  return aspotEntitlementState.map((e) => e.value!).toList();
}

List<enums.AspotEntitlementState> aspotEntitlementStateListFromJson(
  List? aspotEntitlementState, [
  List<enums.AspotEntitlementState>? defaultValue,
]) {
  if (aspotEntitlementState == null) {
    return defaultValue ?? [];
  }

  return aspotEntitlementState
      .map((e) => aspotEntitlementStateFromJson(e.toString()))
      .toList();
}

List<enums.AspotEntitlementState>? aspotEntitlementStateNullableListFromJson(
  List? aspotEntitlementState, [
  List<enums.AspotEntitlementState>? defaultValue,
]) {
  if (aspotEntitlementState == null) {
    return defaultValue;
  }

  return aspotEntitlementState
      .map((e) => aspotEntitlementStateFromJson(e.toString()))
      .toList();
}

String? screenCollectionLayoutToJson(
    enums.ScreenCollectionLayout? screenCollectionLayout) {
  return screenCollectionLayout?.value;
}

enums.ScreenCollectionLayout screenCollectionLayoutFromJson(
  Object? screenCollectionLayout, [
  enums.ScreenCollectionLayout? defaultValue,
]) {
  return enums.ScreenCollectionLayout.values
          .firstWhereOrNull((e) => e.value == screenCollectionLayout) ??
      defaultValue ??
      enums.ScreenCollectionLayout.swaggerGeneratedUnknown;
}

List<String> screenCollectionLayoutListToJson(
    List<enums.ScreenCollectionLayout>? screenCollectionLayout) {
  if (screenCollectionLayout == null) {
    return [];
  }

  return screenCollectionLayout.map((e) => e.value!).toList();
}

List<enums.ScreenCollectionLayout> screenCollectionLayoutListFromJson(
  List? screenCollectionLayout, [
  List<enums.ScreenCollectionLayout>? defaultValue,
]) {
  if (screenCollectionLayout == null) {
    return defaultValue ?? [];
  }

  return screenCollectionLayout
      .map((e) => screenCollectionLayoutFromJson(e.toString()))
      .toList();
}

List<enums.ScreenCollectionLayout>? screenCollectionLayoutNullableListFromJson(
  List? screenCollectionLayout, [
  List<enums.ScreenCollectionLayout>? defaultValue,
]) {
  if (screenCollectionLayout == null) {
    return defaultValue;
  }

  return screenCollectionLayout
      .map((e) => screenCollectionLayoutFromJson(e.toString()))
      .toList();
}

String? screenItemSubTypeToJson(enums.ScreenItemSubType? screenItemSubType) {
  return screenItemSubType?.value;
}

enums.ScreenItemSubType screenItemSubTypeFromJson(
  Object? screenItemSubType, [
  enums.ScreenItemSubType? defaultValue,
]) {
  return enums.ScreenItemSubType.values
          .firstWhereOrNull((e) => e.value == screenItemSubType) ??
      defaultValue ??
      enums.ScreenItemSubType.swaggerGeneratedUnknown;
}

List<String> screenItemSubTypeListToJson(
    List<enums.ScreenItemSubType>? screenItemSubType) {
  if (screenItemSubType == null) {
    return [];
  }

  return screenItemSubType.map((e) => e.value!).toList();
}

List<enums.ScreenItemSubType> screenItemSubTypeListFromJson(
  List? screenItemSubType, [
  List<enums.ScreenItemSubType>? defaultValue,
]) {
  if (screenItemSubType == null) {
    return defaultValue ?? [];
  }

  return screenItemSubType
      .map((e) => screenItemSubTypeFromJson(e.toString()))
      .toList();
}

List<enums.ScreenItemSubType>? screenItemSubTypeNullableListFromJson(
  List? screenItemSubType, [
  List<enums.ScreenItemSubType>? defaultValue,
]) {
  if (screenItemSubType == null) {
    return defaultValue;
  }

  return screenItemSubType
      .map((e) => screenItemSubTypeFromJson(e.toString()))
      .toList();
}

String? screenItemEntitlementStateToJson(
    enums.ScreenItemEntitlementState? screenItemEntitlementState) {
  return screenItemEntitlementState?.value;
}

enums.ScreenItemEntitlementState screenItemEntitlementStateFromJson(
  Object? screenItemEntitlementState, [
  enums.ScreenItemEntitlementState? defaultValue,
]) {
  return enums.ScreenItemEntitlementState.values
          .firstWhereOrNull((e) => e.value == screenItemEntitlementState) ??
      defaultValue ??
      enums.ScreenItemEntitlementState.swaggerGeneratedUnknown;
}

List<String> screenItemEntitlementStateListToJson(
    List<enums.ScreenItemEntitlementState>? screenItemEntitlementState) {
  if (screenItemEntitlementState == null) {
    return [];
  }

  return screenItemEntitlementState.map((e) => e.value!).toList();
}

List<enums.ScreenItemEntitlementState> screenItemEntitlementStateListFromJson(
  List? screenItemEntitlementState, [
  List<enums.ScreenItemEntitlementState>? defaultValue,
]) {
  if (screenItemEntitlementState == null) {
    return defaultValue ?? [];
  }

  return screenItemEntitlementState
      .map((e) => screenItemEntitlementStateFromJson(e.toString()))
      .toList();
}

List<enums.ScreenItemEntitlementState>?
    screenItemEntitlementStateNullableListFromJson(
  List? screenItemEntitlementState, [
  List<enums.ScreenItemEntitlementState>? defaultValue,
]) {
  if (screenItemEntitlementState == null) {
    return defaultValue;
  }

  return screenItemEntitlementState
      .map((e) => screenItemEntitlementStateFromJson(e.toString()))
      .toList();
}

String? feedComposerV1PurchasedItemsGetEncodingToJson(
    enums.FeedComposerV1PurchasedItemsGetEncoding?
        feedComposerV1PurchasedItemsGetEncoding) {
  return feedComposerV1PurchasedItemsGetEncoding?.value;
}

enums.FeedComposerV1PurchasedItemsGetEncoding
    feedComposerV1PurchasedItemsGetEncodingFromJson(
  Object? feedComposerV1PurchasedItemsGetEncoding, [
  enums.FeedComposerV1PurchasedItemsGetEncoding? defaultValue,
]) {
  return enums.FeedComposerV1PurchasedItemsGetEncoding.values.firstWhereOrNull(
          (e) => e.value == feedComposerV1PurchasedItemsGetEncoding) ??
      defaultValue ??
      enums.FeedComposerV1PurchasedItemsGetEncoding.swaggerGeneratedUnknown;
}

List<String> feedComposerV1PurchasedItemsGetEncodingListToJson(
    List<enums.FeedComposerV1PurchasedItemsGetEncoding>?
        feedComposerV1PurchasedItemsGetEncoding) {
  if (feedComposerV1PurchasedItemsGetEncoding == null) {
    return [];
  }

  return feedComposerV1PurchasedItemsGetEncoding.map((e) => e.value!).toList();
}

List<enums.FeedComposerV1PurchasedItemsGetEncoding>
    feedComposerV1PurchasedItemsGetEncodingListFromJson(
  List? feedComposerV1PurchasedItemsGetEncoding, [
  List<enums.FeedComposerV1PurchasedItemsGetEncoding>? defaultValue,
]) {
  if (feedComposerV1PurchasedItemsGetEncoding == null) {
    return defaultValue ?? [];
  }

  return feedComposerV1PurchasedItemsGetEncoding
      .map((e) => feedComposerV1PurchasedItemsGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.FeedComposerV1PurchasedItemsGetEncoding>?
    feedComposerV1PurchasedItemsGetEncodingNullableListFromJson(
  List? feedComposerV1PurchasedItemsGetEncoding, [
  List<enums.FeedComposerV1PurchasedItemsGetEncoding>? defaultValue,
]) {
  if (feedComposerV1PurchasedItemsGetEncoding == null) {
    return defaultValue;
  }

  return feedComposerV1PurchasedItemsGetEncoding
      .map((e) => feedComposerV1PurchasedItemsGetEncodingFromJson(e.toString()))
      .toList();
}

String? feedComposerV1PurchasedItemsGetMaxResToJson(
    enums.FeedComposerV1PurchasedItemsGetMaxRes?
        feedComposerV1PurchasedItemsGetMaxRes) {
  return feedComposerV1PurchasedItemsGetMaxRes?.value;
}

enums.FeedComposerV1PurchasedItemsGetMaxRes
    feedComposerV1PurchasedItemsGetMaxResFromJson(
  Object? feedComposerV1PurchasedItemsGetMaxRes, [
  enums.FeedComposerV1PurchasedItemsGetMaxRes? defaultValue,
]) {
  return enums.FeedComposerV1PurchasedItemsGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == feedComposerV1PurchasedItemsGetMaxRes) ??
      defaultValue ??
      enums.FeedComposerV1PurchasedItemsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> feedComposerV1PurchasedItemsGetMaxResListToJson(
    List<enums.FeedComposerV1PurchasedItemsGetMaxRes>?
        feedComposerV1PurchasedItemsGetMaxRes) {
  if (feedComposerV1PurchasedItemsGetMaxRes == null) {
    return [];
  }

  return feedComposerV1PurchasedItemsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.FeedComposerV1PurchasedItemsGetMaxRes>
    feedComposerV1PurchasedItemsGetMaxResListFromJson(
  List? feedComposerV1PurchasedItemsGetMaxRes, [
  List<enums.FeedComposerV1PurchasedItemsGetMaxRes>? defaultValue,
]) {
  if (feedComposerV1PurchasedItemsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return feedComposerV1PurchasedItemsGetMaxRes
      .map((e) => feedComposerV1PurchasedItemsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.FeedComposerV1PurchasedItemsGetMaxRes>?
    feedComposerV1PurchasedItemsGetMaxResNullableListFromJson(
  List? feedComposerV1PurchasedItemsGetMaxRes, [
  List<enums.FeedComposerV1PurchasedItemsGetMaxRes>? defaultValue,
]) {
  if (feedComposerV1PurchasedItemsGetMaxRes == null) {
    return defaultValue;
  }

  return feedComposerV1PurchasedItemsGetMaxRes
      .map((e) => feedComposerV1PurchasedItemsGetMaxResFromJson(e.toString()))
      .toList();
}

String? feedComposerV1TopListTopListIdGetEncodingToJson(
    enums.FeedComposerV1TopListTopListIdGetEncoding?
        feedComposerV1TopListTopListIdGetEncoding) {
  return feedComposerV1TopListTopListIdGetEncoding?.value;
}

enums.FeedComposerV1TopListTopListIdGetEncoding
    feedComposerV1TopListTopListIdGetEncodingFromJson(
  Object? feedComposerV1TopListTopListIdGetEncoding, [
  enums.FeedComposerV1TopListTopListIdGetEncoding? defaultValue,
]) {
  return enums.FeedComposerV1TopListTopListIdGetEncoding.values
          .firstWhereOrNull(
              (e) => e.value == feedComposerV1TopListTopListIdGetEncoding) ??
      defaultValue ??
      enums.FeedComposerV1TopListTopListIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> feedComposerV1TopListTopListIdGetEncodingListToJson(
    List<enums.FeedComposerV1TopListTopListIdGetEncoding>?
        feedComposerV1TopListTopListIdGetEncoding) {
  if (feedComposerV1TopListTopListIdGetEncoding == null) {
    return [];
  }

  return feedComposerV1TopListTopListIdGetEncoding
      .map((e) => e.value!)
      .toList();
}

List<enums.FeedComposerV1TopListTopListIdGetEncoding>
    feedComposerV1TopListTopListIdGetEncodingListFromJson(
  List? feedComposerV1TopListTopListIdGetEncoding, [
  List<enums.FeedComposerV1TopListTopListIdGetEncoding>? defaultValue,
]) {
  if (feedComposerV1TopListTopListIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return feedComposerV1TopListTopListIdGetEncoding
      .map((e) =>
          feedComposerV1TopListTopListIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.FeedComposerV1TopListTopListIdGetEncoding>?
    feedComposerV1TopListTopListIdGetEncodingNullableListFromJson(
  List? feedComposerV1TopListTopListIdGetEncoding, [
  List<enums.FeedComposerV1TopListTopListIdGetEncoding>? defaultValue,
]) {
  if (feedComposerV1TopListTopListIdGetEncoding == null) {
    return defaultValue;
  }

  return feedComposerV1TopListTopListIdGetEncoding
      .map((e) =>
          feedComposerV1TopListTopListIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? feedComposerV1TopListTopListIdGetMaxResToJson(
    enums.FeedComposerV1TopListTopListIdGetMaxRes?
        feedComposerV1TopListTopListIdGetMaxRes) {
  return feedComposerV1TopListTopListIdGetMaxRes?.value;
}

enums.FeedComposerV1TopListTopListIdGetMaxRes
    feedComposerV1TopListTopListIdGetMaxResFromJson(
  Object? feedComposerV1TopListTopListIdGetMaxRes, [
  enums.FeedComposerV1TopListTopListIdGetMaxRes? defaultValue,
]) {
  return enums.FeedComposerV1TopListTopListIdGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == feedComposerV1TopListTopListIdGetMaxRes) ??
      defaultValue ??
      enums.FeedComposerV1TopListTopListIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> feedComposerV1TopListTopListIdGetMaxResListToJson(
    List<enums.FeedComposerV1TopListTopListIdGetMaxRes>?
        feedComposerV1TopListTopListIdGetMaxRes) {
  if (feedComposerV1TopListTopListIdGetMaxRes == null) {
    return [];
  }

  return feedComposerV1TopListTopListIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.FeedComposerV1TopListTopListIdGetMaxRes>
    feedComposerV1TopListTopListIdGetMaxResListFromJson(
  List? feedComposerV1TopListTopListIdGetMaxRes, [
  List<enums.FeedComposerV1TopListTopListIdGetMaxRes>? defaultValue,
]) {
  if (feedComposerV1TopListTopListIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return feedComposerV1TopListTopListIdGetMaxRes
      .map((e) => feedComposerV1TopListTopListIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.FeedComposerV1TopListTopListIdGetMaxRes>?
    feedComposerV1TopListTopListIdGetMaxResNullableListFromJson(
  List? feedComposerV1TopListTopListIdGetMaxRes, [
  List<enums.FeedComposerV1TopListTopListIdGetMaxRes>? defaultValue,
]) {
  if (feedComposerV1TopListTopListIdGetMaxRes == null) {
    return defaultValue;
  }

  return feedComposerV1TopListTopListIdGetMaxRes
      .map((e) => feedComposerV1TopListTopListIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2VodstructureRootIdGetEncodingToJson(
    enums.V2VodstructureRootIdGetEncoding? v2VodstructureRootIdGetEncoding) {
  return v2VodstructureRootIdGetEncoding?.value;
}

enums.V2VodstructureRootIdGetEncoding v2VodstructureRootIdGetEncodingFromJson(
  Object? v2VodstructureRootIdGetEncoding, [
  enums.V2VodstructureRootIdGetEncoding? defaultValue,
]) {
  return enums.V2VodstructureRootIdGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2VodstructureRootIdGetEncoding) ??
      defaultValue ??
      enums.V2VodstructureRootIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2VodstructureRootIdGetEncodingListToJson(
    List<enums.V2VodstructureRootIdGetEncoding>?
        v2VodstructureRootIdGetEncoding) {
  if (v2VodstructureRootIdGetEncoding == null) {
    return [];
  }

  return v2VodstructureRootIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2VodstructureRootIdGetEncoding>
    v2VodstructureRootIdGetEncodingListFromJson(
  List? v2VodstructureRootIdGetEncoding, [
  List<enums.V2VodstructureRootIdGetEncoding>? defaultValue,
]) {
  if (v2VodstructureRootIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2VodstructureRootIdGetEncoding
      .map((e) => v2VodstructureRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2VodstructureRootIdGetEncoding>?
    v2VodstructureRootIdGetEncodingNullableListFromJson(
  List? v2VodstructureRootIdGetEncoding, [
  List<enums.V2VodstructureRootIdGetEncoding>? defaultValue,
]) {
  if (v2VodstructureRootIdGetEncoding == null) {
    return defaultValue;
  }

  return v2VodstructureRootIdGetEncoding
      .map((e) => v2VodstructureRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2VodstructureRootIdGetMaxResToJson(
    enums.V2VodstructureRootIdGetMaxRes? v2VodstructureRootIdGetMaxRes) {
  return v2VodstructureRootIdGetMaxRes?.value;
}

enums.V2VodstructureRootIdGetMaxRes v2VodstructureRootIdGetMaxResFromJson(
  Object? v2VodstructureRootIdGetMaxRes, [
  enums.V2VodstructureRootIdGetMaxRes? defaultValue,
]) {
  return enums.V2VodstructureRootIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2VodstructureRootIdGetMaxRes) ??
      defaultValue ??
      enums.V2VodstructureRootIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2VodstructureRootIdGetMaxResListToJson(
    List<enums.V2VodstructureRootIdGetMaxRes>? v2VodstructureRootIdGetMaxRes) {
  if (v2VodstructureRootIdGetMaxRes == null) {
    return [];
  }

  return v2VodstructureRootIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2VodstructureRootIdGetMaxRes>
    v2VodstructureRootIdGetMaxResListFromJson(
  List? v2VodstructureRootIdGetMaxRes, [
  List<enums.V2VodstructureRootIdGetMaxRes>? defaultValue,
]) {
  if (v2VodstructureRootIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2VodstructureRootIdGetMaxRes
      .map((e) => v2VodstructureRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2VodstructureRootIdGetMaxRes>?
    v2VodstructureRootIdGetMaxResNullableListFromJson(
  List? v2VodstructureRootIdGetMaxRes, [
  List<enums.V2VodstructureRootIdGetMaxRes>? defaultValue,
]) {
  if (v2VodstructureRootIdGetMaxRes == null) {
    return defaultValue;
  }

  return v2VodstructureRootIdGetMaxRes
      .map((e) => v2VodstructureRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2VodstructureRootIdGetFilterOnDemandToJson(
    enums.V2VodstructureRootIdGetFilterOnDemand?
        v2VodstructureRootIdGetFilterOnDemand) {
  return v2VodstructureRootIdGetFilterOnDemand?.value;
}

enums.V2VodstructureRootIdGetFilterOnDemand
    v2VodstructureRootIdGetFilterOnDemandFromJson(
  Object? v2VodstructureRootIdGetFilterOnDemand, [
  enums.V2VodstructureRootIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V2VodstructureRootIdGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v2VodstructureRootIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V2VodstructureRootIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v2VodstructureRootIdGetFilterOnDemandListToJson(
    List<enums.V2VodstructureRootIdGetFilterOnDemand>?
        v2VodstructureRootIdGetFilterOnDemand) {
  if (v2VodstructureRootIdGetFilterOnDemand == null) {
    return [];
  }

  return v2VodstructureRootIdGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V2VodstructureRootIdGetFilterOnDemand>
    v2VodstructureRootIdGetFilterOnDemandListFromJson(
  List? v2VodstructureRootIdGetFilterOnDemand, [
  List<enums.V2VodstructureRootIdGetFilterOnDemand>? defaultValue,
]) {
  if (v2VodstructureRootIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v2VodstructureRootIdGetFilterOnDemand
      .map((e) => v2VodstructureRootIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V2VodstructureRootIdGetFilterOnDemand>?
    v2VodstructureRootIdGetFilterOnDemandNullableListFromJson(
  List? v2VodstructureRootIdGetFilterOnDemand, [
  List<enums.V2VodstructureRootIdGetFilterOnDemand>? defaultValue,
]) {
  if (v2VodstructureRootIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v2VodstructureRootIdGetFilterOnDemand
      .map((e) => v2VodstructureRootIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v2ContextualvodRootIdGetEncodingToJson(
    enums.V2ContextualvodRootIdGetEncoding? v2ContextualvodRootIdGetEncoding) {
  return v2ContextualvodRootIdGetEncoding?.value;
}

enums.V2ContextualvodRootIdGetEncoding v2ContextualvodRootIdGetEncodingFromJson(
  Object? v2ContextualvodRootIdGetEncoding, [
  enums.V2ContextualvodRootIdGetEncoding? defaultValue,
]) {
  return enums.V2ContextualvodRootIdGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2ContextualvodRootIdGetEncoding) ??
      defaultValue ??
      enums.V2ContextualvodRootIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2ContextualvodRootIdGetEncodingListToJson(
    List<enums.V2ContextualvodRootIdGetEncoding>?
        v2ContextualvodRootIdGetEncoding) {
  if (v2ContextualvodRootIdGetEncoding == null) {
    return [];
  }

  return v2ContextualvodRootIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2ContextualvodRootIdGetEncoding>
    v2ContextualvodRootIdGetEncodingListFromJson(
  List? v2ContextualvodRootIdGetEncoding, [
  List<enums.V2ContextualvodRootIdGetEncoding>? defaultValue,
]) {
  if (v2ContextualvodRootIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2ContextualvodRootIdGetEncoding
      .map((e) => v2ContextualvodRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2ContextualvodRootIdGetEncoding>?
    v2ContextualvodRootIdGetEncodingNullableListFromJson(
  List? v2ContextualvodRootIdGetEncoding, [
  List<enums.V2ContextualvodRootIdGetEncoding>? defaultValue,
]) {
  if (v2ContextualvodRootIdGetEncoding == null) {
    return defaultValue;
  }

  return v2ContextualvodRootIdGetEncoding
      .map((e) => v2ContextualvodRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2ContextualvodRootIdGetMaxResToJson(
    enums.V2ContextualvodRootIdGetMaxRes? v2ContextualvodRootIdGetMaxRes) {
  return v2ContextualvodRootIdGetMaxRes?.value;
}

enums.V2ContextualvodRootIdGetMaxRes v2ContextualvodRootIdGetMaxResFromJson(
  Object? v2ContextualvodRootIdGetMaxRes, [
  enums.V2ContextualvodRootIdGetMaxRes? defaultValue,
]) {
  return enums.V2ContextualvodRootIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2ContextualvodRootIdGetMaxRes) ??
      defaultValue ??
      enums.V2ContextualvodRootIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2ContextualvodRootIdGetMaxResListToJson(
    List<enums.V2ContextualvodRootIdGetMaxRes>?
        v2ContextualvodRootIdGetMaxRes) {
  if (v2ContextualvodRootIdGetMaxRes == null) {
    return [];
  }

  return v2ContextualvodRootIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2ContextualvodRootIdGetMaxRes>
    v2ContextualvodRootIdGetMaxResListFromJson(
  List? v2ContextualvodRootIdGetMaxRes, [
  List<enums.V2ContextualvodRootIdGetMaxRes>? defaultValue,
]) {
  if (v2ContextualvodRootIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2ContextualvodRootIdGetMaxRes
      .map((e) => v2ContextualvodRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2ContextualvodRootIdGetMaxRes>?
    v2ContextualvodRootIdGetMaxResNullableListFromJson(
  List? v2ContextualvodRootIdGetMaxRes, [
  List<enums.V2ContextualvodRootIdGetMaxRes>? defaultValue,
]) {
  if (v2ContextualvodRootIdGetMaxRes == null) {
    return defaultValue;
  }

  return v2ContextualvodRootIdGetMaxRes
      .map((e) => v2ContextualvodRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2RentalsGetEncodingToJson(
    enums.V2RentalsGetEncoding? v2RentalsGetEncoding) {
  return v2RentalsGetEncoding?.value;
}

enums.V2RentalsGetEncoding v2RentalsGetEncodingFromJson(
  Object? v2RentalsGetEncoding, [
  enums.V2RentalsGetEncoding? defaultValue,
]) {
  return enums.V2RentalsGetEncoding.values
          .firstWhereOrNull((e) => e.value == v2RentalsGetEncoding) ??
      defaultValue ??
      enums.V2RentalsGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2RentalsGetEncodingListToJson(
    List<enums.V2RentalsGetEncoding>? v2RentalsGetEncoding) {
  if (v2RentalsGetEncoding == null) {
    return [];
  }

  return v2RentalsGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2RentalsGetEncoding> v2RentalsGetEncodingListFromJson(
  List? v2RentalsGetEncoding, [
  List<enums.V2RentalsGetEncoding>? defaultValue,
]) {
  if (v2RentalsGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2RentalsGetEncoding
      .map((e) => v2RentalsGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2RentalsGetEncoding>? v2RentalsGetEncodingNullableListFromJson(
  List? v2RentalsGetEncoding, [
  List<enums.V2RentalsGetEncoding>? defaultValue,
]) {
  if (v2RentalsGetEncoding == null) {
    return defaultValue;
  }

  return v2RentalsGetEncoding
      .map((e) => v2RentalsGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2RentalsGetMaxResToJson(enums.V2RentalsGetMaxRes? v2RentalsGetMaxRes) {
  return v2RentalsGetMaxRes?.value;
}

enums.V2RentalsGetMaxRes v2RentalsGetMaxResFromJson(
  Object? v2RentalsGetMaxRes, [
  enums.V2RentalsGetMaxRes? defaultValue,
]) {
  return enums.V2RentalsGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2RentalsGetMaxRes) ??
      defaultValue ??
      enums.V2RentalsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2RentalsGetMaxResListToJson(
    List<enums.V2RentalsGetMaxRes>? v2RentalsGetMaxRes) {
  if (v2RentalsGetMaxRes == null) {
    return [];
  }

  return v2RentalsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2RentalsGetMaxRes> v2RentalsGetMaxResListFromJson(
  List? v2RentalsGetMaxRes, [
  List<enums.V2RentalsGetMaxRes>? defaultValue,
]) {
  if (v2RentalsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2RentalsGetMaxRes
      .map((e) => v2RentalsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2RentalsGetMaxRes>? v2RentalsGetMaxResNullableListFromJson(
  List? v2RentalsGetMaxRes, [
  List<enums.V2RentalsGetMaxRes>? defaultValue,
]) {
  if (v2RentalsGetMaxRes == null) {
    return defaultValue;
  }

  return v2RentalsGetMaxRes
      .map((e) => v2RentalsGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2DetailscreenCridGetEncodingToJson(
    enums.V2DetailscreenCridGetEncoding? v2DetailscreenCridGetEncoding) {
  return v2DetailscreenCridGetEncoding?.value;
}

enums.V2DetailscreenCridGetEncoding v2DetailscreenCridGetEncodingFromJson(
  Object? v2DetailscreenCridGetEncoding, [
  enums.V2DetailscreenCridGetEncoding? defaultValue,
]) {
  return enums.V2DetailscreenCridGetEncoding.values
          .firstWhereOrNull((e) => e.value == v2DetailscreenCridGetEncoding) ??
      defaultValue ??
      enums.V2DetailscreenCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2DetailscreenCridGetEncodingListToJson(
    List<enums.V2DetailscreenCridGetEncoding>? v2DetailscreenCridGetEncoding) {
  if (v2DetailscreenCridGetEncoding == null) {
    return [];
  }

  return v2DetailscreenCridGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2DetailscreenCridGetEncoding>
    v2DetailscreenCridGetEncodingListFromJson(
  List? v2DetailscreenCridGetEncoding, [
  List<enums.V2DetailscreenCridGetEncoding>? defaultValue,
]) {
  if (v2DetailscreenCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2DetailscreenCridGetEncoding
      .map((e) => v2DetailscreenCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2DetailscreenCridGetEncoding>?
    v2DetailscreenCridGetEncodingNullableListFromJson(
  List? v2DetailscreenCridGetEncoding, [
  List<enums.V2DetailscreenCridGetEncoding>? defaultValue,
]) {
  if (v2DetailscreenCridGetEncoding == null) {
    return defaultValue;
  }

  return v2DetailscreenCridGetEncoding
      .map((e) => v2DetailscreenCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2DetailscreenCridGetMaxResToJson(
    enums.V2DetailscreenCridGetMaxRes? v2DetailscreenCridGetMaxRes) {
  return v2DetailscreenCridGetMaxRes?.value;
}

enums.V2DetailscreenCridGetMaxRes v2DetailscreenCridGetMaxResFromJson(
  Object? v2DetailscreenCridGetMaxRes, [
  enums.V2DetailscreenCridGetMaxRes? defaultValue,
]) {
  return enums.V2DetailscreenCridGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2DetailscreenCridGetMaxRes) ??
      defaultValue ??
      enums.V2DetailscreenCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2DetailscreenCridGetMaxResListToJson(
    List<enums.V2DetailscreenCridGetMaxRes>? v2DetailscreenCridGetMaxRes) {
  if (v2DetailscreenCridGetMaxRes == null) {
    return [];
  }

  return v2DetailscreenCridGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2DetailscreenCridGetMaxRes> v2DetailscreenCridGetMaxResListFromJson(
  List? v2DetailscreenCridGetMaxRes, [
  List<enums.V2DetailscreenCridGetMaxRes>? defaultValue,
]) {
  if (v2DetailscreenCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2DetailscreenCridGetMaxRes
      .map((e) => v2DetailscreenCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2DetailscreenCridGetMaxRes>?
    v2DetailscreenCridGetMaxResNullableListFromJson(
  List? v2DetailscreenCridGetMaxRes, [
  List<enums.V2DetailscreenCridGetMaxRes>? defaultValue,
]) {
  if (v2DetailscreenCridGetMaxRes == null) {
    return defaultValue;
  }

  return v2DetailscreenCridGetMaxRes
      .map((e) => v2DetailscreenCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2DetailscreenCridGetFilterOnDemandToJson(
    enums.V2DetailscreenCridGetFilterOnDemand?
        v2DetailscreenCridGetFilterOnDemand) {
  return v2DetailscreenCridGetFilterOnDemand?.value;
}

enums.V2DetailscreenCridGetFilterOnDemand
    v2DetailscreenCridGetFilterOnDemandFromJson(
  Object? v2DetailscreenCridGetFilterOnDemand, [
  enums.V2DetailscreenCridGetFilterOnDemand? defaultValue,
]) {
  return enums.V2DetailscreenCridGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v2DetailscreenCridGetFilterOnDemand) ??
      defaultValue ??
      enums.V2DetailscreenCridGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v2DetailscreenCridGetFilterOnDemandListToJson(
    List<enums.V2DetailscreenCridGetFilterOnDemand>?
        v2DetailscreenCridGetFilterOnDemand) {
  if (v2DetailscreenCridGetFilterOnDemand == null) {
    return [];
  }

  return v2DetailscreenCridGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V2DetailscreenCridGetFilterOnDemand>
    v2DetailscreenCridGetFilterOnDemandListFromJson(
  List? v2DetailscreenCridGetFilterOnDemand, [
  List<enums.V2DetailscreenCridGetFilterOnDemand>? defaultValue,
]) {
  if (v2DetailscreenCridGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v2DetailscreenCridGetFilterOnDemand
      .map((e) => v2DetailscreenCridGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V2DetailscreenCridGetFilterOnDemand>?
    v2DetailscreenCridGetFilterOnDemandNullableListFromJson(
  List? v2DetailscreenCridGetFilterOnDemand, [
  List<enums.V2DetailscreenCridGetFilterOnDemand>? defaultValue,
]) {
  if (v2DetailscreenCridGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v2DetailscreenCridGetFilterOnDemand
      .map((e) => v2DetailscreenCridGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v2TrailerDetailsTrailerCridGetEncodingToJson(
    enums.V2TrailerDetailsTrailerCridGetEncoding?
        v2TrailerDetailsTrailerCridGetEncoding) {
  return v2TrailerDetailsTrailerCridGetEncoding?.value;
}

enums.V2TrailerDetailsTrailerCridGetEncoding
    v2TrailerDetailsTrailerCridGetEncodingFromJson(
  Object? v2TrailerDetailsTrailerCridGetEncoding, [
  enums.V2TrailerDetailsTrailerCridGetEncoding? defaultValue,
]) {
  return enums.V2TrailerDetailsTrailerCridGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2TrailerDetailsTrailerCridGetEncoding) ??
      defaultValue ??
      enums.V2TrailerDetailsTrailerCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2TrailerDetailsTrailerCridGetEncodingListToJson(
    List<enums.V2TrailerDetailsTrailerCridGetEncoding>?
        v2TrailerDetailsTrailerCridGetEncoding) {
  if (v2TrailerDetailsTrailerCridGetEncoding == null) {
    return [];
  }

  return v2TrailerDetailsTrailerCridGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2TrailerDetailsTrailerCridGetEncoding>
    v2TrailerDetailsTrailerCridGetEncodingListFromJson(
  List? v2TrailerDetailsTrailerCridGetEncoding, [
  List<enums.V2TrailerDetailsTrailerCridGetEncoding>? defaultValue,
]) {
  if (v2TrailerDetailsTrailerCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2TrailerDetailsTrailerCridGetEncoding
      .map((e) => v2TrailerDetailsTrailerCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2TrailerDetailsTrailerCridGetEncoding>?
    v2TrailerDetailsTrailerCridGetEncodingNullableListFromJson(
  List? v2TrailerDetailsTrailerCridGetEncoding, [
  List<enums.V2TrailerDetailsTrailerCridGetEncoding>? defaultValue,
]) {
  if (v2TrailerDetailsTrailerCridGetEncoding == null) {
    return defaultValue;
  }

  return v2TrailerDetailsTrailerCridGetEncoding
      .map((e) => v2TrailerDetailsTrailerCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2TrailerDetailsTrailerCridGetMaxResToJson(
    enums.V2TrailerDetailsTrailerCridGetMaxRes?
        v2TrailerDetailsTrailerCridGetMaxRes) {
  return v2TrailerDetailsTrailerCridGetMaxRes?.value;
}

enums.V2TrailerDetailsTrailerCridGetMaxRes
    v2TrailerDetailsTrailerCridGetMaxResFromJson(
  Object? v2TrailerDetailsTrailerCridGetMaxRes, [
  enums.V2TrailerDetailsTrailerCridGetMaxRes? defaultValue,
]) {
  return enums.V2TrailerDetailsTrailerCridGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2TrailerDetailsTrailerCridGetMaxRes) ??
      defaultValue ??
      enums.V2TrailerDetailsTrailerCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2TrailerDetailsTrailerCridGetMaxResListToJson(
    List<enums.V2TrailerDetailsTrailerCridGetMaxRes>?
        v2TrailerDetailsTrailerCridGetMaxRes) {
  if (v2TrailerDetailsTrailerCridGetMaxRes == null) {
    return [];
  }

  return v2TrailerDetailsTrailerCridGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2TrailerDetailsTrailerCridGetMaxRes>
    v2TrailerDetailsTrailerCridGetMaxResListFromJson(
  List? v2TrailerDetailsTrailerCridGetMaxRes, [
  List<enums.V2TrailerDetailsTrailerCridGetMaxRes>? defaultValue,
]) {
  if (v2TrailerDetailsTrailerCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2TrailerDetailsTrailerCridGetMaxRes
      .map((e) => v2TrailerDetailsTrailerCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2TrailerDetailsTrailerCridGetMaxRes>?
    v2TrailerDetailsTrailerCridGetMaxResNullableListFromJson(
  List? v2TrailerDetailsTrailerCridGetMaxRes, [
  List<enums.V2TrailerDetailsTrailerCridGetMaxRes>? defaultValue,
]) {
  if (v2TrailerDetailsTrailerCridGetMaxRes == null) {
    return defaultValue;
  }

  return v2TrailerDetailsTrailerCridGetMaxRes
      .map((e) => v2TrailerDetailsTrailerCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2GridoptionsCridGetEncodingToJson(
    enums.V2GridoptionsCridGetEncoding? v2GridoptionsCridGetEncoding) {
  return v2GridoptionsCridGetEncoding?.value;
}

enums.V2GridoptionsCridGetEncoding v2GridoptionsCridGetEncodingFromJson(
  Object? v2GridoptionsCridGetEncoding, [
  enums.V2GridoptionsCridGetEncoding? defaultValue,
]) {
  return enums.V2GridoptionsCridGetEncoding.values
          .firstWhereOrNull((e) => e.value == v2GridoptionsCridGetEncoding) ??
      defaultValue ??
      enums.V2GridoptionsCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2GridoptionsCridGetEncodingListToJson(
    List<enums.V2GridoptionsCridGetEncoding>? v2GridoptionsCridGetEncoding) {
  if (v2GridoptionsCridGetEncoding == null) {
    return [];
  }

  return v2GridoptionsCridGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2GridoptionsCridGetEncoding>
    v2GridoptionsCridGetEncodingListFromJson(
  List? v2GridoptionsCridGetEncoding, [
  List<enums.V2GridoptionsCridGetEncoding>? defaultValue,
]) {
  if (v2GridoptionsCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2GridoptionsCridGetEncoding
      .map((e) => v2GridoptionsCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2GridoptionsCridGetEncoding>?
    v2GridoptionsCridGetEncodingNullableListFromJson(
  List? v2GridoptionsCridGetEncoding, [
  List<enums.V2GridoptionsCridGetEncoding>? defaultValue,
]) {
  if (v2GridoptionsCridGetEncoding == null) {
    return defaultValue;
  }

  return v2GridoptionsCridGetEncoding
      .map((e) => v2GridoptionsCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2GridoptionsCridGetMaxResToJson(
    enums.V2GridoptionsCridGetMaxRes? v2GridoptionsCridGetMaxRes) {
  return v2GridoptionsCridGetMaxRes?.value;
}

enums.V2GridoptionsCridGetMaxRes v2GridoptionsCridGetMaxResFromJson(
  Object? v2GridoptionsCridGetMaxRes, [
  enums.V2GridoptionsCridGetMaxRes? defaultValue,
]) {
  return enums.V2GridoptionsCridGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2GridoptionsCridGetMaxRes) ??
      defaultValue ??
      enums.V2GridoptionsCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2GridoptionsCridGetMaxResListToJson(
    List<enums.V2GridoptionsCridGetMaxRes>? v2GridoptionsCridGetMaxRes) {
  if (v2GridoptionsCridGetMaxRes == null) {
    return [];
  }

  return v2GridoptionsCridGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2GridoptionsCridGetMaxRes> v2GridoptionsCridGetMaxResListFromJson(
  List? v2GridoptionsCridGetMaxRes, [
  List<enums.V2GridoptionsCridGetMaxRes>? defaultValue,
]) {
  if (v2GridoptionsCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2GridoptionsCridGetMaxRes
      .map((e) => v2GridoptionsCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2GridoptionsCridGetMaxRes>?
    v2GridoptionsCridGetMaxResNullableListFromJson(
  List? v2GridoptionsCridGetMaxRes, [
  List<enums.V2GridoptionsCridGetMaxRes>? defaultValue,
]) {
  if (v2GridoptionsCridGetMaxRes == null) {
    return defaultValue;
  }

  return v2GridoptionsCridGetMaxRes
      .map((e) => v2GridoptionsCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2GridoptionsCridGetFilterOnDemandToJson(
    enums.V2GridoptionsCridGetFilterOnDemand?
        v2GridoptionsCridGetFilterOnDemand) {
  return v2GridoptionsCridGetFilterOnDemand?.value;
}

enums.V2GridoptionsCridGetFilterOnDemand
    v2GridoptionsCridGetFilterOnDemandFromJson(
  Object? v2GridoptionsCridGetFilterOnDemand, [
  enums.V2GridoptionsCridGetFilterOnDemand? defaultValue,
]) {
  return enums.V2GridoptionsCridGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v2GridoptionsCridGetFilterOnDemand) ??
      defaultValue ??
      enums.V2GridoptionsCridGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v2GridoptionsCridGetFilterOnDemandListToJson(
    List<enums.V2GridoptionsCridGetFilterOnDemand>?
        v2GridoptionsCridGetFilterOnDemand) {
  if (v2GridoptionsCridGetFilterOnDemand == null) {
    return [];
  }

  return v2GridoptionsCridGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V2GridoptionsCridGetFilterOnDemand>
    v2GridoptionsCridGetFilterOnDemandListFromJson(
  List? v2GridoptionsCridGetFilterOnDemand, [
  List<enums.V2GridoptionsCridGetFilterOnDemand>? defaultValue,
]) {
  if (v2GridoptionsCridGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v2GridoptionsCridGetFilterOnDemand
      .map((e) => v2GridoptionsCridGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V2GridoptionsCridGetFilterOnDemand>?
    v2GridoptionsCridGetFilterOnDemandNullableListFromJson(
  List? v2GridoptionsCridGetFilterOnDemand, [
  List<enums.V2GridoptionsCridGetFilterOnDemand>? defaultValue,
]) {
  if (v2GridoptionsCridGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v2GridoptionsCridGetFilterOnDemand
      .map((e) => v2GridoptionsCridGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v2GridscreenRootIdScreenIdGetSortTypeToJson(
    enums.V2GridscreenRootIdScreenIdGetSortType?
        v2GridscreenRootIdScreenIdGetSortType) {
  return v2GridscreenRootIdScreenIdGetSortType?.value;
}

enums.V2GridscreenRootIdScreenIdGetSortType
    v2GridscreenRootIdScreenIdGetSortTypeFromJson(
  Object? v2GridscreenRootIdScreenIdGetSortType, [
  enums.V2GridscreenRootIdScreenIdGetSortType? defaultValue,
]) {
  return enums.V2GridscreenRootIdScreenIdGetSortType.values.firstWhereOrNull(
          (e) => e.value == v2GridscreenRootIdScreenIdGetSortType) ??
      defaultValue ??
      enums.V2GridscreenRootIdScreenIdGetSortType.swaggerGeneratedUnknown;
}

List<String> v2GridscreenRootIdScreenIdGetSortTypeListToJson(
    List<enums.V2GridscreenRootIdScreenIdGetSortType>?
        v2GridscreenRootIdScreenIdGetSortType) {
  if (v2GridscreenRootIdScreenIdGetSortType == null) {
    return [];
  }

  return v2GridscreenRootIdScreenIdGetSortType.map((e) => e.value!).toList();
}

List<enums.V2GridscreenRootIdScreenIdGetSortType>
    v2GridscreenRootIdScreenIdGetSortTypeListFromJson(
  List? v2GridscreenRootIdScreenIdGetSortType, [
  List<enums.V2GridscreenRootIdScreenIdGetSortType>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetSortType == null) {
    return defaultValue ?? [];
  }

  return v2GridscreenRootIdScreenIdGetSortType
      .map((e) => v2GridscreenRootIdScreenIdGetSortTypeFromJson(e.toString()))
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetSortType>?
    v2GridscreenRootIdScreenIdGetSortTypeNullableListFromJson(
  List? v2GridscreenRootIdScreenIdGetSortType, [
  List<enums.V2GridscreenRootIdScreenIdGetSortType>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetSortType == null) {
    return defaultValue;
  }

  return v2GridscreenRootIdScreenIdGetSortType
      .map((e) => v2GridscreenRootIdScreenIdGetSortTypeFromJson(e.toString()))
      .toList();
}

String? v2GridscreenRootIdScreenIdGetSortDirectionToJson(
    enums.V2GridscreenRootIdScreenIdGetSortDirection?
        v2GridscreenRootIdScreenIdGetSortDirection) {
  return v2GridscreenRootIdScreenIdGetSortDirection?.value;
}

enums.V2GridscreenRootIdScreenIdGetSortDirection
    v2GridscreenRootIdScreenIdGetSortDirectionFromJson(
  Object? v2GridscreenRootIdScreenIdGetSortDirection, [
  enums.V2GridscreenRootIdScreenIdGetSortDirection? defaultValue,
]) {
  return enums.V2GridscreenRootIdScreenIdGetSortDirection.values
          .firstWhereOrNull(
              (e) => e.value == v2GridscreenRootIdScreenIdGetSortDirection) ??
      defaultValue ??
      enums.V2GridscreenRootIdScreenIdGetSortDirection.swaggerGeneratedUnknown;
}

List<String> v2GridscreenRootIdScreenIdGetSortDirectionListToJson(
    List<enums.V2GridscreenRootIdScreenIdGetSortDirection>?
        v2GridscreenRootIdScreenIdGetSortDirection) {
  if (v2GridscreenRootIdScreenIdGetSortDirection == null) {
    return [];
  }

  return v2GridscreenRootIdScreenIdGetSortDirection
      .map((e) => e.value!)
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetSortDirection>
    v2GridscreenRootIdScreenIdGetSortDirectionListFromJson(
  List? v2GridscreenRootIdScreenIdGetSortDirection, [
  List<enums.V2GridscreenRootIdScreenIdGetSortDirection>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetSortDirection == null) {
    return defaultValue ?? [];
  }

  return v2GridscreenRootIdScreenIdGetSortDirection
      .map((e) =>
          v2GridscreenRootIdScreenIdGetSortDirectionFromJson(e.toString()))
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetSortDirection>?
    v2GridscreenRootIdScreenIdGetSortDirectionNullableListFromJson(
  List? v2GridscreenRootIdScreenIdGetSortDirection, [
  List<enums.V2GridscreenRootIdScreenIdGetSortDirection>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetSortDirection == null) {
    return defaultValue;
  }

  return v2GridscreenRootIdScreenIdGetSortDirection
      .map((e) =>
          v2GridscreenRootIdScreenIdGetSortDirectionFromJson(e.toString()))
      .toList();
}

String? v2GridscreenRootIdScreenIdGetFilterTypeToJson(
    enums.V2GridscreenRootIdScreenIdGetFilterType?
        v2GridscreenRootIdScreenIdGetFilterType) {
  return v2GridscreenRootIdScreenIdGetFilterType?.value;
}

enums.V2GridscreenRootIdScreenIdGetFilterType
    v2GridscreenRootIdScreenIdGetFilterTypeFromJson(
  Object? v2GridscreenRootIdScreenIdGetFilterType, [
  enums.V2GridscreenRootIdScreenIdGetFilterType? defaultValue,
]) {
  return enums.V2GridscreenRootIdScreenIdGetFilterType.values.firstWhereOrNull(
          (e) => e.value == v2GridscreenRootIdScreenIdGetFilterType) ??
      defaultValue ??
      enums.V2GridscreenRootIdScreenIdGetFilterType.swaggerGeneratedUnknown;
}

List<String> v2GridscreenRootIdScreenIdGetFilterTypeListToJson(
    List<enums.V2GridscreenRootIdScreenIdGetFilterType>?
        v2GridscreenRootIdScreenIdGetFilterType) {
  if (v2GridscreenRootIdScreenIdGetFilterType == null) {
    return [];
  }

  return v2GridscreenRootIdScreenIdGetFilterType.map((e) => e.value!).toList();
}

List<enums.V2GridscreenRootIdScreenIdGetFilterType>
    v2GridscreenRootIdScreenIdGetFilterTypeListFromJson(
  List? v2GridscreenRootIdScreenIdGetFilterType, [
  List<enums.V2GridscreenRootIdScreenIdGetFilterType>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetFilterType == null) {
    return defaultValue ?? [];
  }

  return v2GridscreenRootIdScreenIdGetFilterType
      .map((e) => v2GridscreenRootIdScreenIdGetFilterTypeFromJson(e.toString()))
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetFilterType>?
    v2GridscreenRootIdScreenIdGetFilterTypeNullableListFromJson(
  List? v2GridscreenRootIdScreenIdGetFilterType, [
  List<enums.V2GridscreenRootIdScreenIdGetFilterType>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetFilterType == null) {
    return defaultValue;
  }

  return v2GridscreenRootIdScreenIdGetFilterType
      .map((e) => v2GridscreenRootIdScreenIdGetFilterTypeFromJson(e.toString()))
      .toList();
}

String? v2GridscreenRootIdScreenIdGetEncodingToJson(
    enums.V2GridscreenRootIdScreenIdGetEncoding?
        v2GridscreenRootIdScreenIdGetEncoding) {
  return v2GridscreenRootIdScreenIdGetEncoding?.value;
}

enums.V2GridscreenRootIdScreenIdGetEncoding
    v2GridscreenRootIdScreenIdGetEncodingFromJson(
  Object? v2GridscreenRootIdScreenIdGetEncoding, [
  enums.V2GridscreenRootIdScreenIdGetEncoding? defaultValue,
]) {
  return enums.V2GridscreenRootIdScreenIdGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2GridscreenRootIdScreenIdGetEncoding) ??
      defaultValue ??
      enums.V2GridscreenRootIdScreenIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2GridscreenRootIdScreenIdGetEncodingListToJson(
    List<enums.V2GridscreenRootIdScreenIdGetEncoding>?
        v2GridscreenRootIdScreenIdGetEncoding) {
  if (v2GridscreenRootIdScreenIdGetEncoding == null) {
    return [];
  }

  return v2GridscreenRootIdScreenIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2GridscreenRootIdScreenIdGetEncoding>
    v2GridscreenRootIdScreenIdGetEncodingListFromJson(
  List? v2GridscreenRootIdScreenIdGetEncoding, [
  List<enums.V2GridscreenRootIdScreenIdGetEncoding>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2GridscreenRootIdScreenIdGetEncoding
      .map((e) => v2GridscreenRootIdScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetEncoding>?
    v2GridscreenRootIdScreenIdGetEncodingNullableListFromJson(
  List? v2GridscreenRootIdScreenIdGetEncoding, [
  List<enums.V2GridscreenRootIdScreenIdGetEncoding>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetEncoding == null) {
    return defaultValue;
  }

  return v2GridscreenRootIdScreenIdGetEncoding
      .map((e) => v2GridscreenRootIdScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2GridscreenRootIdScreenIdGetMaxResToJson(
    enums.V2GridscreenRootIdScreenIdGetMaxRes?
        v2GridscreenRootIdScreenIdGetMaxRes) {
  return v2GridscreenRootIdScreenIdGetMaxRes?.value;
}

enums.V2GridscreenRootIdScreenIdGetMaxRes
    v2GridscreenRootIdScreenIdGetMaxResFromJson(
  Object? v2GridscreenRootIdScreenIdGetMaxRes, [
  enums.V2GridscreenRootIdScreenIdGetMaxRes? defaultValue,
]) {
  return enums.V2GridscreenRootIdScreenIdGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2GridscreenRootIdScreenIdGetMaxRes) ??
      defaultValue ??
      enums.V2GridscreenRootIdScreenIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2GridscreenRootIdScreenIdGetMaxResListToJson(
    List<enums.V2GridscreenRootIdScreenIdGetMaxRes>?
        v2GridscreenRootIdScreenIdGetMaxRes) {
  if (v2GridscreenRootIdScreenIdGetMaxRes == null) {
    return [];
  }

  return v2GridscreenRootIdScreenIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2GridscreenRootIdScreenIdGetMaxRes>
    v2GridscreenRootIdScreenIdGetMaxResListFromJson(
  List? v2GridscreenRootIdScreenIdGetMaxRes, [
  List<enums.V2GridscreenRootIdScreenIdGetMaxRes>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2GridscreenRootIdScreenIdGetMaxRes
      .map((e) => v2GridscreenRootIdScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetMaxRes>?
    v2GridscreenRootIdScreenIdGetMaxResNullableListFromJson(
  List? v2GridscreenRootIdScreenIdGetMaxRes, [
  List<enums.V2GridscreenRootIdScreenIdGetMaxRes>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetMaxRes == null) {
    return defaultValue;
  }

  return v2GridscreenRootIdScreenIdGetMaxRes
      .map((e) => v2GridscreenRootIdScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2GridscreenRootIdScreenIdGetFilterOnDemandToJson(
    enums.V2GridscreenRootIdScreenIdGetFilterOnDemand?
        v2GridscreenRootIdScreenIdGetFilterOnDemand) {
  return v2GridscreenRootIdScreenIdGetFilterOnDemand?.value;
}

enums.V2GridscreenRootIdScreenIdGetFilterOnDemand
    v2GridscreenRootIdScreenIdGetFilterOnDemandFromJson(
  Object? v2GridscreenRootIdScreenIdGetFilterOnDemand, [
  enums.V2GridscreenRootIdScreenIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V2GridscreenRootIdScreenIdGetFilterOnDemand.values
          .firstWhereOrNull(
              (e) => e.value == v2GridscreenRootIdScreenIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V2GridscreenRootIdScreenIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v2GridscreenRootIdScreenIdGetFilterOnDemandListToJson(
    List<enums.V2GridscreenRootIdScreenIdGetFilterOnDemand>?
        v2GridscreenRootIdScreenIdGetFilterOnDemand) {
  if (v2GridscreenRootIdScreenIdGetFilterOnDemand == null) {
    return [];
  }

  return v2GridscreenRootIdScreenIdGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetFilterOnDemand>
    v2GridscreenRootIdScreenIdGetFilterOnDemandListFromJson(
  List? v2GridscreenRootIdScreenIdGetFilterOnDemand, [
  List<enums.V2GridscreenRootIdScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v2GridscreenRootIdScreenIdGetFilterOnDemand
      .map((e) =>
          v2GridscreenRootIdScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V2GridscreenRootIdScreenIdGetFilterOnDemand>?
    v2GridscreenRootIdScreenIdGetFilterOnDemandNullableListFromJson(
  List? v2GridscreenRootIdScreenIdGetFilterOnDemand, [
  List<enums.V2GridscreenRootIdScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v2GridscreenRootIdScreenIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v2GridscreenRootIdScreenIdGetFilterOnDemand
      .map((e) =>
          v2GridscreenRootIdScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v2NextepisodeGetEncodingToJson(
    enums.V2NextepisodeGetEncoding? v2NextepisodeGetEncoding) {
  return v2NextepisodeGetEncoding?.value;
}

enums.V2NextepisodeGetEncoding v2NextepisodeGetEncodingFromJson(
  Object? v2NextepisodeGetEncoding, [
  enums.V2NextepisodeGetEncoding? defaultValue,
]) {
  return enums.V2NextepisodeGetEncoding.values
          .firstWhereOrNull((e) => e.value == v2NextepisodeGetEncoding) ??
      defaultValue ??
      enums.V2NextepisodeGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2NextepisodeGetEncodingListToJson(
    List<enums.V2NextepisodeGetEncoding>? v2NextepisodeGetEncoding) {
  if (v2NextepisodeGetEncoding == null) {
    return [];
  }

  return v2NextepisodeGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2NextepisodeGetEncoding> v2NextepisodeGetEncodingListFromJson(
  List? v2NextepisodeGetEncoding, [
  List<enums.V2NextepisodeGetEncoding>? defaultValue,
]) {
  if (v2NextepisodeGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2NextepisodeGetEncoding
      .map((e) => v2NextepisodeGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2NextepisodeGetEncoding>?
    v2NextepisodeGetEncodingNullableListFromJson(
  List? v2NextepisodeGetEncoding, [
  List<enums.V2NextepisodeGetEncoding>? defaultValue,
]) {
  if (v2NextepisodeGetEncoding == null) {
    return defaultValue;
  }

  return v2NextepisodeGetEncoding
      .map((e) => v2NextepisodeGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2NextepisodeGetMaxResToJson(
    enums.V2NextepisodeGetMaxRes? v2NextepisodeGetMaxRes) {
  return v2NextepisodeGetMaxRes?.value;
}

enums.V2NextepisodeGetMaxRes v2NextepisodeGetMaxResFromJson(
  Object? v2NextepisodeGetMaxRes, [
  enums.V2NextepisodeGetMaxRes? defaultValue,
]) {
  return enums.V2NextepisodeGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2NextepisodeGetMaxRes) ??
      defaultValue ??
      enums.V2NextepisodeGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2NextepisodeGetMaxResListToJson(
    List<enums.V2NextepisodeGetMaxRes>? v2NextepisodeGetMaxRes) {
  if (v2NextepisodeGetMaxRes == null) {
    return [];
  }

  return v2NextepisodeGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2NextepisodeGetMaxRes> v2NextepisodeGetMaxResListFromJson(
  List? v2NextepisodeGetMaxRes, [
  List<enums.V2NextepisodeGetMaxRes>? defaultValue,
]) {
  if (v2NextepisodeGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2NextepisodeGetMaxRes
      .map((e) => v2NextepisodeGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2NextepisodeGetMaxRes>? v2NextepisodeGetMaxResNullableListFromJson(
  List? v2NextepisodeGetMaxRes, [
  List<enums.V2NextepisodeGetMaxRes>? defaultValue,
]) {
  if (v2NextepisodeGetMaxRes == null) {
    return defaultValue;
  }

  return v2NextepisodeGetMaxRes
      .map((e) => v2NextepisodeGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2NextepisodeGetFilterOnDemandToJson(
    enums.V2NextepisodeGetFilterOnDemand? v2NextepisodeGetFilterOnDemand) {
  return v2NextepisodeGetFilterOnDemand?.value;
}

enums.V2NextepisodeGetFilterOnDemand v2NextepisodeGetFilterOnDemandFromJson(
  Object? v2NextepisodeGetFilterOnDemand, [
  enums.V2NextepisodeGetFilterOnDemand? defaultValue,
]) {
  return enums.V2NextepisodeGetFilterOnDemand.values
          .firstWhereOrNull((e) => e.value == v2NextepisodeGetFilterOnDemand) ??
      defaultValue ??
      enums.V2NextepisodeGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v2NextepisodeGetFilterOnDemandListToJson(
    List<enums.V2NextepisodeGetFilterOnDemand>?
        v2NextepisodeGetFilterOnDemand) {
  if (v2NextepisodeGetFilterOnDemand == null) {
    return [];
  }

  return v2NextepisodeGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V2NextepisodeGetFilterOnDemand>
    v2NextepisodeGetFilterOnDemandListFromJson(
  List? v2NextepisodeGetFilterOnDemand, [
  List<enums.V2NextepisodeGetFilterOnDemand>? defaultValue,
]) {
  if (v2NextepisodeGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v2NextepisodeGetFilterOnDemand
      .map((e) => v2NextepisodeGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V2NextepisodeGetFilterOnDemand>?
    v2NextepisodeGetFilterOnDemandNullableListFromJson(
  List? v2NextepisodeGetFilterOnDemand, [
  List<enums.V2NextepisodeGetFilterOnDemand>? defaultValue,
]) {
  if (v2NextepisodeGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v2NextepisodeGetFilterOnDemand
      .map((e) => v2NextepisodeGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v2TilescreenRootIdScreenIdGetEncodingToJson(
    enums.V2TilescreenRootIdScreenIdGetEncoding?
        v2TilescreenRootIdScreenIdGetEncoding) {
  return v2TilescreenRootIdScreenIdGetEncoding?.value;
}

enums.V2TilescreenRootIdScreenIdGetEncoding
    v2TilescreenRootIdScreenIdGetEncodingFromJson(
  Object? v2TilescreenRootIdScreenIdGetEncoding, [
  enums.V2TilescreenRootIdScreenIdGetEncoding? defaultValue,
]) {
  return enums.V2TilescreenRootIdScreenIdGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2TilescreenRootIdScreenIdGetEncoding) ??
      defaultValue ??
      enums.V2TilescreenRootIdScreenIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2TilescreenRootIdScreenIdGetEncodingListToJson(
    List<enums.V2TilescreenRootIdScreenIdGetEncoding>?
        v2TilescreenRootIdScreenIdGetEncoding) {
  if (v2TilescreenRootIdScreenIdGetEncoding == null) {
    return [];
  }

  return v2TilescreenRootIdScreenIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2TilescreenRootIdScreenIdGetEncoding>
    v2TilescreenRootIdScreenIdGetEncodingListFromJson(
  List? v2TilescreenRootIdScreenIdGetEncoding, [
  List<enums.V2TilescreenRootIdScreenIdGetEncoding>? defaultValue,
]) {
  if (v2TilescreenRootIdScreenIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2TilescreenRootIdScreenIdGetEncoding
      .map((e) => v2TilescreenRootIdScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2TilescreenRootIdScreenIdGetEncoding>?
    v2TilescreenRootIdScreenIdGetEncodingNullableListFromJson(
  List? v2TilescreenRootIdScreenIdGetEncoding, [
  List<enums.V2TilescreenRootIdScreenIdGetEncoding>? defaultValue,
]) {
  if (v2TilescreenRootIdScreenIdGetEncoding == null) {
    return defaultValue;
  }

  return v2TilescreenRootIdScreenIdGetEncoding
      .map((e) => v2TilescreenRootIdScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2TilescreenRootIdScreenIdGetMaxResToJson(
    enums.V2TilescreenRootIdScreenIdGetMaxRes?
        v2TilescreenRootIdScreenIdGetMaxRes) {
  return v2TilescreenRootIdScreenIdGetMaxRes?.value;
}

enums.V2TilescreenRootIdScreenIdGetMaxRes
    v2TilescreenRootIdScreenIdGetMaxResFromJson(
  Object? v2TilescreenRootIdScreenIdGetMaxRes, [
  enums.V2TilescreenRootIdScreenIdGetMaxRes? defaultValue,
]) {
  return enums.V2TilescreenRootIdScreenIdGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2TilescreenRootIdScreenIdGetMaxRes) ??
      defaultValue ??
      enums.V2TilescreenRootIdScreenIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2TilescreenRootIdScreenIdGetMaxResListToJson(
    List<enums.V2TilescreenRootIdScreenIdGetMaxRes>?
        v2TilescreenRootIdScreenIdGetMaxRes) {
  if (v2TilescreenRootIdScreenIdGetMaxRes == null) {
    return [];
  }

  return v2TilescreenRootIdScreenIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2TilescreenRootIdScreenIdGetMaxRes>
    v2TilescreenRootIdScreenIdGetMaxResListFromJson(
  List? v2TilescreenRootIdScreenIdGetMaxRes, [
  List<enums.V2TilescreenRootIdScreenIdGetMaxRes>? defaultValue,
]) {
  if (v2TilescreenRootIdScreenIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2TilescreenRootIdScreenIdGetMaxRes
      .map((e) => v2TilescreenRootIdScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2TilescreenRootIdScreenIdGetMaxRes>?
    v2TilescreenRootIdScreenIdGetMaxResNullableListFromJson(
  List? v2TilescreenRootIdScreenIdGetMaxRes, [
  List<enums.V2TilescreenRootIdScreenIdGetMaxRes>? defaultValue,
]) {
  if (v2TilescreenRootIdScreenIdGetMaxRes == null) {
    return defaultValue;
  }

  return v2TilescreenRootIdScreenIdGetMaxRes
      .map((e) => v2TilescreenRootIdScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2VodscreenRootIdCridGetEncodingToJson(
    enums.V2VodscreenRootIdCridGetEncoding? v2VodscreenRootIdCridGetEncoding) {
  return v2VodscreenRootIdCridGetEncoding?.value;
}

enums.V2VodscreenRootIdCridGetEncoding v2VodscreenRootIdCridGetEncodingFromJson(
  Object? v2VodscreenRootIdCridGetEncoding, [
  enums.V2VodscreenRootIdCridGetEncoding? defaultValue,
]) {
  return enums.V2VodscreenRootIdCridGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2VodscreenRootIdCridGetEncoding) ??
      defaultValue ??
      enums.V2VodscreenRootIdCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2VodscreenRootIdCridGetEncodingListToJson(
    List<enums.V2VodscreenRootIdCridGetEncoding>?
        v2VodscreenRootIdCridGetEncoding) {
  if (v2VodscreenRootIdCridGetEncoding == null) {
    return [];
  }

  return v2VodscreenRootIdCridGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2VodscreenRootIdCridGetEncoding>
    v2VodscreenRootIdCridGetEncodingListFromJson(
  List? v2VodscreenRootIdCridGetEncoding, [
  List<enums.V2VodscreenRootIdCridGetEncoding>? defaultValue,
]) {
  if (v2VodscreenRootIdCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2VodscreenRootIdCridGetEncoding
      .map((e) => v2VodscreenRootIdCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2VodscreenRootIdCridGetEncoding>?
    v2VodscreenRootIdCridGetEncodingNullableListFromJson(
  List? v2VodscreenRootIdCridGetEncoding, [
  List<enums.V2VodscreenRootIdCridGetEncoding>? defaultValue,
]) {
  if (v2VodscreenRootIdCridGetEncoding == null) {
    return defaultValue;
  }

  return v2VodscreenRootIdCridGetEncoding
      .map((e) => v2VodscreenRootIdCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2VodscreenRootIdCridGetMaxResToJson(
    enums.V2VodscreenRootIdCridGetMaxRes? v2VodscreenRootIdCridGetMaxRes) {
  return v2VodscreenRootIdCridGetMaxRes?.value;
}

enums.V2VodscreenRootIdCridGetMaxRes v2VodscreenRootIdCridGetMaxResFromJson(
  Object? v2VodscreenRootIdCridGetMaxRes, [
  enums.V2VodscreenRootIdCridGetMaxRes? defaultValue,
]) {
  return enums.V2VodscreenRootIdCridGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v2VodscreenRootIdCridGetMaxRes) ??
      defaultValue ??
      enums.V2VodscreenRootIdCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2VodscreenRootIdCridGetMaxResListToJson(
    List<enums.V2VodscreenRootIdCridGetMaxRes>?
        v2VodscreenRootIdCridGetMaxRes) {
  if (v2VodscreenRootIdCridGetMaxRes == null) {
    return [];
  }

  return v2VodscreenRootIdCridGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2VodscreenRootIdCridGetMaxRes>
    v2VodscreenRootIdCridGetMaxResListFromJson(
  List? v2VodscreenRootIdCridGetMaxRes, [
  List<enums.V2VodscreenRootIdCridGetMaxRes>? defaultValue,
]) {
  if (v2VodscreenRootIdCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2VodscreenRootIdCridGetMaxRes
      .map((e) => v2VodscreenRootIdCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2VodscreenRootIdCridGetMaxRes>?
    v2VodscreenRootIdCridGetMaxResNullableListFromJson(
  List? v2VodscreenRootIdCridGetMaxRes, [
  List<enums.V2VodscreenRootIdCridGetMaxRes>? defaultValue,
]) {
  if (v2VodscreenRootIdCridGetMaxRes == null) {
    return defaultValue;
  }

  return v2VodscreenRootIdCridGetMaxRes
      .map((e) => v2VodscreenRootIdCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2VodscreenRootIdCridGetFilterOnDemandToJson(
    enums.V2VodscreenRootIdCridGetFilterOnDemand?
        v2VodscreenRootIdCridGetFilterOnDemand) {
  return v2VodscreenRootIdCridGetFilterOnDemand?.value;
}

enums.V2VodscreenRootIdCridGetFilterOnDemand
    v2VodscreenRootIdCridGetFilterOnDemandFromJson(
  Object? v2VodscreenRootIdCridGetFilterOnDemand, [
  enums.V2VodscreenRootIdCridGetFilterOnDemand? defaultValue,
]) {
  return enums.V2VodscreenRootIdCridGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v2VodscreenRootIdCridGetFilterOnDemand) ??
      defaultValue ??
      enums.V2VodscreenRootIdCridGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v2VodscreenRootIdCridGetFilterOnDemandListToJson(
    List<enums.V2VodscreenRootIdCridGetFilterOnDemand>?
        v2VodscreenRootIdCridGetFilterOnDemand) {
  if (v2VodscreenRootIdCridGetFilterOnDemand == null) {
    return [];
  }

  return v2VodscreenRootIdCridGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V2VodscreenRootIdCridGetFilterOnDemand>
    v2VodscreenRootIdCridGetFilterOnDemandListFromJson(
  List? v2VodscreenRootIdCridGetFilterOnDemand, [
  List<enums.V2VodscreenRootIdCridGetFilterOnDemand>? defaultValue,
]) {
  if (v2VodscreenRootIdCridGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v2VodscreenRootIdCridGetFilterOnDemand
      .map((e) => v2VodscreenRootIdCridGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V2VodscreenRootIdCridGetFilterOnDemand>?
    v2VodscreenRootIdCridGetFilterOnDemandNullableListFromJson(
  List? v2VodscreenRootIdCridGetFilterOnDemand, [
  List<enums.V2VodscreenRootIdCridGetFilterOnDemand>? defaultValue,
]) {
  if (v2VodscreenRootIdCridGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v2VodscreenRootIdCridGetFilterOnDemand
      .map((e) => v2VodscreenRootIdCridGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v2VodstructureRootIdCridGetEncodingToJson(
    enums.V2VodstructureRootIdCridGetEncoding?
        v2VodstructureRootIdCridGetEncoding) {
  return v2VodstructureRootIdCridGetEncoding?.value;
}

enums.V2VodstructureRootIdCridGetEncoding
    v2VodstructureRootIdCridGetEncodingFromJson(
  Object? v2VodstructureRootIdCridGetEncoding, [
  enums.V2VodstructureRootIdCridGetEncoding? defaultValue,
]) {
  return enums.V2VodstructureRootIdCridGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v2VodstructureRootIdCridGetEncoding) ??
      defaultValue ??
      enums.V2VodstructureRootIdCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> v2VodstructureRootIdCridGetEncodingListToJson(
    List<enums.V2VodstructureRootIdCridGetEncoding>?
        v2VodstructureRootIdCridGetEncoding) {
  if (v2VodstructureRootIdCridGetEncoding == null) {
    return [];
  }

  return v2VodstructureRootIdCridGetEncoding.map((e) => e.value!).toList();
}

List<enums.V2VodstructureRootIdCridGetEncoding>
    v2VodstructureRootIdCridGetEncodingListFromJson(
  List? v2VodstructureRootIdCridGetEncoding, [
  List<enums.V2VodstructureRootIdCridGetEncoding>? defaultValue,
]) {
  if (v2VodstructureRootIdCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v2VodstructureRootIdCridGetEncoding
      .map((e) => v2VodstructureRootIdCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V2VodstructureRootIdCridGetEncoding>?
    v2VodstructureRootIdCridGetEncodingNullableListFromJson(
  List? v2VodstructureRootIdCridGetEncoding, [
  List<enums.V2VodstructureRootIdCridGetEncoding>? defaultValue,
]) {
  if (v2VodstructureRootIdCridGetEncoding == null) {
    return defaultValue;
  }

  return v2VodstructureRootIdCridGetEncoding
      .map((e) => v2VodstructureRootIdCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? v2VodstructureRootIdCridGetMaxResToJson(
    enums.V2VodstructureRootIdCridGetMaxRes?
        v2VodstructureRootIdCridGetMaxRes) {
  return v2VodstructureRootIdCridGetMaxRes?.value;
}

enums.V2VodstructureRootIdCridGetMaxRes
    v2VodstructureRootIdCridGetMaxResFromJson(
  Object? v2VodstructureRootIdCridGetMaxRes, [
  enums.V2VodstructureRootIdCridGetMaxRes? defaultValue,
]) {
  return enums.V2VodstructureRootIdCridGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v2VodstructureRootIdCridGetMaxRes) ??
      defaultValue ??
      enums.V2VodstructureRootIdCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2VodstructureRootIdCridGetMaxResListToJson(
    List<enums.V2VodstructureRootIdCridGetMaxRes>?
        v2VodstructureRootIdCridGetMaxRes) {
  if (v2VodstructureRootIdCridGetMaxRes == null) {
    return [];
  }

  return v2VodstructureRootIdCridGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V2VodstructureRootIdCridGetMaxRes>
    v2VodstructureRootIdCridGetMaxResListFromJson(
  List? v2VodstructureRootIdCridGetMaxRes, [
  List<enums.V2VodstructureRootIdCridGetMaxRes>? defaultValue,
]) {
  if (v2VodstructureRootIdCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2VodstructureRootIdCridGetMaxRes
      .map((e) => v2VodstructureRootIdCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2VodstructureRootIdCridGetMaxRes>?
    v2VodstructureRootIdCridGetMaxResNullableListFromJson(
  List? v2VodstructureRootIdCridGetMaxRes, [
  List<enums.V2VodstructureRootIdCridGetMaxRes>? defaultValue,
]) {
  if (v2VodstructureRootIdCridGetMaxRes == null) {
    return defaultValue;
  }

  return v2VodstructureRootIdCridGetMaxRes
      .map((e) => v2VodstructureRootIdCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3CollectionsScreenIdGetEncodingToJson(
    enums.V3CollectionsScreenIdGetEncoding? v3CollectionsScreenIdGetEncoding) {
  return v3CollectionsScreenIdGetEncoding?.value;
}

enums.V3CollectionsScreenIdGetEncoding v3CollectionsScreenIdGetEncodingFromJson(
  Object? v3CollectionsScreenIdGetEncoding, [
  enums.V3CollectionsScreenIdGetEncoding? defaultValue,
]) {
  return enums.V3CollectionsScreenIdGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v3CollectionsScreenIdGetEncoding) ??
      defaultValue ??
      enums.V3CollectionsScreenIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3CollectionsScreenIdGetEncodingListToJson(
    List<enums.V3CollectionsScreenIdGetEncoding>?
        v3CollectionsScreenIdGetEncoding) {
  if (v3CollectionsScreenIdGetEncoding == null) {
    return [];
  }

  return v3CollectionsScreenIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3CollectionsScreenIdGetEncoding>
    v3CollectionsScreenIdGetEncodingListFromJson(
  List? v3CollectionsScreenIdGetEncoding, [
  List<enums.V3CollectionsScreenIdGetEncoding>? defaultValue,
]) {
  if (v3CollectionsScreenIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3CollectionsScreenIdGetEncoding
      .map((e) => v3CollectionsScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3CollectionsScreenIdGetEncoding>?
    v3CollectionsScreenIdGetEncodingNullableListFromJson(
  List? v3CollectionsScreenIdGetEncoding, [
  List<enums.V3CollectionsScreenIdGetEncoding>? defaultValue,
]) {
  if (v3CollectionsScreenIdGetEncoding == null) {
    return defaultValue;
  }

  return v3CollectionsScreenIdGetEncoding
      .map((e) => v3CollectionsScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3CollectionsScreenIdGetMaxResToJson(
    enums.V3CollectionsScreenIdGetMaxRes? v3CollectionsScreenIdGetMaxRes) {
  return v3CollectionsScreenIdGetMaxRes?.value;
}

enums.V3CollectionsScreenIdGetMaxRes v3CollectionsScreenIdGetMaxResFromJson(
  Object? v3CollectionsScreenIdGetMaxRes, [
  enums.V3CollectionsScreenIdGetMaxRes? defaultValue,
]) {
  return enums.V3CollectionsScreenIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3CollectionsScreenIdGetMaxRes) ??
      defaultValue ??
      enums.V3CollectionsScreenIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3CollectionsScreenIdGetMaxResListToJson(
    List<enums.V3CollectionsScreenIdGetMaxRes>?
        v3CollectionsScreenIdGetMaxRes) {
  if (v3CollectionsScreenIdGetMaxRes == null) {
    return [];
  }

  return v3CollectionsScreenIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3CollectionsScreenIdGetMaxRes>
    v3CollectionsScreenIdGetMaxResListFromJson(
  List? v3CollectionsScreenIdGetMaxRes, [
  List<enums.V3CollectionsScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3CollectionsScreenIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3CollectionsScreenIdGetMaxRes
      .map((e) => v3CollectionsScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3CollectionsScreenIdGetMaxRes>?
    v3CollectionsScreenIdGetMaxResNullableListFromJson(
  List? v3CollectionsScreenIdGetMaxRes, [
  List<enums.V3CollectionsScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3CollectionsScreenIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3CollectionsScreenIdGetMaxRes
      .map((e) => v3CollectionsScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3CollectionsScreenIdGetFilterOnDemandToJson(
    enums.V3CollectionsScreenIdGetFilterOnDemand?
        v3CollectionsScreenIdGetFilterOnDemand) {
  return v3CollectionsScreenIdGetFilterOnDemand?.value;
}

enums.V3CollectionsScreenIdGetFilterOnDemand
    v3CollectionsScreenIdGetFilterOnDemandFromJson(
  Object? v3CollectionsScreenIdGetFilterOnDemand, [
  enums.V3CollectionsScreenIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V3CollectionsScreenIdGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3CollectionsScreenIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V3CollectionsScreenIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3CollectionsScreenIdGetFilterOnDemandListToJson(
    List<enums.V3CollectionsScreenIdGetFilterOnDemand>?
        v3CollectionsScreenIdGetFilterOnDemand) {
  if (v3CollectionsScreenIdGetFilterOnDemand == null) {
    return [];
  }

  return v3CollectionsScreenIdGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3CollectionsScreenIdGetFilterOnDemand>
    v3CollectionsScreenIdGetFilterOnDemandListFromJson(
  List? v3CollectionsScreenIdGetFilterOnDemand, [
  List<enums.V3CollectionsScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3CollectionsScreenIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3CollectionsScreenIdGetFilterOnDemand
      .map((e) => v3CollectionsScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3CollectionsScreenIdGetFilterOnDemand>?
    v3CollectionsScreenIdGetFilterOnDemandNullableListFromJson(
  List? v3CollectionsScreenIdGetFilterOnDemand, [
  List<enums.V3CollectionsScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3CollectionsScreenIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3CollectionsScreenIdGetFilterOnDemand
      .map((e) => v3CollectionsScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3ContextualvodRootIdGetEncodingToJson(
    enums.V3ContextualvodRootIdGetEncoding? v3ContextualvodRootIdGetEncoding) {
  return v3ContextualvodRootIdGetEncoding?.value;
}

enums.V3ContextualvodRootIdGetEncoding v3ContextualvodRootIdGetEncodingFromJson(
  Object? v3ContextualvodRootIdGetEncoding, [
  enums.V3ContextualvodRootIdGetEncoding? defaultValue,
]) {
  return enums.V3ContextualvodRootIdGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v3ContextualvodRootIdGetEncoding) ??
      defaultValue ??
      enums.V3ContextualvodRootIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3ContextualvodRootIdGetEncodingListToJson(
    List<enums.V3ContextualvodRootIdGetEncoding>?
        v3ContextualvodRootIdGetEncoding) {
  if (v3ContextualvodRootIdGetEncoding == null) {
    return [];
  }

  return v3ContextualvodRootIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3ContextualvodRootIdGetEncoding>
    v3ContextualvodRootIdGetEncodingListFromJson(
  List? v3ContextualvodRootIdGetEncoding, [
  List<enums.V3ContextualvodRootIdGetEncoding>? defaultValue,
]) {
  if (v3ContextualvodRootIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3ContextualvodRootIdGetEncoding
      .map((e) => v3ContextualvodRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3ContextualvodRootIdGetEncoding>?
    v3ContextualvodRootIdGetEncodingNullableListFromJson(
  List? v3ContextualvodRootIdGetEncoding, [
  List<enums.V3ContextualvodRootIdGetEncoding>? defaultValue,
]) {
  if (v3ContextualvodRootIdGetEncoding == null) {
    return defaultValue;
  }

  return v3ContextualvodRootIdGetEncoding
      .map((e) => v3ContextualvodRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3ContextualvodRootIdGetMaxResToJson(
    enums.V3ContextualvodRootIdGetMaxRes? v3ContextualvodRootIdGetMaxRes) {
  return v3ContextualvodRootIdGetMaxRes?.value;
}

enums.V3ContextualvodRootIdGetMaxRes v3ContextualvodRootIdGetMaxResFromJson(
  Object? v3ContextualvodRootIdGetMaxRes, [
  enums.V3ContextualvodRootIdGetMaxRes? defaultValue,
]) {
  return enums.V3ContextualvodRootIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3ContextualvodRootIdGetMaxRes) ??
      defaultValue ??
      enums.V3ContextualvodRootIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3ContextualvodRootIdGetMaxResListToJson(
    List<enums.V3ContextualvodRootIdGetMaxRes>?
        v3ContextualvodRootIdGetMaxRes) {
  if (v3ContextualvodRootIdGetMaxRes == null) {
    return [];
  }

  return v3ContextualvodRootIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3ContextualvodRootIdGetMaxRes>
    v3ContextualvodRootIdGetMaxResListFromJson(
  List? v3ContextualvodRootIdGetMaxRes, [
  List<enums.V3ContextualvodRootIdGetMaxRes>? defaultValue,
]) {
  if (v3ContextualvodRootIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3ContextualvodRootIdGetMaxRes
      .map((e) => v3ContextualvodRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3ContextualvodRootIdGetMaxRes>?
    v3ContextualvodRootIdGetMaxResNullableListFromJson(
  List? v3ContextualvodRootIdGetMaxRes, [
  List<enums.V3ContextualvodRootIdGetMaxRes>? defaultValue,
]) {
  if (v3ContextualvodRootIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3ContextualvodRootIdGetMaxRes
      .map((e) => v3ContextualvodRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3DetailsScreenIdGetEncodingToJson(
    enums.V3DetailsScreenIdGetEncoding? v3DetailsScreenIdGetEncoding) {
  return v3DetailsScreenIdGetEncoding?.value;
}

enums.V3DetailsScreenIdGetEncoding v3DetailsScreenIdGetEncodingFromJson(
  Object? v3DetailsScreenIdGetEncoding, [
  enums.V3DetailsScreenIdGetEncoding? defaultValue,
]) {
  return enums.V3DetailsScreenIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3DetailsScreenIdGetEncoding) ??
      defaultValue ??
      enums.V3DetailsScreenIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3DetailsScreenIdGetEncodingListToJson(
    List<enums.V3DetailsScreenIdGetEncoding>? v3DetailsScreenIdGetEncoding) {
  if (v3DetailsScreenIdGetEncoding == null) {
    return [];
  }

  return v3DetailsScreenIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3DetailsScreenIdGetEncoding>
    v3DetailsScreenIdGetEncodingListFromJson(
  List? v3DetailsScreenIdGetEncoding, [
  List<enums.V3DetailsScreenIdGetEncoding>? defaultValue,
]) {
  if (v3DetailsScreenIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3DetailsScreenIdGetEncoding
      .map((e) => v3DetailsScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3DetailsScreenIdGetEncoding>?
    v3DetailsScreenIdGetEncodingNullableListFromJson(
  List? v3DetailsScreenIdGetEncoding, [
  List<enums.V3DetailsScreenIdGetEncoding>? defaultValue,
]) {
  if (v3DetailsScreenIdGetEncoding == null) {
    return defaultValue;
  }

  return v3DetailsScreenIdGetEncoding
      .map((e) => v3DetailsScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3DetailsScreenIdGetMaxResToJson(
    enums.V3DetailsScreenIdGetMaxRes? v3DetailsScreenIdGetMaxRes) {
  return v3DetailsScreenIdGetMaxRes?.value;
}

enums.V3DetailsScreenIdGetMaxRes v3DetailsScreenIdGetMaxResFromJson(
  Object? v3DetailsScreenIdGetMaxRes, [
  enums.V3DetailsScreenIdGetMaxRes? defaultValue,
]) {
  return enums.V3DetailsScreenIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3DetailsScreenIdGetMaxRes) ??
      defaultValue ??
      enums.V3DetailsScreenIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3DetailsScreenIdGetMaxResListToJson(
    List<enums.V3DetailsScreenIdGetMaxRes>? v3DetailsScreenIdGetMaxRes) {
  if (v3DetailsScreenIdGetMaxRes == null) {
    return [];
  }

  return v3DetailsScreenIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3DetailsScreenIdGetMaxRes> v3DetailsScreenIdGetMaxResListFromJson(
  List? v3DetailsScreenIdGetMaxRes, [
  List<enums.V3DetailsScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3DetailsScreenIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3DetailsScreenIdGetMaxRes
      .map((e) => v3DetailsScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3DetailsScreenIdGetMaxRes>?
    v3DetailsScreenIdGetMaxResNullableListFromJson(
  List? v3DetailsScreenIdGetMaxRes, [
  List<enums.V3DetailsScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3DetailsScreenIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3DetailsScreenIdGetMaxRes
      .map((e) => v3DetailsScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3DetailsScreenIdGetFilterOnDemandToJson(
    enums.V3DetailsScreenIdGetFilterOnDemand?
        v3DetailsScreenIdGetFilterOnDemand) {
  return v3DetailsScreenIdGetFilterOnDemand?.value;
}

enums.V3DetailsScreenIdGetFilterOnDemand
    v3DetailsScreenIdGetFilterOnDemandFromJson(
  Object? v3DetailsScreenIdGetFilterOnDemand, [
  enums.V3DetailsScreenIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V3DetailsScreenIdGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3DetailsScreenIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V3DetailsScreenIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3DetailsScreenIdGetFilterOnDemandListToJson(
    List<enums.V3DetailsScreenIdGetFilterOnDemand>?
        v3DetailsScreenIdGetFilterOnDemand) {
  if (v3DetailsScreenIdGetFilterOnDemand == null) {
    return [];
  }

  return v3DetailsScreenIdGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3DetailsScreenIdGetFilterOnDemand>
    v3DetailsScreenIdGetFilterOnDemandListFromJson(
  List? v3DetailsScreenIdGetFilterOnDemand, [
  List<enums.V3DetailsScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3DetailsScreenIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3DetailsScreenIdGetFilterOnDemand
      .map((e) => v3DetailsScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3DetailsScreenIdGetFilterOnDemand>?
    v3DetailsScreenIdGetFilterOnDemandNullableListFromJson(
  List? v3DetailsScreenIdGetFilterOnDemand, [
  List<enums.V3DetailsScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3DetailsScreenIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3DetailsScreenIdGetFilterOnDemand
      .map((e) => v3DetailsScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3GridOptionsIdGetTypeToJson(
    enums.V3GridOptionsIdGetType? v3GridOptionsIdGetType) {
  return v3GridOptionsIdGetType?.value;
}

enums.V3GridOptionsIdGetType v3GridOptionsIdGetTypeFromJson(
  Object? v3GridOptionsIdGetType, [
  enums.V3GridOptionsIdGetType? defaultValue,
]) {
  return enums.V3GridOptionsIdGetType.values
          .firstWhereOrNull((e) => e.value == v3GridOptionsIdGetType) ??
      defaultValue ??
      enums.V3GridOptionsIdGetType.swaggerGeneratedUnknown;
}

List<String> v3GridOptionsIdGetTypeListToJson(
    List<enums.V3GridOptionsIdGetType>? v3GridOptionsIdGetType) {
  if (v3GridOptionsIdGetType == null) {
    return [];
  }

  return v3GridOptionsIdGetType.map((e) => e.value!).toList();
}

List<enums.V3GridOptionsIdGetType> v3GridOptionsIdGetTypeListFromJson(
  List? v3GridOptionsIdGetType, [
  List<enums.V3GridOptionsIdGetType>? defaultValue,
]) {
  if (v3GridOptionsIdGetType == null) {
    return defaultValue ?? [];
  }

  return v3GridOptionsIdGetType
      .map((e) => v3GridOptionsIdGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.V3GridOptionsIdGetType>? v3GridOptionsIdGetTypeNullableListFromJson(
  List? v3GridOptionsIdGetType, [
  List<enums.V3GridOptionsIdGetType>? defaultValue,
]) {
  if (v3GridOptionsIdGetType == null) {
    return defaultValue;
  }

  return v3GridOptionsIdGetType
      .map((e) => v3GridOptionsIdGetTypeFromJson(e.toString()))
      .toList();
}

String? v3GridOptionsIdGetEncodingToJson(
    enums.V3GridOptionsIdGetEncoding? v3GridOptionsIdGetEncoding) {
  return v3GridOptionsIdGetEncoding?.value;
}

enums.V3GridOptionsIdGetEncoding v3GridOptionsIdGetEncodingFromJson(
  Object? v3GridOptionsIdGetEncoding, [
  enums.V3GridOptionsIdGetEncoding? defaultValue,
]) {
  return enums.V3GridOptionsIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3GridOptionsIdGetEncoding) ??
      defaultValue ??
      enums.V3GridOptionsIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3GridOptionsIdGetEncodingListToJson(
    List<enums.V3GridOptionsIdGetEncoding>? v3GridOptionsIdGetEncoding) {
  if (v3GridOptionsIdGetEncoding == null) {
    return [];
  }

  return v3GridOptionsIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3GridOptionsIdGetEncoding> v3GridOptionsIdGetEncodingListFromJson(
  List? v3GridOptionsIdGetEncoding, [
  List<enums.V3GridOptionsIdGetEncoding>? defaultValue,
]) {
  if (v3GridOptionsIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3GridOptionsIdGetEncoding
      .map((e) => v3GridOptionsIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3GridOptionsIdGetEncoding>?
    v3GridOptionsIdGetEncodingNullableListFromJson(
  List? v3GridOptionsIdGetEncoding, [
  List<enums.V3GridOptionsIdGetEncoding>? defaultValue,
]) {
  if (v3GridOptionsIdGetEncoding == null) {
    return defaultValue;
  }

  return v3GridOptionsIdGetEncoding
      .map((e) => v3GridOptionsIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3GridOptionsIdGetMaxResToJson(
    enums.V3GridOptionsIdGetMaxRes? v3GridOptionsIdGetMaxRes) {
  return v3GridOptionsIdGetMaxRes?.value;
}

enums.V3GridOptionsIdGetMaxRes v3GridOptionsIdGetMaxResFromJson(
  Object? v3GridOptionsIdGetMaxRes, [
  enums.V3GridOptionsIdGetMaxRes? defaultValue,
]) {
  return enums.V3GridOptionsIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3GridOptionsIdGetMaxRes) ??
      defaultValue ??
      enums.V3GridOptionsIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3GridOptionsIdGetMaxResListToJson(
    List<enums.V3GridOptionsIdGetMaxRes>? v3GridOptionsIdGetMaxRes) {
  if (v3GridOptionsIdGetMaxRes == null) {
    return [];
  }

  return v3GridOptionsIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3GridOptionsIdGetMaxRes> v3GridOptionsIdGetMaxResListFromJson(
  List? v3GridOptionsIdGetMaxRes, [
  List<enums.V3GridOptionsIdGetMaxRes>? defaultValue,
]) {
  if (v3GridOptionsIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3GridOptionsIdGetMaxRes
      .map((e) => v3GridOptionsIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3GridOptionsIdGetMaxRes>?
    v3GridOptionsIdGetMaxResNullableListFromJson(
  List? v3GridOptionsIdGetMaxRes, [
  List<enums.V3GridOptionsIdGetMaxRes>? defaultValue,
]) {
  if (v3GridOptionsIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3GridOptionsIdGetMaxRes
      .map((e) => v3GridOptionsIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3GridOptionsIdGetFilterOnDemandToJson(
    enums.V3GridOptionsIdGetFilterOnDemand? v3GridOptionsIdGetFilterOnDemand) {
  return v3GridOptionsIdGetFilterOnDemand?.value;
}

enums.V3GridOptionsIdGetFilterOnDemand v3GridOptionsIdGetFilterOnDemandFromJson(
  Object? v3GridOptionsIdGetFilterOnDemand, [
  enums.V3GridOptionsIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V3GridOptionsIdGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3GridOptionsIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V3GridOptionsIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3GridOptionsIdGetFilterOnDemandListToJson(
    List<enums.V3GridOptionsIdGetFilterOnDemand>?
        v3GridOptionsIdGetFilterOnDemand) {
  if (v3GridOptionsIdGetFilterOnDemand == null) {
    return [];
  }

  return v3GridOptionsIdGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3GridOptionsIdGetFilterOnDemand>
    v3GridOptionsIdGetFilterOnDemandListFromJson(
  List? v3GridOptionsIdGetFilterOnDemand, [
  List<enums.V3GridOptionsIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3GridOptionsIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3GridOptionsIdGetFilterOnDemand
      .map((e) => v3GridOptionsIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3GridOptionsIdGetFilterOnDemand>?
    v3GridOptionsIdGetFilterOnDemandNullableListFromJson(
  List? v3GridOptionsIdGetFilterOnDemand, [
  List<enums.V3GridOptionsIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3GridOptionsIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3GridOptionsIdGetFilterOnDemand
      .map((e) => v3GridOptionsIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetTypeToJson(
    enums.V3GridScreenIdGetType? v3GridScreenIdGetType) {
  return v3GridScreenIdGetType?.value;
}

enums.V3GridScreenIdGetType v3GridScreenIdGetTypeFromJson(
  Object? v3GridScreenIdGetType, [
  enums.V3GridScreenIdGetType? defaultValue,
]) {
  return enums.V3GridScreenIdGetType.values
          .firstWhereOrNull((e) => e.value == v3GridScreenIdGetType) ??
      defaultValue ??
      enums.V3GridScreenIdGetType.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetTypeListToJson(
    List<enums.V3GridScreenIdGetType>? v3GridScreenIdGetType) {
  if (v3GridScreenIdGetType == null) {
    return [];
  }

  return v3GridScreenIdGetType.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetType> v3GridScreenIdGetTypeListFromJson(
  List? v3GridScreenIdGetType, [
  List<enums.V3GridScreenIdGetType>? defaultValue,
]) {
  if (v3GridScreenIdGetType == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetType
      .map((e) => v3GridScreenIdGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetType>? v3GridScreenIdGetTypeNullableListFromJson(
  List? v3GridScreenIdGetType, [
  List<enums.V3GridScreenIdGetType>? defaultValue,
]) {
  if (v3GridScreenIdGetType == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetType
      .map((e) => v3GridScreenIdGetTypeFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetSortTypeToJson(
    enums.V3GridScreenIdGetSortType? v3GridScreenIdGetSortType) {
  return v3GridScreenIdGetSortType?.value;
}

enums.V3GridScreenIdGetSortType v3GridScreenIdGetSortTypeFromJson(
  Object? v3GridScreenIdGetSortType, [
  enums.V3GridScreenIdGetSortType? defaultValue,
]) {
  return enums.V3GridScreenIdGetSortType.values
          .firstWhereOrNull((e) => e.value == v3GridScreenIdGetSortType) ??
      defaultValue ??
      enums.V3GridScreenIdGetSortType.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetSortTypeListToJson(
    List<enums.V3GridScreenIdGetSortType>? v3GridScreenIdGetSortType) {
  if (v3GridScreenIdGetSortType == null) {
    return [];
  }

  return v3GridScreenIdGetSortType.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetSortType> v3GridScreenIdGetSortTypeListFromJson(
  List? v3GridScreenIdGetSortType, [
  List<enums.V3GridScreenIdGetSortType>? defaultValue,
]) {
  if (v3GridScreenIdGetSortType == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetSortType
      .map((e) => v3GridScreenIdGetSortTypeFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetSortType>?
    v3GridScreenIdGetSortTypeNullableListFromJson(
  List? v3GridScreenIdGetSortType, [
  List<enums.V3GridScreenIdGetSortType>? defaultValue,
]) {
  if (v3GridScreenIdGetSortType == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetSortType
      .map((e) => v3GridScreenIdGetSortTypeFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetSortDirectionToJson(
    enums.V3GridScreenIdGetSortDirection? v3GridScreenIdGetSortDirection) {
  return v3GridScreenIdGetSortDirection?.value;
}

enums.V3GridScreenIdGetSortDirection v3GridScreenIdGetSortDirectionFromJson(
  Object? v3GridScreenIdGetSortDirection, [
  enums.V3GridScreenIdGetSortDirection? defaultValue,
]) {
  return enums.V3GridScreenIdGetSortDirection.values
          .firstWhereOrNull((e) => e.value == v3GridScreenIdGetSortDirection) ??
      defaultValue ??
      enums.V3GridScreenIdGetSortDirection.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetSortDirectionListToJson(
    List<enums.V3GridScreenIdGetSortDirection>?
        v3GridScreenIdGetSortDirection) {
  if (v3GridScreenIdGetSortDirection == null) {
    return [];
  }

  return v3GridScreenIdGetSortDirection.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetSortDirection>
    v3GridScreenIdGetSortDirectionListFromJson(
  List? v3GridScreenIdGetSortDirection, [
  List<enums.V3GridScreenIdGetSortDirection>? defaultValue,
]) {
  if (v3GridScreenIdGetSortDirection == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetSortDirection
      .map((e) => v3GridScreenIdGetSortDirectionFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetSortDirection>?
    v3GridScreenIdGetSortDirectionNullableListFromJson(
  List? v3GridScreenIdGetSortDirection, [
  List<enums.V3GridScreenIdGetSortDirection>? defaultValue,
]) {
  if (v3GridScreenIdGetSortDirection == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetSortDirection
      .map((e) => v3GridScreenIdGetSortDirectionFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetFilterTypeToJson(
    enums.V3GridScreenIdGetFilterType? v3GridScreenIdGetFilterType) {
  return v3GridScreenIdGetFilterType?.value;
}

enums.V3GridScreenIdGetFilterType v3GridScreenIdGetFilterTypeFromJson(
  Object? v3GridScreenIdGetFilterType, [
  enums.V3GridScreenIdGetFilterType? defaultValue,
]) {
  return enums.V3GridScreenIdGetFilterType.values
          .firstWhereOrNull((e) => e.value == v3GridScreenIdGetFilterType) ??
      defaultValue ??
      enums.V3GridScreenIdGetFilterType.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetFilterTypeListToJson(
    List<enums.V3GridScreenIdGetFilterType>? v3GridScreenIdGetFilterType) {
  if (v3GridScreenIdGetFilterType == null) {
    return [];
  }

  return v3GridScreenIdGetFilterType.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetFilterType> v3GridScreenIdGetFilterTypeListFromJson(
  List? v3GridScreenIdGetFilterType, [
  List<enums.V3GridScreenIdGetFilterType>? defaultValue,
]) {
  if (v3GridScreenIdGetFilterType == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetFilterType
      .map((e) => v3GridScreenIdGetFilterTypeFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetFilterType>?
    v3GridScreenIdGetFilterTypeNullableListFromJson(
  List? v3GridScreenIdGetFilterType, [
  List<enums.V3GridScreenIdGetFilterType>? defaultValue,
]) {
  if (v3GridScreenIdGetFilterType == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetFilterType
      .map((e) => v3GridScreenIdGetFilterTypeFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetEncodingToJson(
    enums.V3GridScreenIdGetEncoding? v3GridScreenIdGetEncoding) {
  return v3GridScreenIdGetEncoding?.value;
}

enums.V3GridScreenIdGetEncoding v3GridScreenIdGetEncodingFromJson(
  Object? v3GridScreenIdGetEncoding, [
  enums.V3GridScreenIdGetEncoding? defaultValue,
]) {
  return enums.V3GridScreenIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3GridScreenIdGetEncoding) ??
      defaultValue ??
      enums.V3GridScreenIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetEncodingListToJson(
    List<enums.V3GridScreenIdGetEncoding>? v3GridScreenIdGetEncoding) {
  if (v3GridScreenIdGetEncoding == null) {
    return [];
  }

  return v3GridScreenIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetEncoding> v3GridScreenIdGetEncodingListFromJson(
  List? v3GridScreenIdGetEncoding, [
  List<enums.V3GridScreenIdGetEncoding>? defaultValue,
]) {
  if (v3GridScreenIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetEncoding
      .map((e) => v3GridScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetEncoding>?
    v3GridScreenIdGetEncodingNullableListFromJson(
  List? v3GridScreenIdGetEncoding, [
  List<enums.V3GridScreenIdGetEncoding>? defaultValue,
]) {
  if (v3GridScreenIdGetEncoding == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetEncoding
      .map((e) => v3GridScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetMaxResToJson(
    enums.V3GridScreenIdGetMaxRes? v3GridScreenIdGetMaxRes) {
  return v3GridScreenIdGetMaxRes?.value;
}

enums.V3GridScreenIdGetMaxRes v3GridScreenIdGetMaxResFromJson(
  Object? v3GridScreenIdGetMaxRes, [
  enums.V3GridScreenIdGetMaxRes? defaultValue,
]) {
  return enums.V3GridScreenIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3GridScreenIdGetMaxRes) ??
      defaultValue ??
      enums.V3GridScreenIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetMaxResListToJson(
    List<enums.V3GridScreenIdGetMaxRes>? v3GridScreenIdGetMaxRes) {
  if (v3GridScreenIdGetMaxRes == null) {
    return [];
  }

  return v3GridScreenIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetMaxRes> v3GridScreenIdGetMaxResListFromJson(
  List? v3GridScreenIdGetMaxRes, [
  List<enums.V3GridScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3GridScreenIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetMaxRes
      .map((e) => v3GridScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetMaxRes>?
    v3GridScreenIdGetMaxResNullableListFromJson(
  List? v3GridScreenIdGetMaxRes, [
  List<enums.V3GridScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3GridScreenIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetMaxRes
      .map((e) => v3GridScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3GridScreenIdGetFilterOnDemandToJson(
    enums.V3GridScreenIdGetFilterOnDemand? v3GridScreenIdGetFilterOnDemand) {
  return v3GridScreenIdGetFilterOnDemand?.value;
}

enums.V3GridScreenIdGetFilterOnDemand v3GridScreenIdGetFilterOnDemandFromJson(
  Object? v3GridScreenIdGetFilterOnDemand, [
  enums.V3GridScreenIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V3GridScreenIdGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3GridScreenIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V3GridScreenIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3GridScreenIdGetFilterOnDemandListToJson(
    List<enums.V3GridScreenIdGetFilterOnDemand>?
        v3GridScreenIdGetFilterOnDemand) {
  if (v3GridScreenIdGetFilterOnDemand == null) {
    return [];
  }

  return v3GridScreenIdGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3GridScreenIdGetFilterOnDemand>
    v3GridScreenIdGetFilterOnDemandListFromJson(
  List? v3GridScreenIdGetFilterOnDemand, [
  List<enums.V3GridScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3GridScreenIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3GridScreenIdGetFilterOnDemand
      .map((e) => v3GridScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3GridScreenIdGetFilterOnDemand>?
    v3GridScreenIdGetFilterOnDemandNullableListFromJson(
  List? v3GridScreenIdGetFilterOnDemand, [
  List<enums.V3GridScreenIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3GridScreenIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3GridScreenIdGetFilterOnDemand
      .map((e) => v3GridScreenIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3NextepisodeGetEncodingToJson(
    enums.V3NextepisodeGetEncoding? v3NextepisodeGetEncoding) {
  return v3NextepisodeGetEncoding?.value;
}

enums.V3NextepisodeGetEncoding v3NextepisodeGetEncodingFromJson(
  Object? v3NextepisodeGetEncoding, [
  enums.V3NextepisodeGetEncoding? defaultValue,
]) {
  return enums.V3NextepisodeGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3NextepisodeGetEncoding) ??
      defaultValue ??
      enums.V3NextepisodeGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3NextepisodeGetEncodingListToJson(
    List<enums.V3NextepisodeGetEncoding>? v3NextepisodeGetEncoding) {
  if (v3NextepisodeGetEncoding == null) {
    return [];
  }

  return v3NextepisodeGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3NextepisodeGetEncoding> v3NextepisodeGetEncodingListFromJson(
  List? v3NextepisodeGetEncoding, [
  List<enums.V3NextepisodeGetEncoding>? defaultValue,
]) {
  if (v3NextepisodeGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3NextepisodeGetEncoding
      .map((e) => v3NextepisodeGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3NextepisodeGetEncoding>?
    v3NextepisodeGetEncodingNullableListFromJson(
  List? v3NextepisodeGetEncoding, [
  List<enums.V3NextepisodeGetEncoding>? defaultValue,
]) {
  if (v3NextepisodeGetEncoding == null) {
    return defaultValue;
  }

  return v3NextepisodeGetEncoding
      .map((e) => v3NextepisodeGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3NextepisodeGetMaxResToJson(
    enums.V3NextepisodeGetMaxRes? v3NextepisodeGetMaxRes) {
  return v3NextepisodeGetMaxRes?.value;
}

enums.V3NextepisodeGetMaxRes v3NextepisodeGetMaxResFromJson(
  Object? v3NextepisodeGetMaxRes, [
  enums.V3NextepisodeGetMaxRes? defaultValue,
]) {
  return enums.V3NextepisodeGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3NextepisodeGetMaxRes) ??
      defaultValue ??
      enums.V3NextepisodeGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3NextepisodeGetMaxResListToJson(
    List<enums.V3NextepisodeGetMaxRes>? v3NextepisodeGetMaxRes) {
  if (v3NextepisodeGetMaxRes == null) {
    return [];
  }

  return v3NextepisodeGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3NextepisodeGetMaxRes> v3NextepisodeGetMaxResListFromJson(
  List? v3NextepisodeGetMaxRes, [
  List<enums.V3NextepisodeGetMaxRes>? defaultValue,
]) {
  if (v3NextepisodeGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3NextepisodeGetMaxRes
      .map((e) => v3NextepisodeGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3NextepisodeGetMaxRes>? v3NextepisodeGetMaxResNullableListFromJson(
  List? v3NextepisodeGetMaxRes, [
  List<enums.V3NextepisodeGetMaxRes>? defaultValue,
]) {
  if (v3NextepisodeGetMaxRes == null) {
    return defaultValue;
  }

  return v3NextepisodeGetMaxRes
      .map((e) => v3NextepisodeGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3NextepisodeGetFilterOnDemandToJson(
    enums.V3NextepisodeGetFilterOnDemand? v3NextepisodeGetFilterOnDemand) {
  return v3NextepisodeGetFilterOnDemand?.value;
}

enums.V3NextepisodeGetFilterOnDemand v3NextepisodeGetFilterOnDemandFromJson(
  Object? v3NextepisodeGetFilterOnDemand, [
  enums.V3NextepisodeGetFilterOnDemand? defaultValue,
]) {
  return enums.V3NextepisodeGetFilterOnDemand.values
          .firstWhereOrNull((e) => e.value == v3NextepisodeGetFilterOnDemand) ??
      defaultValue ??
      enums.V3NextepisodeGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3NextepisodeGetFilterOnDemandListToJson(
    List<enums.V3NextepisodeGetFilterOnDemand>?
        v3NextepisodeGetFilterOnDemand) {
  if (v3NextepisodeGetFilterOnDemand == null) {
    return [];
  }

  return v3NextepisodeGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3NextepisodeGetFilterOnDemand>
    v3NextepisodeGetFilterOnDemandListFromJson(
  List? v3NextepisodeGetFilterOnDemand, [
  List<enums.V3NextepisodeGetFilterOnDemand>? defaultValue,
]) {
  if (v3NextepisodeGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3NextepisodeGetFilterOnDemand
      .map((e) => v3NextepisodeGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3NextepisodeGetFilterOnDemand>?
    v3NextepisodeGetFilterOnDemandNullableListFromJson(
  List? v3NextepisodeGetFilterOnDemand, [
  List<enums.V3NextepisodeGetFilterOnDemand>? defaultValue,
]) {
  if (v3NextepisodeGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3NextepisodeGetFilterOnDemand
      .map((e) => v3NextepisodeGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3RentalsGetEncodingToJson(
    enums.V3RentalsGetEncoding? v3RentalsGetEncoding) {
  return v3RentalsGetEncoding?.value;
}

enums.V3RentalsGetEncoding v3RentalsGetEncodingFromJson(
  Object? v3RentalsGetEncoding, [
  enums.V3RentalsGetEncoding? defaultValue,
]) {
  return enums.V3RentalsGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3RentalsGetEncoding) ??
      defaultValue ??
      enums.V3RentalsGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3RentalsGetEncodingListToJson(
    List<enums.V3RentalsGetEncoding>? v3RentalsGetEncoding) {
  if (v3RentalsGetEncoding == null) {
    return [];
  }

  return v3RentalsGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3RentalsGetEncoding> v3RentalsGetEncodingListFromJson(
  List? v3RentalsGetEncoding, [
  List<enums.V3RentalsGetEncoding>? defaultValue,
]) {
  if (v3RentalsGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3RentalsGetEncoding
      .map((e) => v3RentalsGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3RentalsGetEncoding>? v3RentalsGetEncodingNullableListFromJson(
  List? v3RentalsGetEncoding, [
  List<enums.V3RentalsGetEncoding>? defaultValue,
]) {
  if (v3RentalsGetEncoding == null) {
    return defaultValue;
  }

  return v3RentalsGetEncoding
      .map((e) => v3RentalsGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3RentalsGetMaxResToJson(enums.V3RentalsGetMaxRes? v3RentalsGetMaxRes) {
  return v3RentalsGetMaxRes?.value;
}

enums.V3RentalsGetMaxRes v3RentalsGetMaxResFromJson(
  Object? v3RentalsGetMaxRes, [
  enums.V3RentalsGetMaxRes? defaultValue,
]) {
  return enums.V3RentalsGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3RentalsGetMaxRes) ??
      defaultValue ??
      enums.V3RentalsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3RentalsGetMaxResListToJson(
    List<enums.V3RentalsGetMaxRes>? v3RentalsGetMaxRes) {
  if (v3RentalsGetMaxRes == null) {
    return [];
  }

  return v3RentalsGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3RentalsGetMaxRes> v3RentalsGetMaxResListFromJson(
  List? v3RentalsGetMaxRes, [
  List<enums.V3RentalsGetMaxRes>? defaultValue,
]) {
  if (v3RentalsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3RentalsGetMaxRes
      .map((e) => v3RentalsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3RentalsGetMaxRes>? v3RentalsGetMaxResNullableListFromJson(
  List? v3RentalsGetMaxRes, [
  List<enums.V3RentalsGetMaxRes>? defaultValue,
]) {
  if (v3RentalsGetMaxRes == null) {
    return defaultValue;
  }

  return v3RentalsGetMaxRes
      .map((e) => v3RentalsGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdGetMenuToJson(
    enums.V3StructureRootIdGetMenu? v3StructureRootIdGetMenu) {
  return v3StructureRootIdGetMenu?.value;
}

enums.V3StructureRootIdGetMenu v3StructureRootIdGetMenuFromJson(
  Object? v3StructureRootIdGetMenu, [
  enums.V3StructureRootIdGetMenu? defaultValue,
]) {
  return enums.V3StructureRootIdGetMenu.values
          .firstWhereOrNull((e) => e.value == v3StructureRootIdGetMenu) ??
      defaultValue ??
      enums.V3StructureRootIdGetMenu.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdGetMenuListToJson(
    List<enums.V3StructureRootIdGetMenu>? v3StructureRootIdGetMenu) {
  if (v3StructureRootIdGetMenu == null) {
    return [];
  }

  return v3StructureRootIdGetMenu.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdGetMenu> v3StructureRootIdGetMenuListFromJson(
  List? v3StructureRootIdGetMenu, [
  List<enums.V3StructureRootIdGetMenu>? defaultValue,
]) {
  if (v3StructureRootIdGetMenu == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdGetMenu
      .map((e) => v3StructureRootIdGetMenuFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdGetMenu>?
    v3StructureRootIdGetMenuNullableListFromJson(
  List? v3StructureRootIdGetMenu, [
  List<enums.V3StructureRootIdGetMenu>? defaultValue,
]) {
  if (v3StructureRootIdGetMenu == null) {
    return defaultValue;
  }

  return v3StructureRootIdGetMenu
      .map((e) => v3StructureRootIdGetMenuFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdGetEncodingToJson(
    enums.V3StructureRootIdGetEncoding? v3StructureRootIdGetEncoding) {
  return v3StructureRootIdGetEncoding?.value;
}

enums.V3StructureRootIdGetEncoding v3StructureRootIdGetEncodingFromJson(
  Object? v3StructureRootIdGetEncoding, [
  enums.V3StructureRootIdGetEncoding? defaultValue,
]) {
  return enums.V3StructureRootIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3StructureRootIdGetEncoding) ??
      defaultValue ??
      enums.V3StructureRootIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdGetEncodingListToJson(
    List<enums.V3StructureRootIdGetEncoding>? v3StructureRootIdGetEncoding) {
  if (v3StructureRootIdGetEncoding == null) {
    return [];
  }

  return v3StructureRootIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdGetEncoding>
    v3StructureRootIdGetEncodingListFromJson(
  List? v3StructureRootIdGetEncoding, [
  List<enums.V3StructureRootIdGetEncoding>? defaultValue,
]) {
  if (v3StructureRootIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdGetEncoding
      .map((e) => v3StructureRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdGetEncoding>?
    v3StructureRootIdGetEncodingNullableListFromJson(
  List? v3StructureRootIdGetEncoding, [
  List<enums.V3StructureRootIdGetEncoding>? defaultValue,
]) {
  if (v3StructureRootIdGetEncoding == null) {
    return defaultValue;
  }

  return v3StructureRootIdGetEncoding
      .map((e) => v3StructureRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdGetMaxResToJson(
    enums.V3StructureRootIdGetMaxRes? v3StructureRootIdGetMaxRes) {
  return v3StructureRootIdGetMaxRes?.value;
}

enums.V3StructureRootIdGetMaxRes v3StructureRootIdGetMaxResFromJson(
  Object? v3StructureRootIdGetMaxRes, [
  enums.V3StructureRootIdGetMaxRes? defaultValue,
]) {
  return enums.V3StructureRootIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3StructureRootIdGetMaxRes) ??
      defaultValue ??
      enums.V3StructureRootIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdGetMaxResListToJson(
    List<enums.V3StructureRootIdGetMaxRes>? v3StructureRootIdGetMaxRes) {
  if (v3StructureRootIdGetMaxRes == null) {
    return [];
  }

  return v3StructureRootIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdGetMaxRes> v3StructureRootIdGetMaxResListFromJson(
  List? v3StructureRootIdGetMaxRes, [
  List<enums.V3StructureRootIdGetMaxRes>? defaultValue,
]) {
  if (v3StructureRootIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdGetMaxRes
      .map((e) => v3StructureRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdGetMaxRes>?
    v3StructureRootIdGetMaxResNullableListFromJson(
  List? v3StructureRootIdGetMaxRes, [
  List<enums.V3StructureRootIdGetMaxRes>? defaultValue,
]) {
  if (v3StructureRootIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3StructureRootIdGetMaxRes
      .map((e) => v3StructureRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdGetFilterOnDemandToJson(
    enums.V3StructureRootIdGetFilterOnDemand?
        v3StructureRootIdGetFilterOnDemand) {
  return v3StructureRootIdGetFilterOnDemand?.value;
}

enums.V3StructureRootIdGetFilterOnDemand
    v3StructureRootIdGetFilterOnDemandFromJson(
  Object? v3StructureRootIdGetFilterOnDemand, [
  enums.V3StructureRootIdGetFilterOnDemand? defaultValue,
]) {
  return enums.V3StructureRootIdGetFilterOnDemand.values.firstWhereOrNull(
          (e) => e.value == v3StructureRootIdGetFilterOnDemand) ??
      defaultValue ??
      enums.V3StructureRootIdGetFilterOnDemand.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdGetFilterOnDemandListToJson(
    List<enums.V3StructureRootIdGetFilterOnDemand>?
        v3StructureRootIdGetFilterOnDemand) {
  if (v3StructureRootIdGetFilterOnDemand == null) {
    return [];
  }

  return v3StructureRootIdGetFilterOnDemand.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdGetFilterOnDemand>
    v3StructureRootIdGetFilterOnDemandListFromJson(
  List? v3StructureRootIdGetFilterOnDemand, [
  List<enums.V3StructureRootIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3StructureRootIdGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdGetFilterOnDemand
      .map((e) => v3StructureRootIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdGetFilterOnDemand>?
    v3StructureRootIdGetFilterOnDemandNullableListFromJson(
  List? v3StructureRootIdGetFilterOnDemand, [
  List<enums.V3StructureRootIdGetFilterOnDemand>? defaultValue,
]) {
  if (v3StructureRootIdGetFilterOnDemand == null) {
    return defaultValue;
  }

  return v3StructureRootIdGetFilterOnDemand
      .map((e) => v3StructureRootIdGetFilterOnDemandFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdIdGetMenuToJson(
    enums.V3StructureRootIdIdGetMenu? v3StructureRootIdIdGetMenu) {
  return v3StructureRootIdIdGetMenu?.value;
}

enums.V3StructureRootIdIdGetMenu v3StructureRootIdIdGetMenuFromJson(
  Object? v3StructureRootIdIdGetMenu, [
  enums.V3StructureRootIdIdGetMenu? defaultValue,
]) {
  return enums.V3StructureRootIdIdGetMenu.values
          .firstWhereOrNull((e) => e.value == v3StructureRootIdIdGetMenu) ??
      defaultValue ??
      enums.V3StructureRootIdIdGetMenu.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdIdGetMenuListToJson(
    List<enums.V3StructureRootIdIdGetMenu>? v3StructureRootIdIdGetMenu) {
  if (v3StructureRootIdIdGetMenu == null) {
    return [];
  }

  return v3StructureRootIdIdGetMenu.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdIdGetMenu> v3StructureRootIdIdGetMenuListFromJson(
  List? v3StructureRootIdIdGetMenu, [
  List<enums.V3StructureRootIdIdGetMenu>? defaultValue,
]) {
  if (v3StructureRootIdIdGetMenu == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdIdGetMenu
      .map((e) => v3StructureRootIdIdGetMenuFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdIdGetMenu>?
    v3StructureRootIdIdGetMenuNullableListFromJson(
  List? v3StructureRootIdIdGetMenu, [
  List<enums.V3StructureRootIdIdGetMenu>? defaultValue,
]) {
  if (v3StructureRootIdIdGetMenu == null) {
    return defaultValue;
  }

  return v3StructureRootIdIdGetMenu
      .map((e) => v3StructureRootIdIdGetMenuFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdIdGetEncodingToJson(
    enums.V3StructureRootIdIdGetEncoding? v3StructureRootIdIdGetEncoding) {
  return v3StructureRootIdIdGetEncoding?.value;
}

enums.V3StructureRootIdIdGetEncoding v3StructureRootIdIdGetEncodingFromJson(
  Object? v3StructureRootIdIdGetEncoding, [
  enums.V3StructureRootIdIdGetEncoding? defaultValue,
]) {
  return enums.V3StructureRootIdIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3StructureRootIdIdGetEncoding) ??
      defaultValue ??
      enums.V3StructureRootIdIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdIdGetEncodingListToJson(
    List<enums.V3StructureRootIdIdGetEncoding>?
        v3StructureRootIdIdGetEncoding) {
  if (v3StructureRootIdIdGetEncoding == null) {
    return [];
  }

  return v3StructureRootIdIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdIdGetEncoding>
    v3StructureRootIdIdGetEncodingListFromJson(
  List? v3StructureRootIdIdGetEncoding, [
  List<enums.V3StructureRootIdIdGetEncoding>? defaultValue,
]) {
  if (v3StructureRootIdIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdIdGetEncoding
      .map((e) => v3StructureRootIdIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdIdGetEncoding>?
    v3StructureRootIdIdGetEncodingNullableListFromJson(
  List? v3StructureRootIdIdGetEncoding, [
  List<enums.V3StructureRootIdIdGetEncoding>? defaultValue,
]) {
  if (v3StructureRootIdIdGetEncoding == null) {
    return defaultValue;
  }

  return v3StructureRootIdIdGetEncoding
      .map((e) => v3StructureRootIdIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3StructureRootIdIdGetMaxResToJson(
    enums.V3StructureRootIdIdGetMaxRes? v3StructureRootIdIdGetMaxRes) {
  return v3StructureRootIdIdGetMaxRes?.value;
}

enums.V3StructureRootIdIdGetMaxRes v3StructureRootIdIdGetMaxResFromJson(
  Object? v3StructureRootIdIdGetMaxRes, [
  enums.V3StructureRootIdIdGetMaxRes? defaultValue,
]) {
  return enums.V3StructureRootIdIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3StructureRootIdIdGetMaxRes) ??
      defaultValue ??
      enums.V3StructureRootIdIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3StructureRootIdIdGetMaxResListToJson(
    List<enums.V3StructureRootIdIdGetMaxRes>? v3StructureRootIdIdGetMaxRes) {
  if (v3StructureRootIdIdGetMaxRes == null) {
    return [];
  }

  return v3StructureRootIdIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3StructureRootIdIdGetMaxRes>
    v3StructureRootIdIdGetMaxResListFromJson(
  List? v3StructureRootIdIdGetMaxRes, [
  List<enums.V3StructureRootIdIdGetMaxRes>? defaultValue,
]) {
  if (v3StructureRootIdIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3StructureRootIdIdGetMaxRes
      .map((e) => v3StructureRootIdIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3StructureRootIdIdGetMaxRes>?
    v3StructureRootIdIdGetMaxResNullableListFromJson(
  List? v3StructureRootIdIdGetMaxRes, [
  List<enums.V3StructureRootIdIdGetMaxRes>? defaultValue,
]) {
  if (v3StructureRootIdIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3StructureRootIdIdGetMaxRes
      .map((e) => v3StructureRootIdIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3TileLinkRootIdGetEncodingToJson(
    enums.V3TileLinkRootIdGetEncoding? v3TileLinkRootIdGetEncoding) {
  return v3TileLinkRootIdGetEncoding?.value;
}

enums.V3TileLinkRootIdGetEncoding v3TileLinkRootIdGetEncodingFromJson(
  Object? v3TileLinkRootIdGetEncoding, [
  enums.V3TileLinkRootIdGetEncoding? defaultValue,
]) {
  return enums.V3TileLinkRootIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3TileLinkRootIdGetEncoding) ??
      defaultValue ??
      enums.V3TileLinkRootIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3TileLinkRootIdGetEncodingListToJson(
    List<enums.V3TileLinkRootIdGetEncoding>? v3TileLinkRootIdGetEncoding) {
  if (v3TileLinkRootIdGetEncoding == null) {
    return [];
  }

  return v3TileLinkRootIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3TileLinkRootIdGetEncoding> v3TileLinkRootIdGetEncodingListFromJson(
  List? v3TileLinkRootIdGetEncoding, [
  List<enums.V3TileLinkRootIdGetEncoding>? defaultValue,
]) {
  if (v3TileLinkRootIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3TileLinkRootIdGetEncoding
      .map((e) => v3TileLinkRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3TileLinkRootIdGetEncoding>?
    v3TileLinkRootIdGetEncodingNullableListFromJson(
  List? v3TileLinkRootIdGetEncoding, [
  List<enums.V3TileLinkRootIdGetEncoding>? defaultValue,
]) {
  if (v3TileLinkRootIdGetEncoding == null) {
    return defaultValue;
  }

  return v3TileLinkRootIdGetEncoding
      .map((e) => v3TileLinkRootIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3TileLinkRootIdGetMaxResToJson(
    enums.V3TileLinkRootIdGetMaxRes? v3TileLinkRootIdGetMaxRes) {
  return v3TileLinkRootIdGetMaxRes?.value;
}

enums.V3TileLinkRootIdGetMaxRes v3TileLinkRootIdGetMaxResFromJson(
  Object? v3TileLinkRootIdGetMaxRes, [
  enums.V3TileLinkRootIdGetMaxRes? defaultValue,
]) {
  return enums.V3TileLinkRootIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3TileLinkRootIdGetMaxRes) ??
      defaultValue ??
      enums.V3TileLinkRootIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3TileLinkRootIdGetMaxResListToJson(
    List<enums.V3TileLinkRootIdGetMaxRes>? v3TileLinkRootIdGetMaxRes) {
  if (v3TileLinkRootIdGetMaxRes == null) {
    return [];
  }

  return v3TileLinkRootIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3TileLinkRootIdGetMaxRes> v3TileLinkRootIdGetMaxResListFromJson(
  List? v3TileLinkRootIdGetMaxRes, [
  List<enums.V3TileLinkRootIdGetMaxRes>? defaultValue,
]) {
  if (v3TileLinkRootIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3TileLinkRootIdGetMaxRes
      .map((e) => v3TileLinkRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3TileLinkRootIdGetMaxRes>?
    v3TileLinkRootIdGetMaxResNullableListFromJson(
  List? v3TileLinkRootIdGetMaxRes, [
  List<enums.V3TileLinkRootIdGetMaxRes>? defaultValue,
]) {
  if (v3TileLinkRootIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3TileLinkRootIdGetMaxRes
      .map((e) => v3TileLinkRootIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3TilesScreenIdGetEncodingToJson(
    enums.V3TilesScreenIdGetEncoding? v3TilesScreenIdGetEncoding) {
  return v3TilesScreenIdGetEncoding?.value;
}

enums.V3TilesScreenIdGetEncoding v3TilesScreenIdGetEncodingFromJson(
  Object? v3TilesScreenIdGetEncoding, [
  enums.V3TilesScreenIdGetEncoding? defaultValue,
]) {
  return enums.V3TilesScreenIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v3TilesScreenIdGetEncoding) ??
      defaultValue ??
      enums.V3TilesScreenIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3TilesScreenIdGetEncodingListToJson(
    List<enums.V3TilesScreenIdGetEncoding>? v3TilesScreenIdGetEncoding) {
  if (v3TilesScreenIdGetEncoding == null) {
    return [];
  }

  return v3TilesScreenIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3TilesScreenIdGetEncoding> v3TilesScreenIdGetEncodingListFromJson(
  List? v3TilesScreenIdGetEncoding, [
  List<enums.V3TilesScreenIdGetEncoding>? defaultValue,
]) {
  if (v3TilesScreenIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3TilesScreenIdGetEncoding
      .map((e) => v3TilesScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3TilesScreenIdGetEncoding>?
    v3TilesScreenIdGetEncodingNullableListFromJson(
  List? v3TilesScreenIdGetEncoding, [
  List<enums.V3TilesScreenIdGetEncoding>? defaultValue,
]) {
  if (v3TilesScreenIdGetEncoding == null) {
    return defaultValue;
  }

  return v3TilesScreenIdGetEncoding
      .map((e) => v3TilesScreenIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3TilesScreenIdGetMaxResToJson(
    enums.V3TilesScreenIdGetMaxRes? v3TilesScreenIdGetMaxRes) {
  return v3TilesScreenIdGetMaxRes?.value;
}

enums.V3TilesScreenIdGetMaxRes v3TilesScreenIdGetMaxResFromJson(
  Object? v3TilesScreenIdGetMaxRes, [
  enums.V3TilesScreenIdGetMaxRes? defaultValue,
]) {
  return enums.V3TilesScreenIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v3TilesScreenIdGetMaxRes) ??
      defaultValue ??
      enums.V3TilesScreenIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3TilesScreenIdGetMaxResListToJson(
    List<enums.V3TilesScreenIdGetMaxRes>? v3TilesScreenIdGetMaxRes) {
  if (v3TilesScreenIdGetMaxRes == null) {
    return [];
  }

  return v3TilesScreenIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3TilesScreenIdGetMaxRes> v3TilesScreenIdGetMaxResListFromJson(
  List? v3TilesScreenIdGetMaxRes, [
  List<enums.V3TilesScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3TilesScreenIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3TilesScreenIdGetMaxRes
      .map((e) => v3TilesScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3TilesScreenIdGetMaxRes>?
    v3TilesScreenIdGetMaxResNullableListFromJson(
  List? v3TilesScreenIdGetMaxRes, [
  List<enums.V3TilesScreenIdGetMaxRes>? defaultValue,
]) {
  if (v3TilesScreenIdGetMaxRes == null) {
    return defaultValue;
  }

  return v3TilesScreenIdGetMaxRes
      .map((e) => v3TilesScreenIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? v3TrailerDetailsTrailerCridGetEncodingToJson(
    enums.V3TrailerDetailsTrailerCridGetEncoding?
        v3TrailerDetailsTrailerCridGetEncoding) {
  return v3TrailerDetailsTrailerCridGetEncoding?.value;
}

enums.V3TrailerDetailsTrailerCridGetEncoding
    v3TrailerDetailsTrailerCridGetEncodingFromJson(
  Object? v3TrailerDetailsTrailerCridGetEncoding, [
  enums.V3TrailerDetailsTrailerCridGetEncoding? defaultValue,
]) {
  return enums.V3TrailerDetailsTrailerCridGetEncoding.values.firstWhereOrNull(
          (e) => e.value == v3TrailerDetailsTrailerCridGetEncoding) ??
      defaultValue ??
      enums.V3TrailerDetailsTrailerCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> v3TrailerDetailsTrailerCridGetEncodingListToJson(
    List<enums.V3TrailerDetailsTrailerCridGetEncoding>?
        v3TrailerDetailsTrailerCridGetEncoding) {
  if (v3TrailerDetailsTrailerCridGetEncoding == null) {
    return [];
  }

  return v3TrailerDetailsTrailerCridGetEncoding.map((e) => e.value!).toList();
}

List<enums.V3TrailerDetailsTrailerCridGetEncoding>
    v3TrailerDetailsTrailerCridGetEncodingListFromJson(
  List? v3TrailerDetailsTrailerCridGetEncoding, [
  List<enums.V3TrailerDetailsTrailerCridGetEncoding>? defaultValue,
]) {
  if (v3TrailerDetailsTrailerCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v3TrailerDetailsTrailerCridGetEncoding
      .map((e) => v3TrailerDetailsTrailerCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V3TrailerDetailsTrailerCridGetEncoding>?
    v3TrailerDetailsTrailerCridGetEncodingNullableListFromJson(
  List? v3TrailerDetailsTrailerCridGetEncoding, [
  List<enums.V3TrailerDetailsTrailerCridGetEncoding>? defaultValue,
]) {
  if (v3TrailerDetailsTrailerCridGetEncoding == null) {
    return defaultValue;
  }

  return v3TrailerDetailsTrailerCridGetEncoding
      .map((e) => v3TrailerDetailsTrailerCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? v3TrailerDetailsTrailerCridGetMaxResToJson(
    enums.V3TrailerDetailsTrailerCridGetMaxRes?
        v3TrailerDetailsTrailerCridGetMaxRes) {
  return v3TrailerDetailsTrailerCridGetMaxRes?.value;
}

enums.V3TrailerDetailsTrailerCridGetMaxRes
    v3TrailerDetailsTrailerCridGetMaxResFromJson(
  Object? v3TrailerDetailsTrailerCridGetMaxRes, [
  enums.V3TrailerDetailsTrailerCridGetMaxRes? defaultValue,
]) {
  return enums.V3TrailerDetailsTrailerCridGetMaxRes.values.firstWhereOrNull(
          (e) => e.value == v3TrailerDetailsTrailerCridGetMaxRes) ??
      defaultValue ??
      enums.V3TrailerDetailsTrailerCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v3TrailerDetailsTrailerCridGetMaxResListToJson(
    List<enums.V3TrailerDetailsTrailerCridGetMaxRes>?
        v3TrailerDetailsTrailerCridGetMaxRes) {
  if (v3TrailerDetailsTrailerCridGetMaxRes == null) {
    return [];
  }

  return v3TrailerDetailsTrailerCridGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V3TrailerDetailsTrailerCridGetMaxRes>
    v3TrailerDetailsTrailerCridGetMaxResListFromJson(
  List? v3TrailerDetailsTrailerCridGetMaxRes, [
  List<enums.V3TrailerDetailsTrailerCridGetMaxRes>? defaultValue,
]) {
  if (v3TrailerDetailsTrailerCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v3TrailerDetailsTrailerCridGetMaxRes
      .map((e) => v3TrailerDetailsTrailerCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V3TrailerDetailsTrailerCridGetMaxRes>?
    v3TrailerDetailsTrailerCridGetMaxResNullableListFromJson(
  List? v3TrailerDetailsTrailerCridGetMaxRes, [
  List<enums.V3TrailerDetailsTrailerCridGetMaxRes>? defaultValue,
]) {
  if (v3TrailerDetailsTrailerCridGetMaxRes == null) {
    return defaultValue;
  }

  return v3TrailerDetailsTrailerCridGetMaxRes
      .map((e) => v3TrailerDetailsTrailerCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1FeedFeedIdGetEncodingToJson(
    enums.V1FeedFeedIdGetEncoding? v1FeedFeedIdGetEncoding) {
  return v1FeedFeedIdGetEncoding?.value;
}

enums.V1FeedFeedIdGetEncoding v1FeedFeedIdGetEncodingFromJson(
  Object? v1FeedFeedIdGetEncoding, [
  enums.V1FeedFeedIdGetEncoding? defaultValue,
]) {
  return enums.V1FeedFeedIdGetEncoding.values
          .firstWhereOrNull((e) => e.value == v1FeedFeedIdGetEncoding) ??
      defaultValue ??
      enums.V1FeedFeedIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> v1FeedFeedIdGetEncodingListToJson(
    List<enums.V1FeedFeedIdGetEncoding>? v1FeedFeedIdGetEncoding) {
  if (v1FeedFeedIdGetEncoding == null) {
    return [];
  }

  return v1FeedFeedIdGetEncoding.map((e) => e.value!).toList();
}

List<enums.V1FeedFeedIdGetEncoding> v1FeedFeedIdGetEncodingListFromJson(
  List? v1FeedFeedIdGetEncoding, [
  List<enums.V1FeedFeedIdGetEncoding>? defaultValue,
]) {
  if (v1FeedFeedIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return v1FeedFeedIdGetEncoding
      .map((e) => v1FeedFeedIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.V1FeedFeedIdGetEncoding>?
    v1FeedFeedIdGetEncodingNullableListFromJson(
  List? v1FeedFeedIdGetEncoding, [
  List<enums.V1FeedFeedIdGetEncoding>? defaultValue,
]) {
  if (v1FeedFeedIdGetEncoding == null) {
    return defaultValue;
  }

  return v1FeedFeedIdGetEncoding
      .map((e) => v1FeedFeedIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? v1FeedFeedIdGetMaxResToJson(
    enums.V1FeedFeedIdGetMaxRes? v1FeedFeedIdGetMaxRes) {
  return v1FeedFeedIdGetMaxRes?.value;
}

enums.V1FeedFeedIdGetMaxRes v1FeedFeedIdGetMaxResFromJson(
  Object? v1FeedFeedIdGetMaxRes, [
  enums.V1FeedFeedIdGetMaxRes? defaultValue,
]) {
  return enums.V1FeedFeedIdGetMaxRes.values
          .firstWhereOrNull((e) => e.value == v1FeedFeedIdGetMaxRes) ??
      defaultValue ??
      enums.V1FeedFeedIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1FeedFeedIdGetMaxResListToJson(
    List<enums.V1FeedFeedIdGetMaxRes>? v1FeedFeedIdGetMaxRes) {
  if (v1FeedFeedIdGetMaxRes == null) {
    return [];
  }

  return v1FeedFeedIdGetMaxRes.map((e) => e.value!).toList();
}

List<enums.V1FeedFeedIdGetMaxRes> v1FeedFeedIdGetMaxResListFromJson(
  List? v1FeedFeedIdGetMaxRes, [
  List<enums.V1FeedFeedIdGetMaxRes>? defaultValue,
]) {
  if (v1FeedFeedIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1FeedFeedIdGetMaxRes
      .map((e) => v1FeedFeedIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1FeedFeedIdGetMaxRes>? v1FeedFeedIdGetMaxResNullableListFromJson(
  List? v1FeedFeedIdGetMaxRes, [
  List<enums.V1FeedFeedIdGetMaxRes>? defaultValue,
]) {
  if (v1FeedFeedIdGetMaxRes == null) {
    return defaultValue;
  }

  return v1FeedFeedIdGetMaxRes
      .map((e) => v1FeedFeedIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? hzngoV1EditorialFeedCategoryIdGetSortTypeToJson(
    enums.HzngoV1EditorialFeedCategoryIdGetSortType?
        hzngoV1EditorialFeedCategoryIdGetSortType) {
  return hzngoV1EditorialFeedCategoryIdGetSortType?.value;
}

enums.HzngoV1EditorialFeedCategoryIdGetSortType
    hzngoV1EditorialFeedCategoryIdGetSortTypeFromJson(
  Object? hzngoV1EditorialFeedCategoryIdGetSortType, [
  enums.HzngoV1EditorialFeedCategoryIdGetSortType? defaultValue,
]) {
  return enums.HzngoV1EditorialFeedCategoryIdGetSortType.values
          .firstWhereOrNull(
              (e) => e.value == hzngoV1EditorialFeedCategoryIdGetSortType) ??
      defaultValue ??
      enums.HzngoV1EditorialFeedCategoryIdGetSortType.swaggerGeneratedUnknown;
}

List<String> hzngoV1EditorialFeedCategoryIdGetSortTypeListToJson(
    List<enums.HzngoV1EditorialFeedCategoryIdGetSortType>?
        hzngoV1EditorialFeedCategoryIdGetSortType) {
  if (hzngoV1EditorialFeedCategoryIdGetSortType == null) {
    return [];
  }

  return hzngoV1EditorialFeedCategoryIdGetSortType
      .map((e) => e.value!)
      .toList();
}

List<enums.HzngoV1EditorialFeedCategoryIdGetSortType>
    hzngoV1EditorialFeedCategoryIdGetSortTypeListFromJson(
  List? hzngoV1EditorialFeedCategoryIdGetSortType, [
  List<enums.HzngoV1EditorialFeedCategoryIdGetSortType>? defaultValue,
]) {
  if (hzngoV1EditorialFeedCategoryIdGetSortType == null) {
    return defaultValue ?? [];
  }

  return hzngoV1EditorialFeedCategoryIdGetSortType
      .map((e) =>
          hzngoV1EditorialFeedCategoryIdGetSortTypeFromJson(e.toString()))
      .toList();
}

List<enums.HzngoV1EditorialFeedCategoryIdGetSortType>?
    hzngoV1EditorialFeedCategoryIdGetSortTypeNullableListFromJson(
  List? hzngoV1EditorialFeedCategoryIdGetSortType, [
  List<enums.HzngoV1EditorialFeedCategoryIdGetSortType>? defaultValue,
]) {
  if (hzngoV1EditorialFeedCategoryIdGetSortType == null) {
    return defaultValue;
  }

  return hzngoV1EditorialFeedCategoryIdGetSortType
      .map((e) =>
          hzngoV1EditorialFeedCategoryIdGetSortTypeFromJson(e.toString()))
      .toList();
}

String? hzngoV1EditorialFeedCategoryIdGetSortDirectionToJson(
    enums.HzngoV1EditorialFeedCategoryIdGetSortDirection?
        hzngoV1EditorialFeedCategoryIdGetSortDirection) {
  return hzngoV1EditorialFeedCategoryIdGetSortDirection?.value;
}

enums.HzngoV1EditorialFeedCategoryIdGetSortDirection
    hzngoV1EditorialFeedCategoryIdGetSortDirectionFromJson(
  Object? hzngoV1EditorialFeedCategoryIdGetSortDirection, [
  enums.HzngoV1EditorialFeedCategoryIdGetSortDirection? defaultValue,
]) {
  return enums.HzngoV1EditorialFeedCategoryIdGetSortDirection.values
          .firstWhereOrNull((e) =>
              e.value == hzngoV1EditorialFeedCategoryIdGetSortDirection) ??
      defaultValue ??
      enums.HzngoV1EditorialFeedCategoryIdGetSortDirection
          .swaggerGeneratedUnknown;
}

List<String> hzngoV1EditorialFeedCategoryIdGetSortDirectionListToJson(
    List<enums.HzngoV1EditorialFeedCategoryIdGetSortDirection>?
        hzngoV1EditorialFeedCategoryIdGetSortDirection) {
  if (hzngoV1EditorialFeedCategoryIdGetSortDirection == null) {
    return [];
  }

  return hzngoV1EditorialFeedCategoryIdGetSortDirection
      .map((e) => e.value!)
      .toList();
}

List<enums.HzngoV1EditorialFeedCategoryIdGetSortDirection>
    hzngoV1EditorialFeedCategoryIdGetSortDirectionListFromJson(
  List? hzngoV1EditorialFeedCategoryIdGetSortDirection, [
  List<enums.HzngoV1EditorialFeedCategoryIdGetSortDirection>? defaultValue,
]) {
  if (hzngoV1EditorialFeedCategoryIdGetSortDirection == null) {
    return defaultValue ?? [];
  }

  return hzngoV1EditorialFeedCategoryIdGetSortDirection
      .map((e) =>
          hzngoV1EditorialFeedCategoryIdGetSortDirectionFromJson(e.toString()))
      .toList();
}

List<enums.HzngoV1EditorialFeedCategoryIdGetSortDirection>?
    hzngoV1EditorialFeedCategoryIdGetSortDirectionNullableListFromJson(
  List? hzngoV1EditorialFeedCategoryIdGetSortDirection, [
  List<enums.HzngoV1EditorialFeedCategoryIdGetSortDirection>? defaultValue,
]) {
  if (hzngoV1EditorialFeedCategoryIdGetSortDirection == null) {
    return defaultValue;
  }

  return hzngoV1EditorialFeedCategoryIdGetSortDirection
      .map((e) =>
          hzngoV1EditorialFeedCategoryIdGetSortDirectionFromJson(e.toString()))
      .toList();
}

String? phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandToJson(
    enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand?
        phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand) {
  return phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand?.value;
}

enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand
    phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandFromJson(
  Object? phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand, [
  enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand?
      defaultValue,
]) {
  return enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand
          .values
          .firstWhereOrNull((e) =>
              e.value ==
              phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand) ??
      defaultValue ??
      enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String>
    phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandListToJson(
        List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand>?
            phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand) {
  if (phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand == null) {
    return [];
  }

  return phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand>
    phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandListFromJson(
  List? phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand, [
  List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand>?
      defaultValue,
]) {
  if (phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand
      .map((e) =>
          phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandFromJson(
              e.toString()))
      .toList();
}

List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand>?
    phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandNullableListFromJson(
  List? phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand, [
  List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand>?
      defaultValue,
]) {
  if (phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand == null) {
    return defaultValue;
  }

  return phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemand
      .map((e) =>
          phsV1CustomersCustomerIdProfilesProfileIdASpotGetFilterOnDemandFromJson(
              e.toString()))
      .toList();
}

String? phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandToJson(
    enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand?
        phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand) {
  return phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
      ?.value;
}

enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
    phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandFromJson(
  Object? phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand, [
  enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand?
      defaultValue,
]) {
  return enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
          .values
          .firstWhereOrNull((e) =>
              e.value ==
              phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand) ??
      defaultValue ??
      enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String>
    phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandListToJson(
        List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand>?
            phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand) {
  if (phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand ==
      null) {
    return [];
  }

  return phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand>
    phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandListFromJson(
  List? phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand, [
  List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand>?
      defaultValue,
]) {
  if (phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand ==
      null) {
    return defaultValue ?? [];
  }

  return phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
      .map((e) =>
          phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandFromJson(
              e.toString()))
      .toList();
}

List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand>?
    phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandNullableListFromJson(
  List? phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand, [
  List<enums.PhsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand>?
      defaultValue,
]) {
  if (phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand ==
      null) {
    return defaultValue;
  }

  return phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemand
      .map((e) =>
          phsV1CustomersCustomerIdProfilesProfileIdASpotsGetFilterOnDemandFromJson(
              e.toString()))
      .toList();
}

String? phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandToJson(
    enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand?
        phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand) {
  return phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
      ?.value;
}

enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
    phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandFromJson(
  Object? phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand, [
  enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand?
      defaultValue,
]) {
  return enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
          .values
          .firstWhereOrNull((e) =>
              e.value ==
              phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand) ??
      defaultValue ??
      enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String>
    phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandListToJson(
        List<enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand>?
            phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand) {
  if (phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand ==
      null) {
    return [];
  }

  return phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand>
    phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandListFromJson(
  List? phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand, [
  List<enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand>?
      defaultValue,
]) {
  if (phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand ==
      null) {
    return defaultValue ?? [];
  }

  return phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
      .map((e) =>
          phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandFromJson(
              e.toString()))
      .toList();
}

List<enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand>?
    phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandNullableListFromJson(
  List? phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand, [
  List<enums.PhsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand>?
      defaultValue,
]) {
  if (phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand ==
      null) {
    return defaultValue;
  }

  return phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemand
      .map((e) =>
          phsV1CustomersCustomerIdProfilesProfileIdScreenGetFilterOnDemandFromJson(
              e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
