// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'personalization_service.enums.swagger.dart' as enums;
export 'personalization_service.enums.swagger.dart';

part 'personalization_service.swagger.chopper.dart';
part 'personalization_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PersonalizationService extends ChopperService {
  static PersonalizationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PersonalizationService(client);
    }

    final newClient = ChopperClient(
        services: [_$PersonalizationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$PersonalizationService(newClient);
  }

  ///Retrieve available profile colors for a given country
  ///@param country
  Future<chopper.Response<Object>> v1CommonsAvailableColoursGet({
    String? country,
    String? cacheControl,
  }) {
    return _v1CommonsAvailableColoursGet(
        country: country, cacheControl: cacheControl);
  }

  ///Retrieve available profile colors for a given country
  ///@param country
  @Get(path: '/v1/commons/availableColours')
  Future<chopper.Response<Object>> _v1CommonsAvailableColoursGet({
    @Query('country') String? country,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve genre information for a given language
  ///@param language
  Future<chopper.Response<Genre>> v1CommonsAvailableGenresGet({
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Genre, () => Genre.fromJsonFactory);

    return _v1CommonsAvailableGenresGet(
        language: language, cacheControl: cacheControl);
  }

  ///Retrieve genre information for a given language
  ///@param language
  @Get(path: '/v1/commons/availableGenres')
  Future<chopper.Response<Genre>> _v1CommonsAvailableGenresGet({
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve a list of available colour maps for a specific country
  ///@param country
  Future<chopper.Response<List<Map>>> v2CommonsAvailableColoursGet({
    String? country,
    String? cacheControl,
  }) {
    return _v2CommonsAvailableColoursGet(
        country: country, cacheControl: cacheControl);
  }

  ///Retrieve a list of available colour maps for a specific country
  ///@param country
  @Get(path: '/v2/commons/availableColours')
  Future<chopper.Response<List<Map>>> _v2CommonsAvailableColoursGet({
    @Query('country') String? country,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve genre information for a given language
  ///@param language Language
  Future<chopper.Response<List<GenreV2Result>>> v2CommonsAvailableGenresGet({
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GenreV2Result, () => GenreV2Result.fromJsonFactory);

    return _v2CommonsAvailableGenresGet(
        language: language, cacheControl: cacheControl);
  }

  ///Retrieve genre information for a given language
  ///@param language Language
  @Get(path: '/v2/commons/availableGenres')
  Future<chopper.Response<List<GenreV2Result>>> _v2CommonsAvailableGenresGet({
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve customer information
  ///@param customerId
  Future<chopper.Response<CpsCustomerResponse>> v1CpsCustomerCustomerIdGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CpsCustomerResponse, () => CpsCustomerResponse.fromJsonFactory);

    return _v1CpsCustomerCustomerIdGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve customer information
  ///@param customerId
  @Get(path: '/v1/cps/customer/{customerId}')
  Future<chopper.Response<CpsCustomerResponse>> _v1CpsCustomerCustomerIdGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Purge customer from Datastore
  ///@param customerId
  Future<chopper.Response> v1CpsCustomerCustomerIdDelete({
    required String? customerId,
    String? cacheControl,
  }) {
    return _v1CpsCustomerCustomerIdDelete(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Purge customer from Datastore
  ///@param customerId
  @Delete(path: '/v1/cps/customer/{customerId}')
  Future<chopper.Response> _v1CpsCustomerCustomerIdDelete({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Reset the given pin type for given customer
  ///@param customerId The customer Id
  ///@param pinType The pin type
  Future<chopper.Response> v1CpsCustomerCustomerIdResetPinGet({
    required String? customerId,
    required enums.V1CpsCustomerCustomerIdResetPinGetPinType? pinType,
    String? cacheControl,
  }) {
    return _v1CpsCustomerCustomerIdResetPinGet(
        customerId: customerId,
        pinType: pinType?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Reset the given pin type for given customer
  ///@param customerId The customer Id
  ///@param pinType The pin type
  @Get(path: '/v1/cps/customer/{customerId}/resetPin')
  Future<chopper.Response> _v1CpsCustomerCustomerIdResetPinGet({
    @Path('customerId') required String? customerId,
    @Query('pinType') required String? pinType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update customer status
  ///@param customerId
  Future<chopper.Response> v1CpsCustomerCustomerIdStatusPut({
    required String? customerId,
    String? cacheControl,
    required String? body,
  }) {
    return _v1CpsCustomerCustomerIdStatusPut(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Update customer status
  ///@param customerId
  @Put(
    path: '/v1/cps/customer/{customerId}/status',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CpsCustomerCustomerIdStatusPut({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required String? body,
  });

  ///Update customer
  Future<chopper.Response> v1CpsCustomerPut({
    String? cacheControl,
    required CpsUpdateCustomerRequest? body,
  }) {
    return _v1CpsCustomerPut(cacheControl: cacheControl, body: body);
  }

  ///Update customer
  @Put(
    path: '/v1/cps/customer',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CpsCustomerPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CpsUpdateCustomerRequest? body,
  });

  ///Create customer
  Future<chopper.Response> v1CpsCustomerPost({
    String? cacheControl,
    required CpsCustomerRequest? body,
  }) {
    return _v1CpsCustomerPost(cacheControl: cacheControl, body: body);
  }

  ///Create customer
  @Post(
    path: '/v1/cps/customer',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CpsCustomerPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CpsCustomerRequest? body,
  });

  ///Update CPS customer ADS opt-in (advanced advertising)
  ///@param customerId
  Future<chopper.Response> v1CpsCustomerCustomerIdUpdateAvAdPut({
    required String? customerId,
    String? cacheControl,
    required AdvancedAdvertising? body,
  }) {
    return _v1CpsCustomerCustomerIdUpdateAvAdPut(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Update CPS customer ADS opt-in (advanced advertising)
  ///@param customerId
  @Put(
    path: '/v1/cps/customer/{customerId}/updateAvAd',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CpsCustomerCustomerIdUpdateAvAdPut({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AdvancedAdvertising? body,
  });

  ///Retrieve customer
  ///@param customerId
  ///@param with
  ///@param advertisementDeviceId
  Future<chopper.Response<Customer>> v1CustomerCustomerIdGet({
    required String? customerId,
    String? $with,
    String? advertisementDeviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Customer, () => Customer.fromJsonFactory);

    return _v1CustomerCustomerIdGet(
        customerId: customerId,
        $with: $with,
        advertisementDeviceId: advertisementDeviceId,
        cacheControl: cacheControl);
  }

  ///Retrieve customer
  ///@param customerId
  ///@param with
  ///@param advertisementDeviceId
  @Get(path: '/v1/customer/{customerId}')
  Future<chopper.Response<Customer>> _v1CustomerCustomerIdGet({
    @Path('customerId') required String? customerId,
    @Query('with') String? $with,
    @Query('advertisementDeviceId') String? advertisementDeviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response> v1CustomerCustomerIdPut({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
    required UpdateCustomerRequest? body,
  }) {
    return _v1CustomerCustomerIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Put(
    path: '/v1/customer/{customerId}',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomerCustomerIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required UpdateCustomerRequest? body,
  });

  ///Reset pin for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response<ResetPinResponse>> v1CustomerCustomerIdResetPinGet({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ResetPinResponse, () => ResetPinResponse.fromJsonFactory);

    return _v1CustomerCustomerIdResetPinGet(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl);
  }

  ///Reset pin for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/resetPin')
  Future<chopper.Response<ResetPinResponse>> _v1CustomerCustomerIdResetPinGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify Pin
  ///@param customerId
  Future<chopper.Response<PinVerificationResponse>>
      v1CustomerCustomerIdVerifyPinPost({
    required String? customerId,
    String? cacheControl,
    required PinVerificationRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        PinVerificationResponse, () => PinVerificationResponse.fromJsonFactory);

    return _v1CustomerCustomerIdVerifyPinPost(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Verify Pin
  ///@param customerId
  @Post(
    path: '/v1/customer/{customerId}/verifyPin',
    optionalBody: true,
  )
  Future<chopper.Response<PinVerificationResponse>>
      _v1CustomerCustomerIdVerifyPinPost({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PinVerificationRequest? body,
  });

  ///Retrieve customer information by device Id
  ///@param user-agent
  ///@param X-Dev The device Id
  ///@param byDeviceId
  ///@param with
  ///@param advertisementDeviceId
  Future<chopper.Response<Customer>> v1CustomerGet({
    String? userAgent,
    String? xDev,
    String? byDeviceId,
    String? $with,
    String? advertisementDeviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Customer, () => Customer.fromJsonFactory);

    return _v1CustomerGet(
        userAgent: userAgent,
        xDev: xDev,
        byDeviceId: byDeviceId,
        $with: $with,
        advertisementDeviceId: advertisementDeviceId,
        cacheControl: cacheControl);
  }

  ///Retrieve customer information by device Id
  ///@param user-agent
  ///@param X-Dev The device Id
  ///@param byDeviceId
  ///@param with
  ///@param advertisementDeviceId
  @Get(path: '/v1/customer')
  Future<chopper.Response<Customer>> _v1CustomerGet({
    @Header('user-agent') String? userAgent,
    @Header('X-Dev') String? xDev,
    @Query('byDeviceId') String? byDeviceId,
    @Query('with') String? $with,
    @Query('advertisementDeviceId') String? advertisementDeviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve device information for given customer
  ///@param X-Dev The device Id
  ///@param user-agent
  ///@param customerId
  ///@param deviceId
  Future<chopper.Response<Device>> v1CustomerCustomerIdDevicesDeviceIdGet({
    String? xDev,
    String? userAgent,
    required String? customerId,
    required String? deviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Device, () => Device.fromJsonFactory);

    return _v1CustomerCustomerIdDevicesDeviceIdGet(
        xDev: xDev,
        userAgent: userAgent,
        customerId: customerId,
        deviceId: deviceId,
        cacheControl: cacheControl);
  }

  ///Retrieve device information for given customer
  ///@param X-Dev The device Id
  ///@param user-agent
  ///@param customerId
  ///@param deviceId
  @Get(path: '/v1/customer/{customerId}/devices/{deviceId}')
  Future<chopper.Response<Device>> _v1CustomerCustomerIdDevicesDeviceIdGet({
    @Header('X-Dev') String? xDev,
    @Header('user-agent') String? userAgent,
    @Path('customerId') required String? customerId,
    @Path('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update given device for a given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param deviceId
  Future<chopper.Response> v1CustomerCustomerIdDevicesDeviceIdPut({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    required String? deviceId,
    String? cacheControl,
    required UpdateDeviceRequest? body,
  }) {
    return _v1CustomerCustomerIdDevicesDeviceIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        deviceId: deviceId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update given device for a given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param deviceId
  @Put(
    path: '/v1/customer/{customerId}/devices/{deviceId}',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomerCustomerIdDevicesDeviceIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required UpdateDeviceRequest? body,
  });

  ///Retrieve all device informations for given customer
  ///@param customerId
  Future<chopper.Response<List<Device>>> v1CustomerCustomerIdDevicesGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Device, () => Device.fromJsonFactory);

    return _v1CustomerCustomerIdDevicesGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve all device informations for given customer
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/devices')
  Future<chopper.Response<List<Device>>> _v1CustomerCustomerIdDevicesGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update profile for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  Future<chopper.Response> v1CustomerCustomerIdProfilesProfileIdPut({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    required String? profileId,
    String? cacheControl,
    required ProfileRequest? body,
  }) {
    return _v1CustomerCustomerIdProfilesProfileIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        profileId: profileId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update profile for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  @Put(
    path: '/v1/customer/{customerId}/profiles/{profileId}',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomerCustomerIdProfilesProfileIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ProfileRequest? body,
  });

  ///Delete profile for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  Future<chopper.Response> v1CustomerCustomerIdProfilesProfileIdDelete({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    required String? profileId,
    String? cacheControl,
  }) {
    return _v1CustomerCustomerIdProfilesProfileIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Delete profile for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  @Delete(path: '/v1/customer/{customerId}/profiles/{profileId}')
  Future<chopper.Response> _v1CustomerCustomerIdProfilesProfileIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve list of profiles for given customer
  ///@param customerId
  Future<chopper.Response<List<Profile>>> v1CustomerCustomerIdProfilesGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Profile, () => Profile.fromJsonFactory);

    return _v1CustomerCustomerIdProfilesGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve list of profiles for given customer
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/profiles')
  Future<chopper.Response<List<Profile>>> _v1CustomerCustomerIdProfilesGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create profile for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response<ProfileId>> v1CustomerCustomerIdProfilesPost({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
    required ProfileRequest? body,
  }) {
    generatedMapping.putIfAbsent(ProfileId, () => ProfileId.fromJsonFactory);

    return _v1CustomerCustomerIdProfilesPost(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create profile for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Post(
    path: '/v1/customer/{customerId}/profiles',
    optionalBody: true,
  )
  Future<chopper.Response<ProfileId>> _v1CustomerCustomerIdProfilesPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ProfileRequest? body,
  });

  ///Get reminders for given customer
  ///@param customerId The customer Id
  Future<chopper.Response<List<Reminder>>> v1CustomerCustomerIdRemindersGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Reminder, () => Reminder.fromJsonFactory);

    return _v1CustomerCustomerIdRemindersGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Get reminders for given customer
  ///@param customerId The customer Id
  @Get(path: '/v1/customer/{customerId}/reminders')
  Future<chopper.Response<List<Reminder>>> _v1CustomerCustomerIdRemindersGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set reminder for given customer
  ///@param customerId The customer Id
  Future<chopper.Response<ReminderId>> v1CustomerCustomerIdRemindersPost({
    required String? customerId,
    String? cacheControl,
    required Reminder? body,
  }) {
    generatedMapping.putIfAbsent(ReminderId, () => ReminderId.fromJsonFactory);

    return _v1CustomerCustomerIdRemindersPost(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Set reminder for given customer
  ///@param customerId The customer Id
  @Post(
    path: '/v1/customer/{customerId}/reminders',
    optionalBody: true,
  )
  Future<chopper.Response<ReminderId>> _v1CustomerCustomerIdRemindersPost({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Reminder? body,
  });

  ///Delete a specific reminder for a given customer
  ///@param customerId The customer Id
  ///@param reminderId The reminder Id
  Future<chopper.Response> v1CustomerCustomerIdRemindersReminderIdDelete({
    required String? customerId,
    required String? reminderId,
    String? cacheControl,
  }) {
    return _v1CustomerCustomerIdRemindersReminderIdDelete(
        customerId: customerId,
        reminderId: reminderId,
        cacheControl: cacheControl);
  }

  ///Delete a specific reminder for a given customer
  ///@param customerId The customer Id
  ///@param reminderId The reminder Id
  @Delete(path: '/v1/customer/{customerId}/reminders/{reminderId}')
  Future<chopper.Response> _v1CustomerCustomerIdRemindersReminderIdDelete({
    @Path('customerId') required String? customerId,
    @Path('reminderId') required String? reminderId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Reset pin for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response<ResetPinV2Response>> v2CustomerCustomerIdResetPinGet({
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ResetPinV2Response, () => ResetPinV2Response.fromJsonFactory);

    return _v2CustomerCustomerIdResetPinGet(
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl);
  }

  ///Reset pin for given customer
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Get(path: '/v2/customer/{customerId}/resetPin')
  Future<chopper.Response<ResetPinV2Response>>
      _v2CustomerCustomerIdResetPinGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify Pin
  ///@param customerId
  Future<chopper.Response<PinVerificationV2Response>>
      v2CustomerCustomerIdVerifyPinPost({
    required String? customerId,
    String? cacheControl,
    required PinVerificationV2Request? body,
  }) {
    generatedMapping.putIfAbsent(PinVerificationV2Response,
        () => PinVerificationV2Response.fromJsonFactory);

    return _v2CustomerCustomerIdVerifyPinPost(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Verify Pin
  ///@param customerId
  @Post(
    path: '/v2/customer/{customerId}/verifyPin',
    optionalBody: true,
  )
  Future<chopper.Response<PinVerificationV2Response>>
      _v2CustomerCustomerIdVerifyPinPost({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PinVerificationV2Request? body,
  });

  ///Retrieve customer information by profile Id
  ///@param byProfileId
  ///@param with
  Future<chopper.Response<RengCustomerInformation>> v1RengCustomerGet({
    String? byProfileId,
    String? $with,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RengCustomerInformation, () => RengCustomerInformation.fromJsonFactory);

    return _v1RengCustomerGet(
        byProfileId: byProfileId, $with: $with, cacheControl: cacheControl);
  }

  ///Retrieve customer information by profile Id
  ///@param byProfileId
  ///@param with
  @Get(path: '/v1/reng/customer')
  Future<chopper.Response<RengCustomerInformation>> _v1RengCustomerGet({
    @Query('byProfileId') String? byProfileId,
    @Query('with') String? $with,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get customer config
  Future<chopper.Response> v1ConfigsCustomerconfigGet({String? cacheControl}) {
    return _v1ConfigsCustomerconfigGet(cacheControl: cacheControl);
  }

  ///Get customer config
  @Get(path: '/v1/configs/customerconfig')
  Future<chopper.Response> _v1ConfigsCustomerconfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get customer config
  Future<chopper.Response> v1ConfigsDeviceconfigGet({String? cacheControl}) {
    return _v1ConfigsDeviceconfigGet(cacheControl: cacheControl);
  }

  ///Get customer config
  @Get(path: '/v1/configs/deviceconfig')
  Future<chopper.Response> _v1ConfigsDeviceconfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get shared profile config
  Future<chopper.Response> v1ConfigsSharedprofileconfigGet(
      {String? cacheControl}) {
    return _v1ConfigsSharedprofileconfigGet(cacheControl: cacheControl);
  }

  ///Get shared profile config
  @Get(path: '/v1/configs/sharedprofileconfig')
  Future<chopper.Response> _v1ConfigsSharedprofileconfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Create OTT device for given customer. If device already exists, updates its deviceName.
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response> v1OttCustomerIdDevicePost({
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
    required CreateOttDeviceRequest? body,
  }) {
    return _v1OttCustomerIdDevicePost(
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create OTT device for given customer. If device already exists, updates its deviceName.
  ///@param X-Go-Dev
  ///@param customerId
  @Post(
    path: '/v1/ott/{customerId}/device',
    optionalBody: true,
  )
  Future<chopper.Response> _v1OttCustomerIdDevicePost({
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CreateOttDeviceRequest? body,
  });

  ///Update OTT device for given customer
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  Future<chopper.Response> v1CustomerCustomerIdOttDrmDeviceIdPut({
    String? xGoDev,
    required String? customerId,
    required String? drmDeviceId,
    String? cacheControl,
    required UpdateOttDeviceRequest? body,
  }) {
    return _v1CustomerCustomerIdOttDrmDeviceIdPut(
        xGoDev: xGoDev,
        customerId: customerId,
        drmDeviceId: drmDeviceId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update OTT device for given customer
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  @Put(
    path: '/v1/customer/{customerId}/ott/{drmDeviceId}',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomerCustomerIdOttDrmDeviceIdPut({
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('drmDeviceId') required String? drmDeviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required UpdateOttDeviceRequest? body,
  });

  ///Delete OTT device for given customer
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  Future<chopper.Response> v1CustomerCustomerIdOttDrmDeviceIdDelete({
    String? xGoDev,
    required String? customerId,
    required String? drmDeviceId,
    String? cacheControl,
  }) {
    return _v1CustomerCustomerIdOttDrmDeviceIdDelete(
        xGoDev: xGoDev,
        customerId: customerId,
        drmDeviceId: drmDeviceId,
        cacheControl: cacheControl);
  }

  ///Delete OTT device for given customer
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  @Delete(path: '/v1/customer/{customerId}/ott/{drmDeviceId}')
  Future<chopper.Response> _v1CustomerCustomerIdOttDrmDeviceIdDelete({
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('drmDeviceId') required String? drmDeviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get OTT devices for given customer
  ///@param customerId
  Future<chopper.Response<CustomerOttDevices>>
      v1CustomerCustomerIdDevicesOttGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CustomerOttDevices, () => CustomerOttDevices.fromJsonFactory);

    return _v1CustomerCustomerIdDevicesOttGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Get OTT devices for given customer
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/devices/ott')
  Future<chopper.Response<CustomerOttDevices>>
      _v1CustomerCustomerIdDevicesOttGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve advertisementDeviceId for a customer
  ///@param customerId
  Future<chopper.Response<AdvertisementDeviceIdResponse>>
      v1CustomerCustomerIdAdvertisementDeviceIdGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AdvertisementDeviceIdResponse,
        () => AdvertisementDeviceIdResponse.fromJsonFactory);

    return _v1CustomerCustomerIdAdvertisementDeviceIdGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve advertisementDeviceId for a customer
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/advertisementDeviceId')
  Future<chopper.Response<AdvertisementDeviceIdResponse>>
      _v1CustomerCustomerIdAdvertisementDeviceIdGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Bulk update customer information
  Future<chopper.Response> customerDataPut({
    String? cacheControl,
    required BulkUpdateCustomerRequest? body,
  }) {
    return _customerDataPut(cacheControl: cacheControl, body: body);
  }

  ///Bulk update customer information
  @Put(
    path: '/customerData',
    optionalBody: true,
  )
  Future<chopper.Response> _customerDataPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required BulkUpdateCustomerRequest? body,
  });

  ///Bulk update of OBO customer information
  Future<chopper.Response> oboCustomerDataPut({
    String? cacheControl,
    required BulkUpdateOboCustomerRequest? body,
  }) {
    return _oboCustomerDataPut(cacheControl: cacheControl, body: body);
  }

  ///Bulk update of OBO customer information
  @Put(
    path: '/oboCustomerData',
    optionalBody: true,
  )
  Future<chopper.Response> _oboCustomerDataPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required BulkUpdateOboCustomerRequest? body,
  });

  ///Delete OTT device for given customer
  ///@param customerId
  Future<chopper.Response>
      v1InspectionServiceCustomerIdRegisteredOttDevicesDelete({
    required String? customerId,
    String? cacheControl,
  }) {
    return _v1InspectionServiceCustomerIdRegisteredOttDevicesDelete(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Delete OTT device for given customer
  ///@param customerId
  @Delete(path: '/v1/inspection-service/{customerId}/registeredOttDevices')
  Future<chopper.Response>
      _v1InspectionServiceCustomerIdRegisteredOttDevicesDelete({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Customer migration from current to new customerId
  ///@param X-cus The customer Id
  Future<chopper.Response> v1CustomersMigratePost({
    String? xCus = 'X-Cus',
    String? cacheControl,
    required CustomerMigrationRequest? body,
  }) {
    return _v1CustomersMigratePost(
        xCus: xCus, cacheControl: cacheControl, body: body);
  }

  ///Customer migration from current to new customerId
  ///@param X-cus The customer Id
  @Post(
    path: '/v1/customers/migrate',
    optionalBody: true,
  )
  Future<chopper.Response> _v1CustomersMigratePost({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required CustomerMigrationRequest? body,
  });
}

@JsonSerializable(explicitToJson: true)
class CustomerAccessError {
  CustomerAccessError({
    this.errorMessage,
  });

  factory CustomerAccessError.fromJson(Map<String, dynamic> json) =>
      _$CustomerAccessErrorFromJson(json);

  static const toJsonFactory = _$CustomerAccessErrorToJson;
  Map<String, dynamic> toJson() => _$CustomerAccessErrorToJson(this);

  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  static const fromJsonFactory = _$CustomerAccessErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerAccessError &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errorMessage) ^ runtimeType.hashCode;
}

extension $CustomerAccessErrorExtension on CustomerAccessError {
  CustomerAccessError copyWith({String? errorMessage}) {
    return CustomerAccessError(errorMessage: errorMessage ?? this.errorMessage);
  }

  CustomerAccessError copyWithWrapped({Wrapped<String?>? errorMessage}) {
    return CustomerAccessError(
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage));
  }
}

@JsonSerializable(explicitToJson: true)
class Features {
  Features({
    this.features,
  });

  factory Features.fromJson(Map<String, dynamic> json) =>
      _$FeaturesFromJson(json);

  static const toJsonFactory = _$FeaturesToJson;
  Map<String, dynamic> toJson() => _$FeaturesToJson(this);

  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$FeaturesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Features &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(features) ^ runtimeType.hashCode;
}

extension $FeaturesExtension on Features {
  Features copyWith({List<String>? features}) {
    return Features(features: features ?? this.features);
  }

  Features copyWithWrapped({Wrapped<List<String>?>? features}) {
    return Features(
        features: (features != null ? features.value : this.features));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    this.features,
    this.images,
    this.genreTranslations,
    this.termIds,
    this.type,
    this.language,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <Features>[])
  final List<Features>? features;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <String>[])
  final List<String>? images;
  @JsonKey(
      name: 'genreTranslations', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genreTranslations;
  @JsonKey(name: 'termIds', includeIfNull: false, defaultValue: <TermIds>[])
  final List<TermIds>? termIds;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  static const fromJsonFactory = _$GenreFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.genreTranslations, genreTranslations) ||
                const DeepCollectionEquality()
                    .equals(other.genreTranslations, genreTranslations)) &&
            (identical(other.termIds, termIds) ||
                const DeepCollectionEquality()
                    .equals(other.termIds, termIds)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(features) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(genreTranslations) ^
      const DeepCollectionEquality().hash(termIds) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(language) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith(
      {List<Features>? features,
      List<String>? images,
      List<String>? genreTranslations,
      List<TermIds>? termIds,
      String? type,
      String? language}) {
    return Genre(
        features: features ?? this.features,
        images: images ?? this.images,
        genreTranslations: genreTranslations ?? this.genreTranslations,
        termIds: termIds ?? this.termIds,
        type: type ?? this.type,
        language: language ?? this.language);
  }

  Genre copyWithWrapped(
      {Wrapped<List<Features>?>? features,
      Wrapped<List<String>?>? images,
      Wrapped<List<String>?>? genreTranslations,
      Wrapped<List<TermIds>?>? termIds,
      Wrapped<String?>? type,
      Wrapped<String?>? language}) {
    return Genre(
        features: (features != null ? features.value : this.features),
        images: (images != null ? images.value : this.images),
        genreTranslations: (genreTranslations != null
            ? genreTranslations.value
            : this.genreTranslations),
        termIds: (termIds != null ? termIds.value : this.termIds),
        type: (type != null ? type.value : this.type),
        language: (language != null ? language.value : this.language));
  }
}

@JsonSerializable(explicitToJson: true)
class TermIds {
  TermIds({
    this.termIds,
  });

  factory TermIds.fromJson(Map<String, dynamic> json) =>
      _$TermIdsFromJson(json);

  static const toJsonFactory = _$TermIdsToJson;
  Map<String, dynamic> toJson() => _$TermIdsToJson(this);

  @JsonKey(name: 'termIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? termIds;
  static const fromJsonFactory = _$TermIdsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TermIds &&
            (identical(other.termIds, termIds) ||
                const DeepCollectionEquality().equals(other.termIds, termIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(termIds) ^ runtimeType.hashCode;
}

extension $TermIdsExtension on TermIds {
  TermIds copyWith({List<String>? termIds}) {
    return TermIds(termIds: termIds ?? this.termIds);
  }

  TermIds copyWithWrapped({Wrapped<List<String>?>? termIds}) {
    return TermIds(termIds: (termIds != null ? termIds.value : this.termIds));
  }
}

@JsonSerializable(explicitToJson: true)
class GenreV2Result {
  GenreV2Result({
    this.image,
    this.name,
    this.termIds,
    this.features,
  });

  factory GenreV2Result.fromJson(Map<String, dynamic> json) =>
      _$GenreV2ResultFromJson(json);

  static const toJsonFactory = _$GenreV2ResultToJson;
  Map<String, dynamic> toJson() => _$GenreV2ResultToJson(this);

  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'termIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? termIds;
  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$GenreV2ResultFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenreV2Result &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.termIds, termIds) ||
                const DeepCollectionEquality()
                    .equals(other.termIds, termIds)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(termIds) ^
      const DeepCollectionEquality().hash(features) ^
      runtimeType.hashCode;
}

extension $GenreV2ResultExtension on GenreV2Result {
  GenreV2Result copyWith(
      {String? image,
      String? name,
      List<String>? termIds,
      List<String>? features}) {
    return GenreV2Result(
        image: image ?? this.image,
        name: name ?? this.name,
        termIds: termIds ?? this.termIds,
        features: features ?? this.features);
  }

  GenreV2Result copyWithWrapped(
      {Wrapped<String?>? image,
      Wrapped<String?>? name,
      Wrapped<List<String>?>? termIds,
      Wrapped<List<String>?>? features}) {
    return GenreV2Result(
        image: (image != null ? image.value : this.image),
        name: (name != null ? name.value : this.name),
        termIds: (termIds != null ? termIds.value : this.termIds),
        features: (features != null ? features.value : this.features));
  }
}

@JsonSerializable(explicitToJson: true)
class Customer {
  Customer({
    this.lastModified,
    this.customerOptIns,
    this.profiles,
    this.customerId,
    required this.hashedCustomerId,
    this.assignedDevices,
    this.ottDeviceLimit,
    this.ottDevices,
    this.customerStatus,
    this.autoDeleteFunction,
    this.deleteRecordingReminder,
    this.recordingRetentionPeriod,
    this.countryId,
    this.cityId,
    this.originalCityId,
    this.lockedChannels,
    this.pin,
    this.defaultHhStb,
    this.statusModifiedDate,
    this.ageLock,
    this.deleteRecordingReminderModifiedAt,
    this.dvrPrePadding,
    this.dvrPostPadding,
    this.isFtiPassed,
    this.recordingRetentionPeriodModifiedAt,
    this.autoDeleteFunctionModifiedAt,
    this.advertisementDeviceId,
    this.upgradedHZN4,
    this.zipCode,
    this.serviceType,
  });

  factory Customer.fromJson(Map<String, dynamic> json) =>
      _$CustomerFromJson(json);

  static const toJsonFactory = _$CustomerToJson;
  Map<String, dynamic> toJson() => _$CustomerToJson(this);

  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(
      name: 'customerOptIns',
      includeIfNull: false,
      defaultValue: <CustomerOptIn>[])
  final List<CustomerOptIn>? customerOptIns;
  @JsonKey(name: 'profiles', includeIfNull: false, defaultValue: <Profile>[])
  final List<Profile>? profiles;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'hashedCustomerId', includeIfNull: false, defaultValue: '')
  final String hashedCustomerId;
  @JsonKey(
      name: 'assignedDevices', includeIfNull: false, defaultValue: <Device>[])
  final List<Device>? assignedDevices;
  @JsonKey(name: 'ottDeviceLimit', includeIfNull: false)
  final int? ottDeviceLimit;
  @JsonKey(
      name: 'ottDevices',
      includeIfNull: false,
      defaultValue: <CustomerOttDevice>[])
  final List<CustomerOttDevice>? ottDevices;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: customerCustomerStatusToJson,
    fromJson: customerCustomerStatusFromJson,
  )
  final enums.CustomerCustomerStatus? customerStatus;
  @JsonKey(name: 'autoDeleteFunction', includeIfNull: false)
  final bool? autoDeleteFunction;
  @JsonKey(name: 'deleteRecordingReminder', includeIfNull: false)
  final bool? deleteRecordingReminder;
  @JsonKey(name: 'recordingRetentionPeriod', includeIfNull: false)
  final int? recordingRetentionPeriod;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'originalCityId', includeIfNull: false)
  final int? originalCityId;
  @JsonKey(
      name: 'lockedChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? lockedChannels;
  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  @JsonKey(name: 'defaultHhStb', includeIfNull: false, defaultValue: '')
  final String? defaultHhStb;
  @JsonKey(name: 'statusModifiedDate', includeIfNull: false)
  final DateTime? statusModifiedDate;
  @JsonKey(name: 'ageLock', includeIfNull: false)
  final int? ageLock;
  @JsonKey(name: 'deleteRecordingReminderModifiedAt', includeIfNull: false)
  final DateTime? deleteRecordingReminderModifiedAt;
  @JsonKey(name: 'dvrPrePadding', includeIfNull: false)
  final int? dvrPrePadding;
  @JsonKey(name: 'dvrPostPadding', includeIfNull: false)
  final int? dvrPostPadding;
  @JsonKey(name: 'isFtiPassed', includeIfNull: false)
  final bool? isFtiPassed;
  @JsonKey(name: 'recordingRetentionPeriodModifiedAt', includeIfNull: false)
  final DateTime? recordingRetentionPeriodModifiedAt;
  @JsonKey(name: 'autoDeleteFunctionModifiedAt', includeIfNull: false)
  final DateTime? autoDeleteFunctionModifiedAt;
  @JsonKey(
      name: 'advertisementDeviceId', includeIfNull: false, defaultValue: '')
  final String? advertisementDeviceId;
  @JsonKey(name: 'upgradedHZN4', includeIfNull: false)
  final DateTime? upgradedHZN4;
  @JsonKey(name: 'zipCode', includeIfNull: false, defaultValue: '')
  final String? zipCode;
  @JsonKey(name: 'serviceType', includeIfNull: false, defaultValue: '')
  final String? serviceType;
  static const fromJsonFactory = _$CustomerFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Customer &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.customerOptIns, customerOptIns) ||
                const DeepCollectionEquality()
                    .equals(other.customerOptIns, customerOptIns)) &&
            (identical(other.profiles, profiles) ||
                const DeepCollectionEquality()
                    .equals(other.profiles, profiles)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.hashedCustomerId, hashedCustomerId) ||
                const DeepCollectionEquality()
                    .equals(other.hashedCustomerId, hashedCustomerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.ottDeviceLimit, ottDeviceLimit) ||
                const DeepCollectionEquality()
                    .equals(other.ottDeviceLimit, ottDeviceLimit)) &&
            (identical(other.ottDevices, ottDevices) ||
                const DeepCollectionEquality()
                    .equals(other.ottDevices, ottDevices)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.autoDeleteFunction, autoDeleteFunction) ||
                const DeepCollectionEquality()
                    .equals(other.autoDeleteFunction, autoDeleteFunction)) &&
            (identical(other.deleteRecordingReminder, deleteRecordingReminder) ||
                const DeepCollectionEquality().equals(
                    other.deleteRecordingReminder, deleteRecordingReminder)) &&
            (identical(other.recordingRetentionPeriod, recordingRetentionPeriod) ||
                const DeepCollectionEquality().equals(
                    other.recordingRetentionPeriod,
                    recordingRetentionPeriod)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.originalCityId, originalCityId) ||
                const DeepCollectionEquality()
                    .equals(other.originalCityId, originalCityId)) &&
            (identical(other.lockedChannels, lockedChannels) ||
                const DeepCollectionEquality()
                    .equals(other.lockedChannels, lockedChannels)) &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.defaultHhStb, defaultHhStb) ||
                const DeepCollectionEquality()
                    .equals(other.defaultHhStb, defaultHhStb)) &&
            (identical(other.statusModifiedDate, statusModifiedDate) ||
                const DeepCollectionEquality().equals(other.statusModifiedDate, statusModifiedDate)) &&
            (identical(other.ageLock, ageLock) || const DeepCollectionEquality().equals(other.ageLock, ageLock)) &&
            (identical(other.deleteRecordingReminderModifiedAt, deleteRecordingReminderModifiedAt) || const DeepCollectionEquality().equals(other.deleteRecordingReminderModifiedAt, deleteRecordingReminderModifiedAt)) &&
            (identical(other.dvrPrePadding, dvrPrePadding) || const DeepCollectionEquality().equals(other.dvrPrePadding, dvrPrePadding)) &&
            (identical(other.dvrPostPadding, dvrPostPadding) || const DeepCollectionEquality().equals(other.dvrPostPadding, dvrPostPadding)) &&
            (identical(other.isFtiPassed, isFtiPassed) || const DeepCollectionEquality().equals(other.isFtiPassed, isFtiPassed)) &&
            (identical(other.recordingRetentionPeriodModifiedAt, recordingRetentionPeriodModifiedAt) || const DeepCollectionEquality().equals(other.recordingRetentionPeriodModifiedAt, recordingRetentionPeriodModifiedAt)) &&
            (identical(other.autoDeleteFunctionModifiedAt, autoDeleteFunctionModifiedAt) || const DeepCollectionEquality().equals(other.autoDeleteFunctionModifiedAt, autoDeleteFunctionModifiedAt)) &&
            (identical(other.advertisementDeviceId, advertisementDeviceId) || const DeepCollectionEquality().equals(other.advertisementDeviceId, advertisementDeviceId)) &&
            (identical(other.upgradedHZN4, upgradedHZN4) || const DeepCollectionEquality().equals(other.upgradedHZN4, upgradedHZN4)) &&
            (identical(other.zipCode, zipCode) || const DeepCollectionEquality().equals(other.zipCode, zipCode)) &&
            (identical(other.serviceType, serviceType) || const DeepCollectionEquality().equals(other.serviceType, serviceType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(customerOptIns) ^
      const DeepCollectionEquality().hash(profiles) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(hashedCustomerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(ottDeviceLimit) ^
      const DeepCollectionEquality().hash(ottDevices) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(autoDeleteFunction) ^
      const DeepCollectionEquality().hash(deleteRecordingReminder) ^
      const DeepCollectionEquality().hash(recordingRetentionPeriod) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(originalCityId) ^
      const DeepCollectionEquality().hash(lockedChannels) ^
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(defaultHhStb) ^
      const DeepCollectionEquality().hash(statusModifiedDate) ^
      const DeepCollectionEquality().hash(ageLock) ^
      const DeepCollectionEquality().hash(deleteRecordingReminderModifiedAt) ^
      const DeepCollectionEquality().hash(dvrPrePadding) ^
      const DeepCollectionEquality().hash(dvrPostPadding) ^
      const DeepCollectionEquality().hash(isFtiPassed) ^
      const DeepCollectionEquality().hash(recordingRetentionPeriodModifiedAt) ^
      const DeepCollectionEquality().hash(autoDeleteFunctionModifiedAt) ^
      const DeepCollectionEquality().hash(advertisementDeviceId) ^
      const DeepCollectionEquality().hash(upgradedHZN4) ^
      const DeepCollectionEquality().hash(zipCode) ^
      const DeepCollectionEquality().hash(serviceType) ^
      runtimeType.hashCode;
}

extension $CustomerExtension on Customer {
  Customer copyWith(
      {DateTime? lastModified,
      List<CustomerOptIn>? customerOptIns,
      List<Profile>? profiles,
      String? customerId,
      String? hashedCustomerId,
      List<Device>? assignedDevices,
      int? ottDeviceLimit,
      List<CustomerOttDevice>? ottDevices,
      enums.CustomerCustomerStatus? customerStatus,
      bool? autoDeleteFunction,
      bool? deleteRecordingReminder,
      int? recordingRetentionPeriod,
      String? countryId,
      int? cityId,
      int? originalCityId,
      List<String>? lockedChannels,
      String? pin,
      String? defaultHhStb,
      DateTime? statusModifiedDate,
      int? ageLock,
      DateTime? deleteRecordingReminderModifiedAt,
      int? dvrPrePadding,
      int? dvrPostPadding,
      bool? isFtiPassed,
      DateTime? recordingRetentionPeriodModifiedAt,
      DateTime? autoDeleteFunctionModifiedAt,
      String? advertisementDeviceId,
      DateTime? upgradedHZN4,
      String? zipCode,
      String? serviceType}) {
    return Customer(
        lastModified: lastModified ?? this.lastModified,
        customerOptIns: customerOptIns ?? this.customerOptIns,
        profiles: profiles ?? this.profiles,
        customerId: customerId ?? this.customerId,
        hashedCustomerId: hashedCustomerId ?? this.hashedCustomerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        ottDeviceLimit: ottDeviceLimit ?? this.ottDeviceLimit,
        ottDevices: ottDevices ?? this.ottDevices,
        customerStatus: customerStatus ?? this.customerStatus,
        autoDeleteFunction: autoDeleteFunction ?? this.autoDeleteFunction,
        deleteRecordingReminder:
            deleteRecordingReminder ?? this.deleteRecordingReminder,
        recordingRetentionPeriod:
            recordingRetentionPeriod ?? this.recordingRetentionPeriod,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        originalCityId: originalCityId ?? this.originalCityId,
        lockedChannels: lockedChannels ?? this.lockedChannels,
        pin: pin ?? this.pin,
        defaultHhStb: defaultHhStb ?? this.defaultHhStb,
        statusModifiedDate: statusModifiedDate ?? this.statusModifiedDate,
        ageLock: ageLock ?? this.ageLock,
        deleteRecordingReminderModifiedAt: deleteRecordingReminderModifiedAt ??
            this.deleteRecordingReminderModifiedAt,
        dvrPrePadding: dvrPrePadding ?? this.dvrPrePadding,
        dvrPostPadding: dvrPostPadding ?? this.dvrPostPadding,
        isFtiPassed: isFtiPassed ?? this.isFtiPassed,
        recordingRetentionPeriodModifiedAt:
            recordingRetentionPeriodModifiedAt ??
                this.recordingRetentionPeriodModifiedAt,
        autoDeleteFunctionModifiedAt:
            autoDeleteFunctionModifiedAt ?? this.autoDeleteFunctionModifiedAt,
        advertisementDeviceId:
            advertisementDeviceId ?? this.advertisementDeviceId,
        upgradedHZN4: upgradedHZN4 ?? this.upgradedHZN4,
        zipCode: zipCode ?? this.zipCode,
        serviceType: serviceType ?? this.serviceType);
  }

  Customer copyWithWrapped(
      {Wrapped<DateTime?>? lastModified,
      Wrapped<List<CustomerOptIn>?>? customerOptIns,
      Wrapped<List<Profile>?>? profiles,
      Wrapped<String?>? customerId,
      Wrapped<String>? hashedCustomerId,
      Wrapped<List<Device>?>? assignedDevices,
      Wrapped<int?>? ottDeviceLimit,
      Wrapped<List<CustomerOttDevice>?>? ottDevices,
      Wrapped<enums.CustomerCustomerStatus?>? customerStatus,
      Wrapped<bool?>? autoDeleteFunction,
      Wrapped<bool?>? deleteRecordingReminder,
      Wrapped<int?>? recordingRetentionPeriod,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<int?>? originalCityId,
      Wrapped<List<String>?>? lockedChannels,
      Wrapped<String?>? pin,
      Wrapped<String?>? defaultHhStb,
      Wrapped<DateTime?>? statusModifiedDate,
      Wrapped<int?>? ageLock,
      Wrapped<DateTime?>? deleteRecordingReminderModifiedAt,
      Wrapped<int?>? dvrPrePadding,
      Wrapped<int?>? dvrPostPadding,
      Wrapped<bool?>? isFtiPassed,
      Wrapped<DateTime?>? recordingRetentionPeriodModifiedAt,
      Wrapped<DateTime?>? autoDeleteFunctionModifiedAt,
      Wrapped<String?>? advertisementDeviceId,
      Wrapped<DateTime?>? upgradedHZN4,
      Wrapped<String?>? zipCode,
      Wrapped<String?>? serviceType}) {
    return Customer(
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        customerOptIns: (customerOptIns != null
            ? customerOptIns.value
            : this.customerOptIns),
        profiles: (profiles != null ? profiles.value : this.profiles),
        customerId: (customerId != null ? customerId.value : this.customerId),
        hashedCustomerId: (hashedCustomerId != null
            ? hashedCustomerId.value
            : this.hashedCustomerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        ottDeviceLimit: (ottDeviceLimit != null
            ? ottDeviceLimit.value
            : this.ottDeviceLimit),
        ottDevices: (ottDevices != null ? ottDevices.value : this.ottDevices),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        autoDeleteFunction: (autoDeleteFunction != null
            ? autoDeleteFunction.value
            : this.autoDeleteFunction),
        deleteRecordingReminder: (deleteRecordingReminder != null
            ? deleteRecordingReminder.value
            : this.deleteRecordingReminder),
        recordingRetentionPeriod: (recordingRetentionPeriod != null
            ? recordingRetentionPeriod.value
            : this.recordingRetentionPeriod),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        originalCityId: (originalCityId != null
            ? originalCityId.value
            : this.originalCityId),
        lockedChannels: (lockedChannels != null
            ? lockedChannels.value
            : this.lockedChannels),
        pin: (pin != null ? pin.value : this.pin),
        defaultHhStb:
            (defaultHhStb != null ? defaultHhStb.value : this.defaultHhStb),
        statusModifiedDate: (statusModifiedDate != null
            ? statusModifiedDate.value
            : this.statusModifiedDate),
        ageLock: (ageLock != null ? ageLock.value : this.ageLock),
        deleteRecordingReminderModifiedAt:
            (deleteRecordingReminderModifiedAt != null
                ? deleteRecordingReminderModifiedAt.value
                : this.deleteRecordingReminderModifiedAt),
        dvrPrePadding:
            (dvrPrePadding != null ? dvrPrePadding.value : this.dvrPrePadding),
        dvrPostPadding: (dvrPostPadding != null
            ? dvrPostPadding.value
            : this.dvrPostPadding),
        isFtiPassed:
            (isFtiPassed != null ? isFtiPassed.value : this.isFtiPassed),
        recordingRetentionPeriodModifiedAt:
            (recordingRetentionPeriodModifiedAt != null
                ? recordingRetentionPeriodModifiedAt.value
                : this.recordingRetentionPeriodModifiedAt),
        autoDeleteFunctionModifiedAt: (autoDeleteFunctionModifiedAt != null
            ? autoDeleteFunctionModifiedAt.value
            : this.autoDeleteFunctionModifiedAt),
        advertisementDeviceId: (advertisementDeviceId != null
            ? advertisementDeviceId.value
            : this.advertisementDeviceId),
        upgradedHZN4:
            (upgradedHZN4 != null ? upgradedHZN4.value : this.upgradedHZN4),
        zipCode: (zipCode != null ? zipCode.value : this.zipCode),
        serviceType:
            (serviceType != null ? serviceType.value : this.serviceType));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerMigrationRequest {
  CustomerMigrationRequest({
    this.currentCustomerId,
    this.newCustomerId,
  });

  factory CustomerMigrationRequest.fromJson(Map<String, dynamic> json) =>
      _$CustomerMigrationRequestFromJson(json);

  static const toJsonFactory = _$CustomerMigrationRequestToJson;
  Map<String, dynamic> toJson() => _$CustomerMigrationRequestToJson(this);

  @JsonKey(name: 'currentCustomerId', includeIfNull: false, defaultValue: '')
  final String? currentCustomerId;
  @JsonKey(name: 'newCustomerId', includeIfNull: false, defaultValue: '')
  final String? newCustomerId;
  static const fromJsonFactory = _$CustomerMigrationRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerMigrationRequest &&
            (identical(other.currentCustomerId, currentCustomerId) ||
                const DeepCollectionEquality()
                    .equals(other.currentCustomerId, currentCustomerId)) &&
            (identical(other.newCustomerId, newCustomerId) ||
                const DeepCollectionEquality()
                    .equals(other.newCustomerId, newCustomerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(currentCustomerId) ^
      const DeepCollectionEquality().hash(newCustomerId) ^
      runtimeType.hashCode;
}

extension $CustomerMigrationRequestExtension on CustomerMigrationRequest {
  CustomerMigrationRequest copyWith(
      {String? currentCustomerId, String? newCustomerId}) {
    return CustomerMigrationRequest(
        currentCustomerId: currentCustomerId ?? this.currentCustomerId,
        newCustomerId: newCustomerId ?? this.newCustomerId);
  }

  CustomerMigrationRequest copyWithWrapped(
      {Wrapped<String?>? currentCustomerId, Wrapped<String?>? newCustomerId}) {
    return CustomerMigrationRequest(
        currentCustomerId: (currentCustomerId != null
            ? currentCustomerId.value
            : this.currentCustomerId),
        newCustomerId:
            (newCustomerId != null ? newCustomerId.value : this.newCustomerId));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateCustomerRequest {
  UpdateCustomerRequest({
    this.customerId,
    this.customerStatus,
    this.pin,
    this.ageLock,
    this.dvrPrePadding,
    this.dvrPostPadding,
    this.countryId,
    this.cityId,
    this.originalCityId,
    this.isFtiPassed,
    this.lockedChannels,
    this.customerOptIns,
    this.defaultHhStb,
    this.deleteRecordingReminder,
    this.recordingRetentionPeriod,
    this.autoDeleteFunction,
  });

  factory UpdateCustomerRequest.fromJson(Map<String, dynamic> json) =>
      _$UpdateCustomerRequestFromJson(json);

  static const toJsonFactory = _$UpdateCustomerRequestToJson;
  Map<String, dynamic> toJson() => _$UpdateCustomerRequestToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: updateCustomerRequestCustomerStatusToJson,
    fromJson: updateCustomerRequestCustomerStatusFromJson,
  )
  final enums.UpdateCustomerRequestCustomerStatus? customerStatus;
  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  @JsonKey(name: 'ageLock', includeIfNull: false)
  final int? ageLock;
  @JsonKey(name: 'dvrPrePadding', includeIfNull: false)
  final int? dvrPrePadding;
  @JsonKey(name: 'dvrPostPadding', includeIfNull: false)
  final int? dvrPostPadding;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'originalCityId', includeIfNull: false)
  final int? originalCityId;
  @JsonKey(name: 'isFtiPassed', includeIfNull: false)
  final bool? isFtiPassed;
  @JsonKey(
      name: 'lockedChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? lockedChannels;
  @JsonKey(
      name: 'customerOptIns',
      includeIfNull: false,
      defaultValue: <CustomerOptIn>[])
  final List<CustomerOptIn>? customerOptIns;
  @JsonKey(name: 'defaultHhStb', includeIfNull: false, defaultValue: '')
  final String? defaultHhStb;
  @JsonKey(name: 'deleteRecordingReminder', includeIfNull: false)
  final bool? deleteRecordingReminder;
  @JsonKey(name: 'recordingRetentionPeriod', includeIfNull: false)
  final int? recordingRetentionPeriod;
  @JsonKey(name: 'autoDeleteFunction', includeIfNull: false)
  final bool? autoDeleteFunction;
  static const fromJsonFactory = _$UpdateCustomerRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateCustomerRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.ageLock, ageLock) ||
                const DeepCollectionEquality()
                    .equals(other.ageLock, ageLock)) &&
            (identical(other.dvrPrePadding, dvrPrePadding) ||
                const DeepCollectionEquality()
                    .equals(other.dvrPrePadding, dvrPrePadding)) &&
            (identical(other.dvrPostPadding, dvrPostPadding) ||
                const DeepCollectionEquality()
                    .equals(other.dvrPostPadding, dvrPostPadding)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.originalCityId, originalCityId) ||
                const DeepCollectionEquality()
                    .equals(other.originalCityId, originalCityId)) &&
            (identical(other.isFtiPassed, isFtiPassed) ||
                const DeepCollectionEquality()
                    .equals(other.isFtiPassed, isFtiPassed)) &&
            (identical(other.lockedChannels, lockedChannels) ||
                const DeepCollectionEquality()
                    .equals(other.lockedChannels, lockedChannels)) &&
            (identical(other.customerOptIns, customerOptIns) ||
                const DeepCollectionEquality()
                    .equals(other.customerOptIns, customerOptIns)) &&
            (identical(other.defaultHhStb, defaultHhStb) ||
                const DeepCollectionEquality()
                    .equals(other.defaultHhStb, defaultHhStb)) &&
            (identical(
                    other.deleteRecordingReminder, deleteRecordingReminder) ||
                const DeepCollectionEquality().equals(
                    other.deleteRecordingReminder, deleteRecordingReminder)) &&
            (identical(
                    other.recordingRetentionPeriod, recordingRetentionPeriod) ||
                const DeepCollectionEquality().equals(
                    other.recordingRetentionPeriod,
                    recordingRetentionPeriod)) &&
            (identical(other.autoDeleteFunction, autoDeleteFunction) ||
                const DeepCollectionEquality()
                    .equals(other.autoDeleteFunction, autoDeleteFunction)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(ageLock) ^
      const DeepCollectionEquality().hash(dvrPrePadding) ^
      const DeepCollectionEquality().hash(dvrPostPadding) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(originalCityId) ^
      const DeepCollectionEquality().hash(isFtiPassed) ^
      const DeepCollectionEquality().hash(lockedChannels) ^
      const DeepCollectionEquality().hash(customerOptIns) ^
      const DeepCollectionEquality().hash(defaultHhStb) ^
      const DeepCollectionEquality().hash(deleteRecordingReminder) ^
      const DeepCollectionEquality().hash(recordingRetentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeleteFunction) ^
      runtimeType.hashCode;
}

extension $UpdateCustomerRequestExtension on UpdateCustomerRequest {
  UpdateCustomerRequest copyWith(
      {String? customerId,
      enums.UpdateCustomerRequestCustomerStatus? customerStatus,
      String? pin,
      int? ageLock,
      int? dvrPrePadding,
      int? dvrPostPadding,
      String? countryId,
      int? cityId,
      int? originalCityId,
      bool? isFtiPassed,
      List<String>? lockedChannels,
      List<CustomerOptIn>? customerOptIns,
      String? defaultHhStb,
      bool? deleteRecordingReminder,
      int? recordingRetentionPeriod,
      bool? autoDeleteFunction}) {
    return UpdateCustomerRequest(
        customerId: customerId ?? this.customerId,
        customerStatus: customerStatus ?? this.customerStatus,
        pin: pin ?? this.pin,
        ageLock: ageLock ?? this.ageLock,
        dvrPrePadding: dvrPrePadding ?? this.dvrPrePadding,
        dvrPostPadding: dvrPostPadding ?? this.dvrPostPadding,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        originalCityId: originalCityId ?? this.originalCityId,
        isFtiPassed: isFtiPassed ?? this.isFtiPassed,
        lockedChannels: lockedChannels ?? this.lockedChannels,
        customerOptIns: customerOptIns ?? this.customerOptIns,
        defaultHhStb: defaultHhStb ?? this.defaultHhStb,
        deleteRecordingReminder:
            deleteRecordingReminder ?? this.deleteRecordingReminder,
        recordingRetentionPeriod:
            recordingRetentionPeriod ?? this.recordingRetentionPeriod,
        autoDeleteFunction: autoDeleteFunction ?? this.autoDeleteFunction);
  }

  UpdateCustomerRequest copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<enums.UpdateCustomerRequestCustomerStatus?>? customerStatus,
      Wrapped<String?>? pin,
      Wrapped<int?>? ageLock,
      Wrapped<int?>? dvrPrePadding,
      Wrapped<int?>? dvrPostPadding,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<int?>? originalCityId,
      Wrapped<bool?>? isFtiPassed,
      Wrapped<List<String>?>? lockedChannels,
      Wrapped<List<CustomerOptIn>?>? customerOptIns,
      Wrapped<String?>? defaultHhStb,
      Wrapped<bool?>? deleteRecordingReminder,
      Wrapped<int?>? recordingRetentionPeriod,
      Wrapped<bool?>? autoDeleteFunction}) {
    return UpdateCustomerRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        pin: (pin != null ? pin.value : this.pin),
        ageLock: (ageLock != null ? ageLock.value : this.ageLock),
        dvrPrePadding:
            (dvrPrePadding != null ? dvrPrePadding.value : this.dvrPrePadding),
        dvrPostPadding: (dvrPostPadding != null
            ? dvrPostPadding.value
            : this.dvrPostPadding),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        originalCityId: (originalCityId != null
            ? originalCityId.value
            : this.originalCityId),
        isFtiPassed:
            (isFtiPassed != null ? isFtiPassed.value : this.isFtiPassed),
        lockedChannels: (lockedChannels != null
            ? lockedChannels.value
            : this.lockedChannels),
        customerOptIns: (customerOptIns != null
            ? customerOptIns.value
            : this.customerOptIns),
        defaultHhStb:
            (defaultHhStb != null ? defaultHhStb.value : this.defaultHhStb),
        deleteRecordingReminder: (deleteRecordingReminder != null
            ? deleteRecordingReminder.value
            : this.deleteRecordingReminder),
        recordingRetentionPeriod: (recordingRetentionPeriod != null
            ? recordingRetentionPeriod.value
            : this.recordingRetentionPeriod),
        autoDeleteFunction: (autoDeleteFunction != null
            ? autoDeleteFunction.value
            : this.autoDeleteFunction));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerOptIn {
  CustomerOptIn({
    this.lastModified,
    this.termsAndConditionsVersion,
    this.enabled,
    this.optInType,
  });

  factory CustomerOptIn.fromJson(Map<String, dynamic> json) =>
      _$CustomerOptInFromJson(json);

  static const toJsonFactory = _$CustomerOptInToJson;
  Map<String, dynamic> toJson() => _$CustomerOptInToJson(this);

  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(
      name: 'termsAndConditionsVersion', includeIfNull: false, defaultValue: '')
  final String? termsAndConditionsVersion;
  @JsonKey(name: 'enabled', includeIfNull: false)
  final bool? enabled;
  @JsonKey(name: 'optInType', includeIfNull: false, defaultValue: '')
  final String? optInType;
  static const fromJsonFactory = _$CustomerOptInFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerOptIn &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.termsAndConditionsVersion,
                    termsAndConditionsVersion) ||
                const DeepCollectionEquality().equals(
                    other.termsAndConditionsVersion,
                    termsAndConditionsVersion)) &&
            (identical(other.enabled, enabled) ||
                const DeepCollectionEquality()
                    .equals(other.enabled, enabled)) &&
            (identical(other.optInType, optInType) ||
                const DeepCollectionEquality()
                    .equals(other.optInType, optInType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(termsAndConditionsVersion) ^
      const DeepCollectionEquality().hash(enabled) ^
      const DeepCollectionEquality().hash(optInType) ^
      runtimeType.hashCode;
}

extension $CustomerOptInExtension on CustomerOptIn {
  CustomerOptIn copyWith(
      {DateTime? lastModified,
      String? termsAndConditionsVersion,
      bool? enabled,
      String? optInType}) {
    return CustomerOptIn(
        lastModified: lastModified ?? this.lastModified,
        termsAndConditionsVersion:
            termsAndConditionsVersion ?? this.termsAndConditionsVersion,
        enabled: enabled ?? this.enabled,
        optInType: optInType ?? this.optInType);
  }

  CustomerOptIn copyWithWrapped(
      {Wrapped<DateTime?>? lastModified,
      Wrapped<String?>? termsAndConditionsVersion,
      Wrapped<bool?>? enabled,
      Wrapped<String?>? optInType}) {
    return CustomerOptIn(
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        termsAndConditionsVersion: (termsAndConditionsVersion != null
            ? termsAndConditionsVersion.value
            : this.termsAndConditionsVersion),
        enabled: (enabled != null ? enabled.value : this.enabled),
        optInType: (optInType != null ? optInType.value : this.optInType));
  }
}

@JsonSerializable(explicitToJson: true)
class Device {
  Device({
    this.deviceType,
    this.smartCardId,
    this.lastModified,
    this.serialNumber,
    this.deviceId,
    required this.hashedCPEId,
    this.customerId,
    this.wifiMacAddress,
    this.ethernetMacAddress,
    this.platformType,
    this.productType,
    this.defaultProfileId,
    this.capabilities,
    this.settings,
  });

  factory Device.fromJson(Map<String, dynamic> json) => _$DeviceFromJson(json);

  static const toJsonFactory = _$DeviceToJson;
  Map<String, dynamic> toJson() => _$DeviceToJson(this);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'hashedCPEId', includeIfNull: false, defaultValue: '')
  final String hashedCPEId;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'wifiMacAddress', includeIfNull: false, defaultValue: '')
  final String? wifiMacAddress;
  @JsonKey(name: 'ethernetMacAddress', includeIfNull: false, defaultValue: '')
  final String? ethernetMacAddress;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'productType', includeIfNull: false, defaultValue: '')
  final String? productType;
  @JsonKey(name: 'defaultProfileId', includeIfNull: false, defaultValue: '')
  final String? defaultProfileId;
  @JsonKey(name: 'capabilities', includeIfNull: false)
  final DeviceCapabilities? capabilities;
  @JsonKey(name: 'settings', includeIfNull: false)
  final DeviceSettings? settings;
  static const fromJsonFactory = _$DeviceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Device &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.hashedCPEId, hashedCPEId) ||
                const DeepCollectionEquality()
                    .equals(other.hashedCPEId, hashedCPEId)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.wifiMacAddress, wifiMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.wifiMacAddress, wifiMacAddress)) &&
            (identical(other.ethernetMacAddress, ethernetMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.ethernetMacAddress, ethernetMacAddress)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.productType, productType) ||
                const DeepCollectionEquality()
                    .equals(other.productType, productType)) &&
            (identical(other.defaultProfileId, defaultProfileId) ||
                const DeepCollectionEquality()
                    .equals(other.defaultProfileId, defaultProfileId)) &&
            (identical(other.capabilities, capabilities) ||
                const DeepCollectionEquality()
                    .equals(other.capabilities, capabilities)) &&
            (identical(other.settings, settings) ||
                const DeepCollectionEquality()
                    .equals(other.settings, settings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(hashedCPEId) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(wifiMacAddress) ^
      const DeepCollectionEquality().hash(ethernetMacAddress) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(defaultProfileId) ^
      const DeepCollectionEquality().hash(capabilities) ^
      const DeepCollectionEquality().hash(settings) ^
      runtimeType.hashCode;
}

extension $DeviceExtension on Device {
  Device copyWith(
      {String? deviceType,
      String? smartCardId,
      DateTime? lastModified,
      String? serialNumber,
      String? deviceId,
      String? hashedCPEId,
      String? customerId,
      String? wifiMacAddress,
      String? ethernetMacAddress,
      String? platformType,
      String? productType,
      String? defaultProfileId,
      DeviceCapabilities? capabilities,
      DeviceSettings? settings}) {
    return Device(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        lastModified: lastModified ?? this.lastModified,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        hashedCPEId: hashedCPEId ?? this.hashedCPEId,
        customerId: customerId ?? this.customerId,
        wifiMacAddress: wifiMacAddress ?? this.wifiMacAddress,
        ethernetMacAddress: ethernetMacAddress ?? this.ethernetMacAddress,
        platformType: platformType ?? this.platformType,
        productType: productType ?? this.productType,
        defaultProfileId: defaultProfileId ?? this.defaultProfileId,
        capabilities: capabilities ?? this.capabilities,
        settings: settings ?? this.settings);
  }

  Device copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<DateTime?>? lastModified,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String>? hashedCPEId,
      Wrapped<String?>? customerId,
      Wrapped<String?>? wifiMacAddress,
      Wrapped<String?>? ethernetMacAddress,
      Wrapped<String?>? platformType,
      Wrapped<String?>? productType,
      Wrapped<String?>? defaultProfileId,
      Wrapped<DeviceCapabilities?>? capabilities,
      Wrapped<DeviceSettings?>? settings}) {
    return Device(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        hashedCPEId:
            (hashedCPEId != null ? hashedCPEId.value : this.hashedCPEId),
        customerId: (customerId != null ? customerId.value : this.customerId),
        wifiMacAddress: (wifiMacAddress != null
            ? wifiMacAddress.value
            : this.wifiMacAddress),
        ethernetMacAddress: (ethernetMacAddress != null
            ? ethernetMacAddress.value
            : this.ethernetMacAddress),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        productType:
            (productType != null ? productType.value : this.productType),
        defaultProfileId: (defaultProfileId != null
            ? defaultProfileId.value
            : this.defaultProfileId),
        capabilities:
            (capabilities != null ? capabilities.value : this.capabilities),
        settings: (settings != null ? settings.value : this.settings));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceRequest {
  DeviceRequest({
    this.deviceType,
    this.smartCardId,
    this.serialNumber,
    this.deviceId,
    this.customerId,
    this.wifiMacAddress,
    this.ethernetMacAddress,
    this.platformType,
    this.defaultProfileId,
    this.productType,
    this.settings,
  });

  factory DeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$DeviceRequestFromJson(json);

  static const toJsonFactory = _$DeviceRequestToJson;
  Map<String, dynamic> toJson() => _$DeviceRequestToJson(this);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'wifiMacAddress', includeIfNull: false, defaultValue: '')
  final String? wifiMacAddress;
  @JsonKey(name: 'ethernetMacAddress', includeIfNull: false, defaultValue: '')
  final String? ethernetMacAddress;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'defaultProfileId', includeIfNull: false, defaultValue: '')
  final String? defaultProfileId;
  @JsonKey(name: 'productType', includeIfNull: false, defaultValue: '')
  final String? productType;
  @JsonKey(name: 'settings', includeIfNull: false)
  final DeviceSettingsRequest? settings;
  static const fromJsonFactory = _$DeviceRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceRequest &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.wifiMacAddress, wifiMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.wifiMacAddress, wifiMacAddress)) &&
            (identical(other.ethernetMacAddress, ethernetMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.ethernetMacAddress, ethernetMacAddress)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.defaultProfileId, defaultProfileId) ||
                const DeepCollectionEquality()
                    .equals(other.defaultProfileId, defaultProfileId)) &&
            (identical(other.productType, productType) ||
                const DeepCollectionEquality()
                    .equals(other.productType, productType)) &&
            (identical(other.settings, settings) ||
                const DeepCollectionEquality()
                    .equals(other.settings, settings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(wifiMacAddress) ^
      const DeepCollectionEquality().hash(ethernetMacAddress) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(defaultProfileId) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(settings) ^
      runtimeType.hashCode;
}

extension $DeviceRequestExtension on DeviceRequest {
  DeviceRequest copyWith(
      {String? deviceType,
      String? smartCardId,
      String? serialNumber,
      String? deviceId,
      String? customerId,
      String? wifiMacAddress,
      String? ethernetMacAddress,
      String? platformType,
      String? defaultProfileId,
      String? productType,
      DeviceSettingsRequest? settings}) {
    return DeviceRequest(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        customerId: customerId ?? this.customerId,
        wifiMacAddress: wifiMacAddress ?? this.wifiMacAddress,
        ethernetMacAddress: ethernetMacAddress ?? this.ethernetMacAddress,
        platformType: platformType ?? this.platformType,
        defaultProfileId: defaultProfileId ?? this.defaultProfileId,
        productType: productType ?? this.productType,
        settings: settings ?? this.settings);
  }

  DeviceRequest copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? customerId,
      Wrapped<String?>? wifiMacAddress,
      Wrapped<String?>? ethernetMacAddress,
      Wrapped<String?>? platformType,
      Wrapped<String?>? defaultProfileId,
      Wrapped<String?>? productType,
      Wrapped<DeviceSettingsRequest?>? settings}) {
    return DeviceRequest(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        customerId: (customerId != null ? customerId.value : this.customerId),
        wifiMacAddress: (wifiMacAddress != null
            ? wifiMacAddress.value
            : this.wifiMacAddress),
        ethernetMacAddress: (ethernetMacAddress != null
            ? ethernetMacAddress.value
            : this.ethernetMacAddress),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        defaultProfileId: (defaultProfileId != null
            ? defaultProfileId.value
            : this.defaultProfileId),
        productType:
            (productType != null ? productType.value : this.productType),
        settings: (settings != null ? settings.value : this.settings));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceCapabilities {
  DeviceCapabilities({
    this.hasHDD,
    this.maxRes,
  });

  factory DeviceCapabilities.fromJson(Map<String, dynamic> json) =>
      _$DeviceCapabilitiesFromJson(json);

  static const toJsonFactory = _$DeviceCapabilitiesToJson;
  Map<String, dynamic> toJson() => _$DeviceCapabilitiesToJson(this);

  @JsonKey(name: 'hasHDD', includeIfNull: false)
  final bool? hasHDD;
  @JsonKey(name: 'maxRes', includeIfNull: false, defaultValue: '')
  final String? maxRes;
  static const fromJsonFactory = _$DeviceCapabilitiesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceCapabilities &&
            (identical(other.hasHDD, hasHDD) ||
                const DeepCollectionEquality().equals(other.hasHDD, hasHDD)) &&
            (identical(other.maxRes, maxRes) ||
                const DeepCollectionEquality().equals(other.maxRes, maxRes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(hasHDD) ^
      const DeepCollectionEquality().hash(maxRes) ^
      runtimeType.hashCode;
}

extension $DeviceCapabilitiesExtension on DeviceCapabilities {
  DeviceCapabilities copyWith({bool? hasHDD, String? maxRes}) {
    return DeviceCapabilities(
        hasHDD: hasHDD ?? this.hasHDD, maxRes: maxRes ?? this.maxRes);
  }

  DeviceCapabilities copyWithWrapped(
      {Wrapped<bool?>? hasHDD, Wrapped<String?>? maxRes}) {
    return DeviceCapabilities(
        hasHDD: (hasHDD != null ? hasHDD.value : this.hasHDD),
        maxRes: (maxRes != null ? maxRes.value : this.maxRes));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceSettings {
  DeviceSettings({
    this.autoStandby,
    this.standbyMode,
    this.aspectRatio,
    this.isDataAnonymized,
    this.privacyLevel,
    this.hdmiResolution,
    this.isAudioDolbyDigital,
    this.sdtvDisplayMode,
    this.widescreenDisplayMode,
    this.volume,
    this.primaryVideoOutput,
    this.isDeepStandby,
    this.customData,
    this.ccDigitalService,
    this.ccAnalogService,
    this.audioDelay,
    this.dolbyDigital,
    this.isPurchasePinActive,
    this.isParentalControlPinActive,
    this.prePadding,
    this.postPadding,
    this.prePaddingModifiedAt,
    this.postPaddingModifiedAt,
    this.deviceFriendlyNameModifiedAt,
    this.hdmiColorOutput,
    this.deviceFriendlyName,
    this.isCecEnabled,
    this.isTvAutoStartup,
    this.oneTouchViewTurnOffPolicy,
    this.isAlexaLinked,
    this.ccsMessages,
  });

  factory DeviceSettings.fromJson(Map<String, dynamic> json) =>
      _$DeviceSettingsFromJson(json);

  static const toJsonFactory = _$DeviceSettingsToJson;
  Map<String, dynamic> toJson() => _$DeviceSettingsToJson(this);

  @JsonKey(name: 'autoStandby', includeIfNull: false)
  final int? autoStandby;
  @JsonKey(name: 'standbyMode', includeIfNull: false, defaultValue: '')
  final String? standbyMode;
  @JsonKey(name: 'aspectRatio', includeIfNull: false, defaultValue: '')
  final String? aspectRatio;
  @JsonKey(name: 'isDataAnonymized', includeIfNull: false)
  final bool? isDataAnonymized;
  @JsonKey(name: 'privacyLevel', includeIfNull: false, defaultValue: '')
  final String? privacyLevel;
  @JsonKey(name: 'hdmiResolution', includeIfNull: false, defaultValue: '')
  final String? hdmiResolution;
  @JsonKey(name: 'isAudioDolbyDigital', includeIfNull: false)
  final bool? isAudioDolbyDigital;
  @JsonKey(name: 'sdtvDisplayMode', includeIfNull: false, defaultValue: '')
  final String? sdtvDisplayMode;
  @JsonKey(
      name: 'widescreenDisplayMode', includeIfNull: false, defaultValue: '')
  final String? widescreenDisplayMode;
  @JsonKey(name: 'volume', includeIfNull: false)
  final int? volume;
  @JsonKey(name: 'primaryVideoOutput', includeIfNull: false, defaultValue: '')
  final String? primaryVideoOutput;
  @JsonKey(name: 'isDeepStandby', includeIfNull: false)
  final bool? isDeepStandby;
  @JsonKey(name: 'customData', includeIfNull: false, defaultValue: '')
  final String? customData;
  @JsonKey(
    name: 'ccDigitalService',
    includeIfNull: false,
    toJson: deviceSettingsCcDigitalServiceToJson,
    fromJson: deviceSettingsCcDigitalServiceFromJson,
  )
  final enums.DeviceSettingsCcDigitalService? ccDigitalService;
  @JsonKey(
    name: 'ccAnalogService',
    includeIfNull: false,
    toJson: deviceSettingsCcAnalogServiceToJson,
    fromJson: deviceSettingsCcAnalogServiceFromJson,
  )
  final enums.DeviceSettingsCcAnalogService? ccAnalogService;
  @JsonKey(name: 'audioDelay', includeIfNull: false)
  final int? audioDelay;
  @JsonKey(name: 'dolbyDigital', includeIfNull: false, defaultValue: '')
  final String? dolbyDigital;
  @JsonKey(name: 'isPurchasePinActive', includeIfNull: false)
  final bool? isPurchasePinActive;
  @JsonKey(name: 'isParentalControlPinActive', includeIfNull: false)
  final bool? isParentalControlPinActive;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(name: 'prePaddingModifiedAt', includeIfNull: false)
  final DateTime? prePaddingModifiedAt;
  @JsonKey(name: 'postPaddingModifiedAt', includeIfNull: false)
  final DateTime? postPaddingModifiedAt;
  @JsonKey(name: 'deviceFriendlyNameModifiedAt', includeIfNull: false)
  final DateTime? deviceFriendlyNameModifiedAt;
  @JsonKey(name: 'hdmiColorOutput', includeIfNull: false, defaultValue: '')
  final String? hdmiColorOutput;
  @JsonKey(name: 'deviceFriendlyName', includeIfNull: false, defaultValue: '')
  final String? deviceFriendlyName;
  @JsonKey(name: 'isCecEnabled', includeIfNull: false)
  final bool? isCecEnabled;
  @JsonKey(name: 'isTvAutoStartup', includeIfNull: false)
  final bool? isTvAutoStartup;
  @JsonKey(name: 'oneTouchViewTurnOffPolicy', includeIfNull: false)
  final bool? oneTouchViewTurnOffPolicy;
  @JsonKey(name: 'isAlexaLinked', includeIfNull: false)
  final bool? isAlexaLinked;
  @JsonKey(name: 'ccsMessages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ccsMessages;
  static const fromJsonFactory = _$DeviceSettingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceSettings &&
            (identical(other.autoStandby, autoStandby) ||
                const DeepCollectionEquality()
                    .equals(other.autoStandby, autoStandby)) &&
            (identical(other.standbyMode, standbyMode) ||
                const DeepCollectionEquality()
                    .equals(other.standbyMode, standbyMode)) &&
            (identical(other.aspectRatio, aspectRatio) ||
                const DeepCollectionEquality()
                    .equals(other.aspectRatio, aspectRatio)) &&
            (identical(other.isDataAnonymized, isDataAnonymized) ||
                const DeepCollectionEquality()
                    .equals(other.isDataAnonymized, isDataAnonymized)) &&
            (identical(other.privacyLevel, privacyLevel) ||
                const DeepCollectionEquality()
                    .equals(other.privacyLevel, privacyLevel)) &&
            (identical(other.hdmiResolution, hdmiResolution) ||
                const DeepCollectionEquality()
                    .equals(other.hdmiResolution, hdmiResolution)) &&
            (identical(other.isAudioDolbyDigital, isAudioDolbyDigital) ||
                const DeepCollectionEquality()
                    .equals(other.isAudioDolbyDigital, isAudioDolbyDigital)) &&
            (identical(other.sdtvDisplayMode, sdtvDisplayMode) ||
                const DeepCollectionEquality()
                    .equals(other.sdtvDisplayMode, sdtvDisplayMode)) &&
            (identical(other.widescreenDisplayMode, widescreenDisplayMode) ||
                const DeepCollectionEquality().equals(
                    other.widescreenDisplayMode, widescreenDisplayMode)) &&
            (identical(other.volume, volume) ||
                const DeepCollectionEquality().equals(other.volume, volume)) &&
            (identical(other.primaryVideoOutput, primaryVideoOutput) ||
                const DeepCollectionEquality()
                    .equals(other.primaryVideoOutput, primaryVideoOutput)) &&
            (identical(other.isDeepStandby, isDeepStandby) ||
                const DeepCollectionEquality()
                    .equals(other.isDeepStandby, isDeepStandby)) &&
            (identical(other.customData, customData) ||
                const DeepCollectionEquality()
                    .equals(other.customData, customData)) &&
            (identical(other.ccDigitalService, ccDigitalService) ||
                const DeepCollectionEquality()
                    .equals(other.ccDigitalService, ccDigitalService)) &&
            (identical(other.ccAnalogService, ccAnalogService) ||
                const DeepCollectionEquality()
                    .equals(other.ccAnalogService, ccAnalogService)) &&
            (identical(other.audioDelay, audioDelay) ||
                const DeepCollectionEquality()
                    .equals(other.audioDelay, audioDelay)) &&
            (identical(other.dolbyDigital, dolbyDigital) ||
                const DeepCollectionEquality()
                    .equals(other.dolbyDigital, dolbyDigital)) &&
            (identical(other.isPurchasePinActive, isPurchasePinActive) ||
                const DeepCollectionEquality()
                    .equals(other.isPurchasePinActive, isPurchasePinActive)) &&
            (identical(other.isParentalControlPinActive, isParentalControlPinActive) ||
                const DeepCollectionEquality().equals(
                    other.isParentalControlPinActive,
                    isParentalControlPinActive)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.prePaddingModifiedAt, prePaddingModifiedAt) || const DeepCollectionEquality().equals(other.prePaddingModifiedAt, prePaddingModifiedAt)) &&
            (identical(other.postPaddingModifiedAt, postPaddingModifiedAt) || const DeepCollectionEquality().equals(other.postPaddingModifiedAt, postPaddingModifiedAt)) &&
            (identical(other.deviceFriendlyNameModifiedAt, deviceFriendlyNameModifiedAt) || const DeepCollectionEquality().equals(other.deviceFriendlyNameModifiedAt, deviceFriendlyNameModifiedAt)) &&
            (identical(other.hdmiColorOutput, hdmiColorOutput) || const DeepCollectionEquality().equals(other.hdmiColorOutput, hdmiColorOutput)) &&
            (identical(other.deviceFriendlyName, deviceFriendlyName) || const DeepCollectionEquality().equals(other.deviceFriendlyName, deviceFriendlyName)) &&
            (identical(other.isCecEnabled, isCecEnabled) || const DeepCollectionEquality().equals(other.isCecEnabled, isCecEnabled)) &&
            (identical(other.isTvAutoStartup, isTvAutoStartup) || const DeepCollectionEquality().equals(other.isTvAutoStartup, isTvAutoStartup)) &&
            (identical(other.oneTouchViewTurnOffPolicy, oneTouchViewTurnOffPolicy) || const DeepCollectionEquality().equals(other.oneTouchViewTurnOffPolicy, oneTouchViewTurnOffPolicy)) &&
            (identical(other.isAlexaLinked, isAlexaLinked) || const DeepCollectionEquality().equals(other.isAlexaLinked, isAlexaLinked)) &&
            (identical(other.ccsMessages, ccsMessages) || const DeepCollectionEquality().equals(other.ccsMessages, ccsMessages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(autoStandby) ^
      const DeepCollectionEquality().hash(standbyMode) ^
      const DeepCollectionEquality().hash(aspectRatio) ^
      const DeepCollectionEquality().hash(isDataAnonymized) ^
      const DeepCollectionEquality().hash(privacyLevel) ^
      const DeepCollectionEquality().hash(hdmiResolution) ^
      const DeepCollectionEquality().hash(isAudioDolbyDigital) ^
      const DeepCollectionEquality().hash(sdtvDisplayMode) ^
      const DeepCollectionEquality().hash(widescreenDisplayMode) ^
      const DeepCollectionEquality().hash(volume) ^
      const DeepCollectionEquality().hash(primaryVideoOutput) ^
      const DeepCollectionEquality().hash(isDeepStandby) ^
      const DeepCollectionEquality().hash(customData) ^
      const DeepCollectionEquality().hash(ccDigitalService) ^
      const DeepCollectionEquality().hash(ccAnalogService) ^
      const DeepCollectionEquality().hash(audioDelay) ^
      const DeepCollectionEquality().hash(dolbyDigital) ^
      const DeepCollectionEquality().hash(isPurchasePinActive) ^
      const DeepCollectionEquality().hash(isParentalControlPinActive) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(prePaddingModifiedAt) ^
      const DeepCollectionEquality().hash(postPaddingModifiedAt) ^
      const DeepCollectionEquality().hash(deviceFriendlyNameModifiedAt) ^
      const DeepCollectionEquality().hash(hdmiColorOutput) ^
      const DeepCollectionEquality().hash(deviceFriendlyName) ^
      const DeepCollectionEquality().hash(isCecEnabled) ^
      const DeepCollectionEquality().hash(isTvAutoStartup) ^
      const DeepCollectionEquality().hash(oneTouchViewTurnOffPolicy) ^
      const DeepCollectionEquality().hash(isAlexaLinked) ^
      const DeepCollectionEquality().hash(ccsMessages) ^
      runtimeType.hashCode;
}

extension $DeviceSettingsExtension on DeviceSettings {
  DeviceSettings copyWith(
      {int? autoStandby,
      String? standbyMode,
      String? aspectRatio,
      bool? isDataAnonymized,
      String? privacyLevel,
      String? hdmiResolution,
      bool? isAudioDolbyDigital,
      String? sdtvDisplayMode,
      String? widescreenDisplayMode,
      int? volume,
      String? primaryVideoOutput,
      bool? isDeepStandby,
      String? customData,
      enums.DeviceSettingsCcDigitalService? ccDigitalService,
      enums.DeviceSettingsCcAnalogService? ccAnalogService,
      int? audioDelay,
      String? dolbyDigital,
      bool? isPurchasePinActive,
      bool? isParentalControlPinActive,
      int? prePadding,
      int? postPadding,
      DateTime? prePaddingModifiedAt,
      DateTime? postPaddingModifiedAt,
      DateTime? deviceFriendlyNameModifiedAt,
      String? hdmiColorOutput,
      String? deviceFriendlyName,
      bool? isCecEnabled,
      bool? isTvAutoStartup,
      bool? oneTouchViewTurnOffPolicy,
      bool? isAlexaLinked,
      List<String>? ccsMessages}) {
    return DeviceSettings(
        autoStandby: autoStandby ?? this.autoStandby,
        standbyMode: standbyMode ?? this.standbyMode,
        aspectRatio: aspectRatio ?? this.aspectRatio,
        isDataAnonymized: isDataAnonymized ?? this.isDataAnonymized,
        privacyLevel: privacyLevel ?? this.privacyLevel,
        hdmiResolution: hdmiResolution ?? this.hdmiResolution,
        isAudioDolbyDigital: isAudioDolbyDigital ?? this.isAudioDolbyDigital,
        sdtvDisplayMode: sdtvDisplayMode ?? this.sdtvDisplayMode,
        widescreenDisplayMode:
            widescreenDisplayMode ?? this.widescreenDisplayMode,
        volume: volume ?? this.volume,
        primaryVideoOutput: primaryVideoOutput ?? this.primaryVideoOutput,
        isDeepStandby: isDeepStandby ?? this.isDeepStandby,
        customData: customData ?? this.customData,
        ccDigitalService: ccDigitalService ?? this.ccDigitalService,
        ccAnalogService: ccAnalogService ?? this.ccAnalogService,
        audioDelay: audioDelay ?? this.audioDelay,
        dolbyDigital: dolbyDigital ?? this.dolbyDigital,
        isPurchasePinActive: isPurchasePinActive ?? this.isPurchasePinActive,
        isParentalControlPinActive:
            isParentalControlPinActive ?? this.isParentalControlPinActive,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        prePaddingModifiedAt: prePaddingModifiedAt ?? this.prePaddingModifiedAt,
        postPaddingModifiedAt:
            postPaddingModifiedAt ?? this.postPaddingModifiedAt,
        deviceFriendlyNameModifiedAt:
            deviceFriendlyNameModifiedAt ?? this.deviceFriendlyNameModifiedAt,
        hdmiColorOutput: hdmiColorOutput ?? this.hdmiColorOutput,
        deviceFriendlyName: deviceFriendlyName ?? this.deviceFriendlyName,
        isCecEnabled: isCecEnabled ?? this.isCecEnabled,
        isTvAutoStartup: isTvAutoStartup ?? this.isTvAutoStartup,
        oneTouchViewTurnOffPolicy:
            oneTouchViewTurnOffPolicy ?? this.oneTouchViewTurnOffPolicy,
        isAlexaLinked: isAlexaLinked ?? this.isAlexaLinked,
        ccsMessages: ccsMessages ?? this.ccsMessages);
  }

  DeviceSettings copyWithWrapped(
      {Wrapped<int?>? autoStandby,
      Wrapped<String?>? standbyMode,
      Wrapped<String?>? aspectRatio,
      Wrapped<bool?>? isDataAnonymized,
      Wrapped<String?>? privacyLevel,
      Wrapped<String?>? hdmiResolution,
      Wrapped<bool?>? isAudioDolbyDigital,
      Wrapped<String?>? sdtvDisplayMode,
      Wrapped<String?>? widescreenDisplayMode,
      Wrapped<int?>? volume,
      Wrapped<String?>? primaryVideoOutput,
      Wrapped<bool?>? isDeepStandby,
      Wrapped<String?>? customData,
      Wrapped<enums.DeviceSettingsCcDigitalService?>? ccDigitalService,
      Wrapped<enums.DeviceSettingsCcAnalogService?>? ccAnalogService,
      Wrapped<int?>? audioDelay,
      Wrapped<String?>? dolbyDigital,
      Wrapped<bool?>? isPurchasePinActive,
      Wrapped<bool?>? isParentalControlPinActive,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<DateTime?>? prePaddingModifiedAt,
      Wrapped<DateTime?>? postPaddingModifiedAt,
      Wrapped<DateTime?>? deviceFriendlyNameModifiedAt,
      Wrapped<String?>? hdmiColorOutput,
      Wrapped<String?>? deviceFriendlyName,
      Wrapped<bool?>? isCecEnabled,
      Wrapped<bool?>? isTvAutoStartup,
      Wrapped<bool?>? oneTouchViewTurnOffPolicy,
      Wrapped<bool?>? isAlexaLinked,
      Wrapped<List<String>?>? ccsMessages}) {
    return DeviceSettings(
        autoStandby:
            (autoStandby != null ? autoStandby.value : this.autoStandby),
        standbyMode:
            (standbyMode != null ? standbyMode.value : this.standbyMode),
        aspectRatio:
            (aspectRatio != null ? aspectRatio.value : this.aspectRatio),
        isDataAnonymized: (isDataAnonymized != null
            ? isDataAnonymized.value
            : this.isDataAnonymized),
        privacyLevel:
            (privacyLevel != null ? privacyLevel.value : this.privacyLevel),
        hdmiResolution: (hdmiResolution != null
            ? hdmiResolution.value
            : this.hdmiResolution),
        isAudioDolbyDigital: (isAudioDolbyDigital != null
            ? isAudioDolbyDigital.value
            : this.isAudioDolbyDigital),
        sdtvDisplayMode: (sdtvDisplayMode != null
            ? sdtvDisplayMode.value
            : this.sdtvDisplayMode),
        widescreenDisplayMode: (widescreenDisplayMode != null
            ? widescreenDisplayMode.value
            : this.widescreenDisplayMode),
        volume: (volume != null ? volume.value : this.volume),
        primaryVideoOutput: (primaryVideoOutput != null
            ? primaryVideoOutput.value
            : this.primaryVideoOutput),
        isDeepStandby:
            (isDeepStandby != null ? isDeepStandby.value : this.isDeepStandby),
        customData: (customData != null ? customData.value : this.customData),
        ccDigitalService: (ccDigitalService != null
            ? ccDigitalService.value
            : this.ccDigitalService),
        ccAnalogService: (ccAnalogService != null
            ? ccAnalogService.value
            : this.ccAnalogService),
        audioDelay: (audioDelay != null ? audioDelay.value : this.audioDelay),
        dolbyDigital:
            (dolbyDigital != null ? dolbyDigital.value : this.dolbyDigital),
        isPurchasePinActive: (isPurchasePinActive != null
            ? isPurchasePinActive.value
            : this.isPurchasePinActive),
        isParentalControlPinActive: (isParentalControlPinActive != null
            ? isParentalControlPinActive.value
            : this.isParentalControlPinActive),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        prePaddingModifiedAt: (prePaddingModifiedAt != null
            ? prePaddingModifiedAt.value
            : this.prePaddingModifiedAt),
        postPaddingModifiedAt: (postPaddingModifiedAt != null
            ? postPaddingModifiedAt.value
            : this.postPaddingModifiedAt),
        deviceFriendlyNameModifiedAt: (deviceFriendlyNameModifiedAt != null
            ? deviceFriendlyNameModifiedAt.value
            : this.deviceFriendlyNameModifiedAt),
        hdmiColorOutput: (hdmiColorOutput != null
            ? hdmiColorOutput.value
            : this.hdmiColorOutput),
        deviceFriendlyName: (deviceFriendlyName != null
            ? deviceFriendlyName.value
            : this.deviceFriendlyName),
        isCecEnabled:
            (isCecEnabled != null ? isCecEnabled.value : this.isCecEnabled),
        isTvAutoStartup: (isTvAutoStartup != null
            ? isTvAutoStartup.value
            : this.isTvAutoStartup),
        oneTouchViewTurnOffPolicy: (oneTouchViewTurnOffPolicy != null
            ? oneTouchViewTurnOffPolicy.value
            : this.oneTouchViewTurnOffPolicy),
        isAlexaLinked:
            (isAlexaLinked != null ? isAlexaLinked.value : this.isAlexaLinked),
        ccsMessages:
            (ccsMessages != null ? ccsMessages.value : this.ccsMessages));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceSettingsRequest {
  DeviceSettingsRequest({
    this.autoStandby,
    this.standbyMode,
    this.aspectRatio,
    this.isDataAnonymized,
    this.privacyLevel,
    this.hdmiResolution,
    this.isCecEnabled,
    this.oneTouchViewTurnOffPolicy,
    this.isAudioDolbyDigital,
    this.isTvAutoStartup,
    this.sdtvDisplayMode,
    this.widescreenDisplayMode,
    this.volume,
    this.primaryVideoOutput,
    this.isDeepStandby,
    this.customData,
    this.ccDigitalService,
    this.ccAnalogService,
    this.deviceFriendlyName,
    this.audioDelay,
    this.dolbyDigital,
    this.prePadding,
    this.postPadding,
    this.isPurchasePinActive,
    this.isParentalControlPinActive,
    this.hdmiColorOutput,
    this.isAlexaLinked,
    this.ccsMessages,
  });

  factory DeviceSettingsRequest.fromJson(Map<String, dynamic> json) =>
      _$DeviceSettingsRequestFromJson(json);

  static const toJsonFactory = _$DeviceSettingsRequestToJson;
  Map<String, dynamic> toJson() => _$DeviceSettingsRequestToJson(this);

  @JsonKey(name: 'autoStandby', includeIfNull: false)
  final int? autoStandby;
  @JsonKey(name: 'standbyMode', includeIfNull: false, defaultValue: '')
  final String? standbyMode;
  @JsonKey(name: 'aspectRatio', includeIfNull: false, defaultValue: '')
  final String? aspectRatio;
  @JsonKey(name: 'isDataAnonymized', includeIfNull: false)
  final bool? isDataAnonymized;
  @JsonKey(name: 'privacyLevel', includeIfNull: false, defaultValue: '')
  final String? privacyLevel;
  @JsonKey(name: 'hdmiResolution', includeIfNull: false, defaultValue: '')
  final String? hdmiResolution;
  @JsonKey(name: 'isCecEnabled', includeIfNull: false)
  final bool? isCecEnabled;
  @JsonKey(name: 'oneTouchViewTurnOffPolicy', includeIfNull: false)
  final bool? oneTouchViewTurnOffPolicy;
  @JsonKey(name: 'isAudioDolbyDigital', includeIfNull: false)
  final bool? isAudioDolbyDigital;
  @JsonKey(name: 'isTvAutoStartup', includeIfNull: false)
  final bool? isTvAutoStartup;
  @JsonKey(name: 'sdtvDisplayMode', includeIfNull: false, defaultValue: '')
  final String? sdtvDisplayMode;
  @JsonKey(
      name: 'widescreenDisplayMode', includeIfNull: false, defaultValue: '')
  final String? widescreenDisplayMode;
  @JsonKey(name: 'volume', includeIfNull: false)
  final int? volume;
  @JsonKey(name: 'primaryVideoOutput', includeIfNull: false, defaultValue: '')
  final String? primaryVideoOutput;
  @JsonKey(name: 'isDeepStandby', includeIfNull: false)
  final bool? isDeepStandby;
  @JsonKey(name: 'customData', includeIfNull: false, defaultValue: '')
  final String? customData;
  @JsonKey(
    name: 'ccDigitalService',
    includeIfNull: false,
    toJson: deviceSettingsRequestCcDigitalServiceToJson,
    fromJson: deviceSettingsRequestCcDigitalServiceFromJson,
  )
  final enums.DeviceSettingsRequestCcDigitalService? ccDigitalService;
  @JsonKey(
    name: 'ccAnalogService',
    includeIfNull: false,
    toJson: deviceSettingsRequestCcAnalogServiceToJson,
    fromJson: deviceSettingsRequestCcAnalogServiceFromJson,
  )
  final enums.DeviceSettingsRequestCcAnalogService? ccAnalogService;
  @JsonKey(name: 'deviceFriendlyName', includeIfNull: false, defaultValue: '')
  final String? deviceFriendlyName;
  @JsonKey(name: 'audioDelay', includeIfNull: false)
  final int? audioDelay;
  @JsonKey(name: 'dolbyDigital', includeIfNull: false, defaultValue: '')
  final String? dolbyDigital;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(name: 'isPurchasePinActive', includeIfNull: false)
  final bool? isPurchasePinActive;
  @JsonKey(name: 'isParentalControlPinActive', includeIfNull: false)
  final bool? isParentalControlPinActive;
  @JsonKey(name: 'hdmiColorOutput', includeIfNull: false, defaultValue: '')
  final String? hdmiColorOutput;
  @JsonKey(name: 'isAlexaLinked', includeIfNull: false)
  final bool? isAlexaLinked;
  @JsonKey(name: 'ccsMessages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ccsMessages;
  static const fromJsonFactory = _$DeviceSettingsRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceSettingsRequest &&
            (identical(other.autoStandby, autoStandby) ||
                const DeepCollectionEquality()
                    .equals(other.autoStandby, autoStandby)) &&
            (identical(other.standbyMode, standbyMode) ||
                const DeepCollectionEquality()
                    .equals(other.standbyMode, standbyMode)) &&
            (identical(other.aspectRatio, aspectRatio) ||
                const DeepCollectionEquality()
                    .equals(other.aspectRatio, aspectRatio)) &&
            (identical(other.isDataAnonymized, isDataAnonymized) ||
                const DeepCollectionEquality()
                    .equals(other.isDataAnonymized, isDataAnonymized)) &&
            (identical(other.privacyLevel, privacyLevel) ||
                const DeepCollectionEquality()
                    .equals(other.privacyLevel, privacyLevel)) &&
            (identical(other.hdmiResolution, hdmiResolution) ||
                const DeepCollectionEquality()
                    .equals(other.hdmiResolution, hdmiResolution)) &&
            (identical(other.isCecEnabled, isCecEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.isCecEnabled, isCecEnabled)) &&
            (identical(other.oneTouchViewTurnOffPolicy, oneTouchViewTurnOffPolicy) ||
                const DeepCollectionEquality().equals(
                    other.oneTouchViewTurnOffPolicy,
                    oneTouchViewTurnOffPolicy)) &&
            (identical(other.isAudioDolbyDigital, isAudioDolbyDigital) ||
                const DeepCollectionEquality()
                    .equals(other.isAudioDolbyDigital, isAudioDolbyDigital)) &&
            (identical(other.isTvAutoStartup, isTvAutoStartup) ||
                const DeepCollectionEquality()
                    .equals(other.isTvAutoStartup, isTvAutoStartup)) &&
            (identical(other.sdtvDisplayMode, sdtvDisplayMode) ||
                const DeepCollectionEquality()
                    .equals(other.sdtvDisplayMode, sdtvDisplayMode)) &&
            (identical(other.widescreenDisplayMode, widescreenDisplayMode) ||
                const DeepCollectionEquality().equals(
                    other.widescreenDisplayMode, widescreenDisplayMode)) &&
            (identical(other.volume, volume) ||
                const DeepCollectionEquality().equals(other.volume, volume)) &&
            (identical(other.primaryVideoOutput, primaryVideoOutput) ||
                const DeepCollectionEquality()
                    .equals(other.primaryVideoOutput, primaryVideoOutput)) &&
            (identical(other.isDeepStandby, isDeepStandby) ||
                const DeepCollectionEquality()
                    .equals(other.isDeepStandby, isDeepStandby)) &&
            (identical(other.customData, customData) ||
                const DeepCollectionEquality()
                    .equals(other.customData, customData)) &&
            (identical(other.ccDigitalService, ccDigitalService) ||
                const DeepCollectionEquality()
                    .equals(other.ccDigitalService, ccDigitalService)) &&
            (identical(other.ccAnalogService, ccAnalogService) ||
                const DeepCollectionEquality()
                    .equals(other.ccAnalogService, ccAnalogService)) &&
            (identical(other.deviceFriendlyName, deviceFriendlyName) ||
                const DeepCollectionEquality().equals(other.deviceFriendlyName, deviceFriendlyName)) &&
            (identical(other.audioDelay, audioDelay) || const DeepCollectionEquality().equals(other.audioDelay, audioDelay)) &&
            (identical(other.dolbyDigital, dolbyDigital) || const DeepCollectionEquality().equals(other.dolbyDigital, dolbyDigital)) &&
            (identical(other.prePadding, prePadding) || const DeepCollectionEquality().equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) || const DeepCollectionEquality().equals(other.postPadding, postPadding)) &&
            (identical(other.isPurchasePinActive, isPurchasePinActive) || const DeepCollectionEquality().equals(other.isPurchasePinActive, isPurchasePinActive)) &&
            (identical(other.isParentalControlPinActive, isParentalControlPinActive) || const DeepCollectionEquality().equals(other.isParentalControlPinActive, isParentalControlPinActive)) &&
            (identical(other.hdmiColorOutput, hdmiColorOutput) || const DeepCollectionEquality().equals(other.hdmiColorOutput, hdmiColorOutput)) &&
            (identical(other.isAlexaLinked, isAlexaLinked) || const DeepCollectionEquality().equals(other.isAlexaLinked, isAlexaLinked)) &&
            (identical(other.ccsMessages, ccsMessages) || const DeepCollectionEquality().equals(other.ccsMessages, ccsMessages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(autoStandby) ^
      const DeepCollectionEquality().hash(standbyMode) ^
      const DeepCollectionEquality().hash(aspectRatio) ^
      const DeepCollectionEquality().hash(isDataAnonymized) ^
      const DeepCollectionEquality().hash(privacyLevel) ^
      const DeepCollectionEquality().hash(hdmiResolution) ^
      const DeepCollectionEquality().hash(isCecEnabled) ^
      const DeepCollectionEquality().hash(oneTouchViewTurnOffPolicy) ^
      const DeepCollectionEquality().hash(isAudioDolbyDigital) ^
      const DeepCollectionEquality().hash(isTvAutoStartup) ^
      const DeepCollectionEquality().hash(sdtvDisplayMode) ^
      const DeepCollectionEquality().hash(widescreenDisplayMode) ^
      const DeepCollectionEquality().hash(volume) ^
      const DeepCollectionEquality().hash(primaryVideoOutput) ^
      const DeepCollectionEquality().hash(isDeepStandby) ^
      const DeepCollectionEquality().hash(customData) ^
      const DeepCollectionEquality().hash(ccDigitalService) ^
      const DeepCollectionEquality().hash(ccAnalogService) ^
      const DeepCollectionEquality().hash(deviceFriendlyName) ^
      const DeepCollectionEquality().hash(audioDelay) ^
      const DeepCollectionEquality().hash(dolbyDigital) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(isPurchasePinActive) ^
      const DeepCollectionEquality().hash(isParentalControlPinActive) ^
      const DeepCollectionEquality().hash(hdmiColorOutput) ^
      const DeepCollectionEquality().hash(isAlexaLinked) ^
      const DeepCollectionEquality().hash(ccsMessages) ^
      runtimeType.hashCode;
}

extension $DeviceSettingsRequestExtension on DeviceSettingsRequest {
  DeviceSettingsRequest copyWith(
      {int? autoStandby,
      String? standbyMode,
      String? aspectRatio,
      bool? isDataAnonymized,
      String? privacyLevel,
      String? hdmiResolution,
      bool? isCecEnabled,
      bool? oneTouchViewTurnOffPolicy,
      bool? isAudioDolbyDigital,
      bool? isTvAutoStartup,
      String? sdtvDisplayMode,
      String? widescreenDisplayMode,
      int? volume,
      String? primaryVideoOutput,
      bool? isDeepStandby,
      String? customData,
      enums.DeviceSettingsRequestCcDigitalService? ccDigitalService,
      enums.DeviceSettingsRequestCcAnalogService? ccAnalogService,
      String? deviceFriendlyName,
      int? audioDelay,
      String? dolbyDigital,
      int? prePadding,
      int? postPadding,
      bool? isPurchasePinActive,
      bool? isParentalControlPinActive,
      String? hdmiColorOutput,
      bool? isAlexaLinked,
      List<String>? ccsMessages}) {
    return DeviceSettingsRequest(
        autoStandby: autoStandby ?? this.autoStandby,
        standbyMode: standbyMode ?? this.standbyMode,
        aspectRatio: aspectRatio ?? this.aspectRatio,
        isDataAnonymized: isDataAnonymized ?? this.isDataAnonymized,
        privacyLevel: privacyLevel ?? this.privacyLevel,
        hdmiResolution: hdmiResolution ?? this.hdmiResolution,
        isCecEnabled: isCecEnabled ?? this.isCecEnabled,
        oneTouchViewTurnOffPolicy:
            oneTouchViewTurnOffPolicy ?? this.oneTouchViewTurnOffPolicy,
        isAudioDolbyDigital: isAudioDolbyDigital ?? this.isAudioDolbyDigital,
        isTvAutoStartup: isTvAutoStartup ?? this.isTvAutoStartup,
        sdtvDisplayMode: sdtvDisplayMode ?? this.sdtvDisplayMode,
        widescreenDisplayMode:
            widescreenDisplayMode ?? this.widescreenDisplayMode,
        volume: volume ?? this.volume,
        primaryVideoOutput: primaryVideoOutput ?? this.primaryVideoOutput,
        isDeepStandby: isDeepStandby ?? this.isDeepStandby,
        customData: customData ?? this.customData,
        ccDigitalService: ccDigitalService ?? this.ccDigitalService,
        ccAnalogService: ccAnalogService ?? this.ccAnalogService,
        deviceFriendlyName: deviceFriendlyName ?? this.deviceFriendlyName,
        audioDelay: audioDelay ?? this.audioDelay,
        dolbyDigital: dolbyDigital ?? this.dolbyDigital,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        isPurchasePinActive: isPurchasePinActive ?? this.isPurchasePinActive,
        isParentalControlPinActive:
            isParentalControlPinActive ?? this.isParentalControlPinActive,
        hdmiColorOutput: hdmiColorOutput ?? this.hdmiColorOutput,
        isAlexaLinked: isAlexaLinked ?? this.isAlexaLinked,
        ccsMessages: ccsMessages ?? this.ccsMessages);
  }

  DeviceSettingsRequest copyWithWrapped(
      {Wrapped<int?>? autoStandby,
      Wrapped<String?>? standbyMode,
      Wrapped<String?>? aspectRatio,
      Wrapped<bool?>? isDataAnonymized,
      Wrapped<String?>? privacyLevel,
      Wrapped<String?>? hdmiResolution,
      Wrapped<bool?>? isCecEnabled,
      Wrapped<bool?>? oneTouchViewTurnOffPolicy,
      Wrapped<bool?>? isAudioDolbyDigital,
      Wrapped<bool?>? isTvAutoStartup,
      Wrapped<String?>? sdtvDisplayMode,
      Wrapped<String?>? widescreenDisplayMode,
      Wrapped<int?>? volume,
      Wrapped<String?>? primaryVideoOutput,
      Wrapped<bool?>? isDeepStandby,
      Wrapped<String?>? customData,
      Wrapped<enums.DeviceSettingsRequestCcDigitalService?>? ccDigitalService,
      Wrapped<enums.DeviceSettingsRequestCcAnalogService?>? ccAnalogService,
      Wrapped<String?>? deviceFriendlyName,
      Wrapped<int?>? audioDelay,
      Wrapped<String?>? dolbyDigital,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<bool?>? isPurchasePinActive,
      Wrapped<bool?>? isParentalControlPinActive,
      Wrapped<String?>? hdmiColorOutput,
      Wrapped<bool?>? isAlexaLinked,
      Wrapped<List<String>?>? ccsMessages}) {
    return DeviceSettingsRequest(
        autoStandby:
            (autoStandby != null ? autoStandby.value : this.autoStandby),
        standbyMode:
            (standbyMode != null ? standbyMode.value : this.standbyMode),
        aspectRatio:
            (aspectRatio != null ? aspectRatio.value : this.aspectRatio),
        isDataAnonymized: (isDataAnonymized != null
            ? isDataAnonymized.value
            : this.isDataAnonymized),
        privacyLevel:
            (privacyLevel != null ? privacyLevel.value : this.privacyLevel),
        hdmiResolution: (hdmiResolution != null
            ? hdmiResolution.value
            : this.hdmiResolution),
        isCecEnabled:
            (isCecEnabled != null ? isCecEnabled.value : this.isCecEnabled),
        oneTouchViewTurnOffPolicy: (oneTouchViewTurnOffPolicy != null
            ? oneTouchViewTurnOffPolicy.value
            : this.oneTouchViewTurnOffPolicy),
        isAudioDolbyDigital: (isAudioDolbyDigital != null
            ? isAudioDolbyDigital.value
            : this.isAudioDolbyDigital),
        isTvAutoStartup: (isTvAutoStartup != null
            ? isTvAutoStartup.value
            : this.isTvAutoStartup),
        sdtvDisplayMode: (sdtvDisplayMode != null
            ? sdtvDisplayMode.value
            : this.sdtvDisplayMode),
        widescreenDisplayMode: (widescreenDisplayMode != null
            ? widescreenDisplayMode.value
            : this.widescreenDisplayMode),
        volume: (volume != null ? volume.value : this.volume),
        primaryVideoOutput: (primaryVideoOutput != null
            ? primaryVideoOutput.value
            : this.primaryVideoOutput),
        isDeepStandby:
            (isDeepStandby != null ? isDeepStandby.value : this.isDeepStandby),
        customData: (customData != null ? customData.value : this.customData),
        ccDigitalService: (ccDigitalService != null
            ? ccDigitalService.value
            : this.ccDigitalService),
        ccAnalogService: (ccAnalogService != null
            ? ccAnalogService.value
            : this.ccAnalogService),
        deviceFriendlyName: (deviceFriendlyName != null
            ? deviceFriendlyName.value
            : this.deviceFriendlyName),
        audioDelay: (audioDelay != null ? audioDelay.value : this.audioDelay),
        dolbyDigital:
            (dolbyDigital != null ? dolbyDigital.value : this.dolbyDigital),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        isPurchasePinActive: (isPurchasePinActive != null
            ? isPurchasePinActive.value
            : this.isPurchasePinActive),
        isParentalControlPinActive: (isParentalControlPinActive != null
            ? isParentalControlPinActive.value
            : this.isParentalControlPinActive),
        hdmiColorOutput: (hdmiColorOutput != null
            ? hdmiColorOutput.value
            : this.hdmiColorOutput),
        isAlexaLinked:
            (isAlexaLinked != null ? isAlexaLinked.value : this.isAlexaLinked),
        ccsMessages:
            (ccsMessages != null ? ccsMessages.value : this.ccsMessages));
  }
}

@JsonSerializable(explicitToJson: true)
class JsonNode {
  JsonNode({
    this.nodeType,
    this.valueNode,
    this.containerNode,
    this.missingNode,
    this.object,
    this.pojo,
    this.$number,
    this.integralNumber,
    this.floatingPointNumber,
    this.short,
    this.$int,
    this.long,
    this.$float,
    this.$double,
    this.bigDecimal,
    this.bigInteger,
    this.textual,
    this.$boolean,
    this.binary,
    this.array,
    this.$null,
  });

  factory JsonNode.fromJson(Map<String, dynamic> json) =>
      _$JsonNodeFromJson(json);

  static const toJsonFactory = _$JsonNodeToJson;
  Map<String, dynamic> toJson() => _$JsonNodeToJson(this);

  @JsonKey(
    name: 'nodeType',
    includeIfNull: false,
    toJson: jsonNodeNodeTypeToJson,
    fromJson: jsonNodeNodeTypeFromJson,
  )
  final enums.JsonNodeNodeType? nodeType;
  @JsonKey(name: 'valueNode', includeIfNull: false)
  final bool? valueNode;
  @JsonKey(name: 'containerNode', includeIfNull: false)
  final bool? containerNode;
  @JsonKey(name: 'missingNode', includeIfNull: false)
  final bool? missingNode;
  @JsonKey(name: 'object', includeIfNull: false)
  final bool? object;
  @JsonKey(name: 'pojo', includeIfNull: false)
  final bool? pojo;
  @JsonKey(name: 'number', includeIfNull: false)
  final bool? $number;
  @JsonKey(name: 'integralNumber', includeIfNull: false)
  final bool? integralNumber;
  @JsonKey(name: 'floatingPointNumber', includeIfNull: false)
  final bool? floatingPointNumber;
  @JsonKey(name: 'short', includeIfNull: false)
  final bool? short;
  @JsonKey(name: 'int', includeIfNull: false)
  final bool? $int;
  @JsonKey(name: 'long', includeIfNull: false)
  final bool? long;
  @JsonKey(name: 'float', includeIfNull: false)
  final bool? $float;
  @JsonKey(name: 'double', includeIfNull: false)
  final bool? $double;
  @JsonKey(name: 'bigDecimal', includeIfNull: false)
  final bool? bigDecimal;
  @JsonKey(name: 'bigInteger', includeIfNull: false)
  final bool? bigInteger;
  @JsonKey(name: 'textual', includeIfNull: false)
  final bool? textual;
  @JsonKey(name: 'boolean', includeIfNull: false)
  final bool? $boolean;
  @JsonKey(name: 'binary', includeIfNull: false)
  final bool? binary;
  @JsonKey(name: 'array', includeIfNull: false)
  final bool? array;
  @JsonKey(name: 'null', includeIfNull: false)
  final bool? $null;
  static const fromJsonFactory = _$JsonNodeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is JsonNode &&
            (identical(other.nodeType, nodeType) ||
                const DeepCollectionEquality()
                    .equals(other.nodeType, nodeType)) &&
            (identical(other.valueNode, valueNode) ||
                const DeepCollectionEquality()
                    .equals(other.valueNode, valueNode)) &&
            (identical(other.containerNode, containerNode) ||
                const DeepCollectionEquality()
                    .equals(other.containerNode, containerNode)) &&
            (identical(other.missingNode, missingNode) ||
                const DeepCollectionEquality()
                    .equals(other.missingNode, missingNode)) &&
            (identical(other.object, object) ||
                const DeepCollectionEquality().equals(other.object, object)) &&
            (identical(other.pojo, pojo) ||
                const DeepCollectionEquality().equals(other.pojo, pojo)) &&
            (identical(other.$number, $number) ||
                const DeepCollectionEquality()
                    .equals(other.$number, $number)) &&
            (identical(other.integralNumber, integralNumber) ||
                const DeepCollectionEquality()
                    .equals(other.integralNumber, integralNumber)) &&
            (identical(other.floatingPointNumber, floatingPointNumber) ||
                const DeepCollectionEquality()
                    .equals(other.floatingPointNumber, floatingPointNumber)) &&
            (identical(other.short, short) ||
                const DeepCollectionEquality().equals(other.short, short)) &&
            (identical(other.$int, $int) ||
                const DeepCollectionEquality().equals(other.$int, $int)) &&
            (identical(other.long, long) ||
                const DeepCollectionEquality().equals(other.long, long)) &&
            (identical(other.$float, $float) ||
                const DeepCollectionEquality().equals(other.$float, $float)) &&
            (identical(other.$double, $double) ||
                const DeepCollectionEquality()
                    .equals(other.$double, $double)) &&
            (identical(other.bigDecimal, bigDecimal) ||
                const DeepCollectionEquality()
                    .equals(other.bigDecimal, bigDecimal)) &&
            (identical(other.bigInteger, bigInteger) ||
                const DeepCollectionEquality()
                    .equals(other.bigInteger, bigInteger)) &&
            (identical(other.textual, textual) ||
                const DeepCollectionEquality()
                    .equals(other.textual, textual)) &&
            (identical(other.$boolean, $boolean) ||
                const DeepCollectionEquality()
                    .equals(other.$boolean, $boolean)) &&
            (identical(other.binary, binary) ||
                const DeepCollectionEquality().equals(other.binary, binary)) &&
            (identical(other.array, array) ||
                const DeepCollectionEquality().equals(other.array, array)) &&
            (identical(other.$null, $null) ||
                const DeepCollectionEquality().equals(other.$null, $null)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nodeType) ^
      const DeepCollectionEquality().hash(valueNode) ^
      const DeepCollectionEquality().hash(containerNode) ^
      const DeepCollectionEquality().hash(missingNode) ^
      const DeepCollectionEquality().hash(object) ^
      const DeepCollectionEquality().hash(pojo) ^
      const DeepCollectionEquality().hash($number) ^
      const DeepCollectionEquality().hash(integralNumber) ^
      const DeepCollectionEquality().hash(floatingPointNumber) ^
      const DeepCollectionEquality().hash(short) ^
      const DeepCollectionEquality().hash($int) ^
      const DeepCollectionEquality().hash(long) ^
      const DeepCollectionEquality().hash($float) ^
      const DeepCollectionEquality().hash($double) ^
      const DeepCollectionEquality().hash(bigDecimal) ^
      const DeepCollectionEquality().hash(bigInteger) ^
      const DeepCollectionEquality().hash(textual) ^
      const DeepCollectionEquality().hash($boolean) ^
      const DeepCollectionEquality().hash(binary) ^
      const DeepCollectionEquality().hash(array) ^
      const DeepCollectionEquality().hash($null) ^
      runtimeType.hashCode;
}

extension $JsonNodeExtension on JsonNode {
  JsonNode copyWith(
      {enums.JsonNodeNodeType? nodeType,
      bool? valueNode,
      bool? containerNode,
      bool? missingNode,
      bool? object,
      bool? pojo,
      bool? $number,
      bool? integralNumber,
      bool? floatingPointNumber,
      bool? short,
      bool? $int,
      bool? long,
      bool? $float,
      bool? $double,
      bool? bigDecimal,
      bool? bigInteger,
      bool? textual,
      bool? $boolean,
      bool? binary,
      bool? array,
      bool? $null}) {
    return JsonNode(
        nodeType: nodeType ?? this.nodeType,
        valueNode: valueNode ?? this.valueNode,
        containerNode: containerNode ?? this.containerNode,
        missingNode: missingNode ?? this.missingNode,
        object: object ?? this.object,
        pojo: pojo ?? this.pojo,
        $number: $number ?? this.$number,
        integralNumber: integralNumber ?? this.integralNumber,
        floatingPointNumber: floatingPointNumber ?? this.floatingPointNumber,
        short: short ?? this.short,
        $int: $int ?? this.$int,
        long: long ?? this.long,
        $float: $float ?? this.$float,
        $double: $double ?? this.$double,
        bigDecimal: bigDecimal ?? this.bigDecimal,
        bigInteger: bigInteger ?? this.bigInteger,
        textual: textual ?? this.textual,
        $boolean: $boolean ?? this.$boolean,
        binary: binary ?? this.binary,
        array: array ?? this.array,
        $null: $null ?? this.$null);
  }

  JsonNode copyWithWrapped(
      {Wrapped<enums.JsonNodeNodeType?>? nodeType,
      Wrapped<bool?>? valueNode,
      Wrapped<bool?>? containerNode,
      Wrapped<bool?>? missingNode,
      Wrapped<bool?>? object,
      Wrapped<bool?>? pojo,
      Wrapped<bool?>? $number,
      Wrapped<bool?>? integralNumber,
      Wrapped<bool?>? floatingPointNumber,
      Wrapped<bool?>? short,
      Wrapped<bool?>? $int,
      Wrapped<bool?>? long,
      Wrapped<bool?>? $float,
      Wrapped<bool?>? $double,
      Wrapped<bool?>? bigDecimal,
      Wrapped<bool?>? bigInteger,
      Wrapped<bool?>? textual,
      Wrapped<bool?>? $boolean,
      Wrapped<bool?>? binary,
      Wrapped<bool?>? array,
      Wrapped<bool?>? $null}) {
    return JsonNode(
        nodeType: (nodeType != null ? nodeType.value : this.nodeType),
        valueNode: (valueNode != null ? valueNode.value : this.valueNode),
        containerNode:
            (containerNode != null ? containerNode.value : this.containerNode),
        missingNode:
            (missingNode != null ? missingNode.value : this.missingNode),
        object: (object != null ? object.value : this.object),
        pojo: (pojo != null ? pojo.value : this.pojo),
        $number: ($number != null ? $number.value : this.$number),
        integralNumber: (integralNumber != null
            ? integralNumber.value
            : this.integralNumber),
        floatingPointNumber: (floatingPointNumber != null
            ? floatingPointNumber.value
            : this.floatingPointNumber),
        short: (short != null ? short.value : this.short),
        $int: ($int != null ? $int.value : this.$int),
        long: (long != null ? long.value : this.long),
        $float: ($float != null ? $float.value : this.$float),
        $double: ($double != null ? $double.value : this.$double),
        bigDecimal: (bigDecimal != null ? bigDecimal.value : this.bigDecimal),
        bigInteger: (bigInteger != null ? bigInteger.value : this.bigInteger),
        textual: (textual != null ? textual.value : this.textual),
        $boolean: ($boolean != null ? $boolean.value : this.$boolean),
        binary: (binary != null ? binary.value : this.binary),
        array: (array != null ? array.value : this.array),
        $null: ($null != null ? $null.value : this.$null));
  }
}

@JsonSerializable(explicitToJson: true)
class Profile {
  Profile({
    this.externalId,
    this.lastWatchedChannel,
    this.lastModified,
    this.options,
    this.customerId,
    this.profileId,
    required this.hashedProfileId,
    this.shared,
    this.colour,
    this.favoriteChannels,
    this.jsonOptions,
    this.recentlyUsedApps,
    this.recentlyUsedSettings,
    this.accessibleViews,
    this.name,
  });

  factory Profile.fromJson(Map<String, dynamic> json) =>
      _$ProfileFromJson(json);

  static const toJsonFactory = _$ProfileToJson;
  Map<String, dynamic> toJson() => _$ProfileToJson(this);

  @JsonKey(name: 'externalId', includeIfNull: false, defaultValue: '')
  final String? externalId;
  @JsonKey(name: 'lastWatchedChannel', includeIfNull: false)
  final int? lastWatchedChannel;
  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(name: 'options', includeIfNull: false)
  final ProfileOptions? options;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'hashedProfileId', includeIfNull: false, defaultValue: '')
  final String hashedProfileId;
  @JsonKey(name: 'shared', includeIfNull: false)
  final bool? shared;
  @JsonKey(name: 'colour', includeIfNull: false, defaultValue: '')
  final String? colour;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? favoriteChannels;
  @JsonKey(name: 'jsonOptions', includeIfNull: false)
  final ProfileJsonOptions? jsonOptions;
  @JsonKey(
      name: 'recentlyUsedApps', includeIfNull: false, defaultValue: <String>[])
  final List<String>? recentlyUsedApps;
  @JsonKey(
      name: 'recentlyUsedSettings',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? recentlyUsedSettings;
  @JsonKey(
      name: 'accessibleViews', includeIfNull: false, defaultValue: <String>[])
  final List<String>? accessibleViews;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$ProfileFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Profile &&
            (identical(other.externalId, externalId) ||
                const DeepCollectionEquality()
                    .equals(other.externalId, externalId)) &&
            (identical(other.lastWatchedChannel, lastWatchedChannel) ||
                const DeepCollectionEquality()
                    .equals(other.lastWatchedChannel, lastWatchedChannel)) &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality()
                    .equals(other.options, options)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.hashedProfileId, hashedProfileId) ||
                const DeepCollectionEquality()
                    .equals(other.hashedProfileId, hashedProfileId)) &&
            (identical(other.shared, shared) ||
                const DeepCollectionEquality().equals(other.shared, shared)) &&
            (identical(other.colour, colour) ||
                const DeepCollectionEquality().equals(other.colour, colour)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)) &&
            (identical(other.jsonOptions, jsonOptions) ||
                const DeepCollectionEquality()
                    .equals(other.jsonOptions, jsonOptions)) &&
            (identical(other.recentlyUsedApps, recentlyUsedApps) ||
                const DeepCollectionEquality()
                    .equals(other.recentlyUsedApps, recentlyUsedApps)) &&
            (identical(other.recentlyUsedSettings, recentlyUsedSettings) ||
                const DeepCollectionEquality().equals(
                    other.recentlyUsedSettings, recentlyUsedSettings)) &&
            (identical(other.accessibleViews, accessibleViews) ||
                const DeepCollectionEquality()
                    .equals(other.accessibleViews, accessibleViews)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(externalId) ^
      const DeepCollectionEquality().hash(lastWatchedChannel) ^
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(options) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(hashedProfileId) ^
      const DeepCollectionEquality().hash(shared) ^
      const DeepCollectionEquality().hash(colour) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      const DeepCollectionEquality().hash(jsonOptions) ^
      const DeepCollectionEquality().hash(recentlyUsedApps) ^
      const DeepCollectionEquality().hash(recentlyUsedSettings) ^
      const DeepCollectionEquality().hash(accessibleViews) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $ProfileExtension on Profile {
  Profile copyWith(
      {String? externalId,
      int? lastWatchedChannel,
      DateTime? lastModified,
      ProfileOptions? options,
      String? customerId,
      String? profileId,
      String? hashedProfileId,
      bool? shared,
      String? colour,
      List<String>? favoriteChannels,
      ProfileJsonOptions? jsonOptions,
      List<String>? recentlyUsedApps,
      List<String>? recentlyUsedSettings,
      List<String>? accessibleViews,
      String? name}) {
    return Profile(
        externalId: externalId ?? this.externalId,
        lastWatchedChannel: lastWatchedChannel ?? this.lastWatchedChannel,
        lastModified: lastModified ?? this.lastModified,
        options: options ?? this.options,
        customerId: customerId ?? this.customerId,
        profileId: profileId ?? this.profileId,
        hashedProfileId: hashedProfileId ?? this.hashedProfileId,
        shared: shared ?? this.shared,
        colour: colour ?? this.colour,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels,
        jsonOptions: jsonOptions ?? this.jsonOptions,
        recentlyUsedApps: recentlyUsedApps ?? this.recentlyUsedApps,
        recentlyUsedSettings: recentlyUsedSettings ?? this.recentlyUsedSettings,
        accessibleViews: accessibleViews ?? this.accessibleViews,
        name: name ?? this.name);
  }

  Profile copyWithWrapped(
      {Wrapped<String?>? externalId,
      Wrapped<int?>? lastWatchedChannel,
      Wrapped<DateTime?>? lastModified,
      Wrapped<ProfileOptions?>? options,
      Wrapped<String?>? customerId,
      Wrapped<String?>? profileId,
      Wrapped<String>? hashedProfileId,
      Wrapped<bool?>? shared,
      Wrapped<String?>? colour,
      Wrapped<List<String>?>? favoriteChannels,
      Wrapped<ProfileJsonOptions?>? jsonOptions,
      Wrapped<List<String>?>? recentlyUsedApps,
      Wrapped<List<String>?>? recentlyUsedSettings,
      Wrapped<List<String>?>? accessibleViews,
      Wrapped<String?>? name}) {
    return Profile(
        externalId: (externalId != null ? externalId.value : this.externalId),
        lastWatchedChannel: (lastWatchedChannel != null
            ? lastWatchedChannel.value
            : this.lastWatchedChannel),
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        options: (options != null ? options.value : this.options),
        customerId: (customerId != null ? customerId.value : this.customerId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        hashedProfileId: (hashedProfileId != null
            ? hashedProfileId.value
            : this.hashedProfileId),
        shared: (shared != null ? shared.value : this.shared),
        colour: (colour != null ? colour.value : this.colour),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels),
        jsonOptions:
            (jsonOptions != null ? jsonOptions.value : this.jsonOptions),
        recentlyUsedApps: (recentlyUsedApps != null
            ? recentlyUsedApps.value
            : this.recentlyUsedApps),
        recentlyUsedSettings: (recentlyUsedSettings != null
            ? recentlyUsedSettings.value
            : this.recentlyUsedSettings),
        accessibleViews: (accessibleViews != null
            ? accessibleViews.value
            : this.accessibleViews),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileJsonOptions {
  ProfileJsonOptions({
    this.tipsAndTricksModifiedAt,
    this.tipsAndTricks,
    this.voiceOverGuidanceVoiceModifiedAt,
    this.voiceOverGuidanceVoice,
  });

  factory ProfileJsonOptions.fromJson(Map<String, dynamic> json) =>
      _$ProfileJsonOptionsFromJson(json);

  static const toJsonFactory = _$ProfileJsonOptionsToJson;
  Map<String, dynamic> toJson() => _$ProfileJsonOptionsToJson(this);

  @JsonKey(name: 'tipsAndTricksModifiedAt', includeIfNull: false)
  final DateTime? tipsAndTricksModifiedAt;
  @JsonKey(name: 'tipsAndTricks', includeIfNull: false)
  final JsonNode? tipsAndTricks;
  @JsonKey(name: 'voiceOverGuidanceVoiceModifiedAt', includeIfNull: false)
  final DateTime? voiceOverGuidanceVoiceModifiedAt;
  @JsonKey(name: 'voiceOverGuidanceVoice', includeIfNull: false)
  final JsonNode? voiceOverGuidanceVoice;
  static const fromJsonFactory = _$ProfileJsonOptionsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileJsonOptions &&
            (identical(
                    other.tipsAndTricksModifiedAt, tipsAndTricksModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.tipsAndTricksModifiedAt, tipsAndTricksModifiedAt)) &&
            (identical(other.tipsAndTricks, tipsAndTricks) ||
                const DeepCollectionEquality()
                    .equals(other.tipsAndTricks, tipsAndTricks)) &&
            (identical(other.voiceOverGuidanceVoiceModifiedAt,
                    voiceOverGuidanceVoiceModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.voiceOverGuidanceVoiceModifiedAt,
                    voiceOverGuidanceVoiceModifiedAt)) &&
            (identical(other.voiceOverGuidanceVoice, voiceOverGuidanceVoice) ||
                const DeepCollectionEquality().equals(
                    other.voiceOverGuidanceVoice, voiceOverGuidanceVoice)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tipsAndTricksModifiedAt) ^
      const DeepCollectionEquality().hash(tipsAndTricks) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceVoiceModifiedAt) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceVoice) ^
      runtimeType.hashCode;
}

extension $ProfileJsonOptionsExtension on ProfileJsonOptions {
  ProfileJsonOptions copyWith(
      {DateTime? tipsAndTricksModifiedAt,
      JsonNode? tipsAndTricks,
      DateTime? voiceOverGuidanceVoiceModifiedAt,
      JsonNode? voiceOverGuidanceVoice}) {
    return ProfileJsonOptions(
        tipsAndTricksModifiedAt:
            tipsAndTricksModifiedAt ?? this.tipsAndTricksModifiedAt,
        tipsAndTricks: tipsAndTricks ?? this.tipsAndTricks,
        voiceOverGuidanceVoiceModifiedAt: voiceOverGuidanceVoiceModifiedAt ??
            this.voiceOverGuidanceVoiceModifiedAt,
        voiceOverGuidanceVoice:
            voiceOverGuidanceVoice ?? this.voiceOverGuidanceVoice);
  }

  ProfileJsonOptions copyWithWrapped(
      {Wrapped<DateTime?>? tipsAndTricksModifiedAt,
      Wrapped<JsonNode?>? tipsAndTricks,
      Wrapped<DateTime?>? voiceOverGuidanceVoiceModifiedAt,
      Wrapped<JsonNode?>? voiceOverGuidanceVoice}) {
    return ProfileJsonOptions(
        tipsAndTricksModifiedAt: (tipsAndTricksModifiedAt != null
            ? tipsAndTricksModifiedAt.value
            : this.tipsAndTricksModifiedAt),
        tipsAndTricks:
            (tipsAndTricks != null ? tipsAndTricks.value : this.tipsAndTricks),
        voiceOverGuidanceVoiceModifiedAt:
            (voiceOverGuidanceVoiceModifiedAt != null
                ? voiceOverGuidanceVoiceModifiedAt.value
                : this.voiceOverGuidanceVoiceModifiedAt),
        voiceOverGuidanceVoice: (voiceOverGuidanceVoice != null
            ? voiceOverGuidanceVoice.value
            : this.voiceOverGuidanceVoice));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileOptions {
  ProfileOptions({
    this.lang,
    this.langModifiedAt,
    this.audioLang,
    this.audioLangModifiedAt,
    this.subLang,
    this.subLangModifiedAt,
    this.hardOfHearing,
    this.hardOfHearingModifiedAt,
    this.audioDescription,
    this.audioDescriptionModifiedAt,
    this.showSubtitles,
    this.showSubtitlesModifiedAt,
    this.signLanguage,
    this.signLanguageModifiedAt,
    this.keyboardMode,
    this.keyboardModeModifiedAt,
    this.myListId,
    this.isVoiceOverGuidanceEnabled,
    this.isVoiceOverGuidanceEnabledModifiedAt,
    this.voiceOverGuidanceSpeed,
    this.voiceOverGuidanceSpeedModifiedAt,
    this.voiceOverGuidanceVolume,
    this.voiceOverGuidanceVolumeModifiedAt,
  });

  factory ProfileOptions.fromJson(Map<String, dynamic> json) =>
      _$ProfileOptionsFromJson(json);

  static const toJsonFactory = _$ProfileOptionsToJson;
  Map<String, dynamic> toJson() => _$ProfileOptionsToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String? lang;
  @JsonKey(name: 'langModifiedAt', includeIfNull: false)
  final DateTime? langModifiedAt;
  @JsonKey(name: 'audioLang', includeIfNull: false, defaultValue: '')
  final String? audioLang;
  @JsonKey(name: 'audioLangModifiedAt', includeIfNull: false)
  final DateTime? audioLangModifiedAt;
  @JsonKey(name: 'subLang', includeIfNull: false, defaultValue: '')
  final String? subLang;
  @JsonKey(name: 'subLangModifiedAt', includeIfNull: false)
  final DateTime? subLangModifiedAt;
  @JsonKey(name: 'hardOfHearing', includeIfNull: false)
  final bool? hardOfHearing;
  @JsonKey(name: 'hardOfHearingModifiedAt', includeIfNull: false)
  final DateTime? hardOfHearingModifiedAt;
  @JsonKey(name: 'audioDescription', includeIfNull: false)
  final bool? audioDescription;
  @JsonKey(name: 'audioDescriptionModifiedAt', includeIfNull: false)
  final DateTime? audioDescriptionModifiedAt;
  @JsonKey(name: 'showSubtitles', includeIfNull: false)
  final bool? showSubtitles;
  @JsonKey(name: 'showSubtitlesModifiedAt', includeIfNull: false)
  final DateTime? showSubtitlesModifiedAt;
  @JsonKey(name: 'signLanguage', includeIfNull: false)
  final bool? signLanguage;
  @JsonKey(name: 'signLanguageModifiedAt', includeIfNull: false)
  final DateTime? signLanguageModifiedAt;
  @JsonKey(name: 'keyboardMode', includeIfNull: false, defaultValue: '')
  final String? keyboardMode;
  @JsonKey(name: 'keyboardModeModifiedAt', includeIfNull: false)
  final DateTime? keyboardModeModifiedAt;
  @JsonKey(name: 'myListId', includeIfNull: false, defaultValue: '')
  final String? myListId;
  @JsonKey(name: 'isVoiceOverGuidanceEnabled', includeIfNull: false)
  final bool? isVoiceOverGuidanceEnabled;
  @JsonKey(name: 'isVoiceOverGuidanceEnabledModifiedAt', includeIfNull: false)
  final DateTime? isVoiceOverGuidanceEnabledModifiedAt;
  @JsonKey(
      name: 'voiceOverGuidanceSpeed', includeIfNull: false, defaultValue: '')
  final String? voiceOverGuidanceSpeed;
  @JsonKey(name: 'voiceOverGuidanceSpeedModifiedAt', includeIfNull: false)
  final DateTime? voiceOverGuidanceSpeedModifiedAt;
  @JsonKey(
      name: 'voiceOverGuidanceVolume', includeIfNull: false, defaultValue: '')
  final String? voiceOverGuidanceVolume;
  @JsonKey(name: 'voiceOverGuidanceVolumeModifiedAt', includeIfNull: false)
  final DateTime? voiceOverGuidanceVolumeModifiedAt;
  static const fromJsonFactory = _$ProfileOptionsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileOptions &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.langModifiedAt, langModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.langModifiedAt, langModifiedAt)) &&
            (identical(other.audioLang, audioLang) ||
                const DeepCollectionEquality()
                    .equals(other.audioLang, audioLang)) &&
            (identical(other.audioLangModifiedAt, audioLangModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.audioLangModifiedAt, audioLangModifiedAt)) &&
            (identical(other.subLang, subLang) ||
                const DeepCollectionEquality()
                    .equals(other.subLang, subLang)) &&
            (identical(other.subLangModifiedAt, subLangModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.subLangModifiedAt, subLangModifiedAt)) &&
            (identical(other.hardOfHearing, hardOfHearing) ||
                const DeepCollectionEquality()
                    .equals(other.hardOfHearing, hardOfHearing)) &&
            (identical(other.hardOfHearingModifiedAt, hardOfHearingModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.hardOfHearingModifiedAt, hardOfHearingModifiedAt)) &&
            (identical(other.audioDescription, audioDescription) ||
                const DeepCollectionEquality()
                    .equals(other.audioDescription, audioDescription)) &&
            (identical(other.audioDescriptionModifiedAt, audioDescriptionModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.audioDescriptionModifiedAt,
                    audioDescriptionModifiedAt)) &&
            (identical(other.showSubtitles, showSubtitles) ||
                const DeepCollectionEquality()
                    .equals(other.showSubtitles, showSubtitles)) &&
            (identical(other.showSubtitlesModifiedAt, showSubtitlesModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.showSubtitlesModifiedAt, showSubtitlesModifiedAt)) &&
            (identical(other.signLanguage, signLanguage) ||
                const DeepCollectionEquality()
                    .equals(other.signLanguage, signLanguage)) &&
            (identical(other.signLanguageModifiedAt, signLanguageModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.signLanguageModifiedAt, signLanguageModifiedAt)) &&
            (identical(other.keyboardMode, keyboardMode) ||
                const DeepCollectionEquality()
                    .equals(other.keyboardMode, keyboardMode)) &&
            (identical(other.keyboardModeModifiedAt, keyboardModeModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.keyboardModeModifiedAt, keyboardModeModifiedAt)) &&
            (identical(other.myListId, myListId) || const DeepCollectionEquality().equals(other.myListId, myListId)) &&
            (identical(other.isVoiceOverGuidanceEnabled, isVoiceOverGuidanceEnabled) || const DeepCollectionEquality().equals(other.isVoiceOverGuidanceEnabled, isVoiceOverGuidanceEnabled)) &&
            (identical(other.isVoiceOverGuidanceEnabledModifiedAt, isVoiceOverGuidanceEnabledModifiedAt) || const DeepCollectionEquality().equals(other.isVoiceOverGuidanceEnabledModifiedAt, isVoiceOverGuidanceEnabledModifiedAt)) &&
            (identical(other.voiceOverGuidanceSpeed, voiceOverGuidanceSpeed) || const DeepCollectionEquality().equals(other.voiceOverGuidanceSpeed, voiceOverGuidanceSpeed)) &&
            (identical(other.voiceOverGuidanceSpeedModifiedAt, voiceOverGuidanceSpeedModifiedAt) || const DeepCollectionEquality().equals(other.voiceOverGuidanceSpeedModifiedAt, voiceOverGuidanceSpeedModifiedAt)) &&
            (identical(other.voiceOverGuidanceVolume, voiceOverGuidanceVolume) || const DeepCollectionEquality().equals(other.voiceOverGuidanceVolume, voiceOverGuidanceVolume)) &&
            (identical(other.voiceOverGuidanceVolumeModifiedAt, voiceOverGuidanceVolumeModifiedAt) || const DeepCollectionEquality().equals(other.voiceOverGuidanceVolumeModifiedAt, voiceOverGuidanceVolumeModifiedAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(langModifiedAt) ^
      const DeepCollectionEquality().hash(audioLang) ^
      const DeepCollectionEquality().hash(audioLangModifiedAt) ^
      const DeepCollectionEquality().hash(subLang) ^
      const DeepCollectionEquality().hash(subLangModifiedAt) ^
      const DeepCollectionEquality().hash(hardOfHearing) ^
      const DeepCollectionEquality().hash(hardOfHearingModifiedAt) ^
      const DeepCollectionEquality().hash(audioDescription) ^
      const DeepCollectionEquality().hash(audioDescriptionModifiedAt) ^
      const DeepCollectionEquality().hash(showSubtitles) ^
      const DeepCollectionEquality().hash(showSubtitlesModifiedAt) ^
      const DeepCollectionEquality().hash(signLanguage) ^
      const DeepCollectionEquality().hash(signLanguageModifiedAt) ^
      const DeepCollectionEquality().hash(keyboardMode) ^
      const DeepCollectionEquality().hash(keyboardModeModifiedAt) ^
      const DeepCollectionEquality().hash(myListId) ^
      const DeepCollectionEquality().hash(isVoiceOverGuidanceEnabled) ^
      const DeepCollectionEquality()
          .hash(isVoiceOverGuidanceEnabledModifiedAt) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceSpeed) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceSpeedModifiedAt) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceVolume) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceVolumeModifiedAt) ^
      runtimeType.hashCode;
}

extension $ProfileOptionsExtension on ProfileOptions {
  ProfileOptions copyWith(
      {String? lang,
      DateTime? langModifiedAt,
      String? audioLang,
      DateTime? audioLangModifiedAt,
      String? subLang,
      DateTime? subLangModifiedAt,
      bool? hardOfHearing,
      DateTime? hardOfHearingModifiedAt,
      bool? audioDescription,
      DateTime? audioDescriptionModifiedAt,
      bool? showSubtitles,
      DateTime? showSubtitlesModifiedAt,
      bool? signLanguage,
      DateTime? signLanguageModifiedAt,
      String? keyboardMode,
      DateTime? keyboardModeModifiedAt,
      String? myListId,
      bool? isVoiceOverGuidanceEnabled,
      DateTime? isVoiceOverGuidanceEnabledModifiedAt,
      String? voiceOverGuidanceSpeed,
      DateTime? voiceOverGuidanceSpeedModifiedAt,
      String? voiceOverGuidanceVolume,
      DateTime? voiceOverGuidanceVolumeModifiedAt}) {
    return ProfileOptions(
        lang: lang ?? this.lang,
        langModifiedAt: langModifiedAt ?? this.langModifiedAt,
        audioLang: audioLang ?? this.audioLang,
        audioLangModifiedAt: audioLangModifiedAt ?? this.audioLangModifiedAt,
        subLang: subLang ?? this.subLang,
        subLangModifiedAt: subLangModifiedAt ?? this.subLangModifiedAt,
        hardOfHearing: hardOfHearing ?? this.hardOfHearing,
        hardOfHearingModifiedAt:
            hardOfHearingModifiedAt ?? this.hardOfHearingModifiedAt,
        audioDescription: audioDescription ?? this.audioDescription,
        audioDescriptionModifiedAt:
            audioDescriptionModifiedAt ?? this.audioDescriptionModifiedAt,
        showSubtitles: showSubtitles ?? this.showSubtitles,
        showSubtitlesModifiedAt:
            showSubtitlesModifiedAt ?? this.showSubtitlesModifiedAt,
        signLanguage: signLanguage ?? this.signLanguage,
        signLanguageModifiedAt:
            signLanguageModifiedAt ?? this.signLanguageModifiedAt,
        keyboardMode: keyboardMode ?? this.keyboardMode,
        keyboardModeModifiedAt:
            keyboardModeModifiedAt ?? this.keyboardModeModifiedAt,
        myListId: myListId ?? this.myListId,
        isVoiceOverGuidanceEnabled:
            isVoiceOverGuidanceEnabled ?? this.isVoiceOverGuidanceEnabled,
        isVoiceOverGuidanceEnabledModifiedAt:
            isVoiceOverGuidanceEnabledModifiedAt ??
                this.isVoiceOverGuidanceEnabledModifiedAt,
        voiceOverGuidanceSpeed:
            voiceOverGuidanceSpeed ?? this.voiceOverGuidanceSpeed,
        voiceOverGuidanceSpeedModifiedAt: voiceOverGuidanceSpeedModifiedAt ??
            this.voiceOverGuidanceSpeedModifiedAt,
        voiceOverGuidanceVolume:
            voiceOverGuidanceVolume ?? this.voiceOverGuidanceVolume,
        voiceOverGuidanceVolumeModifiedAt: voiceOverGuidanceVolumeModifiedAt ??
            this.voiceOverGuidanceVolumeModifiedAt);
  }

  ProfileOptions copyWithWrapped(
      {Wrapped<String?>? lang,
      Wrapped<DateTime?>? langModifiedAt,
      Wrapped<String?>? audioLang,
      Wrapped<DateTime?>? audioLangModifiedAt,
      Wrapped<String?>? subLang,
      Wrapped<DateTime?>? subLangModifiedAt,
      Wrapped<bool?>? hardOfHearing,
      Wrapped<DateTime?>? hardOfHearingModifiedAt,
      Wrapped<bool?>? audioDescription,
      Wrapped<DateTime?>? audioDescriptionModifiedAt,
      Wrapped<bool?>? showSubtitles,
      Wrapped<DateTime?>? showSubtitlesModifiedAt,
      Wrapped<bool?>? signLanguage,
      Wrapped<DateTime?>? signLanguageModifiedAt,
      Wrapped<String?>? keyboardMode,
      Wrapped<DateTime?>? keyboardModeModifiedAt,
      Wrapped<String?>? myListId,
      Wrapped<bool?>? isVoiceOverGuidanceEnabled,
      Wrapped<DateTime?>? isVoiceOverGuidanceEnabledModifiedAt,
      Wrapped<String?>? voiceOverGuidanceSpeed,
      Wrapped<DateTime?>? voiceOverGuidanceSpeedModifiedAt,
      Wrapped<String?>? voiceOverGuidanceVolume,
      Wrapped<DateTime?>? voiceOverGuidanceVolumeModifiedAt}) {
    return ProfileOptions(
        lang: (lang != null ? lang.value : this.lang),
        langModifiedAt: (langModifiedAt != null
            ? langModifiedAt.value
            : this.langModifiedAt),
        audioLang: (audioLang != null ? audioLang.value : this.audioLang),
        audioLangModifiedAt: (audioLangModifiedAt != null
            ? audioLangModifiedAt.value
            : this.audioLangModifiedAt),
        subLang: (subLang != null ? subLang.value : this.subLang),
        subLangModifiedAt: (subLangModifiedAt != null
            ? subLangModifiedAt.value
            : this.subLangModifiedAt),
        hardOfHearing:
            (hardOfHearing != null ? hardOfHearing.value : this.hardOfHearing),
        hardOfHearingModifiedAt: (hardOfHearingModifiedAt != null
            ? hardOfHearingModifiedAt.value
            : this.hardOfHearingModifiedAt),
        audioDescription: (audioDescription != null
            ? audioDescription.value
            : this.audioDescription),
        audioDescriptionModifiedAt: (audioDescriptionModifiedAt != null
            ? audioDescriptionModifiedAt.value
            : this.audioDescriptionModifiedAt),
        showSubtitles:
            (showSubtitles != null ? showSubtitles.value : this.showSubtitles),
        showSubtitlesModifiedAt: (showSubtitlesModifiedAt != null
            ? showSubtitlesModifiedAt.value
            : this.showSubtitlesModifiedAt),
        signLanguage:
            (signLanguage != null ? signLanguage.value : this.signLanguage),
        signLanguageModifiedAt: (signLanguageModifiedAt != null
            ? signLanguageModifiedAt.value
            : this.signLanguageModifiedAt),
        keyboardMode:
            (keyboardMode != null ? keyboardMode.value : this.keyboardMode),
        keyboardModeModifiedAt: (keyboardModeModifiedAt != null
            ? keyboardModeModifiedAt.value
            : this.keyboardModeModifiedAt),
        myListId: (myListId != null ? myListId.value : this.myListId),
        isVoiceOverGuidanceEnabled: (isVoiceOverGuidanceEnabled != null
            ? isVoiceOverGuidanceEnabled.value
            : this.isVoiceOverGuidanceEnabled),
        isVoiceOverGuidanceEnabledModifiedAt:
            (isVoiceOverGuidanceEnabledModifiedAt != null
                ? isVoiceOverGuidanceEnabledModifiedAt.value
                : this.isVoiceOverGuidanceEnabledModifiedAt),
        voiceOverGuidanceSpeed: (voiceOverGuidanceSpeed != null
            ? voiceOverGuidanceSpeed.value
            : this.voiceOverGuidanceSpeed),
        voiceOverGuidanceSpeedModifiedAt:
            (voiceOverGuidanceSpeedModifiedAt != null
                ? voiceOverGuidanceSpeedModifiedAt.value
                : this.voiceOverGuidanceSpeedModifiedAt),
        voiceOverGuidanceVolume: (voiceOverGuidanceVolume != null
            ? voiceOverGuidanceVolume.value
            : this.voiceOverGuidanceVolume),
        voiceOverGuidanceVolumeModifiedAt:
            (voiceOverGuidanceVolumeModifiedAt != null
                ? voiceOverGuidanceVolumeModifiedAt.value
                : this.voiceOverGuidanceVolumeModifiedAt));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileRequest {
  ProfileRequest({
    this.profileId,
    this.customerId,
    this.externalId,
    this.name,
    this.shared,
    this.colour,
    this.lastWatchedChannel,
    this.options,
    this.jsonOptions,
    this.favoriteChannels,
    this.recentlyUsedApps,
    this.recentlyUsedSettings,
    this.accessibleViews,
  });

  factory ProfileRequest.fromJson(Map<String, dynamic> json) =>
      _$ProfileRequestFromJson(json);

  static const toJsonFactory = _$ProfileRequestToJson;
  Map<String, dynamic> toJson() => _$ProfileRequestToJson(this);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'externalId', includeIfNull: false, defaultValue: '')
  final String? externalId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'shared', includeIfNull: false)
  final bool? shared;
  @JsonKey(name: 'colour', includeIfNull: false, defaultValue: '')
  final String? colour;
  @JsonKey(name: 'lastWatchedChannel', includeIfNull: false)
  final int? lastWatchedChannel;
  @JsonKey(name: 'options', includeIfNull: false)
  final ProfileOptionsRequest? options;
  @JsonKey(name: 'jsonOptions', includeIfNull: false)
  final ProfileJsonOptionsRequest? jsonOptions;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? favoriteChannels;
  @JsonKey(
      name: 'recentlyUsedApps', includeIfNull: false, defaultValue: <String>[])
  final List<String>? recentlyUsedApps;
  @JsonKey(
      name: 'recentlyUsedSettings',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? recentlyUsedSettings;
  @JsonKey(
      name: 'accessibleViews', includeIfNull: false, defaultValue: <String>[])
  final List<String>? accessibleViews;
  static const fromJsonFactory = _$ProfileRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileRequest &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.externalId, externalId) ||
                const DeepCollectionEquality()
                    .equals(other.externalId, externalId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.shared, shared) ||
                const DeepCollectionEquality().equals(other.shared, shared)) &&
            (identical(other.colour, colour) ||
                const DeepCollectionEquality().equals(other.colour, colour)) &&
            (identical(other.lastWatchedChannel, lastWatchedChannel) ||
                const DeepCollectionEquality()
                    .equals(other.lastWatchedChannel, lastWatchedChannel)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality()
                    .equals(other.options, options)) &&
            (identical(other.jsonOptions, jsonOptions) ||
                const DeepCollectionEquality()
                    .equals(other.jsonOptions, jsonOptions)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)) &&
            (identical(other.recentlyUsedApps, recentlyUsedApps) ||
                const DeepCollectionEquality()
                    .equals(other.recentlyUsedApps, recentlyUsedApps)) &&
            (identical(other.recentlyUsedSettings, recentlyUsedSettings) ||
                const DeepCollectionEquality().equals(
                    other.recentlyUsedSettings, recentlyUsedSettings)) &&
            (identical(other.accessibleViews, accessibleViews) ||
                const DeepCollectionEquality()
                    .equals(other.accessibleViews, accessibleViews)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(externalId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(shared) ^
      const DeepCollectionEquality().hash(colour) ^
      const DeepCollectionEquality().hash(lastWatchedChannel) ^
      const DeepCollectionEquality().hash(options) ^
      const DeepCollectionEquality().hash(jsonOptions) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      const DeepCollectionEquality().hash(recentlyUsedApps) ^
      const DeepCollectionEquality().hash(recentlyUsedSettings) ^
      const DeepCollectionEquality().hash(accessibleViews) ^
      runtimeType.hashCode;
}

extension $ProfileRequestExtension on ProfileRequest {
  ProfileRequest copyWith(
      {String? profileId,
      String? customerId,
      String? externalId,
      String? name,
      bool? shared,
      String? colour,
      int? lastWatchedChannel,
      ProfileOptionsRequest? options,
      ProfileJsonOptionsRequest? jsonOptions,
      List<String>? favoriteChannels,
      List<String>? recentlyUsedApps,
      List<String>? recentlyUsedSettings,
      List<String>? accessibleViews}) {
    return ProfileRequest(
        profileId: profileId ?? this.profileId,
        customerId: customerId ?? this.customerId,
        externalId: externalId ?? this.externalId,
        name: name ?? this.name,
        shared: shared ?? this.shared,
        colour: colour ?? this.colour,
        lastWatchedChannel: lastWatchedChannel ?? this.lastWatchedChannel,
        options: options ?? this.options,
        jsonOptions: jsonOptions ?? this.jsonOptions,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels,
        recentlyUsedApps: recentlyUsedApps ?? this.recentlyUsedApps,
        recentlyUsedSettings: recentlyUsedSettings ?? this.recentlyUsedSettings,
        accessibleViews: accessibleViews ?? this.accessibleViews);
  }

  ProfileRequest copyWithWrapped(
      {Wrapped<String?>? profileId,
      Wrapped<String?>? customerId,
      Wrapped<String?>? externalId,
      Wrapped<String?>? name,
      Wrapped<bool?>? shared,
      Wrapped<String?>? colour,
      Wrapped<int?>? lastWatchedChannel,
      Wrapped<ProfileOptionsRequest?>? options,
      Wrapped<ProfileJsonOptionsRequest?>? jsonOptions,
      Wrapped<List<String>?>? favoriteChannels,
      Wrapped<List<String>?>? recentlyUsedApps,
      Wrapped<List<String>?>? recentlyUsedSettings,
      Wrapped<List<String>?>? accessibleViews}) {
    return ProfileRequest(
        profileId: (profileId != null ? profileId.value : this.profileId),
        customerId: (customerId != null ? customerId.value : this.customerId),
        externalId: (externalId != null ? externalId.value : this.externalId),
        name: (name != null ? name.value : this.name),
        shared: (shared != null ? shared.value : this.shared),
        colour: (colour != null ? colour.value : this.colour),
        lastWatchedChannel: (lastWatchedChannel != null
            ? lastWatchedChannel.value
            : this.lastWatchedChannel),
        options: (options != null ? options.value : this.options),
        jsonOptions:
            (jsonOptions != null ? jsonOptions.value : this.jsonOptions),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels),
        recentlyUsedApps: (recentlyUsedApps != null
            ? recentlyUsedApps.value
            : this.recentlyUsedApps),
        recentlyUsedSettings: (recentlyUsedSettings != null
            ? recentlyUsedSettings.value
            : this.recentlyUsedSettings),
        accessibleViews: (accessibleViews != null
            ? accessibleViews.value
            : this.accessibleViews));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileOptionsRequest {
  ProfileOptionsRequest({
    this.lang,
    this.audioLang,
    this.subLang,
    this.hardOfHearing,
    this.audioDescription,
    this.showSubtitles,
    this.signLanguage,
    this.keyboardMode,
    this.myListId,
    this.isVoiceOverGuidanceEnabled,
    this.voiceOverGuidanceSpeed,
    this.voiceOverGuidanceVolume,
  });

  factory ProfileOptionsRequest.fromJson(Map<String, dynamic> json) =>
      _$ProfileOptionsRequestFromJson(json);

  static const toJsonFactory = _$ProfileOptionsRequestToJson;
  Map<String, dynamic> toJson() => _$ProfileOptionsRequestToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String? lang;
  @JsonKey(name: 'audioLang', includeIfNull: false, defaultValue: '')
  final String? audioLang;
  @JsonKey(name: 'subLang', includeIfNull: false, defaultValue: '')
  final String? subLang;
  @JsonKey(name: 'hardOfHearing', includeIfNull: false)
  final bool? hardOfHearing;
  @JsonKey(name: 'audioDescription', includeIfNull: false)
  final bool? audioDescription;
  @JsonKey(name: 'showSubtitles', includeIfNull: false)
  final bool? showSubtitles;
  @JsonKey(name: 'signLanguage', includeIfNull: false)
  final bool? signLanguage;
  @JsonKey(name: 'keyboardMode', includeIfNull: false, defaultValue: '')
  final String? keyboardMode;
  @JsonKey(name: 'myListId', includeIfNull: false, defaultValue: '')
  final String? myListId;
  @JsonKey(name: 'isVoiceOverGuidanceEnabled', includeIfNull: false)
  final bool? isVoiceOverGuidanceEnabled;
  @JsonKey(
      name: 'voiceOverGuidanceSpeed', includeIfNull: false, defaultValue: '')
  final String? voiceOverGuidanceSpeed;
  @JsonKey(
      name: 'voiceOverGuidanceVolume', includeIfNull: false, defaultValue: '')
  final String? voiceOverGuidanceVolume;
  static const fromJsonFactory = _$ProfileOptionsRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileOptionsRequest &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.audioLang, audioLang) ||
                const DeepCollectionEquality()
                    .equals(other.audioLang, audioLang)) &&
            (identical(other.subLang, subLang) ||
                const DeepCollectionEquality()
                    .equals(other.subLang, subLang)) &&
            (identical(other.hardOfHearing, hardOfHearing) ||
                const DeepCollectionEquality()
                    .equals(other.hardOfHearing, hardOfHearing)) &&
            (identical(other.audioDescription, audioDescription) ||
                const DeepCollectionEquality()
                    .equals(other.audioDescription, audioDescription)) &&
            (identical(other.showSubtitles, showSubtitles) ||
                const DeepCollectionEquality()
                    .equals(other.showSubtitles, showSubtitles)) &&
            (identical(other.signLanguage, signLanguage) ||
                const DeepCollectionEquality()
                    .equals(other.signLanguage, signLanguage)) &&
            (identical(other.keyboardMode, keyboardMode) ||
                const DeepCollectionEquality()
                    .equals(other.keyboardMode, keyboardMode)) &&
            (identical(other.myListId, myListId) ||
                const DeepCollectionEquality()
                    .equals(other.myListId, myListId)) &&
            (identical(other.isVoiceOverGuidanceEnabled,
                    isVoiceOverGuidanceEnabled) ||
                const DeepCollectionEquality().equals(
                    other.isVoiceOverGuidanceEnabled,
                    isVoiceOverGuidanceEnabled)) &&
            (identical(other.voiceOverGuidanceSpeed, voiceOverGuidanceSpeed) ||
                const DeepCollectionEquality().equals(
                    other.voiceOverGuidanceSpeed, voiceOverGuidanceSpeed)) &&
            (identical(
                    other.voiceOverGuidanceVolume, voiceOverGuidanceVolume) ||
                const DeepCollectionEquality().equals(
                    other.voiceOverGuidanceVolume, voiceOverGuidanceVolume)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(audioLang) ^
      const DeepCollectionEquality().hash(subLang) ^
      const DeepCollectionEquality().hash(hardOfHearing) ^
      const DeepCollectionEquality().hash(audioDescription) ^
      const DeepCollectionEquality().hash(showSubtitles) ^
      const DeepCollectionEquality().hash(signLanguage) ^
      const DeepCollectionEquality().hash(keyboardMode) ^
      const DeepCollectionEquality().hash(myListId) ^
      const DeepCollectionEquality().hash(isVoiceOverGuidanceEnabled) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceSpeed) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceVolume) ^
      runtimeType.hashCode;
}

extension $ProfileOptionsRequestExtension on ProfileOptionsRequest {
  ProfileOptionsRequest copyWith(
      {String? lang,
      String? audioLang,
      String? subLang,
      bool? hardOfHearing,
      bool? audioDescription,
      bool? showSubtitles,
      bool? signLanguage,
      String? keyboardMode,
      String? myListId,
      bool? isVoiceOverGuidanceEnabled,
      String? voiceOverGuidanceSpeed,
      String? voiceOverGuidanceVolume}) {
    return ProfileOptionsRequest(
        lang: lang ?? this.lang,
        audioLang: audioLang ?? this.audioLang,
        subLang: subLang ?? this.subLang,
        hardOfHearing: hardOfHearing ?? this.hardOfHearing,
        audioDescription: audioDescription ?? this.audioDescription,
        showSubtitles: showSubtitles ?? this.showSubtitles,
        signLanguage: signLanguage ?? this.signLanguage,
        keyboardMode: keyboardMode ?? this.keyboardMode,
        myListId: myListId ?? this.myListId,
        isVoiceOverGuidanceEnabled:
            isVoiceOverGuidanceEnabled ?? this.isVoiceOverGuidanceEnabled,
        voiceOverGuidanceSpeed:
            voiceOverGuidanceSpeed ?? this.voiceOverGuidanceSpeed,
        voiceOverGuidanceVolume:
            voiceOverGuidanceVolume ?? this.voiceOverGuidanceVolume);
  }

  ProfileOptionsRequest copyWithWrapped(
      {Wrapped<String?>? lang,
      Wrapped<String?>? audioLang,
      Wrapped<String?>? subLang,
      Wrapped<bool?>? hardOfHearing,
      Wrapped<bool?>? audioDescription,
      Wrapped<bool?>? showSubtitles,
      Wrapped<bool?>? signLanguage,
      Wrapped<String?>? keyboardMode,
      Wrapped<String?>? myListId,
      Wrapped<bool?>? isVoiceOverGuidanceEnabled,
      Wrapped<String?>? voiceOverGuidanceSpeed,
      Wrapped<String?>? voiceOverGuidanceVolume}) {
    return ProfileOptionsRequest(
        lang: (lang != null ? lang.value : this.lang),
        audioLang: (audioLang != null ? audioLang.value : this.audioLang),
        subLang: (subLang != null ? subLang.value : this.subLang),
        hardOfHearing:
            (hardOfHearing != null ? hardOfHearing.value : this.hardOfHearing),
        audioDescription: (audioDescription != null
            ? audioDescription.value
            : this.audioDescription),
        showSubtitles:
            (showSubtitles != null ? showSubtitles.value : this.showSubtitles),
        signLanguage:
            (signLanguage != null ? signLanguage.value : this.signLanguage),
        keyboardMode:
            (keyboardMode != null ? keyboardMode.value : this.keyboardMode),
        myListId: (myListId != null ? myListId.value : this.myListId),
        isVoiceOverGuidanceEnabled: (isVoiceOverGuidanceEnabled != null
            ? isVoiceOverGuidanceEnabled.value
            : this.isVoiceOverGuidanceEnabled),
        voiceOverGuidanceSpeed: (voiceOverGuidanceSpeed != null
            ? voiceOverGuidanceSpeed.value
            : this.voiceOverGuidanceSpeed),
        voiceOverGuidanceVolume: (voiceOverGuidanceVolume != null
            ? voiceOverGuidanceVolume.value
            : this.voiceOverGuidanceVolume));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileJsonOptionsRequest {
  ProfileJsonOptionsRequest({
    this.tipsAndTricks,
    this.voiceOverGuidanceVoice,
  });

  factory ProfileJsonOptionsRequest.fromJson(Map<String, dynamic> json) =>
      _$ProfileJsonOptionsRequestFromJson(json);

  static const toJsonFactory = _$ProfileJsonOptionsRequestToJson;
  Map<String, dynamic> toJson() => _$ProfileJsonOptionsRequestToJson(this);

  @JsonKey(name: 'tipsAndTricks', includeIfNull: false)
  final JsonNode? tipsAndTricks;
  @JsonKey(name: 'voiceOverGuidanceVoice', includeIfNull: false)
  final JsonNode? voiceOverGuidanceVoice;
  static const fromJsonFactory = _$ProfileJsonOptionsRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileJsonOptionsRequest &&
            (identical(other.tipsAndTricks, tipsAndTricks) ||
                const DeepCollectionEquality()
                    .equals(other.tipsAndTricks, tipsAndTricks)) &&
            (identical(other.voiceOverGuidanceVoice, voiceOverGuidanceVoice) ||
                const DeepCollectionEquality().equals(
                    other.voiceOverGuidanceVoice, voiceOverGuidanceVoice)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tipsAndTricks) ^
      const DeepCollectionEquality().hash(voiceOverGuidanceVoice) ^
      runtimeType.hashCode;
}

extension $ProfileJsonOptionsRequestExtension on ProfileJsonOptionsRequest {
  ProfileJsonOptionsRequest copyWith(
      {JsonNode? tipsAndTricks, JsonNode? voiceOverGuidanceVoice}) {
    return ProfileJsonOptionsRequest(
        tipsAndTricks: tipsAndTricks ?? this.tipsAndTricks,
        voiceOverGuidanceVoice:
            voiceOverGuidanceVoice ?? this.voiceOverGuidanceVoice);
  }

  ProfileJsonOptionsRequest copyWithWrapped(
      {Wrapped<JsonNode?>? tipsAndTricks,
      Wrapped<JsonNode?>? voiceOverGuidanceVoice}) {
    return ProfileJsonOptionsRequest(
        tipsAndTricks:
            (tipsAndTricks != null ? tipsAndTricks.value : this.tipsAndTricks),
        voiceOverGuidanceVoice: (voiceOverGuidanceVoice != null
            ? voiceOverGuidanceVoice.value
            : this.voiceOverGuidanceVoice));
  }
}

@JsonSerializable(explicitToJson: true)
class AdvancedAdvertising {
  AdvancedAdvertising({
    this.disableAdvancedAdvertising,
    this.advancedAdvertisingMode,
    this.a2aStbEnabled,
    this.a2aHgoEnabled,
  });

  factory AdvancedAdvertising.fromJson(Map<String, dynamic> json) =>
      _$AdvancedAdvertisingFromJson(json);

  static const toJsonFactory = _$AdvancedAdvertisingToJson;
  Map<String, dynamic> toJson() => _$AdvancedAdvertisingToJson(this);

  @JsonKey(name: 'disableAdvancedAdvertising', includeIfNull: false)
  final bool? disableAdvancedAdvertising;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  @JsonKey(name: 'a2aStbEnabled', includeIfNull: false)
  final bool? a2aStbEnabled;
  @JsonKey(name: 'a2aHgoEnabled', includeIfNull: false)
  final bool? a2aHgoEnabled;
  static const fromJsonFactory = _$AdvancedAdvertisingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AdvancedAdvertising &&
            (identical(other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising) ||
                const DeepCollectionEquality().equals(
                    other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)) &&
            (identical(other.a2aStbEnabled, a2aStbEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.a2aStbEnabled, a2aStbEnabled)) &&
            (identical(other.a2aHgoEnabled, a2aHgoEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.a2aHgoEnabled, a2aHgoEnabled)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(disableAdvancedAdvertising) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      const DeepCollectionEquality().hash(a2aStbEnabled) ^
      const DeepCollectionEquality().hash(a2aHgoEnabled) ^
      runtimeType.hashCode;
}

extension $AdvancedAdvertisingExtension on AdvancedAdvertising {
  AdvancedAdvertising copyWith(
      {bool? disableAdvancedAdvertising,
      String? advancedAdvertisingMode,
      bool? a2aStbEnabled,
      bool? a2aHgoEnabled}) {
    return AdvancedAdvertising(
        disableAdvancedAdvertising:
            disableAdvancedAdvertising ?? this.disableAdvancedAdvertising,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode,
        a2aStbEnabled: a2aStbEnabled ?? this.a2aStbEnabled,
        a2aHgoEnabled: a2aHgoEnabled ?? this.a2aHgoEnabled);
  }

  AdvancedAdvertising copyWithWrapped(
      {Wrapped<bool?>? disableAdvancedAdvertising,
      Wrapped<String?>? advancedAdvertisingMode,
      Wrapped<bool?>? a2aStbEnabled,
      Wrapped<bool?>? a2aHgoEnabled}) {
    return AdvancedAdvertising(
        disableAdvancedAdvertising: (disableAdvancedAdvertising != null
            ? disableAdvancedAdvertising.value
            : this.disableAdvancedAdvertising),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode),
        a2aStbEnabled:
            (a2aStbEnabled != null ? a2aStbEnabled.value : this.a2aStbEnabled),
        a2aHgoEnabled:
            (a2aHgoEnabled != null ? a2aHgoEnabled.value : this.a2aHgoEnabled));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileId {
  ProfileId({
    this.profileId,
  });

  factory ProfileId.fromJson(Map<String, dynamic> json) =>
      _$ProfileIdFromJson(json);

  static const toJsonFactory = _$ProfileIdToJson;
  Map<String, dynamic> toJson() => _$ProfileIdToJson(this);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  static const fromJsonFactory = _$ProfileIdFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileId &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^ runtimeType.hashCode;
}

extension $ProfileIdExtension on ProfileId {
  ProfileId copyWith({String? profileId}) {
    return ProfileId(profileId: profileId ?? this.profileId);
  }

  ProfileId copyWithWrapped({Wrapped<String?>? profileId}) {
    return ProfileId(
        profileId: (profileId != null ? profileId.value : this.profileId));
  }
}

@JsonSerializable(explicitToJson: true)
class Reminder {
  Reminder({
    this.deviceId,
    this.reminderId,
    this.availabilityStart,
    this.channelId,
    this.profileId,
    this.content,
  });

  factory Reminder.fromJson(Map<String, dynamic> json) =>
      _$ReminderFromJson(json);

  static const toJsonFactory = _$ReminderToJson;
  Map<String, dynamic> toJson() => _$ReminderToJson(this);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'reminderId', includeIfNull: false, defaultValue: '')
  final String? reminderId;
  @JsonKey(name: 'availabilityStart', includeIfNull: false)
  final DateTime? availabilityStart;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'content', includeIfNull: false, defaultValue: '')
  final String? content;
  static const fromJsonFactory = _$ReminderFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Reminder &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.reminderId, reminderId) ||
                const DeepCollectionEquality()
                    .equals(other.reminderId, reminderId)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(reminderId) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $ReminderExtension on Reminder {
  Reminder copyWith(
      {String? deviceId,
      String? reminderId,
      DateTime? availabilityStart,
      String? channelId,
      String? profileId,
      String? content}) {
    return Reminder(
        deviceId: deviceId ?? this.deviceId,
        reminderId: reminderId ?? this.reminderId,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        channelId: channelId ?? this.channelId,
        profileId: profileId ?? this.profileId,
        content: content ?? this.content);
  }

  Reminder copyWithWrapped(
      {Wrapped<String?>? deviceId,
      Wrapped<String?>? reminderId,
      Wrapped<DateTime?>? availabilityStart,
      Wrapped<String?>? channelId,
      Wrapped<String?>? profileId,
      Wrapped<String?>? content}) {
    return Reminder(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        reminderId: (reminderId != null ? reminderId.value : this.reminderId),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        channelId: (channelId != null ? channelId.value : this.channelId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class ReminderId {
  ReminderId({
    this.reminderId,
  });

  factory ReminderId.fromJson(Map<String, dynamic> json) =>
      _$ReminderIdFromJson(json);

  static const toJsonFactory = _$ReminderIdToJson;
  Map<String, dynamic> toJson() => _$ReminderIdToJson(this);

  @JsonKey(name: 'reminderId', includeIfNull: false, defaultValue: '')
  final String? reminderId;
  static const fromJsonFactory = _$ReminderIdFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReminderId &&
            (identical(other.reminderId, reminderId) ||
                const DeepCollectionEquality()
                    .equals(other.reminderId, reminderId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(reminderId) ^ runtimeType.hashCode;
}

extension $ReminderIdExtension on ReminderId {
  ReminderId copyWith({String? reminderId}) {
    return ReminderId(reminderId: reminderId ?? this.reminderId);
  }

  ReminderId copyWithWrapped({Wrapped<String?>? reminderId}) {
    return ReminderId(
        reminderId: (reminderId != null ? reminderId.value : this.reminderId));
  }
}

@JsonSerializable(explicitToJson: true)
class RengCustomer {
  RengCustomer({
    this.personalization,
    this.customerId,
    this.countryId,
    this.cityId,
    this.lockedChannels,
    this.ageLock,
  });

  factory RengCustomer.fromJson(Map<String, dynamic> json) =>
      _$RengCustomerFromJson(json);

  static const toJsonFactory = _$RengCustomerToJson;
  Map<String, dynamic> toJson() => _$RengCustomerToJson(this);

  @JsonKey(name: 'personalization', includeIfNull: false)
  final bool? personalization;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(
      name: 'lockedChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? lockedChannels;
  @JsonKey(name: 'ageLock', includeIfNull: false)
  final int? ageLock;
  static const fromJsonFactory = _$RengCustomerFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RengCustomer &&
            (identical(other.personalization, personalization) ||
                const DeepCollectionEquality()
                    .equals(other.personalization, personalization)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.lockedChannels, lockedChannels) ||
                const DeepCollectionEquality()
                    .equals(other.lockedChannels, lockedChannels)) &&
            (identical(other.ageLock, ageLock) ||
                const DeepCollectionEquality().equals(other.ageLock, ageLock)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(personalization) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(lockedChannels) ^
      const DeepCollectionEquality().hash(ageLock) ^
      runtimeType.hashCode;
}

extension $RengCustomerExtension on RengCustomer {
  RengCustomer copyWith(
      {bool? personalization,
      String? customerId,
      String? countryId,
      int? cityId,
      List<String>? lockedChannels,
      int? ageLock}) {
    return RengCustomer(
        personalization: personalization ?? this.personalization,
        customerId: customerId ?? this.customerId,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        lockedChannels: lockedChannels ?? this.lockedChannels,
        ageLock: ageLock ?? this.ageLock);
  }

  RengCustomer copyWithWrapped(
      {Wrapped<bool?>? personalization,
      Wrapped<String?>? customerId,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<List<String>?>? lockedChannels,
      Wrapped<int?>? ageLock}) {
    return RengCustomer(
        personalization: (personalization != null
            ? personalization.value
            : this.personalization),
        customerId: (customerId != null ? customerId.value : this.customerId),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        lockedChannels: (lockedChannels != null
            ? lockedChannels.value
            : this.lockedChannels),
        ageLock: (ageLock != null ? ageLock.value : this.ageLock));
  }
}

@JsonSerializable(explicitToJson: true)
class RengCustomerInformation {
  RengCustomerInformation({
    this.customer,
    this.profile,
  });

  factory RengCustomerInformation.fromJson(Map<String, dynamic> json) =>
      _$RengCustomerInformationFromJson(json);

  static const toJsonFactory = _$RengCustomerInformationToJson;
  Map<String, dynamic> toJson() => _$RengCustomerInformationToJson(this);

  @JsonKey(name: 'customer', includeIfNull: false)
  final RengCustomer? customer;
  @JsonKey(name: 'profile', includeIfNull: false)
  final RengProfile? profile;
  static const fromJsonFactory = _$RengCustomerInformationFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RengCustomerInformation &&
            (identical(other.customer, customer) ||
                const DeepCollectionEquality()
                    .equals(other.customer, customer)) &&
            (identical(other.profile, profile) ||
                const DeepCollectionEquality().equals(other.profile, profile)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customer) ^
      const DeepCollectionEquality().hash(profile) ^
      runtimeType.hashCode;
}

extension $RengCustomerInformationExtension on RengCustomerInformation {
  RengCustomerInformation copyWith(
      {RengCustomer? customer, RengProfile? profile}) {
    return RengCustomerInformation(
        customer: customer ?? this.customer, profile: profile ?? this.profile);
  }

  RengCustomerInformation copyWithWrapped(
      {Wrapped<RengCustomer?>? customer, Wrapped<RengProfile?>? profile}) {
    return RengCustomerInformation(
        customer: (customer != null ? customer.value : this.customer),
        profile: (profile != null ? profile.value : this.profile));
  }
}

@JsonSerializable(explicitToJson: true)
class RengProfile {
  RengProfile({
    this.ageRating,
    this.lang,
    this.profileId,
    this.shared,
    this.favoriteChannels,
  });

  factory RengProfile.fromJson(Map<String, dynamic> json) =>
      _$RengProfileFromJson(json);

  static const toJsonFactory = _$RengProfileToJson;
  Map<String, dynamic> toJson() => _$RengProfileToJson(this);

  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String? lang;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'shared', includeIfNull: false)
  final bool? shared;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? favoriteChannels;
  static const fromJsonFactory = _$RengProfileFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RengProfile &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.shared, shared) ||
                const DeepCollectionEquality().equals(other.shared, shared)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(shared) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      runtimeType.hashCode;
}

extension $RengProfileExtension on RengProfile {
  RengProfile copyWith(
      {int? ageRating,
      String? lang,
      String? profileId,
      bool? shared,
      List<String>? favoriteChannels}) {
    return RengProfile(
        ageRating: ageRating ?? this.ageRating,
        lang: lang ?? this.lang,
        profileId: profileId ?? this.profileId,
        shared: shared ?? this.shared,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels);
  }

  RengProfile copyWithWrapped(
      {Wrapped<int?>? ageRating,
      Wrapped<String?>? lang,
      Wrapped<String?>? profileId,
      Wrapped<bool?>? shared,
      Wrapped<List<String>?>? favoriteChannels}) {
    return RengProfile(
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        lang: (lang != null ? lang.value : this.lang),
        profileId: (profileId != null ? profileId.value : this.profileId),
        shared: (shared != null ? shared.value : this.shared),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels));
  }
}

@JsonSerializable(explicitToJson: true)
class CreateOttDeviceRequest {
  CreateOttDeviceRequest({
    this.deviceName,
    this.deviceFamily,
    this.drmDeviceId,
    this.ottDeviceLimit,
  });

  factory CreateOttDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$CreateOttDeviceRequestFromJson(json);

  static const toJsonFactory = _$CreateOttDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$CreateOttDeviceRequestToJson(this);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  @JsonKey(name: 'deviceFamily', includeIfNull: false, defaultValue: '')
  final String? deviceFamily;
  @JsonKey(name: 'drmDeviceId', includeIfNull: false, defaultValue: '')
  final String? drmDeviceId;
  @JsonKey(name: 'ottDeviceLimit', includeIfNull: false)
  final int? ottDeviceLimit;
  static const fromJsonFactory = _$CreateOttDeviceRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CreateOttDeviceRequest &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.deviceFamily, deviceFamily) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFamily, deviceFamily)) &&
            (identical(other.drmDeviceId, drmDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.drmDeviceId, drmDeviceId)) &&
            (identical(other.ottDeviceLimit, ottDeviceLimit) ||
                const DeepCollectionEquality()
                    .equals(other.ottDeviceLimit, ottDeviceLimit)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(deviceFamily) ^
      const DeepCollectionEquality().hash(drmDeviceId) ^
      const DeepCollectionEquality().hash(ottDeviceLimit) ^
      runtimeType.hashCode;
}

extension $CreateOttDeviceRequestExtension on CreateOttDeviceRequest {
  CreateOttDeviceRequest copyWith(
      {String? deviceName,
      String? deviceFamily,
      String? drmDeviceId,
      int? ottDeviceLimit}) {
    return CreateOttDeviceRequest(
        deviceName: deviceName ?? this.deviceName,
        deviceFamily: deviceFamily ?? this.deviceFamily,
        drmDeviceId: drmDeviceId ?? this.drmDeviceId,
        ottDeviceLimit: ottDeviceLimit ?? this.ottDeviceLimit);
  }

  CreateOttDeviceRequest copyWithWrapped(
      {Wrapped<String?>? deviceName,
      Wrapped<String?>? deviceFamily,
      Wrapped<String?>? drmDeviceId,
      Wrapped<int?>? ottDeviceLimit}) {
    return CreateOttDeviceRequest(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        deviceFamily:
            (deviceFamily != null ? deviceFamily.value : this.deviceFamily),
        drmDeviceId:
            (drmDeviceId != null ? drmDeviceId.value : this.drmDeviceId),
        ottDeviceLimit: (ottDeviceLimit != null
            ? ottDeviceLimit.value
            : this.ottDeviceLimit));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateOttDeviceRequest {
  UpdateOttDeviceRequest({
    this.deviceName,
  });

  factory UpdateOttDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$UpdateOttDeviceRequestFromJson(json);

  static const toJsonFactory = _$UpdateOttDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$UpdateOttDeviceRequestToJson(this);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  static const fromJsonFactory = _$UpdateOttDeviceRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateOttDeviceRequest &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^ runtimeType.hashCode;
}

extension $UpdateOttDeviceRequestExtension on UpdateOttDeviceRequest {
  UpdateOttDeviceRequest copyWith({String? deviceName}) {
    return UpdateOttDeviceRequest(deviceName: deviceName ?? this.deviceName);
  }

  UpdateOttDeviceRequest copyWithWrapped({Wrapped<String?>? deviceName}) {
    return UpdateOttDeviceRequest(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerOttDevices {
  CustomerOttDevices({
    this.ottDeviceLimit,
    this.deviceDeactivationLimit,
    this.deviceDeactivationCount,
    this.deviceDeactivationCountResetDate,
    this.ottDevices,
  });

  factory CustomerOttDevices.fromJson(Map<String, dynamic> json) =>
      _$CustomerOttDevicesFromJson(json);

  static const toJsonFactory = _$CustomerOttDevicesToJson;
  Map<String, dynamic> toJson() => _$CustomerOttDevicesToJson(this);

  @JsonKey(name: 'ottDeviceLimit', includeIfNull: false)
  final int? ottDeviceLimit;
  @JsonKey(name: 'deviceDeactivationLimit', includeIfNull: false)
  final int? deviceDeactivationLimit;
  @JsonKey(name: 'deviceDeactivationCount', includeIfNull: false)
  final int? deviceDeactivationCount;
  @JsonKey(name: 'deviceDeactivationCountResetDate', includeIfNull: false)
  final DateTime? deviceDeactivationCountResetDate;
  @JsonKey(
      name: 'ottDevices',
      includeIfNull: false,
      defaultValue: <CustomerOttDevice>[])
  final List<CustomerOttDevice>? ottDevices;
  static const fromJsonFactory = _$CustomerOttDevicesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerOttDevices &&
            (identical(other.ottDeviceLimit, ottDeviceLimit) ||
                const DeepCollectionEquality()
                    .equals(other.ottDeviceLimit, ottDeviceLimit)) &&
            (identical(
                    other.deviceDeactivationLimit, deviceDeactivationLimit) ||
                const DeepCollectionEquality().equals(
                    other.deviceDeactivationLimit, deviceDeactivationLimit)) &&
            (identical(
                    other.deviceDeactivationCount, deviceDeactivationCount) ||
                const DeepCollectionEquality().equals(
                    other.deviceDeactivationCount, deviceDeactivationCount)) &&
            (identical(other.deviceDeactivationCountResetDate,
                    deviceDeactivationCountResetDate) ||
                const DeepCollectionEquality().equals(
                    other.deviceDeactivationCountResetDate,
                    deviceDeactivationCountResetDate)) &&
            (identical(other.ottDevices, ottDevices) ||
                const DeepCollectionEquality()
                    .equals(other.ottDevices, ottDevices)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ottDeviceLimit) ^
      const DeepCollectionEquality().hash(deviceDeactivationLimit) ^
      const DeepCollectionEquality().hash(deviceDeactivationCount) ^
      const DeepCollectionEquality().hash(deviceDeactivationCountResetDate) ^
      const DeepCollectionEquality().hash(ottDevices) ^
      runtimeType.hashCode;
}

extension $CustomerOttDevicesExtension on CustomerOttDevices {
  CustomerOttDevices copyWith(
      {int? ottDeviceLimit,
      int? deviceDeactivationLimit,
      int? deviceDeactivationCount,
      DateTime? deviceDeactivationCountResetDate,
      List<CustomerOttDevice>? ottDevices}) {
    return CustomerOttDevices(
        ottDeviceLimit: ottDeviceLimit ?? this.ottDeviceLimit,
        deviceDeactivationLimit:
            deviceDeactivationLimit ?? this.deviceDeactivationLimit,
        deviceDeactivationCount:
            deviceDeactivationCount ?? this.deviceDeactivationCount,
        deviceDeactivationCountResetDate: deviceDeactivationCountResetDate ??
            this.deviceDeactivationCountResetDate,
        ottDevices: ottDevices ?? this.ottDevices);
  }

  CustomerOttDevices copyWithWrapped(
      {Wrapped<int?>? ottDeviceLimit,
      Wrapped<int?>? deviceDeactivationLimit,
      Wrapped<int?>? deviceDeactivationCount,
      Wrapped<DateTime?>? deviceDeactivationCountResetDate,
      Wrapped<List<CustomerOttDevice>?>? ottDevices}) {
    return CustomerOttDevices(
        ottDeviceLimit: (ottDeviceLimit != null
            ? ottDeviceLimit.value
            : this.ottDeviceLimit),
        deviceDeactivationLimit: (deviceDeactivationLimit != null
            ? deviceDeactivationLimit.value
            : this.deviceDeactivationLimit),
        deviceDeactivationCount: (deviceDeactivationCount != null
            ? deviceDeactivationCount.value
            : this.deviceDeactivationCount),
        deviceDeactivationCountResetDate:
            (deviceDeactivationCountResetDate != null
                ? deviceDeactivationCountResetDate.value
                : this.deviceDeactivationCountResetDate),
        ottDevices: (ottDevices != null ? ottDevices.value : this.ottDevices));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerOttDevice {
  CustomerOttDevice({
    this.deviceName,
    this.deviceFamily,
    this.drmDeviceId,
    this.createdAt,
  });

  factory CustomerOttDevice.fromJson(Map<String, dynamic> json) =>
      _$CustomerOttDeviceFromJson(json);

  static const toJsonFactory = _$CustomerOttDeviceToJson;
  Map<String, dynamic> toJson() => _$CustomerOttDeviceToJson(this);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  @JsonKey(name: 'deviceFamily', includeIfNull: false, defaultValue: '')
  final String? deviceFamily;
  @JsonKey(name: 'drmDeviceId', includeIfNull: false, defaultValue: '')
  final String? drmDeviceId;
  @JsonKey(name: 'createdAt', includeIfNull: false)
  final DateTime? createdAt;
  static const fromJsonFactory = _$CustomerOttDeviceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerOttDevice &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.deviceFamily, deviceFamily) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFamily, deviceFamily)) &&
            (identical(other.drmDeviceId, drmDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.drmDeviceId, drmDeviceId)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(deviceFamily) ^
      const DeepCollectionEquality().hash(drmDeviceId) ^
      const DeepCollectionEquality().hash(createdAt) ^
      runtimeType.hashCode;
}

extension $CustomerOttDeviceExtension on CustomerOttDevice {
  CustomerOttDevice copyWith(
      {String? deviceName,
      String? deviceFamily,
      String? drmDeviceId,
      DateTime? createdAt}) {
    return CustomerOttDevice(
        deviceName: deviceName ?? this.deviceName,
        deviceFamily: deviceFamily ?? this.deviceFamily,
        drmDeviceId: drmDeviceId ?? this.drmDeviceId,
        createdAt: createdAt ?? this.createdAt);
  }

  CustomerOttDevice copyWithWrapped(
      {Wrapped<String?>? deviceName,
      Wrapped<String?>? deviceFamily,
      Wrapped<String?>? drmDeviceId,
      Wrapped<DateTime?>? createdAt}) {
    return CustomerOttDevice(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        deviceFamily:
            (deviceFamily != null ? deviceFamily.value : this.deviceFamily),
        drmDeviceId:
            (drmDeviceId != null ? drmDeviceId.value : this.drmDeviceId),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt));
  }
}

@JsonSerializable(explicitToJson: true)
class AdvertisementDeviceIdResponse {
  AdvertisementDeviceIdResponse({
    this.advertisementDeviceId,
  });

  factory AdvertisementDeviceIdResponse.fromJson(Map<String, dynamic> json) =>
      _$AdvertisementDeviceIdResponseFromJson(json);

  static const toJsonFactory = _$AdvertisementDeviceIdResponseToJson;
  Map<String, dynamic> toJson() => _$AdvertisementDeviceIdResponseToJson(this);

  @JsonKey(
      name: 'advertisementDeviceId', includeIfNull: false, defaultValue: '')
  final String? advertisementDeviceId;
  static const fromJsonFactory = _$AdvertisementDeviceIdResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AdvertisementDeviceIdResponse &&
            (identical(other.advertisementDeviceId, advertisementDeviceId) ||
                const DeepCollectionEquality().equals(
                    other.advertisementDeviceId, advertisementDeviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(advertisementDeviceId) ^
      runtimeType.hashCode;
}

extension $AdvertisementDeviceIdResponseExtension
    on AdvertisementDeviceIdResponse {
  AdvertisementDeviceIdResponse copyWith({String? advertisementDeviceId}) {
    return AdvertisementDeviceIdResponse(
        advertisementDeviceId:
            advertisementDeviceId ?? this.advertisementDeviceId);
  }

  AdvertisementDeviceIdResponse copyWithWrapped(
      {Wrapped<String?>? advertisementDeviceId}) {
    return AdvertisementDeviceIdResponse(
        advertisementDeviceId: (advertisementDeviceId != null
            ? advertisementDeviceId.value
            : this.advertisementDeviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsCustomerRequest {
  CpsCustomerRequest({
    this.customerId,
    this.assignedDevices,
    this.customerStatus,
    this.countryId,
    this.cityId,
    this.originalCityId,
    this.pin,
    this.disableAdvancedAdvertising,
    this.advancedAdvertisingMode,
    this.a2aStbEnabled,
    this.a2aHgoEnabled,
    this.zipCode,
    this.serviceType,
  });

  factory CpsCustomerRequest.fromJson(Map<String, dynamic> json) =>
      _$CpsCustomerRequestFromJson(json);

  static const toJsonFactory = _$CpsCustomerRequestToJson;
  Map<String, dynamic> toJson() => _$CpsCustomerRequestToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'assignedDevices',
      includeIfNull: false,
      defaultValue: <CpsDeviceRequest>[])
  final List<CpsDeviceRequest>? assignedDevices;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: cpsCustomerRequestCustomerStatusToJson,
    fromJson: cpsCustomerRequestCustomerStatusFromJson,
  )
  final enums.CpsCustomerRequestCustomerStatus? customerStatus;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'originalCityId', includeIfNull: false)
  final int? originalCityId;
  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  @JsonKey(name: 'disableAdvancedAdvertising', includeIfNull: false)
  final bool? disableAdvancedAdvertising;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  @JsonKey(name: 'a2aStbEnabled', includeIfNull: false)
  final bool? a2aStbEnabled;
  @JsonKey(name: 'a2aHgoEnabled', includeIfNull: false)
  final bool? a2aHgoEnabled;
  @JsonKey(name: 'zipCode', includeIfNull: false, defaultValue: '')
  final String? zipCode;
  @JsonKey(name: 'serviceType', includeIfNull: false, defaultValue: '')
  final String? serviceType;
  static const fromJsonFactory = _$CpsCustomerRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsCustomerRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.originalCityId, originalCityId) ||
                const DeepCollectionEquality()
                    .equals(other.originalCityId, originalCityId)) &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising) ||
                const DeepCollectionEquality().equals(
                    other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)) &&
            (identical(other.a2aStbEnabled, a2aStbEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.a2aStbEnabled, a2aStbEnabled)) &&
            (identical(other.a2aHgoEnabled, a2aHgoEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.a2aHgoEnabled, a2aHgoEnabled)) &&
            (identical(other.zipCode, zipCode) ||
                const DeepCollectionEquality()
                    .equals(other.zipCode, zipCode)) &&
            (identical(other.serviceType, serviceType) ||
                const DeepCollectionEquality()
                    .equals(other.serviceType, serviceType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(originalCityId) ^
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(disableAdvancedAdvertising) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      const DeepCollectionEquality().hash(a2aStbEnabled) ^
      const DeepCollectionEquality().hash(a2aHgoEnabled) ^
      const DeepCollectionEquality().hash(zipCode) ^
      const DeepCollectionEquality().hash(serviceType) ^
      runtimeType.hashCode;
}

extension $CpsCustomerRequestExtension on CpsCustomerRequest {
  CpsCustomerRequest copyWith(
      {String? customerId,
      List<CpsDeviceRequest>? assignedDevices,
      enums.CpsCustomerRequestCustomerStatus? customerStatus,
      String? countryId,
      int? cityId,
      int? originalCityId,
      String? pin,
      bool? disableAdvancedAdvertising,
      String? advancedAdvertisingMode,
      bool? a2aStbEnabled,
      bool? a2aHgoEnabled,
      String? zipCode,
      String? serviceType}) {
    return CpsCustomerRequest(
        customerId: customerId ?? this.customerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        customerStatus: customerStatus ?? this.customerStatus,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        originalCityId: originalCityId ?? this.originalCityId,
        pin: pin ?? this.pin,
        disableAdvancedAdvertising:
            disableAdvancedAdvertising ?? this.disableAdvancedAdvertising,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode,
        a2aStbEnabled: a2aStbEnabled ?? this.a2aStbEnabled,
        a2aHgoEnabled: a2aHgoEnabled ?? this.a2aHgoEnabled,
        zipCode: zipCode ?? this.zipCode,
        serviceType: serviceType ?? this.serviceType);
  }

  CpsCustomerRequest copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<List<CpsDeviceRequest>?>? assignedDevices,
      Wrapped<enums.CpsCustomerRequestCustomerStatus?>? customerStatus,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<int?>? originalCityId,
      Wrapped<String?>? pin,
      Wrapped<bool?>? disableAdvancedAdvertising,
      Wrapped<String?>? advancedAdvertisingMode,
      Wrapped<bool?>? a2aStbEnabled,
      Wrapped<bool?>? a2aHgoEnabled,
      Wrapped<String?>? zipCode,
      Wrapped<String?>? serviceType}) {
    return CpsCustomerRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        originalCityId: (originalCityId != null
            ? originalCityId.value
            : this.originalCityId),
        pin: (pin != null ? pin.value : this.pin),
        disableAdvancedAdvertising: (disableAdvancedAdvertising != null
            ? disableAdvancedAdvertising.value
            : this.disableAdvancedAdvertising),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode),
        a2aStbEnabled:
            (a2aStbEnabled != null ? a2aStbEnabled.value : this.a2aStbEnabled),
        a2aHgoEnabled:
            (a2aHgoEnabled != null ? a2aHgoEnabled.value : this.a2aHgoEnabled),
        zipCode: (zipCode != null ? zipCode.value : this.zipCode),
        serviceType:
            (serviceType != null ? serviceType.value : this.serviceType));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsDeviceRequest {
  CpsDeviceRequest({
    this.deviceType,
    this.smartCardId,
    this.serialNumber,
    this.deviceId,
    this.platformType,
    this.productType,
  });

  factory CpsDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$CpsDeviceRequestFromJson(json);

  static const toJsonFactory = _$CpsDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$CpsDeviceRequestToJson(this);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'productType', includeIfNull: false, defaultValue: '')
  final String? productType;
  static const fromJsonFactory = _$CpsDeviceRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsDeviceRequest &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.productType, productType) ||
                const DeepCollectionEquality()
                    .equals(other.productType, productType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(productType) ^
      runtimeType.hashCode;
}

extension $CpsDeviceRequestExtension on CpsDeviceRequest {
  CpsDeviceRequest copyWith(
      {String? deviceType,
      String? smartCardId,
      String? serialNumber,
      String? deviceId,
      String? platformType,
      String? productType}) {
    return CpsDeviceRequest(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        platformType: platformType ?? this.platformType,
        productType: productType ?? this.productType);
  }

  CpsDeviceRequest copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? platformType,
      Wrapped<String?>? productType}) {
    return CpsDeviceRequest(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        productType:
            (productType != null ? productType.value : this.productType));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsUpdateCustomerRequest {
  CpsUpdateCustomerRequest({
    this.customerId,
    this.countryId,
    this.cityId,
    this.originalCityId,
    this.assignedDevices,
    this.autoDeleteFunction,
    this.deleteRecordingReminder,
    this.recordingRetentionPeriod,
    this.zipCode,
    this.serviceType,
  });

  factory CpsUpdateCustomerRequest.fromJson(Map<String, dynamic> json) =>
      _$CpsUpdateCustomerRequestFromJson(json);

  static const toJsonFactory = _$CpsUpdateCustomerRequestToJson;
  Map<String, dynamic> toJson() => _$CpsUpdateCustomerRequestToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'originalCityId', includeIfNull: false)
  final int? originalCityId;
  @JsonKey(
      name: 'assignedDevices',
      includeIfNull: false,
      defaultValue: <DeviceRequest>[])
  final List<DeviceRequest>? assignedDevices;
  @JsonKey(name: 'autoDeleteFunction', includeIfNull: false)
  final bool? autoDeleteFunction;
  @JsonKey(name: 'deleteRecordingReminder', includeIfNull: false)
  final bool? deleteRecordingReminder;
  @JsonKey(name: 'recordingRetentionPeriod', includeIfNull: false)
  final int? recordingRetentionPeriod;
  @JsonKey(name: 'zipCode', includeIfNull: false, defaultValue: '')
  final String? zipCode;
  @JsonKey(name: 'serviceType', includeIfNull: false, defaultValue: '')
  final String? serviceType;
  static const fromJsonFactory = _$CpsUpdateCustomerRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsUpdateCustomerRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.originalCityId, originalCityId) ||
                const DeepCollectionEquality()
                    .equals(other.originalCityId, originalCityId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.autoDeleteFunction, autoDeleteFunction) ||
                const DeepCollectionEquality()
                    .equals(other.autoDeleteFunction, autoDeleteFunction)) &&
            (identical(
                    other.deleteRecordingReminder, deleteRecordingReminder) ||
                const DeepCollectionEquality().equals(
                    other.deleteRecordingReminder, deleteRecordingReminder)) &&
            (identical(
                    other.recordingRetentionPeriod, recordingRetentionPeriod) ||
                const DeepCollectionEquality().equals(
                    other.recordingRetentionPeriod,
                    recordingRetentionPeriod)) &&
            (identical(other.zipCode, zipCode) ||
                const DeepCollectionEquality()
                    .equals(other.zipCode, zipCode)) &&
            (identical(other.serviceType, serviceType) ||
                const DeepCollectionEquality()
                    .equals(other.serviceType, serviceType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(originalCityId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(autoDeleteFunction) ^
      const DeepCollectionEquality().hash(deleteRecordingReminder) ^
      const DeepCollectionEquality().hash(recordingRetentionPeriod) ^
      const DeepCollectionEquality().hash(zipCode) ^
      const DeepCollectionEquality().hash(serviceType) ^
      runtimeType.hashCode;
}

extension $CpsUpdateCustomerRequestExtension on CpsUpdateCustomerRequest {
  CpsUpdateCustomerRequest copyWith(
      {String? customerId,
      String? countryId,
      int? cityId,
      int? originalCityId,
      List<DeviceRequest>? assignedDevices,
      bool? autoDeleteFunction,
      bool? deleteRecordingReminder,
      int? recordingRetentionPeriod,
      String? zipCode,
      String? serviceType}) {
    return CpsUpdateCustomerRequest(
        customerId: customerId ?? this.customerId,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        originalCityId: originalCityId ?? this.originalCityId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        autoDeleteFunction: autoDeleteFunction ?? this.autoDeleteFunction,
        deleteRecordingReminder:
            deleteRecordingReminder ?? this.deleteRecordingReminder,
        recordingRetentionPeriod:
            recordingRetentionPeriod ?? this.recordingRetentionPeriod,
        zipCode: zipCode ?? this.zipCode,
        serviceType: serviceType ?? this.serviceType);
  }

  CpsUpdateCustomerRequest copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<int?>? originalCityId,
      Wrapped<List<DeviceRequest>?>? assignedDevices,
      Wrapped<bool?>? autoDeleteFunction,
      Wrapped<bool?>? deleteRecordingReminder,
      Wrapped<int?>? recordingRetentionPeriod,
      Wrapped<String?>? zipCode,
      Wrapped<String?>? serviceType}) {
    return CpsUpdateCustomerRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        originalCityId: (originalCityId != null
            ? originalCityId.value
            : this.originalCityId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        autoDeleteFunction: (autoDeleteFunction != null
            ? autoDeleteFunction.value
            : this.autoDeleteFunction),
        deleteRecordingReminder: (deleteRecordingReminder != null
            ? deleteRecordingReminder.value
            : this.deleteRecordingReminder),
        recordingRetentionPeriod: (recordingRetentionPeriod != null
            ? recordingRetentionPeriod.value
            : this.recordingRetentionPeriod),
        zipCode: (zipCode != null ? zipCode.value : this.zipCode),
        serviceType:
            (serviceType != null ? serviceType.value : this.serviceType));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsCustomerResponse {
  CpsCustomerResponse({
    this.customerId,
    this.assignedDevices,
    this.customerStatus,
    this.countryId,
    this.cityId,
    this.originalCityId,
    this.disableAdvancedAdvertising,
    this.advancedAdvertisingMode,
    this.a2aStbEnabled,
    this.a2aHgoEnabled,
    this.statusModifiedDate,
    this.zipCode,
    this.serviceType,
  });

  factory CpsCustomerResponse.fromJson(Map<String, dynamic> json) =>
      _$CpsCustomerResponseFromJson(json);

  static const toJsonFactory = _$CpsCustomerResponseToJson;
  Map<String, dynamic> toJson() => _$CpsCustomerResponseToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'assignedDevices',
      includeIfNull: false,
      defaultValue: <CpsDeviceResponse>[])
  final List<CpsDeviceResponse>? assignedDevices;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: cpsCustomerResponseCustomerStatusToJson,
    fromJson: cpsCustomerResponseCustomerStatusFromJson,
  )
  final enums.CpsCustomerResponseCustomerStatus? customerStatus;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'originalCityId', includeIfNull: false)
  final int? originalCityId;
  @JsonKey(name: 'disableAdvancedAdvertising', includeIfNull: false)
  final bool? disableAdvancedAdvertising;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  @JsonKey(name: 'a2aStbEnabled', includeIfNull: false)
  final bool? a2aStbEnabled;
  @JsonKey(name: 'a2aHgoEnabled', includeIfNull: false)
  final bool? a2aHgoEnabled;
  @JsonKey(name: 'statusModifiedDate', includeIfNull: false)
  final DateTime? statusModifiedDate;
  @JsonKey(name: 'zipCode', includeIfNull: false, defaultValue: '')
  final String? zipCode;
  @JsonKey(name: 'serviceType', includeIfNull: false, defaultValue: '')
  final String? serviceType;
  static const fromJsonFactory = _$CpsCustomerResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsCustomerResponse &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.originalCityId, originalCityId) ||
                const DeepCollectionEquality()
                    .equals(other.originalCityId, originalCityId)) &&
            (identical(other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising) ||
                const DeepCollectionEquality().equals(
                    other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)) &&
            (identical(other.a2aStbEnabled, a2aStbEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.a2aStbEnabled, a2aStbEnabled)) &&
            (identical(other.a2aHgoEnabled, a2aHgoEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.a2aHgoEnabled, a2aHgoEnabled)) &&
            (identical(other.statusModifiedDate, statusModifiedDate) ||
                const DeepCollectionEquality()
                    .equals(other.statusModifiedDate, statusModifiedDate)) &&
            (identical(other.zipCode, zipCode) ||
                const DeepCollectionEquality()
                    .equals(other.zipCode, zipCode)) &&
            (identical(other.serviceType, serviceType) ||
                const DeepCollectionEquality()
                    .equals(other.serviceType, serviceType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(originalCityId) ^
      const DeepCollectionEquality().hash(disableAdvancedAdvertising) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      const DeepCollectionEquality().hash(a2aStbEnabled) ^
      const DeepCollectionEquality().hash(a2aHgoEnabled) ^
      const DeepCollectionEquality().hash(statusModifiedDate) ^
      const DeepCollectionEquality().hash(zipCode) ^
      const DeepCollectionEquality().hash(serviceType) ^
      runtimeType.hashCode;
}

extension $CpsCustomerResponseExtension on CpsCustomerResponse {
  CpsCustomerResponse copyWith(
      {String? customerId,
      List<CpsDeviceResponse>? assignedDevices,
      enums.CpsCustomerResponseCustomerStatus? customerStatus,
      String? countryId,
      int? cityId,
      int? originalCityId,
      bool? disableAdvancedAdvertising,
      String? advancedAdvertisingMode,
      bool? a2aStbEnabled,
      bool? a2aHgoEnabled,
      DateTime? statusModifiedDate,
      String? zipCode,
      String? serviceType}) {
    return CpsCustomerResponse(
        customerId: customerId ?? this.customerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        customerStatus: customerStatus ?? this.customerStatus,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        originalCityId: originalCityId ?? this.originalCityId,
        disableAdvancedAdvertising:
            disableAdvancedAdvertising ?? this.disableAdvancedAdvertising,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode,
        a2aStbEnabled: a2aStbEnabled ?? this.a2aStbEnabled,
        a2aHgoEnabled: a2aHgoEnabled ?? this.a2aHgoEnabled,
        statusModifiedDate: statusModifiedDate ?? this.statusModifiedDate,
        zipCode: zipCode ?? this.zipCode,
        serviceType: serviceType ?? this.serviceType);
  }

  CpsCustomerResponse copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<List<CpsDeviceResponse>?>? assignedDevices,
      Wrapped<enums.CpsCustomerResponseCustomerStatus?>? customerStatus,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<int?>? originalCityId,
      Wrapped<bool?>? disableAdvancedAdvertising,
      Wrapped<String?>? advancedAdvertisingMode,
      Wrapped<bool?>? a2aStbEnabled,
      Wrapped<bool?>? a2aHgoEnabled,
      Wrapped<DateTime?>? statusModifiedDate,
      Wrapped<String?>? zipCode,
      Wrapped<String?>? serviceType}) {
    return CpsCustomerResponse(
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        originalCityId: (originalCityId != null
            ? originalCityId.value
            : this.originalCityId),
        disableAdvancedAdvertising: (disableAdvancedAdvertising != null
            ? disableAdvancedAdvertising.value
            : this.disableAdvancedAdvertising),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode),
        a2aStbEnabled:
            (a2aStbEnabled != null ? a2aStbEnabled.value : this.a2aStbEnabled),
        a2aHgoEnabled:
            (a2aHgoEnabled != null ? a2aHgoEnabled.value : this.a2aHgoEnabled),
        statusModifiedDate: (statusModifiedDate != null
            ? statusModifiedDate.value
            : this.statusModifiedDate),
        zipCode: (zipCode != null ? zipCode.value : this.zipCode),
        serviceType:
            (serviceType != null ? serviceType.value : this.serviceType));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsDeviceResponse {
  CpsDeviceResponse({
    this.deviceType,
    this.smartCardId,
    this.serialNumber,
    this.deviceId,
    this.platformType,
    this.productType,
  });

  factory CpsDeviceResponse.fromJson(Map<String, dynamic> json) =>
      _$CpsDeviceResponseFromJson(json);

  static const toJsonFactory = _$CpsDeviceResponseToJson;
  Map<String, dynamic> toJson() => _$CpsDeviceResponseToJson(this);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'productType', includeIfNull: false, defaultValue: '')
  final String? productType;
  static const fromJsonFactory = _$CpsDeviceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsDeviceResponse &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.productType, productType) ||
                const DeepCollectionEquality()
                    .equals(other.productType, productType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(productType) ^
      runtimeType.hashCode;
}

extension $CpsDeviceResponseExtension on CpsDeviceResponse {
  CpsDeviceResponse copyWith(
      {String? deviceType,
      String? smartCardId,
      String? serialNumber,
      String? deviceId,
      String? platformType,
      String? productType}) {
    return CpsDeviceResponse(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        platformType: platformType ?? this.platformType,
        productType: productType ?? this.productType);
  }

  CpsDeviceResponse copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? platformType,
      Wrapped<String?>? productType}) {
    return CpsDeviceResponse(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        productType:
            (productType != null ? productType.value : this.productType));
  }
}

@JsonSerializable(explicitToJson: true)
class PinVerificationRequest {
  PinVerificationRequest({
    this.pin,
  });

  factory PinVerificationRequest.fromJson(Map<String, dynamic> json) =>
      _$PinVerificationRequestFromJson(json);

  static const toJsonFactory = _$PinVerificationRequestToJson;
  Map<String, dynamic> toJson() => _$PinVerificationRequestToJson(this);

  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  static const fromJsonFactory = _$PinVerificationRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinVerificationRequest &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pin) ^ runtimeType.hashCode;
}

extension $PinVerificationRequestExtension on PinVerificationRequest {
  PinVerificationRequest copyWith({String? pin}) {
    return PinVerificationRequest(pin: pin ?? this.pin);
  }

  PinVerificationRequest copyWithWrapped({Wrapped<String?>? pin}) {
    return PinVerificationRequest(pin: (pin != null ? pin.value : this.pin));
  }
}

@JsonSerializable(explicitToJson: true)
class PinVerificationV2Request {
  PinVerificationV2Request({
    this.pin,
  });

  factory PinVerificationV2Request.fromJson(Map<String, dynamic> json) =>
      _$PinVerificationV2RequestFromJson(json);

  static const toJsonFactory = _$PinVerificationV2RequestToJson;
  Map<String, dynamic> toJson() => _$PinVerificationV2RequestToJson(this);

  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  static const fromJsonFactory = _$PinVerificationV2RequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinVerificationV2Request &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pin) ^ runtimeType.hashCode;
}

extension $PinVerificationV2RequestExtension on PinVerificationV2Request {
  PinVerificationV2Request copyWith({String? pin}) {
    return PinVerificationV2Request(pin: pin ?? this.pin);
  }

  PinVerificationV2Request copyWithWrapped({Wrapped<String?>? pin}) {
    return PinVerificationV2Request(pin: (pin != null ? pin.value : this.pin));
  }
}

@JsonSerializable(explicitToJson: true)
class PinVerificationResponse {
  PinVerificationResponse({
    this.result,
  });

  factory PinVerificationResponse.fromJson(Map<String, dynamic> json) =>
      _$PinVerificationResponseFromJson(json);

  static const toJsonFactory = _$PinVerificationResponseToJson;
  Map<String, dynamic> toJson() => _$PinVerificationResponseToJson(this);

  @JsonKey(name: 'result', includeIfNull: false)
  final bool? result;
  static const fromJsonFactory = _$PinVerificationResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinVerificationResponse &&
            (identical(other.result, result) ||
                const DeepCollectionEquality().equals(other.result, result)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(result) ^ runtimeType.hashCode;
}

extension $PinVerificationResponseExtension on PinVerificationResponse {
  PinVerificationResponse copyWith({bool? result}) {
    return PinVerificationResponse(result: result ?? this.result);
  }

  PinVerificationResponse copyWithWrapped({Wrapped<bool?>? result}) {
    return PinVerificationResponse(
        result: (result != null ? result.value : this.result));
  }
}

@JsonSerializable(explicitToJson: true)
class PinVerificationV2Response {
  PinVerificationV2Response({
    this.result,
    this.attempt,
    this.maxAttempts,
    this.lockedAt,
    this.duration,
  });

  factory PinVerificationV2Response.fromJson(Map<String, dynamic> json) =>
      _$PinVerificationV2ResponseFromJson(json);

  static const toJsonFactory = _$PinVerificationV2ResponseToJson;
  Map<String, dynamic> toJson() => _$PinVerificationV2ResponseToJson(this);

  @JsonKey(name: 'result', includeIfNull: false)
  final bool? result;
  @JsonKey(name: 'attempt', includeIfNull: false)
  final int? attempt;
  @JsonKey(name: 'maxAttempts', includeIfNull: false)
  final int? maxAttempts;
  @JsonKey(name: 'lockedAt', includeIfNull: false)
  final DateTime? lockedAt;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  static const fromJsonFactory = _$PinVerificationV2ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinVerificationV2Response &&
            (identical(other.result, result) ||
                const DeepCollectionEquality().equals(other.result, result)) &&
            (identical(other.attempt, attempt) ||
                const DeepCollectionEquality()
                    .equals(other.attempt, attempt)) &&
            (identical(other.maxAttempts, maxAttempts) ||
                const DeepCollectionEquality()
                    .equals(other.maxAttempts, maxAttempts)) &&
            (identical(other.lockedAt, lockedAt) ||
                const DeepCollectionEquality()
                    .equals(other.lockedAt, lockedAt)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(result) ^
      const DeepCollectionEquality().hash(attempt) ^
      const DeepCollectionEquality().hash(maxAttempts) ^
      const DeepCollectionEquality().hash(lockedAt) ^
      const DeepCollectionEquality().hash(duration) ^
      runtimeType.hashCode;
}

extension $PinVerificationV2ResponseExtension on PinVerificationV2Response {
  PinVerificationV2Response copyWith(
      {bool? result,
      int? attempt,
      int? maxAttempts,
      DateTime? lockedAt,
      int? duration}) {
    return PinVerificationV2Response(
        result: result ?? this.result,
        attempt: attempt ?? this.attempt,
        maxAttempts: maxAttempts ?? this.maxAttempts,
        lockedAt: lockedAt ?? this.lockedAt,
        duration: duration ?? this.duration);
  }

  PinVerificationV2Response copyWithWrapped(
      {Wrapped<bool?>? result,
      Wrapped<int?>? attempt,
      Wrapped<int?>? maxAttempts,
      Wrapped<DateTime?>? lockedAt,
      Wrapped<int?>? duration}) {
    return PinVerificationV2Response(
        result: (result != null ? result.value : this.result),
        attempt: (attempt != null ? attempt.value : this.attempt),
        maxAttempts:
            (maxAttempts != null ? maxAttempts.value : this.maxAttempts),
        lockedAt: (lockedAt != null ? lockedAt.value : this.lockedAt),
        duration: (duration != null ? duration.value : this.duration));
  }
}

@JsonSerializable(explicitToJson: true)
class ResetPinResponse {
  ResetPinResponse({
    this.pin,
  });

  factory ResetPinResponse.fromJson(Map<String, dynamic> json) =>
      _$ResetPinResponseFromJson(json);

  static const toJsonFactory = _$ResetPinResponseToJson;
  Map<String, dynamic> toJson() => _$ResetPinResponseToJson(this);

  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  static const fromJsonFactory = _$ResetPinResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ResetPinResponse &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pin) ^ runtimeType.hashCode;
}

extension $ResetPinResponseExtension on ResetPinResponse {
  ResetPinResponse copyWith({String? pin}) {
    return ResetPinResponse(pin: pin ?? this.pin);
  }

  ResetPinResponse copyWithWrapped({Wrapped<String?>? pin}) {
    return ResetPinResponse(pin: (pin != null ? pin.value : this.pin));
  }
}

@JsonSerializable(explicitToJson: true)
class ResetPinV2Response {
  ResetPinV2Response({
    this.pin,
    this.result,
    this.lockedAt,
    this.duration,
  });

  factory ResetPinV2Response.fromJson(Map<String, dynamic> json) =>
      _$ResetPinV2ResponseFromJson(json);

  static const toJsonFactory = _$ResetPinV2ResponseToJson;
  Map<String, dynamic> toJson() => _$ResetPinV2ResponseToJson(this);

  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  @JsonKey(name: 'result', includeIfNull: false)
  final bool? result;
  @JsonKey(name: 'lockedAt', includeIfNull: false)
  final DateTime? lockedAt;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  static const fromJsonFactory = _$ResetPinV2ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ResetPinV2Response &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.result, result) ||
                const DeepCollectionEquality().equals(other.result, result)) &&
            (identical(other.lockedAt, lockedAt) ||
                const DeepCollectionEquality()
                    .equals(other.lockedAt, lockedAt)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(result) ^
      const DeepCollectionEquality().hash(lockedAt) ^
      const DeepCollectionEquality().hash(duration) ^
      runtimeType.hashCode;
}

extension $ResetPinV2ResponseExtension on ResetPinV2Response {
  ResetPinV2Response copyWith(
      {String? pin, bool? result, DateTime? lockedAt, int? duration}) {
    return ResetPinV2Response(
        pin: pin ?? this.pin,
        result: result ?? this.result,
        lockedAt: lockedAt ?? this.lockedAt,
        duration: duration ?? this.duration);
  }

  ResetPinV2Response copyWithWrapped(
      {Wrapped<String?>? pin,
      Wrapped<bool?>? result,
      Wrapped<DateTime?>? lockedAt,
      Wrapped<int?>? duration}) {
    return ResetPinV2Response(
        pin: (pin != null ? pin.value : this.pin),
        result: (result != null ? result.value : this.result),
        lockedAt: (lockedAt != null ? lockedAt.value : this.lockedAt),
        duration: (duration != null ? duration.value : this.duration));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateDeviceRequest {
  UpdateDeviceRequest({
    this.defaultProfileId,
    this.platformType,
    this.wifiMacAddress,
    this.ethernetMacAddress,
    this.settings,
  });

  factory UpdateDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$UpdateDeviceRequestFromJson(json);

  static const toJsonFactory = _$UpdateDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$UpdateDeviceRequestToJson(this);

  @JsonKey(name: 'defaultProfileId', includeIfNull: false, defaultValue: '')
  final String? defaultProfileId;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'wifiMacAddress', includeIfNull: false, defaultValue: '')
  final String? wifiMacAddress;
  @JsonKey(name: 'ethernetMacAddress', includeIfNull: false, defaultValue: '')
  final String? ethernetMacAddress;
  @JsonKey(name: 'settings', includeIfNull: false)
  final DeviceSettingsRequest? settings;
  static const fromJsonFactory = _$UpdateDeviceRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateDeviceRequest &&
            (identical(other.defaultProfileId, defaultProfileId) ||
                const DeepCollectionEquality()
                    .equals(other.defaultProfileId, defaultProfileId)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.wifiMacAddress, wifiMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.wifiMacAddress, wifiMacAddress)) &&
            (identical(other.ethernetMacAddress, ethernetMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.ethernetMacAddress, ethernetMacAddress)) &&
            (identical(other.settings, settings) ||
                const DeepCollectionEquality()
                    .equals(other.settings, settings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(defaultProfileId) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(wifiMacAddress) ^
      const DeepCollectionEquality().hash(ethernetMacAddress) ^
      const DeepCollectionEquality().hash(settings) ^
      runtimeType.hashCode;
}

extension $UpdateDeviceRequestExtension on UpdateDeviceRequest {
  UpdateDeviceRequest copyWith(
      {String? defaultProfileId,
      String? platformType,
      String? wifiMacAddress,
      String? ethernetMacAddress,
      DeviceSettingsRequest? settings}) {
    return UpdateDeviceRequest(
        defaultProfileId: defaultProfileId ?? this.defaultProfileId,
        platformType: platformType ?? this.platformType,
        wifiMacAddress: wifiMacAddress ?? this.wifiMacAddress,
        ethernetMacAddress: ethernetMacAddress ?? this.ethernetMacAddress,
        settings: settings ?? this.settings);
  }

  UpdateDeviceRequest copyWithWrapped(
      {Wrapped<String?>? defaultProfileId,
      Wrapped<String?>? platformType,
      Wrapped<String?>? wifiMacAddress,
      Wrapped<String?>? ethernetMacAddress,
      Wrapped<DeviceSettingsRequest?>? settings}) {
    return UpdateDeviceRequest(
        defaultProfileId: (defaultProfileId != null
            ? defaultProfileId.value
            : this.defaultProfileId),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        wifiMacAddress: (wifiMacAddress != null
            ? wifiMacAddress.value
            : this.wifiMacAddress),
        ethernetMacAddress: (ethernetMacAddress != null
            ? ethernetMacAddress.value
            : this.ethernetMacAddress),
        settings: (settings != null ? settings.value : this.settings));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkUpdateCustomerRequest {
  BulkUpdateCustomerRequest({
    required this.customerId,
    this.hashedPin,
    this.salt,
    this.ageLock,
    this.favoriteChannels,
    this.assignedSTBDevices,
    this.customerOptIns,
    this.assignedOTTDevices,
  });

  factory BulkUpdateCustomerRequest.fromJson(Map<String, dynamic> json) =>
      _$BulkUpdateCustomerRequestFromJson(json);

  static const toJsonFactory = _$BulkUpdateCustomerRequestToJson;
  Map<String, dynamic> toJson() => _$BulkUpdateCustomerRequestToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'hashedPin', includeIfNull: false, defaultValue: '')
  final String? hashedPin;
  @JsonKey(name: 'salt', includeIfNull: false, defaultValue: '')
  final String? salt;
  @JsonKey(name: 'ageLock', includeIfNull: false)
  final int? ageLock;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? favoriteChannels;
  @JsonKey(
      name: 'assignedSTBDevices',
      includeIfNull: false,
      defaultValue: <BulkAssignedSTBDevice>[])
  final List<BulkAssignedSTBDevice>? assignedSTBDevices;
  @JsonKey(
      name: 'customerOptIns',
      includeIfNull: false,
      defaultValue: <BulkCustomerOptIn>[])
  final List<BulkCustomerOptIn>? customerOptIns;
  @JsonKey(
      name: 'assignedOTTDevices',
      includeIfNull: false,
      defaultValue: <BulkAssignedOTTDevice>[])
  final List<BulkAssignedOTTDevice>? assignedOTTDevices;
  static const fromJsonFactory = _$BulkUpdateCustomerRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkUpdateCustomerRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.hashedPin, hashedPin) ||
                const DeepCollectionEquality()
                    .equals(other.hashedPin, hashedPin)) &&
            (identical(other.salt, salt) ||
                const DeepCollectionEquality().equals(other.salt, salt)) &&
            (identical(other.ageLock, ageLock) ||
                const DeepCollectionEquality()
                    .equals(other.ageLock, ageLock)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)) &&
            (identical(other.assignedSTBDevices, assignedSTBDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedSTBDevices, assignedSTBDevices)) &&
            (identical(other.customerOptIns, customerOptIns) ||
                const DeepCollectionEquality()
                    .equals(other.customerOptIns, customerOptIns)) &&
            (identical(other.assignedOTTDevices, assignedOTTDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedOTTDevices, assignedOTTDevices)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(hashedPin) ^
      const DeepCollectionEquality().hash(salt) ^
      const DeepCollectionEquality().hash(ageLock) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      const DeepCollectionEquality().hash(assignedSTBDevices) ^
      const DeepCollectionEquality().hash(customerOptIns) ^
      const DeepCollectionEquality().hash(assignedOTTDevices) ^
      runtimeType.hashCode;
}

extension $BulkUpdateCustomerRequestExtension on BulkUpdateCustomerRequest {
  BulkUpdateCustomerRequest copyWith(
      {String? customerId,
      String? hashedPin,
      String? salt,
      int? ageLock,
      List<String>? favoriteChannels,
      List<BulkAssignedSTBDevice>? assignedSTBDevices,
      List<BulkCustomerOptIn>? customerOptIns,
      List<BulkAssignedOTTDevice>? assignedOTTDevices}) {
    return BulkUpdateCustomerRequest(
        customerId: customerId ?? this.customerId,
        hashedPin: hashedPin ?? this.hashedPin,
        salt: salt ?? this.salt,
        ageLock: ageLock ?? this.ageLock,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels,
        assignedSTBDevices: assignedSTBDevices ?? this.assignedSTBDevices,
        customerOptIns: customerOptIns ?? this.customerOptIns,
        assignedOTTDevices: assignedOTTDevices ?? this.assignedOTTDevices);
  }

  BulkUpdateCustomerRequest copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<String?>? hashedPin,
      Wrapped<String?>? salt,
      Wrapped<int?>? ageLock,
      Wrapped<List<String>?>? favoriteChannels,
      Wrapped<List<BulkAssignedSTBDevice>?>? assignedSTBDevices,
      Wrapped<List<BulkCustomerOptIn>?>? customerOptIns,
      Wrapped<List<BulkAssignedOTTDevice>?>? assignedOTTDevices}) {
    return BulkUpdateCustomerRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        hashedPin: (hashedPin != null ? hashedPin.value : this.hashedPin),
        salt: (salt != null ? salt.value : this.salt),
        ageLock: (ageLock != null ? ageLock.value : this.ageLock),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels),
        assignedSTBDevices: (assignedSTBDevices != null
            ? assignedSTBDevices.value
            : this.assignedSTBDevices),
        customerOptIns: (customerOptIns != null
            ? customerOptIns.value
            : this.customerOptIns),
        assignedOTTDevices: (assignedOTTDevices != null
            ? assignedOTTDevices.value
            : this.assignedOTTDevices));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkUpdateOboCustomerRequest {
  BulkUpdateOboCustomerRequest({
    required this.customerId,
    required this.assignedOTTDevices,
  });

  factory BulkUpdateOboCustomerRequest.fromJson(Map<String, dynamic> json) =>
      _$BulkUpdateOboCustomerRequestFromJson(json);

  static const toJsonFactory = _$BulkUpdateOboCustomerRequestToJson;
  Map<String, dynamic> toJson() => _$BulkUpdateOboCustomerRequestToJson(this);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(
      name: 'assignedOTTDevices',
      includeIfNull: false,
      defaultValue: <BulkAssignedOboOTTDevice>[])
  final List<BulkAssignedOboOTTDevice> assignedOTTDevices;
  static const fromJsonFactory = _$BulkUpdateOboCustomerRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkUpdateOboCustomerRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedOTTDevices, assignedOTTDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedOTTDevices, assignedOTTDevices)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedOTTDevices) ^
      runtimeType.hashCode;
}

extension $BulkUpdateOboCustomerRequestExtension
    on BulkUpdateOboCustomerRequest {
  BulkUpdateOboCustomerRequest copyWith(
      {String? customerId,
      List<BulkAssignedOboOTTDevice>? assignedOTTDevices}) {
    return BulkUpdateOboCustomerRequest(
        customerId: customerId ?? this.customerId,
        assignedOTTDevices: assignedOTTDevices ?? this.assignedOTTDevices);
  }

  BulkUpdateOboCustomerRequest copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<List<BulkAssignedOboOTTDevice>>? assignedOTTDevices}) {
    return BulkUpdateOboCustomerRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedOTTDevices: (assignedOTTDevices != null
            ? assignedOTTDevices.value
            : this.assignedOTTDevices));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkCustomerOptIn {
  BulkCustomerOptIn({
    required this.lastModified,
    required this.optInType,
    required this.enabled,
    this.termsAndConditionsVersion,
  });

  factory BulkCustomerOptIn.fromJson(Map<String, dynamic> json) =>
      _$BulkCustomerOptInFromJson(json);

  static const toJsonFactory = _$BulkCustomerOptInToJson;
  Map<String, dynamic> toJson() => _$BulkCustomerOptInToJson(this);

  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime lastModified;
  @JsonKey(name: 'optInType', includeIfNull: false, defaultValue: '')
  final String optInType;
  @JsonKey(name: 'enabled', includeIfNull: false)
  final bool enabled;
  @JsonKey(
      name: 'termsAndConditionsVersion', includeIfNull: false, defaultValue: '')
  final String? termsAndConditionsVersion;
  static const fromJsonFactory = _$BulkCustomerOptInFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkCustomerOptIn &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.optInType, optInType) ||
                const DeepCollectionEquality()
                    .equals(other.optInType, optInType)) &&
            (identical(other.enabled, enabled) ||
                const DeepCollectionEquality()
                    .equals(other.enabled, enabled)) &&
            (identical(other.termsAndConditionsVersion,
                    termsAndConditionsVersion) ||
                const DeepCollectionEquality().equals(
                    other.termsAndConditionsVersion,
                    termsAndConditionsVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(optInType) ^
      const DeepCollectionEquality().hash(enabled) ^
      const DeepCollectionEquality().hash(termsAndConditionsVersion) ^
      runtimeType.hashCode;
}

extension $BulkCustomerOptInExtension on BulkCustomerOptIn {
  BulkCustomerOptIn copyWith(
      {DateTime? lastModified,
      String? optInType,
      bool? enabled,
      String? termsAndConditionsVersion}) {
    return BulkCustomerOptIn(
        lastModified: lastModified ?? this.lastModified,
        optInType: optInType ?? this.optInType,
        enabled: enabled ?? this.enabled,
        termsAndConditionsVersion:
            termsAndConditionsVersion ?? this.termsAndConditionsVersion);
  }

  BulkCustomerOptIn copyWithWrapped(
      {Wrapped<DateTime>? lastModified,
      Wrapped<String>? optInType,
      Wrapped<bool>? enabled,
      Wrapped<String?>? termsAndConditionsVersion}) {
    return BulkCustomerOptIn(
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        optInType: (optInType != null ? optInType.value : this.optInType),
        enabled: (enabled != null ? enabled.value : this.enabled),
        termsAndConditionsVersion: (termsAndConditionsVersion != null
            ? termsAndConditionsVersion.value
            : this.termsAndConditionsVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkAssignedSTBDevice {
  BulkAssignedSTBDevice({
    required this.deviceId,
    required this.deviceFriendlyName,
  });

  factory BulkAssignedSTBDevice.fromJson(Map<String, dynamic> json) =>
      _$BulkAssignedSTBDeviceFromJson(json);

  static const toJsonFactory = _$BulkAssignedSTBDeviceToJson;
  Map<String, dynamic> toJson() => _$BulkAssignedSTBDeviceToJson(this);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  @JsonKey(name: 'deviceFriendlyName', includeIfNull: false, defaultValue: '')
  final String deviceFriendlyName;
  static const fromJsonFactory = _$BulkAssignedSTBDeviceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkAssignedSTBDevice &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.deviceFriendlyName, deviceFriendlyName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFriendlyName, deviceFriendlyName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(deviceFriendlyName) ^
      runtimeType.hashCode;
}

extension $BulkAssignedSTBDeviceExtension on BulkAssignedSTBDevice {
  BulkAssignedSTBDevice copyWith(
      {String? deviceId, String? deviceFriendlyName}) {
    return BulkAssignedSTBDevice(
        deviceId: deviceId ?? this.deviceId,
        deviceFriendlyName: deviceFriendlyName ?? this.deviceFriendlyName);
  }

  BulkAssignedSTBDevice copyWithWrapped(
      {Wrapped<String>? deviceId, Wrapped<String>? deviceFriendlyName}) {
    return BulkAssignedSTBDevice(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        deviceFriendlyName: (deviceFriendlyName != null
            ? deviceFriendlyName.value
            : this.deviceFriendlyName));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkAssignedOTTDevice {
  BulkAssignedOTTDevice({
    this.deviceName,
    this.deviceFamily,
    required this.drmDeviceId,
  });

  factory BulkAssignedOTTDevice.fromJson(Map<String, dynamic> json) =>
      _$BulkAssignedOTTDeviceFromJson(json);

  static const toJsonFactory = _$BulkAssignedOTTDeviceToJson;
  Map<String, dynamic> toJson() => _$BulkAssignedOTTDeviceToJson(this);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  @JsonKey(name: 'deviceFamily', includeIfNull: false, defaultValue: '')
  final String? deviceFamily;
  @JsonKey(name: 'drmDeviceId', includeIfNull: false, defaultValue: '')
  final String drmDeviceId;
  static const fromJsonFactory = _$BulkAssignedOTTDeviceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkAssignedOTTDevice &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.deviceFamily, deviceFamily) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFamily, deviceFamily)) &&
            (identical(other.drmDeviceId, drmDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.drmDeviceId, drmDeviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(deviceFamily) ^
      const DeepCollectionEquality().hash(drmDeviceId) ^
      runtimeType.hashCode;
}

extension $BulkAssignedOTTDeviceExtension on BulkAssignedOTTDevice {
  BulkAssignedOTTDevice copyWith(
      {String? deviceName, String? deviceFamily, String? drmDeviceId}) {
    return BulkAssignedOTTDevice(
        deviceName: deviceName ?? this.deviceName,
        deviceFamily: deviceFamily ?? this.deviceFamily,
        drmDeviceId: drmDeviceId ?? this.drmDeviceId);
  }

  BulkAssignedOTTDevice copyWithWrapped(
      {Wrapped<String?>? deviceName,
      Wrapped<String?>? deviceFamily,
      Wrapped<String>? drmDeviceId}) {
    return BulkAssignedOTTDevice(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        deviceFamily:
            (deviceFamily != null ? deviceFamily.value : this.deviceFamily),
        drmDeviceId:
            (drmDeviceId != null ? drmDeviceId.value : this.drmDeviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class BulkAssignedOboOTTDevice {
  BulkAssignedOboOTTDevice({
    required this.deviceName,
    this.deviceFamily,
    required this.drmDeviceId,
  });

  factory BulkAssignedOboOTTDevice.fromJson(Map<String, dynamic> json) =>
      _$BulkAssignedOboOTTDeviceFromJson(json);

  static const toJsonFactory = _$BulkAssignedOboOTTDeviceToJson;
  Map<String, dynamic> toJson() => _$BulkAssignedOboOTTDeviceToJson(this);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String deviceName;
  @JsonKey(name: 'deviceFamily', includeIfNull: false, defaultValue: '')
  final String? deviceFamily;
  @JsonKey(name: 'drmDeviceId', includeIfNull: false, defaultValue: '')
  final String drmDeviceId;
  static const fromJsonFactory = _$BulkAssignedOboOTTDeviceFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BulkAssignedOboOTTDevice &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.deviceFamily, deviceFamily) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFamily, deviceFamily)) &&
            (identical(other.drmDeviceId, drmDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.drmDeviceId, drmDeviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(deviceFamily) ^
      const DeepCollectionEquality().hash(drmDeviceId) ^
      runtimeType.hashCode;
}

extension $BulkAssignedOboOTTDeviceExtension on BulkAssignedOboOTTDevice {
  BulkAssignedOboOTTDevice copyWith(
      {String? deviceName, String? deviceFamily, String? drmDeviceId}) {
    return BulkAssignedOboOTTDevice(
        deviceName: deviceName ?? this.deviceName,
        deviceFamily: deviceFamily ?? this.deviceFamily,
        drmDeviceId: drmDeviceId ?? this.drmDeviceId);
  }

  BulkAssignedOboOTTDevice copyWithWrapped(
      {Wrapped<String>? deviceName,
      Wrapped<String?>? deviceFamily,
      Wrapped<String>? drmDeviceId}) {
    return BulkAssignedOboOTTDevice(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        deviceFamily:
            (deviceFamily != null ? deviceFamily.value : this.deviceFamily),
        drmDeviceId:
            (drmDeviceId != null ? drmDeviceId.value : this.drmDeviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class ValidationErrorMessage {
  ValidationErrorMessage({
    required this.errors,
  });

  factory ValidationErrorMessage.fromJson(Map<String, dynamic> json) =>
      _$ValidationErrorMessageFromJson(json);

  static const toJsonFactory = _$ValidationErrorMessageToJson;
  Map<String, dynamic> toJson() => _$ValidationErrorMessageToJson(this);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ValidationErrorMessageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidationErrorMessage &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ValidationErrorMessageExtension on ValidationErrorMessage {
  ValidationErrorMessage copyWith({List<String>? errors}) {
    return ValidationErrorMessage(errors: errors ?? this.errors);
  }

  ValidationErrorMessage copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ValidationErrorMessage(
        errors: (errors != null ? errors.value : this.errors));
  }
}

String? customerCustomerStatusToJson(
    enums.CustomerCustomerStatus? customerCustomerStatus) {
  return customerCustomerStatus?.value;
}

enums.CustomerCustomerStatus customerCustomerStatusFromJson(
  Object? customerCustomerStatus, [
  enums.CustomerCustomerStatus? defaultValue,
]) {
  return enums.CustomerCustomerStatus.values
          .firstWhereOrNull((e) => e.value == customerCustomerStatus) ??
      defaultValue ??
      enums.CustomerCustomerStatus.swaggerGeneratedUnknown;
}

List<String> customerCustomerStatusListToJson(
    List<enums.CustomerCustomerStatus>? customerCustomerStatus) {
  if (customerCustomerStatus == null) {
    return [];
  }

  return customerCustomerStatus.map((e) => e.value!).toList();
}

List<enums.CustomerCustomerStatus> customerCustomerStatusListFromJson(
  List? customerCustomerStatus, [
  List<enums.CustomerCustomerStatus>? defaultValue,
]) {
  if (customerCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return customerCustomerStatus
      .map((e) => customerCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CustomerCustomerStatus>? customerCustomerStatusNullableListFromJson(
  List? customerCustomerStatus, [
  List<enums.CustomerCustomerStatus>? defaultValue,
]) {
  if (customerCustomerStatus == null) {
    return defaultValue;
  }

  return customerCustomerStatus
      .map((e) => customerCustomerStatusFromJson(e.toString()))
      .toList();
}

String? updateCustomerRequestCustomerStatusToJson(
    enums.UpdateCustomerRequestCustomerStatus?
        updateCustomerRequestCustomerStatus) {
  return updateCustomerRequestCustomerStatus?.value;
}

enums.UpdateCustomerRequestCustomerStatus
    updateCustomerRequestCustomerStatusFromJson(
  Object? updateCustomerRequestCustomerStatus, [
  enums.UpdateCustomerRequestCustomerStatus? defaultValue,
]) {
  return enums.UpdateCustomerRequestCustomerStatus.values.firstWhereOrNull(
          (e) => e.value == updateCustomerRequestCustomerStatus) ??
      defaultValue ??
      enums.UpdateCustomerRequestCustomerStatus.swaggerGeneratedUnknown;
}

List<String> updateCustomerRequestCustomerStatusListToJson(
    List<enums.UpdateCustomerRequestCustomerStatus>?
        updateCustomerRequestCustomerStatus) {
  if (updateCustomerRequestCustomerStatus == null) {
    return [];
  }

  return updateCustomerRequestCustomerStatus.map((e) => e.value!).toList();
}

List<enums.UpdateCustomerRequestCustomerStatus>
    updateCustomerRequestCustomerStatusListFromJson(
  List? updateCustomerRequestCustomerStatus, [
  List<enums.UpdateCustomerRequestCustomerStatus>? defaultValue,
]) {
  if (updateCustomerRequestCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return updateCustomerRequestCustomerStatus
      .map((e) => updateCustomerRequestCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.UpdateCustomerRequestCustomerStatus>?
    updateCustomerRequestCustomerStatusNullableListFromJson(
  List? updateCustomerRequestCustomerStatus, [
  List<enums.UpdateCustomerRequestCustomerStatus>? defaultValue,
]) {
  if (updateCustomerRequestCustomerStatus == null) {
    return defaultValue;
  }

  return updateCustomerRequestCustomerStatus
      .map((e) => updateCustomerRequestCustomerStatusFromJson(e.toString()))
      .toList();
}

String? deviceSettingsCcDigitalServiceToJson(
    enums.DeviceSettingsCcDigitalService? deviceSettingsCcDigitalService) {
  return deviceSettingsCcDigitalService?.value;
}

enums.DeviceSettingsCcDigitalService deviceSettingsCcDigitalServiceFromJson(
  Object? deviceSettingsCcDigitalService, [
  enums.DeviceSettingsCcDigitalService? defaultValue,
]) {
  return enums.DeviceSettingsCcDigitalService.values
          .firstWhereOrNull((e) => e.value == deviceSettingsCcDigitalService) ??
      defaultValue ??
      enums.DeviceSettingsCcDigitalService.swaggerGeneratedUnknown;
}

List<String> deviceSettingsCcDigitalServiceListToJson(
    List<enums.DeviceSettingsCcDigitalService>?
        deviceSettingsCcDigitalService) {
  if (deviceSettingsCcDigitalService == null) {
    return [];
  }

  return deviceSettingsCcDigitalService.map((e) => e.value!).toList();
}

List<enums.DeviceSettingsCcDigitalService>
    deviceSettingsCcDigitalServiceListFromJson(
  List? deviceSettingsCcDigitalService, [
  List<enums.DeviceSettingsCcDigitalService>? defaultValue,
]) {
  if (deviceSettingsCcDigitalService == null) {
    return defaultValue ?? [];
  }

  return deviceSettingsCcDigitalService
      .map((e) => deviceSettingsCcDigitalServiceFromJson(e.toString()))
      .toList();
}

List<enums.DeviceSettingsCcDigitalService>?
    deviceSettingsCcDigitalServiceNullableListFromJson(
  List? deviceSettingsCcDigitalService, [
  List<enums.DeviceSettingsCcDigitalService>? defaultValue,
]) {
  if (deviceSettingsCcDigitalService == null) {
    return defaultValue;
  }

  return deviceSettingsCcDigitalService
      .map((e) => deviceSettingsCcDigitalServiceFromJson(e.toString()))
      .toList();
}

String? deviceSettingsCcAnalogServiceToJson(
    enums.DeviceSettingsCcAnalogService? deviceSettingsCcAnalogService) {
  return deviceSettingsCcAnalogService?.value;
}

enums.DeviceSettingsCcAnalogService deviceSettingsCcAnalogServiceFromJson(
  Object? deviceSettingsCcAnalogService, [
  enums.DeviceSettingsCcAnalogService? defaultValue,
]) {
  return enums.DeviceSettingsCcAnalogService.values
          .firstWhereOrNull((e) => e.value == deviceSettingsCcAnalogService) ??
      defaultValue ??
      enums.DeviceSettingsCcAnalogService.swaggerGeneratedUnknown;
}

List<String> deviceSettingsCcAnalogServiceListToJson(
    List<enums.DeviceSettingsCcAnalogService>? deviceSettingsCcAnalogService) {
  if (deviceSettingsCcAnalogService == null) {
    return [];
  }

  return deviceSettingsCcAnalogService.map((e) => e.value!).toList();
}

List<enums.DeviceSettingsCcAnalogService>
    deviceSettingsCcAnalogServiceListFromJson(
  List? deviceSettingsCcAnalogService, [
  List<enums.DeviceSettingsCcAnalogService>? defaultValue,
]) {
  if (deviceSettingsCcAnalogService == null) {
    return defaultValue ?? [];
  }

  return deviceSettingsCcAnalogService
      .map((e) => deviceSettingsCcAnalogServiceFromJson(e.toString()))
      .toList();
}

List<enums.DeviceSettingsCcAnalogService>?
    deviceSettingsCcAnalogServiceNullableListFromJson(
  List? deviceSettingsCcAnalogService, [
  List<enums.DeviceSettingsCcAnalogService>? defaultValue,
]) {
  if (deviceSettingsCcAnalogService == null) {
    return defaultValue;
  }

  return deviceSettingsCcAnalogService
      .map((e) => deviceSettingsCcAnalogServiceFromJson(e.toString()))
      .toList();
}

String? deviceSettingsRequestCcDigitalServiceToJson(
    enums.DeviceSettingsRequestCcDigitalService?
        deviceSettingsRequestCcDigitalService) {
  return deviceSettingsRequestCcDigitalService?.value;
}

enums.DeviceSettingsRequestCcDigitalService
    deviceSettingsRequestCcDigitalServiceFromJson(
  Object? deviceSettingsRequestCcDigitalService, [
  enums.DeviceSettingsRequestCcDigitalService? defaultValue,
]) {
  return enums.DeviceSettingsRequestCcDigitalService.values.firstWhereOrNull(
          (e) => e.value == deviceSettingsRequestCcDigitalService) ??
      defaultValue ??
      enums.DeviceSettingsRequestCcDigitalService.swaggerGeneratedUnknown;
}

List<String> deviceSettingsRequestCcDigitalServiceListToJson(
    List<enums.DeviceSettingsRequestCcDigitalService>?
        deviceSettingsRequestCcDigitalService) {
  if (deviceSettingsRequestCcDigitalService == null) {
    return [];
  }

  return deviceSettingsRequestCcDigitalService.map((e) => e.value!).toList();
}

List<enums.DeviceSettingsRequestCcDigitalService>
    deviceSettingsRequestCcDigitalServiceListFromJson(
  List? deviceSettingsRequestCcDigitalService, [
  List<enums.DeviceSettingsRequestCcDigitalService>? defaultValue,
]) {
  if (deviceSettingsRequestCcDigitalService == null) {
    return defaultValue ?? [];
  }

  return deviceSettingsRequestCcDigitalService
      .map((e) => deviceSettingsRequestCcDigitalServiceFromJson(e.toString()))
      .toList();
}

List<enums.DeviceSettingsRequestCcDigitalService>?
    deviceSettingsRequestCcDigitalServiceNullableListFromJson(
  List? deviceSettingsRequestCcDigitalService, [
  List<enums.DeviceSettingsRequestCcDigitalService>? defaultValue,
]) {
  if (deviceSettingsRequestCcDigitalService == null) {
    return defaultValue;
  }

  return deviceSettingsRequestCcDigitalService
      .map((e) => deviceSettingsRequestCcDigitalServiceFromJson(e.toString()))
      .toList();
}

String? deviceSettingsRequestCcAnalogServiceToJson(
    enums.DeviceSettingsRequestCcAnalogService?
        deviceSettingsRequestCcAnalogService) {
  return deviceSettingsRequestCcAnalogService?.value;
}

enums.DeviceSettingsRequestCcAnalogService
    deviceSettingsRequestCcAnalogServiceFromJson(
  Object? deviceSettingsRequestCcAnalogService, [
  enums.DeviceSettingsRequestCcAnalogService? defaultValue,
]) {
  return enums.DeviceSettingsRequestCcAnalogService.values.firstWhereOrNull(
          (e) => e.value == deviceSettingsRequestCcAnalogService) ??
      defaultValue ??
      enums.DeviceSettingsRequestCcAnalogService.swaggerGeneratedUnknown;
}

List<String> deviceSettingsRequestCcAnalogServiceListToJson(
    List<enums.DeviceSettingsRequestCcAnalogService>?
        deviceSettingsRequestCcAnalogService) {
  if (deviceSettingsRequestCcAnalogService == null) {
    return [];
  }

  return deviceSettingsRequestCcAnalogService.map((e) => e.value!).toList();
}

List<enums.DeviceSettingsRequestCcAnalogService>
    deviceSettingsRequestCcAnalogServiceListFromJson(
  List? deviceSettingsRequestCcAnalogService, [
  List<enums.DeviceSettingsRequestCcAnalogService>? defaultValue,
]) {
  if (deviceSettingsRequestCcAnalogService == null) {
    return defaultValue ?? [];
  }

  return deviceSettingsRequestCcAnalogService
      .map((e) => deviceSettingsRequestCcAnalogServiceFromJson(e.toString()))
      .toList();
}

List<enums.DeviceSettingsRequestCcAnalogService>?
    deviceSettingsRequestCcAnalogServiceNullableListFromJson(
  List? deviceSettingsRequestCcAnalogService, [
  List<enums.DeviceSettingsRequestCcAnalogService>? defaultValue,
]) {
  if (deviceSettingsRequestCcAnalogService == null) {
    return defaultValue;
  }

  return deviceSettingsRequestCcAnalogService
      .map((e) => deviceSettingsRequestCcAnalogServiceFromJson(e.toString()))
      .toList();
}

String? jsonNodeNodeTypeToJson(enums.JsonNodeNodeType? jsonNodeNodeType) {
  return jsonNodeNodeType?.value;
}

enums.JsonNodeNodeType jsonNodeNodeTypeFromJson(
  Object? jsonNodeNodeType, [
  enums.JsonNodeNodeType? defaultValue,
]) {
  return enums.JsonNodeNodeType.values
          .firstWhereOrNull((e) => e.value == jsonNodeNodeType) ??
      defaultValue ??
      enums.JsonNodeNodeType.swaggerGeneratedUnknown;
}

List<String> jsonNodeNodeTypeListToJson(
    List<enums.JsonNodeNodeType>? jsonNodeNodeType) {
  if (jsonNodeNodeType == null) {
    return [];
  }

  return jsonNodeNodeType.map((e) => e.value!).toList();
}

List<enums.JsonNodeNodeType> jsonNodeNodeTypeListFromJson(
  List? jsonNodeNodeType, [
  List<enums.JsonNodeNodeType>? defaultValue,
]) {
  if (jsonNodeNodeType == null) {
    return defaultValue ?? [];
  }

  return jsonNodeNodeType
      .map((e) => jsonNodeNodeTypeFromJson(e.toString()))
      .toList();
}

List<enums.JsonNodeNodeType>? jsonNodeNodeTypeNullableListFromJson(
  List? jsonNodeNodeType, [
  List<enums.JsonNodeNodeType>? defaultValue,
]) {
  if (jsonNodeNodeType == null) {
    return defaultValue;
  }

  return jsonNodeNodeType
      .map((e) => jsonNodeNodeTypeFromJson(e.toString()))
      .toList();
}

String? cpsCustomerRequestCustomerStatusToJson(
    enums.CpsCustomerRequestCustomerStatus? cpsCustomerRequestCustomerStatus) {
  return cpsCustomerRequestCustomerStatus?.value;
}

enums.CpsCustomerRequestCustomerStatus cpsCustomerRequestCustomerStatusFromJson(
  Object? cpsCustomerRequestCustomerStatus, [
  enums.CpsCustomerRequestCustomerStatus? defaultValue,
]) {
  return enums.CpsCustomerRequestCustomerStatus.values.firstWhereOrNull(
          (e) => e.value == cpsCustomerRequestCustomerStatus) ??
      defaultValue ??
      enums.CpsCustomerRequestCustomerStatus.swaggerGeneratedUnknown;
}

List<String> cpsCustomerRequestCustomerStatusListToJson(
    List<enums.CpsCustomerRequestCustomerStatus>?
        cpsCustomerRequestCustomerStatus) {
  if (cpsCustomerRequestCustomerStatus == null) {
    return [];
  }

  return cpsCustomerRequestCustomerStatus.map((e) => e.value!).toList();
}

List<enums.CpsCustomerRequestCustomerStatus>
    cpsCustomerRequestCustomerStatusListFromJson(
  List? cpsCustomerRequestCustomerStatus, [
  List<enums.CpsCustomerRequestCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerRequestCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return cpsCustomerRequestCustomerStatus
      .map((e) => cpsCustomerRequestCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CpsCustomerRequestCustomerStatus>?
    cpsCustomerRequestCustomerStatusNullableListFromJson(
  List? cpsCustomerRequestCustomerStatus, [
  List<enums.CpsCustomerRequestCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerRequestCustomerStatus == null) {
    return defaultValue;
  }

  return cpsCustomerRequestCustomerStatus
      .map((e) => cpsCustomerRequestCustomerStatusFromJson(e.toString()))
      .toList();
}

String? cpsCustomerResponseCustomerStatusToJson(
    enums.CpsCustomerResponseCustomerStatus?
        cpsCustomerResponseCustomerStatus) {
  return cpsCustomerResponseCustomerStatus?.value;
}

enums.CpsCustomerResponseCustomerStatus
    cpsCustomerResponseCustomerStatusFromJson(
  Object? cpsCustomerResponseCustomerStatus, [
  enums.CpsCustomerResponseCustomerStatus? defaultValue,
]) {
  return enums.CpsCustomerResponseCustomerStatus.values.firstWhereOrNull(
          (e) => e.value == cpsCustomerResponseCustomerStatus) ??
      defaultValue ??
      enums.CpsCustomerResponseCustomerStatus.swaggerGeneratedUnknown;
}

List<String> cpsCustomerResponseCustomerStatusListToJson(
    List<enums.CpsCustomerResponseCustomerStatus>?
        cpsCustomerResponseCustomerStatus) {
  if (cpsCustomerResponseCustomerStatus == null) {
    return [];
  }

  return cpsCustomerResponseCustomerStatus.map((e) => e.value!).toList();
}

List<enums.CpsCustomerResponseCustomerStatus>
    cpsCustomerResponseCustomerStatusListFromJson(
  List? cpsCustomerResponseCustomerStatus, [
  List<enums.CpsCustomerResponseCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerResponseCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return cpsCustomerResponseCustomerStatus
      .map((e) => cpsCustomerResponseCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CpsCustomerResponseCustomerStatus>?
    cpsCustomerResponseCustomerStatusNullableListFromJson(
  List? cpsCustomerResponseCustomerStatus, [
  List<enums.CpsCustomerResponseCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerResponseCustomerStatus == null) {
    return defaultValue;
  }

  return cpsCustomerResponseCustomerStatus
      .map((e) => cpsCustomerResponseCustomerStatusFromJson(e.toString()))
      .toList();
}

String? v1CpsCustomerCustomerIdResetPinGetPinTypeToJson(
    enums.V1CpsCustomerCustomerIdResetPinGetPinType?
        v1CpsCustomerCustomerIdResetPinGetPinType) {
  return v1CpsCustomerCustomerIdResetPinGetPinType?.value;
}

enums.V1CpsCustomerCustomerIdResetPinGetPinType
    v1CpsCustomerCustomerIdResetPinGetPinTypeFromJson(
  Object? v1CpsCustomerCustomerIdResetPinGetPinType, [
  enums.V1CpsCustomerCustomerIdResetPinGetPinType? defaultValue,
]) {
  return enums.V1CpsCustomerCustomerIdResetPinGetPinType.values
          .firstWhereOrNull(
              (e) => e.value == v1CpsCustomerCustomerIdResetPinGetPinType) ??
      defaultValue ??
      enums.V1CpsCustomerCustomerIdResetPinGetPinType.swaggerGeneratedUnknown;
}

List<String> v1CpsCustomerCustomerIdResetPinGetPinTypeListToJson(
    List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>?
        v1CpsCustomerCustomerIdResetPinGetPinType) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType == null) {
    return [];
  }

  return v1CpsCustomerCustomerIdResetPinGetPinType
      .map((e) => e.value!)
      .toList();
}

List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>
    v1CpsCustomerCustomerIdResetPinGetPinTypeListFromJson(
  List? v1CpsCustomerCustomerIdResetPinGetPinType, [
  List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>? defaultValue,
]) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType == null) {
    return defaultValue ?? [];
  }

  return v1CpsCustomerCustomerIdResetPinGetPinType
      .map((e) =>
          v1CpsCustomerCustomerIdResetPinGetPinTypeFromJson(e.toString()))
      .toList();
}

List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>?
    v1CpsCustomerCustomerIdResetPinGetPinTypeNullableListFromJson(
  List? v1CpsCustomerCustomerIdResetPinGetPinType, [
  List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>? defaultValue,
]) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType == null) {
    return defaultValue;
  }

  return v1CpsCustomerCustomerIdResetPinGetPinType
      .map((e) =>
          v1CpsCustomerCustomerIdResetPinGetPinTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
