// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'picker_service.enums.swagger.dart' as enums;
export 'picker_service.enums.swagger.dart';

part 'picker_service.swagger.chopper.dart';
part 'picker_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PickerService extends ChopperService {
  static PickerService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PickerService(client);
    }

    final newClient = ChopperClient(
        services: [_$PickerService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$PickerService(newClient);
  }

  ///Retrieve series details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param showCrid Show's crid. Should be used only, when ''seriesCrid'' is a season's crid.
  ///@param seasonCrid Series crid to retrieve episodes. Season's crid or show's (in case if show doesn't have seasons)
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedEventId The ''CRID'' and ''IMI'' of the selected event.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  Future<chopper.Response<SeriesDetailResponse$Response>>
      v1SeriesDetailSeasonCridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? profileId,
    String? showCrid,
    required String? seasonCrid,
    required String? country,
    required String? language,
    String? selectedEventId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SeriesDetailResponse$Response,
        () => SeriesDetailResponse$Response.fromJsonFactory);

    return _v1SeriesDetailSeasonCridGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        showCrid: showCrid,
        seasonCrid: seasonCrid,
        country: country,
        language: language,
        selectedEventId: selectedEventId,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        cacheControl: cacheControl);
  }

  ///Retrieve series details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param showCrid Show's crid. Should be used only, when ''seriesCrid'' is a season's crid.
  ///@param seasonCrid Series crid to retrieve episodes. Season's crid or show's (in case if show doesn't have seasons)
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedEventId The ''CRID'' and ''IMI'' of the selected event.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  @Get(path: '/v1/seriesDetail/{seasonCrid}')
  Future<chopper.Response<SeriesDetailResponse$Response>>
      _v1SeriesDetailSeasonCridGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        required String? profileId,
    @Query('showCrid')
        String? showCrid,
    @Path('seasonCrid')
        required String? seasonCrid,
    @Query('country')
        required String? country,
    @Query('language')
        required String? language,
    @Query('selectedEventId')
        String? selectedEventId,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieve event details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Series Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param titleCrid Title Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param eventId Event Instance Metadata Identifier (eg: 'imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxRes Highest possible maxResolution.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  Future<chopper.Response<EventDetailResponse$Response>> v1EventDetailGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? profileId,
    required String? language,
    required String? country,
    String? seriesId,
    String? titleCrid,
    String? eventId,
    enums.MaxRes? maxRes,
    int? replayOptedInTime,
    int? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(EventDetailResponse$Response,
        () => EventDetailResponse$Response.fromJsonFactory);

    return _v1EventDetailGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        seriesId: seriesId,
        titleCrid: titleCrid,
        eventId: eventId,
        maxRes: maxRes?.value?.toString(),
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Retrieve event details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Series Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param titleCrid Title Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param eventId Event Instance Metadata Identifier (eg: 'imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxRes Highest possible maxResolution.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  @Get(path: '/v1/eventDetail')
  Future<chopper.Response<EventDetailResponse$Response>> _v1EventDetailGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        required String? profileId,
    @Query('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('seriesId')
        String? seriesId,
    @Query('titleCrid')
        String? titleCrid,
    @Query('eventId')
        String? eventId,
    @Query('maxRes')
        String? maxRes,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        int? cityId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieve episode, season, special counts and corresponding channels for a list of series.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  Future<chopper.Response<SearchDetailsResponse$Response>> v1SearchDetailsPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    bool? mergingOn,
    String? includeExternalProvider,
    enums.FilterOnDemand? filterOnDemand,
    bool? goPlayableOnly,
    String? cacheControl,
    required SearchDetails$RequestBody? body,
  }) {
    generatedMapping.putIfAbsent(SearchDetailsResponse$Response,
        () => SearchDetailsResponse$Response.fromJsonFactory);

    return _v1SearchDetailsPost(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        filterOnDemand: filterOnDemand?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl,
        body: body);
  }

  ///Retrieve episode, season, special counts and corresponding channels for a list of series.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  @Post(
    path: '/v1/searchDetails',
    optionalBody: true,
  )
  Future<chopper.Response<SearchDetailsResponse$Response>>
      _v1SearchDetailsPost({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Session-Id')
        String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required SearchDetails$RequestBody? body,
  });

  ///Return most relevant source for given title
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Used to filter content by a specific provider
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  Future<chopper.Response<MostRelevantSourceResponse$Response>>
      v1MostRelevantSourceGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    required String? language,
    required String? country,
    required String? titleId,
    int? cityId,
    int? replayOptedInTime,
    enums.MaxRes? maxRes,
    String? brandingProviderId,
    String? includeExternalProvider,
    bool? mergingOn,
    enums.FilterOnDemand? filterOnDemand,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(MostRelevantSourceResponse$Response,
        () => MostRelevantSourceResponse$Response.fromJsonFactory);

    return _v1MostRelevantSourceGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        titleId: titleId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        maxRes: maxRes?.value?.toString(),
        brandingProviderId: brandingProviderId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        filterOnDemand: filterOnDemand?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Return most relevant source for given title
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Used to filter content by a specific provider
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  @Get(path: '/v1/mostRelevantSource')
  Future<chopper.Response<MostRelevantSourceResponse$Response>>
      _v1MostRelevantSourceGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('titleId')
        required String? titleId,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('maxRes')
        String? maxRes,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///DEPRECATED. Please use /v2/mostRelevantEpisode . Returns a title crid of the most relevant episode of a series
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Crid of a show
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param noSource Boolean to signal to not get the most relevant source or not for the most relevant episode. (mainly used for testing and debugging)
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  Future<chopper.Response<MostRelevantEpisodeResponse$Response>>
      v1MostRelevantEpisodeGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    required String? language,
    required String? country,
    required String? seriesId,
    int? cityId,
    int? replayOptedInTime,
    bool? noSource,
    enums.MaxRes? maxRes,
    String? brandingProviderId,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(MostRelevantEpisodeResponse$Response,
        () => MostRelevantEpisodeResponse$Response.fromJsonFactory);

    return _v1MostRelevantEpisodeGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        seriesId: seriesId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        noSource: noSource,
        maxRes: maxRes?.value?.toString(),
        brandingProviderId: brandingProviderId,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///DEPRECATED. Please use /v2/mostRelevantEpisode . Returns a title crid of the most relevant episode of a series
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Crid of a show
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param noSource Boolean to signal to not get the most relevant source or not for the most relevant episode. (mainly used for testing and debugging)
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  @Get(path: '/v1/mostRelevantEpisode')
  Future<chopper.Response<MostRelevantEpisodeResponse$Response>>
      _v1MostRelevantEpisodeGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('seriesId')
        required String? seriesId,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('noSource')
        bool? noSource,
    @Query('maxRes')
        String? maxRes,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Returns most relevant episode of a series with related metadata
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param seriesId Show crid or season crid
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  Future<chopper.Response<Object>> v2MostRelevantEpisodeGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? seriesId,
    required String? language,
    required String? country,
    String? brandingProviderId,
    int? cityId,
    int? replayOptedInTime,
    String? profileId,
    enums.MaxRes? maxRes,
    String? includeExternalProvider,
    bool? mergingOn,
    enums.FilterOnDemand? filterOnDemand,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    return _v2MostRelevantEpisodeGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        seriesId: seriesId,
        language: language,
        country: country,
        brandingProviderId: brandingProviderId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        profileId: profileId,
        maxRes: maxRes?.value?.toString(),
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        filterOnDemand: filterOnDemand?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Returns most relevant episode of a series with related metadata
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param seriesId Show crid or season crid
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  @Get(path: '/v2/mostRelevantEpisode')
  Future<chopper.Response<Object>> _v2MostRelevantEpisodeGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('seriesId')
        required String? seriesId,
    @Query('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('profileId')
        String? profileId,
    @Query('maxRes')
        String? maxRes,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///A bulk version of the normal mostRelevantEpisode endpoint
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  Future<chopper.Response<MostRelevantEpisodeBulkResponse$Response>>
      v2MostRelevantEpisodeBulkPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? cacheControl,
    required MostRelevantEpisodeBulk$RequestBody? body,
  }) {
    generatedMapping.putIfAbsent(MostRelevantEpisodeBulkResponse$Response,
        () => MostRelevantEpisodeBulkResponse$Response.fromJsonFactory);

    return _v2MostRelevantEpisodeBulkPost(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///A bulk version of the normal mostRelevantEpisode endpoint
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  @Post(
    path: '/v2/mostRelevantEpisodeBulk',
    optionalBody: true,
  )
  Future<chopper.Response<MostRelevantEpisodeBulkResponse$Response>>
      _v2MostRelevantEpisodeBulkPost({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required MostRelevantEpisodeBulk$RequestBody? body,
  });

  ///Shows the other sources where the content is available
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param excludedBrandingProviderId Exclude VOD contents for specified branding provider. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param excludedChannelId Exclude events and recordings played on specified channel id. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param selectedEventId The ''CRID'' and ''IMI''. Parameter used for deduplication of vod sources in combination with excludedChannelid.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  Future<chopper.Response<Object>> v1TitleAlsoAvailableOnGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    required String? language,
    required String? country,
    required String? titleId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? excludedBrandingProviderId,
    String? excludedChannelId,
    String? includeExternalProvider,
    bool? mergingOn,
    String? selectedEventId,
    enums.FilterOnDemand? filterOnDemand,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    return _v1TitleAlsoAvailableOnGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        titleId: titleId,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        excludedBrandingProviderId: excludedBrandingProviderId,
        excludedChannelId: excludedChannelId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        selectedEventId: selectedEventId,
        filterOnDemand: filterOnDemand?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Shows the other sources where the content is available
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param excludedBrandingProviderId Exclude VOD contents for specified branding provider. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param excludedChannelId Exclude events and recordings played on specified channel id. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param selectedEventId The ''CRID'' and ''IMI''. Parameter used for deduplication of vod sources in combination with excludedChannelid.
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  @Get(path: '/v1/titleAlsoAvailableOn')
  Future<chopper.Response<Object>> _v1TitleAlsoAvailableOnGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('titleId')
        required String? titleId,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('excludedBrandingProviderId')
        String? excludedBrandingProviderId,
    @Query('excludedChannelId')
        String? excludedChannelId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('selectedEventId')
        String? selectedEventId,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Provides details of the show.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param country Country in ISO3166
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<ShowPageResponse$Response>>
      v1ShowPageShowCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? showCrid,
    required String? language,
    int? cityId,
    required String? country,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ShowPageResponse$Response,
        () => ShowPageResponse$Response.fromJsonFactory);

    return _v1ShowPageShowCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        showCrid: showCrid,
        language: language,
        cityId: cityId,
        country: country,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Provides details of the show.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param country Country in ISO3166
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/showPage/{showCrid}/{language}')
  Future<chopper.Response<ShowPageResponse$Response>>
      _v1ShowPageShowCridLanguageGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Path('showCrid')
        required String? showCrid,
    @Path('language')
        required String? language,
    @Query('cityId')
        int? cityId,
    @Query('country')
        required String? country,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Responds with the Show information and a list of all the seasons
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<EpisodePickerResponse$Response>> v1EpisodePickerGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    required String? seriesCrid,
    required String? country,
    required String? language,
    String? selectedAssetId,
    String? selectedBrandingProviderId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? channelId,
    String? brandingProviderId,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(EpisodePickerResponse$Response,
        () => EpisodePickerResponse$Response.fromJsonFactory);

    return _v1EpisodePickerGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        seriesCrid: seriesCrid,
        country: country,
        language: language,
        selectedAssetId: selectedAssetId,
        selectedBrandingProviderId: selectedBrandingProviderId,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        channelId: channelId,
        brandingProviderId: brandingProviderId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Responds with the Show information and a list of all the seasons
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/episodePicker')
  Future<chopper.Response<EpisodePickerResponse$Response>> _v1EpisodePickerGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('seriesCrid')
        required String? seriesCrid,
    @Query('country')
        required String? country,
    @Query('language')
        required String? language,
    @Query('selectedAssetId')
        String? selectedAssetId,
    @Query('selectedBrandingProviderId')
        String? selectedBrandingProviderId,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('channelId')
        String? channelId,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Responds with the Show information and a list of all the seasons or episodes or episodes grouped by the year of production
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  Future<chopper.Response<EpisodePickerV2Response$Response>>
      v2EpisodePickerGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    String? profileId,
    required String? seriesCrid,
    required String? country,
    required String? language,
    String? selectedAssetId,
    String? selectedBrandingProviderId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? channelId,
    String? brandingProviderId,
    String? includeExternalProvider,
    bool? mergingOn,
    enums.FilterOnDemand? filterOnDemand,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(EpisodePickerV2Response$Response,
        () => EpisodePickerV2Response$Response.fromJsonFactory);

    return _v2EpisodePickerGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        profileId: profileId,
        seriesCrid: seriesCrid,
        country: country,
        language: language,
        selectedAssetId: selectedAssetId,
        selectedBrandingProviderId: selectedBrandingProviderId,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        channelId: channelId,
        brandingProviderId: brandingProviderId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        filterOnDemand: filterOnDemand?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Responds with the Show information and a list of all the seasons or episodes or episodes grouped by the year of production
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  @Get(path: '/v2/episodePicker')
  Future<chopper.Response<EpisodePickerV2Response$Response>>
      _v2EpisodePickerGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('profileId')
        String? profileId,
    @Query('seriesCrid')
        required String? seriesCrid,
    @Query('country')
        required String? country,
    @Query('language')
        required String? language,
    @Query('selectedAssetId')
        String? selectedAssetId,
    @Query('selectedBrandingProviderId')
        String? selectedBrandingProviderId,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('channelId')
        String? channelId,
    @Query('brandingProviderId')
        String? brandingProviderId,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Allows for resolving which seasons are available per source
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param showCrid Show's crid.
  ///@param selectedResource Crid and imi (linear) or Crid (VOD) of the selected item.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  Future<chopper.Response<SaaoResponse$Response>> v1ShowAlsoAvailableOnGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? language,
    required String? country,
    required String? showCrid,
    String? selectedResource,
    String? selectedBrandingProviderId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? includeExternalProvider,
    bool? mergingOn,
    enums.FilterOnDemand? filterOnDemand,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SaaoResponse$Response, () => SaaoResponse$Response.fromJsonFactory);

    return _v1ShowAlsoAvailableOnGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        language: language,
        country: country,
        showCrid: showCrid,
        selectedResource: selectedResource,
        selectedBrandingProviderId: selectedBrandingProviderId,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        filterOnDemand: filterOnDemand?.value?.toString(),
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Allows for resolving which seasons are available per source
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param showCrid Show's crid.
  ///@param selectedResource Crid and imi (linear) or Crid (VOD) of the selected item.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param filterOnDemand Flag to trigger filtering out of TVOD content
  ///@param goPlayableOnly Flag to return only Go playable content
  @Get(path: '/v1/showAlsoAvailableOn')
  Future<chopper.Response<SaaoResponse$Response>> _v1ShowAlsoAvailableOnGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Query('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('showCrid')
        required String? showCrid,
    @Query('selectedResource')
        String? selectedResource,
    @Query('selectedBrandingProviderId')
        String? selectedBrandingProviderId,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('filterOnDemand')
        String? filterOnDemand,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has VoD showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  Future<chopper.Response<SpaResponse$Response>>
      v1ShowPageAvailableShowCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? showCrid,
    required String? language,
    int? cityId,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SpaResponse$Response, () => SpaResponse$Response.fromJsonFactory);

    return _v1ShowPageAvailableShowCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        showCrid: showCrid,
        language: language,
        cityId: cityId,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has VoD showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  @Get(path: '/v1/showPageAvailable/{showCrid}/{language}')
  Future<chopper.Response<SpaResponse$Response>>
      _v1ShowPageAvailableShowCridLanguageGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Path('showCrid')
        required String? showCrid,
    @Path('language')
        required String? language,
    @Query('cityId')
        int? cityId,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has at least one VOD or one OTT or one EST showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  Future<chopper.Response<SpaResponse$Response>>
      v2ShowPageAvailableShowCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? showCrid,
    required String? language,
    int? cityId,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SpaResponse$Response, () => SpaResponse$Response.fromJsonFactory);

    return _v2ShowPageAvailableShowCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        showCrid: showCrid,
        language: language,
        cityId: cityId,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has at least one VOD or one OTT or one EST showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider Comma separated list of external provider ids that should be included. If "All" (case insensitive) is sent, providers won't be filtered out.
  @Get(path: '/v2/showPageAvailable/{showCrid}/{language}')
  Future<chopper.Response<SpaResponse$Response>>
      _v2ShowPageAvailableShowCridLanguageGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Path('showCrid')
        required String? showCrid,
    @Path('language')
        required String? language,
    @Query('cityId')
        int? cityId,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///This endpoint basically calculates the seed episode for the given show. Seed episode are always calculated within sources of the same channel and applies only for linear sources. VOD contents are ignored. This endpoint basically uses Most Relevant Episode Logic underneath it.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param crid Show's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param channelId Channel id of the source.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<RreResponse$Response>>
      v1ResolveRecordableEpisodeCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required String? crid,
    required String? language,
    required String? country,
    required String? channelId,
    int? cityId,
    int? replayOptedInTime,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RreResponse$Response, () => RreResponse$Response.fromJsonFactory);

    return _v1ResolveRecordableEpisodeCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        crid: crid,
        language: language,
        country: country,
        channelId: channelId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///This endpoint basically calculates the seed episode for the given show. Seed episode are always calculated within sources of the same channel and applies only for linear sources. VOD contents are ignored. This endpoint basically uses Most Relevant Episode Logic underneath it.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param crid Show's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param channelId Channel id of the source.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/resolveRecordableEpisode/{crid}/{language}')
  Future<chopper.Response<RreResponse$Response>>
      _v1ResolveRecordableEpisodeCridLanguageGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Path('crid')
        required String? crid,
    @Path('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('channelId')
        required String? channelId,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///GET /recordingSources endpoint basically retrieves various channel sources of a series (or) title that can be recorded. The information provided by this endpoint will help the UI to overlay information indicating the available sources to record. Customer can choose preferred source to be recorded from the returned list
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param type Indication of what type of crid is passed
  ///@param crid Show's or title's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeSeedEvent boolean flag indicating to return seedEvent information along with the existing response
  Future<chopper.Response<RecordingSourcesResponse$Response>>
      v1RecordingSourcesTypeCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xExplicitLogging,
    required enums.V1RecordingSourcesTypeCridLanguageGetType? type,
    required String? crid,
    required String? language,
    required String? country,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? includeSeedEvent,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(RecordingSourcesResponse$Response,
        () => RecordingSourcesResponse$Response.fromJsonFactory);

    return _v1RecordingSourcesTypeCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xExplicitLogging: xExplicitLogging,
        type: type?.value?.toString(),
        crid: crid,
        language: language,
        country: country,
        maxRes: maxRes?.value?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        includeSeedEvent: includeSeedEvent,
        cacheControl: cacheControl);
  }

  ///GET /recordingSources endpoint basically retrieves various channel sources of a series (or) title that can be recorded. The information provided by this endpoint will help the UI to overlay information indicating the available sources to record. Customer can choose preferred source to be recorded from the returned list
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param x-explicit-logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param type Indication of what type of crid is passed
  ///@param crid Show's or title's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeSeedEvent boolean flag indicating to return seedEvent information along with the existing response
  @Get(path: '/v1/recordingSources/{type}/{crid}/{language}')
  Future<chopper.Response<RecordingSourcesResponse$Response>>
      _v1RecordingSourcesTypeCridLanguageGet({
    @Header('X-dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('x-explicit-logging')
        String? xExplicitLogging,
    @Path('type')
        required String? type,
    @Path('crid')
        required String? crid,
    @Path('language')
        required String? language,
    @Query('country')
        required String? country,
    @Query('maxRes')
        String? maxRes,
    @Query('cityId')
        int? cityId,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('mergingOn')
        bool? mergingOn,
    @Query('includeSeedEvent')
        bool? includeSeedEvent,
    @Header('Cache-Control')
        String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class SeasonResponse {
  SeasonResponse({
    required this.id,
    required this.title,
    this.synopsis,
    this.image,
    this.landscape,
    this.landscapeTile,
    required this.totalEpisodes,
    this.type,
    this.season,
    this.episodes,
    this.imageVersion,
    this.genres,
  });

  factory SeasonResponse.fromJson(Map<String, dynamic> json) =>
      _$SeasonResponseFromJson(json);

  static const toJsonFactory = _$SeasonResponseToJson;
  Map<String, dynamic> toJson() => _$SeasonResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'landscape', includeIfNull: false, defaultValue: '')
  final String? landscape;
  @JsonKey(name: 'landscapeTile', includeIfNull: false, defaultValue: '')
  final String? landscapeTile;
  @JsonKey(name: 'totalEpisodes', includeIfNull: false)
  final int totalEpisodes;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'season', includeIfNull: false)
  final int? season;
  @JsonKey(name: 'episodes', includeIfNull: false)
  final EpisodeResponse? episodes;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  static const fromJsonFactory = _$SeasonResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeasonResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.landscape, landscape) ||
                const DeepCollectionEquality()
                    .equals(other.landscape, landscape)) &&
            (identical(other.landscapeTile, landscapeTile) ||
                const DeepCollectionEquality()
                    .equals(other.landscapeTile, landscapeTile)) &&
            (identical(other.totalEpisodes, totalEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.totalEpisodes, totalEpisodes)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(landscape) ^
      const DeepCollectionEquality().hash(landscapeTile) ^
      const DeepCollectionEquality().hash(totalEpisodes) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(genres) ^
      runtimeType.hashCode;
}

extension $SeasonResponseExtension on SeasonResponse {
  SeasonResponse copyWith(
      {String? id,
      String? title,
      String? synopsis,
      String? image,
      String? landscape,
      String? landscapeTile,
      int? totalEpisodes,
      String? type,
      int? season,
      EpisodeResponse? episodes,
      String? imageVersion,
      List<String>? genres}) {
    return SeasonResponse(
        id: id ?? this.id,
        title: title ?? this.title,
        synopsis: synopsis ?? this.synopsis,
        image: image ?? this.image,
        landscape: landscape ?? this.landscape,
        landscapeTile: landscapeTile ?? this.landscapeTile,
        totalEpisodes: totalEpisodes ?? this.totalEpisodes,
        type: type ?? this.type,
        season: season ?? this.season,
        episodes: episodes ?? this.episodes,
        imageVersion: imageVersion ?? this.imageVersion,
        genres: genres ?? this.genres);
  }

  SeasonResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? image,
      Wrapped<String?>? landscape,
      Wrapped<String?>? landscapeTile,
      Wrapped<int>? totalEpisodes,
      Wrapped<String?>? type,
      Wrapped<int?>? season,
      Wrapped<EpisodeResponse?>? episodes,
      Wrapped<String?>? imageVersion,
      Wrapped<List<String>?>? genres}) {
    return SeasonResponse(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        image: (image != null ? image.value : this.image),
        landscape: (landscape != null ? landscape.value : this.landscape),
        landscapeTile:
            (landscapeTile != null ? landscapeTile.value : this.landscapeTile),
        totalEpisodes:
            (totalEpisodes != null ? totalEpisodes.value : this.totalEpisodes),
        type: (type != null ? type.value : this.type),
        season: (season != null ? season.value : this.season),
        episodes: (episodes != null ? episodes.value : this.episodes),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodeResponse {
  EpisodeResponse({
    required this.id,
    this.episode,
    required this.title,
    this.image,
    this.landscape,
    this.landscapeTile,
    this.ageRating,
    this.synopsis,
    required this.isAdult,
    this.isWatchedCompletely,
    this.replayContainsAdult,
    this.replayMinAge,
    this.bookmark,
    this.duration,
    this.broadcastDate,
    this.type,
    this.isReplay,
    this.isRecording,
    this.eventId,
    this.channelId,
    required this.est,
    this.replayAvailable,
    this.vod,
    this.imageVersion,
  });

  factory EpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodeResponseFromJson(json);

  static const toJsonFactory = _$EpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodeResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'episode', includeIfNull: false)
  final int? episode;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'landscape', includeIfNull: false, defaultValue: '')
  final String? landscape;
  @JsonKey(name: 'landscapeTile', includeIfNull: false, defaultValue: '')
  final String? landscapeTile;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'isWatchedCompletely', includeIfNull: false)
  final bool? isWatchedCompletely;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false)
  final bool? isRecording;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse> est;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'vod', includeIfNull: false)
  final VodResponse? vod;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodeResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodeResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.landscape, landscape) ||
                const DeepCollectionEquality()
                    .equals(other.landscape, landscape)) &&
            (identical(other.landscapeTile, landscapeTile) ||
                const DeepCollectionEquality()
                    .equals(other.landscapeTile, landscapeTile)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isWatchedCompletely, isWatchedCompletely) ||
                const DeepCollectionEquality()
                    .equals(other.isWatchedCompletely, isWatchedCompletely)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.vod, vod) ||
                const DeepCollectionEquality().equals(other.vod, vod)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(landscape) ^
      const DeepCollectionEquality().hash(landscapeTile) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isWatchedCompletely) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(vod) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodeResponseExtension on EpisodeResponse {
  EpisodeResponse copyWith(
      {String? id,
      int? episode,
      String? title,
      String? image,
      String? landscape,
      String? landscapeTile,
      String? ageRating,
      String? synopsis,
      bool? isAdult,
      bool? isWatchedCompletely,
      bool? replayContainsAdult,
      int? replayMinAge,
      int? bookmark,
      int? duration,
      String? broadcastDate,
      String? type,
      bool? isReplay,
      bool? isRecording,
      String? eventId,
      String? channelId,
      List<EstResponse>? est,
      bool? replayAvailable,
      VodResponse? vod,
      String? imageVersion}) {
    return EpisodeResponse(
        id: id ?? this.id,
        episode: episode ?? this.episode,
        title: title ?? this.title,
        image: image ?? this.image,
        landscape: landscape ?? this.landscape,
        landscapeTile: landscapeTile ?? this.landscapeTile,
        ageRating: ageRating ?? this.ageRating,
        synopsis: synopsis ?? this.synopsis,
        isAdult: isAdult ?? this.isAdult,
        isWatchedCompletely: isWatchedCompletely ?? this.isWatchedCompletely,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        bookmark: bookmark ?? this.bookmark,
        duration: duration ?? this.duration,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        type: type ?? this.type,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        est: est ?? this.est,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        vod: vod ?? this.vod,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodeResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<int?>? episode,
      Wrapped<String>? title,
      Wrapped<String?>? image,
      Wrapped<String?>? landscape,
      Wrapped<String?>? landscapeTile,
      Wrapped<String?>? ageRating,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? isAdult,
      Wrapped<bool?>? isWatchedCompletely,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<int?>? bookmark,
      Wrapped<int?>? duration,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? type,
      Wrapped<bool?>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String?>? eventId,
      Wrapped<String?>? channelId,
      Wrapped<List<EstResponse>>? est,
      Wrapped<bool?>? replayAvailable,
      Wrapped<VodResponse?>? vod,
      Wrapped<String?>? imageVersion}) {
    return EpisodeResponse(
        id: (id != null ? id.value : this.id),
        episode: (episode != null ? episode.value : this.episode),
        title: (title != null ? title.value : this.title),
        image: (image != null ? image.value : this.image),
        landscape: (landscape != null ? landscape.value : this.landscape),
        landscapeTile:
            (landscapeTile != null ? landscapeTile.value : this.landscapeTile),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isWatchedCompletely: (isWatchedCompletely != null
            ? isWatchedCompletely.value
            : this.isWatchedCompletely),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        duration: (duration != null ? duration.value : this.duration),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        type: (type != null ? type.value : this.type),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        est: (est != null ? est.value : this.est),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        vod: (vod != null ? vod.value : this.vod),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class VodResponse {
  VodResponse({
    required this.type,
    this.entitlemendEnd,
    this.entitlementState,
  });

  factory VodResponse.fromJson(Map<String, dynamic> json) =>
      _$VodResponseFromJson(json);

  static const toJsonFactory = _$VodResponseToJson;
  Map<String, dynamic> toJson() => _$VodResponseToJson(this);

  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: vodResponseTypeToJson,
    fromJson: vodResponseTypeFromJson,
  )
  final enums.VodResponseType type;
  @JsonKey(name: 'entitlemendEnd', includeIfNull: false, defaultValue: '')
  final String? entitlemendEnd;
  @JsonKey(
    name: 'entitlementState',
    includeIfNull: false,
    toJson: vodResponseEntitlementStateToJson,
    fromJson: vodResponseEntitlementStateFromJson,
  )
  final enums.VodResponseEntitlementState? entitlementState;
  static const fromJsonFactory = _$VodResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodResponse &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlemendEnd, entitlemendEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlemendEnd, entitlemendEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlemendEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      runtimeType.hashCode;
}

extension $VodResponseExtension on VodResponse {
  VodResponse copyWith(
      {enums.VodResponseType? type,
      String? entitlemendEnd,
      enums.VodResponseEntitlementState? entitlementState}) {
    return VodResponse(
        type: type ?? this.type,
        entitlemendEnd: entitlemendEnd ?? this.entitlemendEnd,
        entitlementState: entitlementState ?? this.entitlementState);
  }

  VodResponse copyWithWrapped(
      {Wrapped<enums.VodResponseType>? type,
      Wrapped<String?>? entitlemendEnd,
      Wrapped<enums.VodResponseEntitlementState?>? entitlementState}) {
    return VodResponse(
        type: (type != null ? type.value : this.type),
        entitlemendEnd: (entitlemendEnd != null
            ? entitlemendEnd.value
            : this.entitlemendEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelEventDetailResponse {
  ChannelEventDetailResponse({
    required this.channelId,
    required this.eventId,
    required this.contentType,
    this.broadcastDate,
    this.broadcastEndDate,
    this.isRecording,
    this.isReplay,
    this.bookmark,
  });

  factory ChannelEventDetailResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelEventDetailResponseFromJson(json);

  static const toJsonFactory = _$ChannelEventDetailResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelEventDetailResponseToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'broadcastEndDate', includeIfNull: false, defaultValue: '')
  final String? broadcastEndDate;
  @JsonKey(name: 'isRecording', includeIfNull: false)
  final bool? isRecording;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  static const fromJsonFactory = _$ChannelEventDetailResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelEventDetailResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.broadcastEndDate, broadcastEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastEndDate, broadcastEndDate)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(broadcastEndDate) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(bookmark) ^
      runtimeType.hashCode;
}

extension $ChannelEventDetailResponseExtension on ChannelEventDetailResponse {
  ChannelEventDetailResponse copyWith(
      {String? channelId,
      String? eventId,
      String? contentType,
      String? broadcastDate,
      String? broadcastEndDate,
      bool? isRecording,
      bool? isReplay,
      int? bookmark}) {
    return ChannelEventDetailResponse(
        channelId: channelId ?? this.channelId,
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        broadcastEndDate: broadcastEndDate ?? this.broadcastEndDate,
        isRecording: isRecording ?? this.isRecording,
        isReplay: isReplay ?? this.isReplay,
        bookmark: bookmark ?? this.bookmark);
  }

  ChannelEventDetailResponse copyWithWrapped(
      {Wrapped<String>? channelId,
      Wrapped<String>? eventId,
      Wrapped<String>? contentType,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? broadcastEndDate,
      Wrapped<bool?>? isRecording,
      Wrapped<bool?>? isReplay,
      Wrapped<int?>? bookmark}) {
    return ChannelEventDetailResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        broadcastEndDate: (broadcastEndDate != null
            ? broadcastEndDate.value
            : this.broadcastEndDate),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleChannelResponse {
  SimpleChannelResponse({
    this.id,
    this.name,
  });

  factory SimpleChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$SimpleChannelResponseFromJson(json);

  static const toJsonFactory = _$SimpleChannelResponseToJson;
  Map<String, dynamic> toJson() => _$SimpleChannelResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$SimpleChannelResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleChannelResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $SimpleChannelResponseExtension on SimpleChannelResponse {
  SimpleChannelResponse copyWith({String? id, String? name}) {
    return SimpleChannelResponse(id: id ?? this.id, name: name ?? this.name);
  }

  SimpleChannelResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<String?>? name}) {
    return SimpleChannelResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class EstResponse {
  EstResponse({
    required this.minPrice,
    required this.minPriceDisplay,
    required this.currency,
    required this.videoHost,
    required this.videoUrl,
  });

  factory EstResponse.fromJson(Map<String, dynamic> json) =>
      _$EstResponseFromJson(json);

  static const toJsonFactory = _$EstResponseToJson;
  Map<String, dynamic> toJson() => _$EstResponseToJson(this);

  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  static const fromJsonFactory = _$EstResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstResponse &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      runtimeType.hashCode;
}

extension $EstResponseExtension on EstResponse {
  EstResponse copyWith(
      {String? minPrice,
      String? minPriceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl}) {
    return EstResponse(
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl);
  }

  EstResponse copyWithWrapped(
      {Wrapped<String>? minPrice,
      Wrapped<String>? minPriceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl}) {
    return EstResponse(
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoLinearResponse {
  TaaoLinearResponse({
    this.viewProgress,
    required this.sourceType,
    required this.source,
  });

  factory TaaoLinearResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoLinearResponseFromJson(json);

  static const toJsonFactory = _$TaaoLinearResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoLinearResponseToJson(this);

  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final LinearSourceResponse source;
  static const fromJsonFactory = _$TaaoLinearResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoLinearResponse &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoLinearResponseExtension on TaaoLinearResponse {
  TaaoLinearResponse copyWith(
      {ViewProgressResponse? viewProgress,
      enums.SourceTypeResponse? sourceType,
      LinearSourceResponse? source}) {
    return TaaoLinearResponse(
        viewProgress: viewProgress ?? this.viewProgress,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoLinearResponse copyWithWrapped(
      {Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<LinearSourceResponse>? source}) {
    return TaaoLinearResponse(
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoRecordingResponse {
  TaaoRecordingResponse({
    this.viewProgress,
    required this.sourceType,
    required this.source,
  });

  factory TaaoRecordingResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoRecordingResponseFromJson(json);

  static const toJsonFactory = _$TaaoRecordingResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoRecordingResponseToJson(this);

  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final RecordingSourceResponse source;
  static const fromJsonFactory = _$TaaoRecordingResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoRecordingResponse &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoRecordingResponseExtension on TaaoRecordingResponse {
  TaaoRecordingResponse copyWith(
      {ViewProgressResponse? viewProgress,
      enums.SourceTypeResponse? sourceType,
      RecordingSourceResponse? source}) {
    return TaaoRecordingResponse(
        viewProgress: viewProgress ?? this.viewProgress,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoRecordingResponse copyWithWrapped(
      {Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<RecordingSourceResponse>? source}) {
    return TaaoRecordingResponse(
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoVodResponse {
  TaaoVodResponse({
    this.viewProgress,
    required this.sourceType,
    required this.source,
  });

  factory TaaoVodResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoVodResponseFromJson(json);

  static const toJsonFactory = _$TaaoVodResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoVodResponseToJson(this);

  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final VodSourceResponse source;
  static const fromJsonFactory = _$TaaoVodResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoVodResponse &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoVodResponseExtension on TaaoVodResponse {
  TaaoVodResponse copyWith(
      {ViewProgressResponse? viewProgress,
      enums.SourceTypeResponse? sourceType,
      VodSourceResponse? source}) {
    return TaaoVodResponse(
        viewProgress: viewProgress ?? this.viewProgress,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoVodResponse copyWithWrapped(
      {Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<VodSourceResponse>? source}) {
    return TaaoVodResponse(
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoOttResponse {
  TaaoOttResponse({
    required this.sourceType,
    required this.source,
  });

  factory TaaoOttResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoOttResponseFromJson(json);

  static const toJsonFactory = _$TaaoOttResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoOttResponseToJson(this);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final OttSourceResponse source;
  static const fromJsonFactory = _$TaaoOttResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoOttResponse &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoOttResponseExtension on TaaoOttResponse {
  TaaoOttResponse copyWith(
      {enums.SourceTypeResponse? sourceType, OttSourceResponse? source}) {
    return TaaoOttResponse(
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoOttResponse copyWithWrapped(
      {Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<OttSourceResponse>? source}) {
    return TaaoOttResponse(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class ViewProgressResponse {
  ViewProgressResponse({
    required this.viewState,
    required this.position,
    required this.duration,
  });

  factory ViewProgressResponse.fromJson(Map<String, dynamic> json) =>
      _$ViewProgressResponseFromJson(json);

  static const toJsonFactory = _$ViewProgressResponseToJson;
  Map<String, dynamic> toJson() => _$ViewProgressResponseToJson(this);

  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewProgressResponseViewStateToJson,
    fromJson: viewProgressResponseViewStateFromJson,
  )
  final enums.ViewProgressResponseViewState viewState;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  static const fromJsonFactory = _$ViewProgressResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ViewProgressResponse &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      runtimeType.hashCode;
}

extension $ViewProgressResponseExtension on ViewProgressResponse {
  ViewProgressResponse copyWith(
      {enums.ViewProgressResponseViewState? viewState,
      int? position,
      int? duration}) {
    return ViewProgressResponse(
        viewState: viewState ?? this.viewState,
        position: position ?? this.position,
        duration: duration ?? this.duration);
  }

  ViewProgressResponse copyWithWrapped(
      {Wrapped<enums.ViewProgressResponseViewState>? viewState,
      Wrapped<int>? position,
      Wrapped<int>? duration}) {
    return ViewProgressResponse(
        viewState: (viewState != null ? viewState.value : this.viewState),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration));
  }
}

@JsonSerializable(explicitToJson: true)
class LinearSourceResponse {
  LinearSourceResponse({
    required this.titleId,
    required this.eventId,
    required this.channel,
    required this.broadcastDate,
    required this.duration,
    this.eventReplay,
    this.imageVersion,
    this.audioQuality,
    this.hasLiveTVOTT,
    this.ageRating,
  });

  factory LinearSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$LinearSourceResponseFromJson(json);

  static const toJsonFactory = _$LinearSourceResponseToJson;
  Map<String, dynamic> toJson() => _$LinearSourceResponseToJson(this);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channel', includeIfNull: false)
  final ChannelResponse channel;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'hasLiveTVOTT', includeIfNull: false)
  final bool? hasLiveTVOTT;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  static const fromJsonFactory = _$LinearSourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LinearSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.hasLiveTVOTT, hasLiveTVOTT) ||
                const DeepCollectionEquality()
                    .equals(other.hasLiveTVOTT, hasLiveTVOTT)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(hasLiveTVOTT) ^
      const DeepCollectionEquality().hash(ageRating) ^
      runtimeType.hashCode;
}

extension $LinearSourceResponseExtension on LinearSourceResponse {
  LinearSourceResponse copyWith(
      {String? titleId,
      String? eventId,
      ChannelResponse? channel,
      String? broadcastDate,
      int? duration,
      EventReplayResponse? eventReplay,
      String? imageVersion,
      String? audioQuality,
      bool? hasLiveTVOTT,
      int? ageRating}) {
    return LinearSourceResponse(
        titleId: titleId ?? this.titleId,
        eventId: eventId ?? this.eventId,
        channel: channel ?? this.channel,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        duration: duration ?? this.duration,
        eventReplay: eventReplay ?? this.eventReplay,
        imageVersion: imageVersion ?? this.imageVersion,
        audioQuality: audioQuality ?? this.audioQuality,
        hasLiveTVOTT: hasLiveTVOTT ?? this.hasLiveTVOTT,
        ageRating: ageRating ?? this.ageRating);
  }

  LinearSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? eventId,
      Wrapped<ChannelResponse>? channel,
      Wrapped<String>? broadcastDate,
      Wrapped<int>? duration,
      Wrapped<EventReplayResponse?>? eventReplay,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? audioQuality,
      Wrapped<bool?>? hasLiveTVOTT,
      Wrapped<int?>? ageRating}) {
    return LinearSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channel: (channel != null ? channel.value : this.channel),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        duration: (duration != null ? duration.value : this.duration),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        hasLiveTVOTT:
            (hasLiveTVOTT != null ? hasLiveTVOTT.value : this.hasLiveTVOTT),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingSourceResponse {
  RecordingSourceResponse({
    required this.titleId,
    required this.recordingId,
    this.cpeId,
    required this.broadcastDate,
    required this.duration,
    this.technicalDuration,
    required this.channel,
    this.containsAdult,
    this.imageVersion,
    this.audioQuality,
    this.isOttBlackout,
    this.restricted,
    this.resolution,
    this.recordingState,
    this.ageRating,
  });

  factory RecordingSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingSourceResponseFromJson(json);

  static const toJsonFactory = _$RecordingSourceResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingSourceResponseToJson(this);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String recordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final ChannelResponse channel;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingSourceResponseRecordingStateToJson,
    fromJson: recordingSourceResponseRecordingStateFromJson,
  )
  final enums.RecordingSourceResponseRecordingState? recordingState;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  static const fromJsonFactory = _$RecordingSourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.isOttBlackout, isOttBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(ageRating) ^
      runtimeType.hashCode;
}

extension $RecordingSourceResponseExtension on RecordingSourceResponse {
  RecordingSourceResponse copyWith(
      {String? titleId,
      String? recordingId,
      String? cpeId,
      String? broadcastDate,
      int? duration,
      int? technicalDuration,
      ChannelResponse? channel,
      bool? containsAdult,
      String? imageVersion,
      String? audioQuality,
      bool? isOttBlackout,
      bool? restricted,
      String? resolution,
      enums.RecordingSourceResponseRecordingState? recordingState,
      int? ageRating}) {
    return RecordingSourceResponse(
        titleId: titleId ?? this.titleId,
        recordingId: recordingId ?? this.recordingId,
        cpeId: cpeId ?? this.cpeId,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        channel: channel ?? this.channel,
        containsAdult: containsAdult ?? this.containsAdult,
        imageVersion: imageVersion ?? this.imageVersion,
        audioQuality: audioQuality ?? this.audioQuality,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        restricted: restricted ?? this.restricted,
        resolution: resolution ?? this.resolution,
        recordingState: recordingState ?? this.recordingState,
        ageRating: ageRating ?? this.ageRating);
  }

  RecordingSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? recordingId,
      Wrapped<String?>? cpeId,
      Wrapped<String>? broadcastDate,
      Wrapped<int>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<ChannelResponse>? channel,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? audioQuality,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? restricted,
      Wrapped<String?>? resolution,
      Wrapped<enums.RecordingSourceResponseRecordingState?>? recordingState,
      Wrapped<int?>? ageRating}) {
    return RecordingSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        channel: (channel != null ? channel.value : this.channel),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        restricted: (restricted != null ? restricted.value : this.restricted),
        resolution: (resolution != null ? resolution.value : this.resolution),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating));
  }
}

@JsonSerializable(explicitToJson: true)
class VodSourceResponse {
  VodSourceResponse({
    required this.titleId,
    required this.type,
    this.entitlementEnd,
    required this.entitlementState,
    required this.brandingProviderId,
    this.priceDisplay,
    this.minPriceDisplay,
    this.currency,
    required this.isGoPlayable,
    required this.duration,
    this.audioQuality,
    this.imageVersion,
    this.ageRating,
  });

  factory VodSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$VodSourceResponseFromJson(json);

  static const toJsonFactory = _$VodSourceResponseToJson;
  Map<String, dynamic> toJson() => _$VodSourceResponseToJson(this);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: vodSourceResponseTypeToJson,
    fromJson: vodSourceResponseTypeFromJson,
  )
  final enums.VodSourceResponseType type;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String entitlementState;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String brandingProviderId;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  static const fromJsonFactory = _$VodSourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(ageRating) ^
      runtimeType.hashCode;
}

extension $VodSourceResponseExtension on VodSourceResponse {
  VodSourceResponse copyWith(
      {String? titleId,
      enums.VodSourceResponseType? type,
      String? entitlementEnd,
      String? entitlementState,
      String? brandingProviderId,
      String? priceDisplay,
      String? minPriceDisplay,
      String? currency,
      bool? isGoPlayable,
      int? duration,
      String? audioQuality,
      String? imageVersion,
      int? ageRating}) {
    return VodSourceResponse(
        titleId: titleId ?? this.titleId,
        type: type ?? this.type,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        duration: duration ?? this.duration,
        audioQuality: audioQuality ?? this.audioQuality,
        imageVersion: imageVersion ?? this.imageVersion,
        ageRating: ageRating ?? this.ageRating);
  }

  VodSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<enums.VodSourceResponseType>? type,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String>? entitlementState,
      Wrapped<String>? brandingProviderId,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? currency,
      Wrapped<bool>? isGoPlayable,
      Wrapped<int>? duration,
      Wrapped<String?>? audioQuality,
      Wrapped<String?>? imageVersion,
      Wrapped<int?>? ageRating}) {
    return VodSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        type: (type != null ? type.value : this.type),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        duration: (duration != null ? duration.value : this.duration),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerVodSourceResponse {
  EpisodePickerVodSourceResponse({
    this.goDownloadable,
    required this.titleId,
    required this.type,
    this.entitlementEnd,
    required this.entitlementState,
    required this.brandingProviderId,
    this.priceDisplay,
    this.minPriceDisplay,
    this.currency,
    required this.isGoPlayable,
    required this.duration,
    this.audioQuality,
    this.imageVersion,
    this.ageRating,
  });

  factory EpisodePickerVodSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerVodSourceResponseFromJson(json);

  static const toJsonFactory = _$EpisodePickerVodSourceResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerVodSourceResponseToJson(this);

  @JsonKey(name: 'goDownloadable', includeIfNull: false)
  final bool? goDownloadable;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: episodePickerVodSourceResponseTypeToJson,
    fromJson: episodePickerVodSourceResponseTypeFromJson,
  )
  final enums.EpisodePickerVodSourceResponseType type;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String entitlementState;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String brandingProviderId;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  static const fromJsonFactory = _$EpisodePickerVodSourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerVodSourceResponse &&
            (identical(other.goDownloadable, goDownloadable) ||
                const DeepCollectionEquality()
                    .equals(other.goDownloadable, goDownloadable)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(goDownloadable) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(ageRating) ^
      runtimeType.hashCode;
}

extension $EpisodePickerVodSourceResponseExtension
    on EpisodePickerVodSourceResponse {
  EpisodePickerVodSourceResponse copyWith(
      {bool? goDownloadable,
      String? titleId,
      enums.EpisodePickerVodSourceResponseType? type,
      String? entitlementEnd,
      String? entitlementState,
      String? brandingProviderId,
      String? priceDisplay,
      String? minPriceDisplay,
      String? currency,
      bool? isGoPlayable,
      int? duration,
      String? audioQuality,
      String? imageVersion,
      int? ageRating}) {
    return EpisodePickerVodSourceResponse(
        goDownloadable: goDownloadable ?? this.goDownloadable,
        titleId: titleId ?? this.titleId,
        type: type ?? this.type,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        duration: duration ?? this.duration,
        audioQuality: audioQuality ?? this.audioQuality,
        imageVersion: imageVersion ?? this.imageVersion,
        ageRating: ageRating ?? this.ageRating);
  }

  EpisodePickerVodSourceResponse copyWithWrapped(
      {Wrapped<bool?>? goDownloadable,
      Wrapped<String>? titleId,
      Wrapped<enums.EpisodePickerVodSourceResponseType>? type,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String>? entitlementState,
      Wrapped<String>? brandingProviderId,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? currency,
      Wrapped<bool>? isGoPlayable,
      Wrapped<int>? duration,
      Wrapped<String?>? audioQuality,
      Wrapped<String?>? imageVersion,
      Wrapped<int?>? ageRating}) {
    return EpisodePickerVodSourceResponse(
        goDownloadable: (goDownloadable != null
            ? goDownloadable.value
            : this.goDownloadable),
        titleId: (titleId != null ? titleId.value : this.titleId),
        type: (type != null ? type.value : this.type),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        duration: (duration != null ? duration.value : this.duration),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating));
  }
}

@JsonSerializable(explicitToJson: true)
class OttSourceResponse {
  OttSourceResponse({
    required this.titleId,
    required this.minPriceDisplay,
    required this.priceDisplay,
    required this.currency,
    required this.videoHost,
    required this.videoUrl,
    required this.isEST,
    required this.brandingProviderId,
    this.audioQuality,
    this.imageVersion,
    this.ageRating,
  });

  factory OttSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$OttSourceResponseFromJson(json);

  static const toJsonFactory = _$OttSourceResponseToJson;
  Map<String, dynamic> toJson() => _$OttSourceResponseToJson(this);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String minPriceDisplay;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String priceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  @JsonKey(name: 'isEST', includeIfNull: false)
  final bool isEST;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String brandingProviderId;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  static const fromJsonFactory = _$OttSourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OttSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.isEST, isEST) ||
                const DeepCollectionEquality().equals(other.isEST, isEST)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(isEST) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(ageRating) ^
      runtimeType.hashCode;
}

extension $OttSourceResponseExtension on OttSourceResponse {
  OttSourceResponse copyWith(
      {String? titleId,
      String? minPriceDisplay,
      String? priceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl,
      bool? isEST,
      String? brandingProviderId,
      String? audioQuality,
      String? imageVersion,
      int? ageRating}) {
    return OttSourceResponse(
        titleId: titleId ?? this.titleId,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        isEST: isEST ?? this.isEST,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        audioQuality: audioQuality ?? this.audioQuality,
        imageVersion: imageVersion ?? this.imageVersion,
        ageRating: ageRating ?? this.ageRating);
  }

  OttSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? minPriceDisplay,
      Wrapped<String>? priceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl,
      Wrapped<bool>? isEST,
      Wrapped<String>? brandingProviderId,
      Wrapped<String?>? audioQuality,
      Wrapped<String?>? imageVersion,
      Wrapped<int?>? ageRating}) {
    return OttSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        isEST: (isEST != null ? isEST.value : this.isEST),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponse {
  ChannelResponse({
    required this.channelId,
    required this.channelName,
  });

  factory ChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseFromJson(json);

  static const toJsonFactory = _$ChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String channelName;
  static const fromJsonFactory = _$ChannelResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      runtimeType.hashCode;
}

extension $ChannelResponseExtension on ChannelResponse {
  ChannelResponse copyWith({String? channelId, String? channelName}) {
    return ChannelResponse(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName);
  }

  ChannelResponse copyWithWrapped(
      {Wrapped<String>? channelId, Wrapped<String>? channelName}) {
    return ChannelResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName));
  }
}

@JsonSerializable(explicitToJson: true)
class EventReplayResponse {
  EventReplayResponse({
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.replayContainsAdult,
    this.replayMinAge,
    required this.isGoPlayable,
    required this.displayAgeRating,
    required this.goPlayableViaExternalApp,
    this.externalAppUrls,
  });

  factory EventReplayResponse.fromJson(Map<String, dynamic> json) =>
      _$EventReplayResponseFromJson(json);

  static const toJsonFactory = _$EventReplayResponseToJson;
  Map<String, dynamic> toJson() => _$EventReplayResponseToJson(this);

  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final int? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final int? replayAvailabilityEnd;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'displayAgeRating', includeIfNull: false)
  final bool displayAgeRating;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool goPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrlResponse>[])
  final List<ExternalAppUrlResponse>? externalAppUrls;
  static const fromJsonFactory = _$EventReplayResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventReplayResponse &&
            (identical(
                    other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.displayAgeRating, displayAgeRating) ||
                const DeepCollectionEquality()
                    .equals(other.displayAgeRating, displayAgeRating)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) ||
                const DeepCollectionEquality()
                    .equals(other.externalAppUrls, externalAppUrls)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(displayAgeRating) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      runtimeType.hashCode;
}

extension $EventReplayResponseExtension on EventReplayResponse {
  EventReplayResponse copyWith(
      {int? replayAvailabilityStart,
      int? replayAvailabilityEnd,
      bool? replayContainsAdult,
      int? replayMinAge,
      bool? isGoPlayable,
      bool? displayAgeRating,
      bool? goPlayableViaExternalApp,
      List<ExternalAppUrlResponse>? externalAppUrls}) {
    return EventReplayResponse(
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        displayAgeRating: displayAgeRating ?? this.displayAgeRating,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls);
  }

  EventReplayResponse copyWithWrapped(
      {Wrapped<int?>? replayAvailabilityStart,
      Wrapped<int?>? replayAvailabilityEnd,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<bool>? isGoPlayable,
      Wrapped<bool>? displayAgeRating,
      Wrapped<bool>? goPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrlResponse>?>? externalAppUrls}) {
    return EventReplayResponse(
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        displayAgeRating: (displayAgeRating != null
            ? displayAgeRating.value
            : this.displayAgeRating),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerSeasonResponse {
  EpisodePickerSeasonResponse({
    this.id,
    this.episodes,
    required this.season,
    this.synopsis,
    required this.title,
    required this.totalEpisodes,
    this.imageVersion,
  });

  factory EpisodePickerSeasonResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerSeasonResponseFromJson(json);

  static const toJsonFactory = _$EpisodePickerSeasonResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerSeasonResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? episodes;
  @JsonKey(name: 'season', includeIfNull: false)
  final int season;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'totalEpisodes', includeIfNull: false)
  final int totalEpisodes;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodePickerSeasonResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerSeasonResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.totalEpisodes, totalEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.totalEpisodes, totalEpisodes)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(totalEpisodes) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodePickerSeasonResponseExtension on EpisodePickerSeasonResponse {
  EpisodePickerSeasonResponse copyWith(
      {String? id,
      List<EpisodePickerEpisodeResponse>? episodes,
      int? season,
      String? synopsis,
      String? title,
      int? totalEpisodes,
      String? imageVersion}) {
    return EpisodePickerSeasonResponse(
        id: id ?? this.id,
        episodes: episodes ?? this.episodes,
        season: season ?? this.season,
        synopsis: synopsis ?? this.synopsis,
        title: title ?? this.title,
        totalEpisodes: totalEpisodes ?? this.totalEpisodes,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodePickerSeasonResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? episodes,
      Wrapped<int>? season,
      Wrapped<String?>? synopsis,
      Wrapped<String>? title,
      Wrapped<int>? totalEpisodes,
      Wrapped<String?>? imageVersion}) {
    return EpisodePickerSeasonResponse(
        id: (id != null ? id.value : this.id),
        episodes: (episodes != null ? episodes.value : this.episodes),
        season: (season != null ? season.value : this.season),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        title: (title != null ? title.value : this.title),
        totalEpisodes:
            (totalEpisodes != null ? totalEpisodes.value : this.totalEpisodes),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerEpisodeResponse {
  EpisodePickerEpisodeResponse({
    required this.id,
    this.episode,
    this.episodePart,
    this.title,
    this.ageRating,
    this.synopsis,
    required this.isAdult,
    this.viewProgress,
    required this.type,
    required this.sourceType,
    required this.source,
    this.mergedId,
    this.recordingId,
    this.imageVersion,
  });

  factory EpisodePickerEpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerEpisodeResponseFromJson(json);

  static const toJsonFactory = _$EpisodePickerEpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerEpisodeResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'episode', includeIfNull: false)
  final int? episode;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: episodePickerEpisodeResponseTypeToJson,
    fromJson: episodePickerEpisodeResponseTypeFromJson,
  )
  final enums.EpisodePickerEpisodeResponseType type;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final Object source;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String? recordingId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodePickerEpisodeResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerEpisodeResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodePickerEpisodeResponseExtension
    on EpisodePickerEpisodeResponse {
  EpisodePickerEpisodeResponse copyWith(
      {String? id,
      int? episode,
      int? episodePart,
      String? title,
      String? ageRating,
      String? synopsis,
      bool? isAdult,
      ViewProgressResponse? viewProgress,
      enums.EpisodePickerEpisodeResponseType? type,
      enums.SourceTypeResponse? sourceType,
      Object? source,
      String? mergedId,
      String? recordingId,
      String? imageVersion}) {
    return EpisodePickerEpisodeResponse(
        id: id ?? this.id,
        episode: episode ?? this.episode,
        episodePart: episodePart ?? this.episodePart,
        title: title ?? this.title,
        ageRating: ageRating ?? this.ageRating,
        synopsis: synopsis ?? this.synopsis,
        isAdult: isAdult ?? this.isAdult,
        viewProgress: viewProgress ?? this.viewProgress,
        type: type ?? this.type,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source,
        mergedId: mergedId ?? this.mergedId,
        recordingId: recordingId ?? this.recordingId,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodePickerEpisodeResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<int?>? episode,
      Wrapped<int?>? episodePart,
      Wrapped<String?>? title,
      Wrapped<String?>? ageRating,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? isAdult,
      Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.EpisodePickerEpisodeResponseType>? type,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<Object>? source,
      Wrapped<String?>? mergedId,
      Wrapped<String?>? recordingId,
      Wrapped<String?>? imageVersion}) {
    return EpisodePickerEpisodeResponse(
        id: (id != null ? id.value : this.id),
        episode: (episode != null ? episode.value : this.episode),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        title: (title != null ? title.value : this.title),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        type: (type != null ? type.value : this.type),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerYearOfProductionResponse {
  EpisodePickerYearOfProductionResponse({
    required this.year,
    required this.episodes,
  });

  factory EpisodePickerYearOfProductionResponse.fromJson(
          Map<String, dynamic> json) =>
      _$EpisodePickerYearOfProductionResponseFromJson(json);

  static const toJsonFactory = _$EpisodePickerYearOfProductionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$EpisodePickerYearOfProductionResponseToJson(this);

  @JsonKey(name: 'year', includeIfNull: false, defaultValue: '')
  final String year;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse> episodes;
  static const fromJsonFactory =
      _$EpisodePickerYearOfProductionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerYearOfProductionResponse &&
            (identical(other.year, year) ||
                const DeepCollectionEquality().equals(other.year, year)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(year) ^
      const DeepCollectionEquality().hash(episodes) ^
      runtimeType.hashCode;
}

extension $EpisodePickerYearOfProductionResponseExtension
    on EpisodePickerYearOfProductionResponse {
  EpisodePickerYearOfProductionResponse copyWith(
      {String? year, List<EpisodePickerEpisodeResponse>? episodes}) {
    return EpisodePickerYearOfProductionResponse(
        year: year ?? this.year, episodes: episodes ?? this.episodes);
  }

  EpisodePickerYearOfProductionResponse copyWithWrapped(
      {Wrapped<String>? year,
      Wrapped<List<EpisodePickerEpisodeResponse>>? episodes}) {
    return EpisodePickerYearOfProductionResponse(
        year: (year != null ? year.value : this.year),
        episodes: (episodes != null ? episodes.value : this.episodes));
  }
}

@JsonSerializable(explicitToJson: true)
class SaaoSourceResponse {
  SaaoSourceResponse({
    required this.showId,
    required this.contentType,
    this.brandingProviderId,
    this.channel,
    required this.seasonList,
    required this.episodeCount,
    required this.specialsCount,
    this.imageVersion,
    this.mepSeriesFinale,
    this.premiereAirings,
  });

  factory SaaoSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$SaaoSourceResponseFromJson(json);

  static const toJsonFactory = _$SaaoSourceResponseToJson;
  Map<String, dynamic> toJson() => _$SaaoSourceResponseToJson(this);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: saaoSourceResponseContentTypeToJson,
    fromJson: saaoSourceResponseContentTypeFromJson,
  )
  final enums.SaaoSourceResponseContentType contentType;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'channel', includeIfNull: false)
  final ChannelResponse? channel;
  @JsonKey(name: 'seasonList', includeIfNull: false, defaultValue: <int>[])
  final List<int> seasonList;
  @JsonKey(name: 'episodeCount', includeIfNull: false)
  final int episodeCount;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int specialsCount;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  static const fromJsonFactory = _$SaaoSourceResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SaaoSourceResponse &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.seasonList, seasonList) ||
                const DeepCollectionEquality()
                    .equals(other.seasonList, seasonList)) &&
            (identical(other.episodeCount, episodeCount) ||
                const DeepCollectionEquality()
                    .equals(other.episodeCount, episodeCount)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(seasonList) ^
      const DeepCollectionEquality().hash(episodeCount) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      runtimeType.hashCode;
}

extension $SaaoSourceResponseExtension on SaaoSourceResponse {
  SaaoSourceResponse copyWith(
      {String? showId,
      enums.SaaoSourceResponseContentType? contentType,
      String? brandingProviderId,
      ChannelResponse? channel,
      List<int>? seasonList,
      int? episodeCount,
      int? specialsCount,
      String? imageVersion,
      String? mepSeriesFinale,
      bool? premiereAirings}) {
    return SaaoSourceResponse(
        showId: showId ?? this.showId,
        contentType: contentType ?? this.contentType,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        channel: channel ?? this.channel,
        seasonList: seasonList ?? this.seasonList,
        episodeCount: episodeCount ?? this.episodeCount,
        specialsCount: specialsCount ?? this.specialsCount,
        imageVersion: imageVersion ?? this.imageVersion,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings);
  }

  SaaoSourceResponse copyWithWrapped(
      {Wrapped<String>? showId,
      Wrapped<enums.SaaoSourceResponseContentType>? contentType,
      Wrapped<String?>? brandingProviderId,
      Wrapped<ChannelResponse?>? channel,
      Wrapped<List<int>>? seasonList,
      Wrapped<int>? episodeCount,
      Wrapped<int>? specialsCount,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings}) {
    return SaaoSourceResponse(
        showId: (showId != null ? showId.value : this.showId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        channel: (channel != null ? channel.value : this.channel),
        seasonList: (seasonList != null ? seasonList.value : this.seasonList),
        episodeCount:
            (episodeCount != null ? episodeCount.value : this.episodeCount),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings));
  }
}

@JsonSerializable(explicitToJson: true)
class TrailerInfoResponse {
  TrailerInfoResponse({
    required this.id,
  });

  factory TrailerInfoResponse.fromJson(Map<String, dynamic> json) =>
      _$TrailerInfoResponseFromJson(json);

  static const toJsonFactory = _$TrailerInfoResponseToJson;
  Map<String, dynamic> toJson() => _$TrailerInfoResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  static const fromJsonFactory = _$TrailerInfoResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TrailerInfoResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $TrailerInfoResponseExtension on TrailerInfoResponse {
  TrailerInfoResponse copyWith({String? id}) {
    return TrailerInfoResponse(id: id ?? this.id);
  }

  TrailerInfoResponse copyWithWrapped({Wrapped<String>? id}) {
    return TrailerInfoResponse(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class LanguagesResponse {
  LanguagesResponse({
    required this.audio,
    required this.audioDescription,
    required this.subtitle,
    required this.sign,
  });

  factory LanguagesResponse.fromJson(Map<String, dynamic> json) =>
      _$LanguagesResponseFromJson(json);

  static const toJsonFactory = _$LanguagesResponseToJson;
  Map<String, dynamic> toJson() => _$LanguagesResponseToJson(this);

  @JsonKey(name: 'audio', includeIfNull: false, defaultValue: <String>[])
  final List<String> audio;
  @JsonKey(
      name: 'audioDescription', includeIfNull: false, defaultValue: <String>[])
  final List<String> audioDescription;
  @JsonKey(name: 'subtitle', includeIfNull: false, defaultValue: <String>[])
  final List<String> subtitle;
  @JsonKey(name: 'sign', includeIfNull: false, defaultValue: <String>[])
  final List<String> sign;
  static const fromJsonFactory = _$LanguagesResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LanguagesResponse &&
            (identical(other.audio, audio) ||
                const DeepCollectionEquality().equals(other.audio, audio)) &&
            (identical(other.audioDescription, audioDescription) ||
                const DeepCollectionEquality()
                    .equals(other.audioDescription, audioDescription)) &&
            (identical(other.subtitle, subtitle) ||
                const DeepCollectionEquality()
                    .equals(other.subtitle, subtitle)) &&
            (identical(other.sign, sign) ||
                const DeepCollectionEquality().equals(other.sign, sign)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(audio) ^
      const DeepCollectionEquality().hash(audioDescription) ^
      const DeepCollectionEquality().hash(subtitle) ^
      const DeepCollectionEquality().hash(sign) ^
      runtimeType.hashCode;
}

extension $LanguagesResponseExtension on LanguagesResponse {
  LanguagesResponse copyWith(
      {List<String>? audio,
      List<String>? audioDescription,
      List<String>? subtitle,
      List<String>? sign}) {
    return LanguagesResponse(
        audio: audio ?? this.audio,
        audioDescription: audioDescription ?? this.audioDescription,
        subtitle: subtitle ?? this.subtitle,
        sign: sign ?? this.sign);
  }

  LanguagesResponse copyWithWrapped(
      {Wrapped<List<String>>? audio,
      Wrapped<List<String>>? audioDescription,
      Wrapped<List<String>>? subtitle,
      Wrapped<List<String>>? sign}) {
    return LanguagesResponse(
        audio: (audio != null ? audio.value : this.audio),
        audioDescription: (audioDescription != null
            ? audioDescription.value
            : this.audioDescription),
        subtitle: (subtitle != null ? subtitle.value : this.subtitle),
        sign: (sign != null ? sign.value : this.sign));
  }
}

@JsonSerializable(explicitToJson: true)
class PersonResponse {
  PersonResponse({
    this.personId,
    this.name,
  });

  factory PersonResponse.fromJson(Map<String, dynamic> json) =>
      _$PersonResponseFromJson(json);

  static const toJsonFactory = _$PersonResponseToJson;
  Map<String, dynamic> toJson() => _$PersonResponseToJson(this);

  @JsonKey(name: 'personId', includeIfNull: false, defaultValue: '')
  final String? personId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$PersonResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PersonResponse &&
            (identical(other.personId, personId) ||
                const DeepCollectionEquality()
                    .equals(other.personId, personId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(personId) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $PersonResponseExtension on PersonResponse {
  PersonResponse copyWith({String? personId, String? name}) {
    return PersonResponse(
        personId: personId ?? this.personId, name: name ?? this.name);
  }

  PersonResponse copyWithWrapped(
      {Wrapped<String?>? personId, Wrapped<String?>? name}) {
    return PersonResponse(
        personId: (personId != null ? personId.value : this.personId),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeV2ResponseLinear {
  MostRelevantEpisodeV2ResponseLinear({
    required this.episode,
    required this.show,
    this.season,
    required this.content,
  });

  factory MostRelevantEpisodeV2ResponseLinear.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeV2ResponseLinearFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeV2ResponseLinearToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeV2ResponseLinearToJson(this);

  @JsonKey(name: 'episode', includeIfNull: false)
  final MREEpisodeResponse episode;
  @JsonKey(name: 'show', includeIfNull: false)
  final MREShowResponse show;
  @JsonKey(name: 'season', includeIfNull: false)
  final MRESeasonResponse? season;
  @JsonKey(name: 'content', includeIfNull: false)
  final LinearContent content;
  static const fromJsonFactory = _$MostRelevantEpisodeV2ResponseLinearFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeV2ResponseLinear &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.show, show) ||
                const DeepCollectionEquality().equals(other.show, show)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(show) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeV2ResponseLinearExtension
    on MostRelevantEpisodeV2ResponseLinear {
  MostRelevantEpisodeV2ResponseLinear copyWith(
      {MREEpisodeResponse? episode,
      MREShowResponse? show,
      MRESeasonResponse? season,
      LinearContent? content}) {
    return MostRelevantEpisodeV2ResponseLinear(
        episode: episode ?? this.episode,
        show: show ?? this.show,
        season: season ?? this.season,
        content: content ?? this.content);
  }

  MostRelevantEpisodeV2ResponseLinear copyWithWrapped(
      {Wrapped<MREEpisodeResponse>? episode,
      Wrapped<MREShowResponse>? show,
      Wrapped<MRESeasonResponse?>? season,
      Wrapped<LinearContent>? content}) {
    return MostRelevantEpisodeV2ResponseLinear(
        episode: (episode != null ? episode.value : this.episode),
        show: (show != null ? show.value : this.show),
        season: (season != null ? season.value : this.season),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeV2ResponseVod {
  MostRelevantEpisodeV2ResponseVod({
    required this.episode,
    required this.show,
    this.season,
    required this.content,
  });

  factory MostRelevantEpisodeV2ResponseVod.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeV2ResponseVodFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeV2ResponseVodToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeV2ResponseVodToJson(this);

  @JsonKey(name: 'episode', includeIfNull: false)
  final MREEpisodeResponse episode;
  @JsonKey(name: 'show', includeIfNull: false)
  final MREShowResponse show;
  @JsonKey(name: 'season', includeIfNull: false)
  final MRESeasonResponse? season;
  @JsonKey(name: 'content', includeIfNull: false)
  final VodContent content;
  static const fromJsonFactory = _$MostRelevantEpisodeV2ResponseVodFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeV2ResponseVod &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.show, show) ||
                const DeepCollectionEquality().equals(other.show, show)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(show) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeV2ResponseVodExtension
    on MostRelevantEpisodeV2ResponseVod {
  MostRelevantEpisodeV2ResponseVod copyWith(
      {MREEpisodeResponse? episode,
      MREShowResponse? show,
      MRESeasonResponse? season,
      VodContent? content}) {
    return MostRelevantEpisodeV2ResponseVod(
        episode: episode ?? this.episode,
        show: show ?? this.show,
        season: season ?? this.season,
        content: content ?? this.content);
  }

  MostRelevantEpisodeV2ResponseVod copyWithWrapped(
      {Wrapped<MREEpisodeResponse>? episode,
      Wrapped<MREShowResponse>? show,
      Wrapped<MRESeasonResponse?>? season,
      Wrapped<VodContent>? content}) {
    return MostRelevantEpisodeV2ResponseVod(
        episode: (episode != null ? episode.value : this.episode),
        show: (show != null ? show.value : this.show),
        season: (season != null ? season.value : this.season),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeV2ResponseOtt {
  MostRelevantEpisodeV2ResponseOtt({
    required this.episode,
    required this.show,
    this.season,
    required this.content,
  });

  factory MostRelevantEpisodeV2ResponseOtt.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeV2ResponseOttFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeV2ResponseOttToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeV2ResponseOttToJson(this);

  @JsonKey(name: 'episode', includeIfNull: false)
  final MREEpisodeResponse episode;
  @JsonKey(name: 'show', includeIfNull: false)
  final MREShowResponse show;
  @JsonKey(name: 'season', includeIfNull: false)
  final MRESeasonResponse? season;
  @JsonKey(name: 'content', includeIfNull: false)
  final OTTContent content;
  static const fromJsonFactory = _$MostRelevantEpisodeV2ResponseOttFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeV2ResponseOtt &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.show, show) ||
                const DeepCollectionEquality().equals(other.show, show)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(show) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeV2ResponseOttExtension
    on MostRelevantEpisodeV2ResponseOtt {
  MostRelevantEpisodeV2ResponseOtt copyWith(
      {MREEpisodeResponse? episode,
      MREShowResponse? show,
      MRESeasonResponse? season,
      OTTContent? content}) {
    return MostRelevantEpisodeV2ResponseOtt(
        episode: episode ?? this.episode,
        show: show ?? this.show,
        season: season ?? this.season,
        content: content ?? this.content);
  }

  MostRelevantEpisodeV2ResponseOtt copyWithWrapped(
      {Wrapped<MREEpisodeResponse>? episode,
      Wrapped<MREShowResponse>? show,
      Wrapped<MRESeasonResponse?>? season,
      Wrapped<OTTContent>? content}) {
    return MostRelevantEpisodeV2ResponseOtt(
        episode: (episode != null ? episode.value : this.episode),
        show: (show != null ? show.value : this.show),
        season: (season != null ? season.value : this.season),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeV2ResponseRecording {
  MostRelevantEpisodeV2ResponseRecording({
    required this.episode,
    required this.show,
    this.season,
    required this.content,
  });

  factory MostRelevantEpisodeV2ResponseRecording.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeV2ResponseRecordingFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeV2ResponseRecordingToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeV2ResponseRecordingToJson(this);

  @JsonKey(name: 'episode', includeIfNull: false)
  final MREEpisodeResponse episode;
  @JsonKey(name: 'show', includeIfNull: false)
  final MREShowResponse show;
  @JsonKey(name: 'season', includeIfNull: false)
  final MRESeasonResponse? season;
  @JsonKey(name: 'content', includeIfNull: false)
  final RecordingContent content;
  static const fromJsonFactory =
      _$MostRelevantEpisodeV2ResponseRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeV2ResponseRecording &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.show, show) ||
                const DeepCollectionEquality().equals(other.show, show)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(show) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeV2ResponseRecordingExtension
    on MostRelevantEpisodeV2ResponseRecording {
  MostRelevantEpisodeV2ResponseRecording copyWith(
      {MREEpisodeResponse? episode,
      MREShowResponse? show,
      MRESeasonResponse? season,
      RecordingContent? content}) {
    return MostRelevantEpisodeV2ResponseRecording(
        episode: episode ?? this.episode,
        show: show ?? this.show,
        season: season ?? this.season,
        content: content ?? this.content);
  }

  MostRelevantEpisodeV2ResponseRecording copyWithWrapped(
      {Wrapped<MREEpisodeResponse>? episode,
      Wrapped<MREShowResponse>? show,
      Wrapped<MRESeasonResponse?>? season,
      Wrapped<RecordingContent>? content}) {
    return MostRelevantEpisodeV2ResponseRecording(
        episode: (episode != null ? episode.value : this.episode),
        show: (show != null ? show.value : this.show),
        season: (season != null ? season.value : this.season),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeBulkResponse {
  MostRelevantEpisodeBulkResponse({
    required this.seriesId,
    this.episode,
    this.show,
    this.season,
    this.content,
  });

  factory MostRelevantEpisodeBulkResponse.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantEpisodeBulkResponseFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeBulkResponseToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeBulkResponseToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String seriesId;
  @JsonKey(name: 'episode', includeIfNull: false)
  final MREEpisodeResponse? episode;
  @JsonKey(name: 'show', includeIfNull: false)
  final MREShowResponse? show;
  @JsonKey(name: 'season', includeIfNull: false)
  final MRESeasonResponse? season;
  @JsonKey(name: 'content', includeIfNull: false)
  final dynamic content;
  static const fromJsonFactory = _$MostRelevantEpisodeBulkResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeBulkResponse &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.show, show) ||
                const DeepCollectionEquality().equals(other.show, show)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(show) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeBulkResponseExtension
    on MostRelevantEpisodeBulkResponse {
  MostRelevantEpisodeBulkResponse copyWith(
      {String? seriesId,
      MREEpisodeResponse? episode,
      MREShowResponse? show,
      MRESeasonResponse? season,
      dynamic content}) {
    return MostRelevantEpisodeBulkResponse(
        seriesId: seriesId ?? this.seriesId,
        episode: episode ?? this.episode,
        show: show ?? this.show,
        season: season ?? this.season,
        content: content ?? this.content);
  }

  MostRelevantEpisodeBulkResponse copyWithWrapped(
      {Wrapped<String>? seriesId,
      Wrapped<MREEpisodeResponse?>? episode,
      Wrapped<MREShowResponse?>? show,
      Wrapped<MRESeasonResponse?>? season,
      Wrapped<dynamic>? content}) {
    return MostRelevantEpisodeBulkResponse(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        episode: (episode != null ? episode.value : this.episode),
        show: (show != null ? show.value : this.show),
        season: (season != null ? season.value : this.season),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class LinearContent {
  LinearContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory LinearContent.fromJson(Map<String, dynamic> json) =>
      _$LinearContentFromJson(json);

  static const toJsonFactory = _$LinearContentToJson;
  Map<String, dynamic> toJson() => _$LinearContentToJson(this);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: linearContentSourceTypeToJson,
    fromJson: linearContentSourceTypeFromJson,
  )
  final enums.LinearContentSourceType sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final LinearSourceResponse source;
  static const fromJsonFactory = _$LinearContentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LinearContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $LinearContentExtension on LinearContent {
  LinearContent copyWith(
      {int? rengContentSource,
      enums.LinearContentSourceType? sourceType,
      LinearSourceResponse? source}) {
    return LinearContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  LinearContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<enums.LinearContentSourceType>? sourceType,
      Wrapped<LinearSourceResponse>? source}) {
    return LinearContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class VodContent {
  VodContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory VodContent.fromJson(Map<String, dynamic> json) =>
      _$VodContentFromJson(json);

  static const toJsonFactory = _$VodContentToJson;
  Map<String, dynamic> toJson() => _$VodContentToJson(this);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(name: 'sourceType', includeIfNull: false, defaultValue: '')
  final String sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final VodSourceResponse source;
  static const fromJsonFactory = _$VodContentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $VodContentExtension on VodContent {
  VodContent copyWith(
      {int? rengContentSource, String? sourceType, VodSourceResponse? source}) {
    return VodContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  VodContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<String>? sourceType,
      Wrapped<VodSourceResponse>? source}) {
    return VodContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class OTTContent {
  OTTContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory OTTContent.fromJson(Map<String, dynamic> json) =>
      _$OTTContentFromJson(json);

  static const toJsonFactory = _$OTTContentToJson;
  Map<String, dynamic> toJson() => _$OTTContentToJson(this);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(name: 'sourceType', includeIfNull: false, defaultValue: '')
  final String sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final OttSourceResponse source;
  static const fromJsonFactory = _$OTTContentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OTTContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $OTTContentExtension on OTTContent {
  OTTContent copyWith(
      {int? rengContentSource, String? sourceType, OttSourceResponse? source}) {
    return OTTContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  OTTContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<String>? sourceType,
      Wrapped<OttSourceResponse>? source}) {
    return OTTContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingContent {
  RecordingContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory RecordingContent.fromJson(Map<String, dynamic> json) =>
      _$RecordingContentFromJson(json);

  static const toJsonFactory = _$RecordingContentToJson;
  Map<String, dynamic> toJson() => _$RecordingContentToJson(this);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(name: 'sourceType', includeIfNull: false, defaultValue: '')
  final String sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final RecordingSourceResponse source;
  static const fromJsonFactory = _$RecordingContentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $RecordingContentExtension on RecordingContent {
  RecordingContent copyWith(
      {int? rengContentSource,
      String? sourceType,
      RecordingSourceResponse? source}) {
    return RecordingContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  RecordingContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<String>? sourceType,
      Wrapped<RecordingSourceResponse>? source}) {
    return RecordingContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class MRESeasonResponse {
  MRESeasonResponse({
    required this.id,
    this.name,
    this.$number,
    this.imageVersion,
  });

  factory MRESeasonResponse.fromJson(Map<String, dynamic> json) =>
      _$MRESeasonResponseFromJson(json);

  static const toJsonFactory = _$MRESeasonResponseToJson;
  Map<String, dynamic> toJson() => _$MRESeasonResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'number', includeIfNull: false)
  final int? $number;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$MRESeasonResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MRESeasonResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.$number, $number) ||
                const DeepCollectionEquality()
                    .equals(other.$number, $number)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash($number) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $MRESeasonResponseExtension on MRESeasonResponse {
  MRESeasonResponse copyWith(
      {String? id, String? name, int? $number, String? imageVersion}) {
    return MRESeasonResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        $number: $number ?? this.$number,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  MRESeasonResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? $number,
      Wrapped<String?>? imageVersion}) {
    return MRESeasonResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        $number: ($number != null ? $number.value : this.$number),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class MREShowResponse {
  MREShowResponse({
    required this.id,
    required this.name,
    required this.isBoxset,
    required this.includesVOD,
    required this.hasInteracted,
    this.imageVersion,
    this.showPageAvailable,
    this.mergedId,
  });

  factory MREShowResponse.fromJson(Map<String, dynamic> json) =>
      _$MREShowResponseFromJson(json);

  static const toJsonFactory = _$MREShowResponseToJson;
  Map<String, dynamic> toJson() => _$MREShowResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool isBoxset;
  @JsonKey(name: 'includesVOD', includeIfNull: false)
  final bool includesVOD;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool hasInteracted;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'showPageAvailable', includeIfNull: false)
  final bool? showPageAvailable;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$MREShowResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MREShowResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.includesVOD, includesVOD) ||
                const DeepCollectionEquality()
                    .equals(other.includesVOD, includesVOD)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.showPageAvailable, showPageAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.showPageAvailable, showPageAvailable)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(includesVOD) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(showPageAvailable) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $MREShowResponseExtension on MREShowResponse {
  MREShowResponse copyWith(
      {String? id,
      String? name,
      bool? isBoxset,
      bool? includesVOD,
      bool? hasInteracted,
      String? imageVersion,
      bool? showPageAvailable,
      String? mergedId}) {
    return MREShowResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        isBoxset: isBoxset ?? this.isBoxset,
        includesVOD: includesVOD ?? this.includesVOD,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        imageVersion: imageVersion ?? this.imageVersion,
        showPageAvailable: showPageAvailable ?? this.showPageAvailable,
        mergedId: mergedId ?? this.mergedId);
  }

  MREShowResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<bool>? isBoxset,
      Wrapped<bool>? includesVOD,
      Wrapped<bool>? hasInteracted,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? showPageAvailable,
      Wrapped<String?>? mergedId}) {
    return MREShowResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        includesVOD:
            (includesVOD != null ? includesVOD.value : this.includesVOD),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        showPageAvailable: (showPageAvailable != null
            ? showPageAvailable.value
            : this.showPageAvailable),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class MREEpisodeResponse {
  MREEpisodeResponse({
    required this.id,
    this.name,
    this.$number,
    this.episodePart,
    this.ageRating,
    this.viewProgress,
    this.parentalGuidanceText,
    this.description,
    this.longDescription,
    required this.genres,
    this.productionYear,
    this.resolution,
    required this.languages,
    this.cast,
    this.crew,
    this.mergedId,
  });

  factory MREEpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$MREEpisodeResponseFromJson(json);

  static const toJsonFactory = _$MREEpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$MREEpisodeResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'number', includeIfNull: false)
  final int? $number;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(name: 'parentalGuidanceText', includeIfNull: false, defaultValue: '')
  final String? parentalGuidanceText;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String> genres;
  @JsonKey(name: 'productionYear', includeIfNull: false)
  final int? productionYear;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: <String>[])
  final List<String>? resolution;
  @JsonKey(name: 'languages', includeIfNull: false)
  final LanguagesResponse languages;
  @JsonKey(name: 'cast', includeIfNull: false, defaultValue: <PersonResponse>[])
  final List<PersonResponse>? cast;
  @JsonKey(name: 'crew', includeIfNull: false, defaultValue: <PersonResponse>[])
  final List<PersonResponse>? crew;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$MREEpisodeResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MREEpisodeResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.$number, $number) ||
                const DeepCollectionEquality()
                    .equals(other.$number, $number)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.parentalGuidanceText, parentalGuidanceText) ||
                const DeepCollectionEquality().equals(
                    other.parentalGuidanceText, parentalGuidanceText)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.longDescription, longDescription) ||
                const DeepCollectionEquality()
                    .equals(other.longDescription, longDescription)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.productionYear, productionYear) ||
                const DeepCollectionEquality()
                    .equals(other.productionYear, productionYear)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.languages, languages) ||
                const DeepCollectionEquality()
                    .equals(other.languages, languages)) &&
            (identical(other.cast, cast) ||
                const DeepCollectionEquality().equals(other.cast, cast)) &&
            (identical(other.crew, crew) ||
                const DeepCollectionEquality().equals(other.crew, crew)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash($number) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(parentalGuidanceText) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(productionYear) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(languages) ^
      const DeepCollectionEquality().hash(cast) ^
      const DeepCollectionEquality().hash(crew) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $MREEpisodeResponseExtension on MREEpisodeResponse {
  MREEpisodeResponse copyWith(
      {String? id,
      String? name,
      int? $number,
      int? episodePart,
      int? ageRating,
      ViewProgressResponse? viewProgress,
      String? parentalGuidanceText,
      String? description,
      String? longDescription,
      List<String>? genres,
      int? productionYear,
      List<String>? resolution,
      LanguagesResponse? languages,
      List<PersonResponse>? cast,
      List<PersonResponse>? crew,
      String? mergedId}) {
    return MREEpisodeResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        $number: $number ?? this.$number,
        episodePart: episodePart ?? this.episodePart,
        ageRating: ageRating ?? this.ageRating,
        viewProgress: viewProgress ?? this.viewProgress,
        parentalGuidanceText: parentalGuidanceText ?? this.parentalGuidanceText,
        description: description ?? this.description,
        longDescription: longDescription ?? this.longDescription,
        genres: genres ?? this.genres,
        productionYear: productionYear ?? this.productionYear,
        resolution: resolution ?? this.resolution,
        languages: languages ?? this.languages,
        cast: cast ?? this.cast,
        crew: crew ?? this.crew,
        mergedId: mergedId ?? this.mergedId);
  }

  MREEpisodeResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? $number,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? ageRating,
      Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<String?>? parentalGuidanceText,
      Wrapped<String?>? description,
      Wrapped<String?>? longDescription,
      Wrapped<List<String>>? genres,
      Wrapped<int?>? productionYear,
      Wrapped<List<String>?>? resolution,
      Wrapped<LanguagesResponse>? languages,
      Wrapped<List<PersonResponse>?>? cast,
      Wrapped<List<PersonResponse>?>? crew,
      Wrapped<String?>? mergedId}) {
    return MREEpisodeResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        $number: ($number != null ? $number.value : this.$number),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        parentalGuidanceText: (parentalGuidanceText != null
            ? parentalGuidanceText.value
            : this.parentalGuidanceText),
        description:
            (description != null ? description.value : this.description),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        genres: (genres != null ? genres.value : this.genres),
        productionYear: (productionYear != null
            ? productionYear.value
            : this.productionYear),
        resolution: (resolution != null ? resolution.value : this.resolution),
        languages: (languages != null ? languages.value : this.languages),
        cast: (cast != null ? cast.value : this.cast),
        crew: (crew != null ? crew.value : this.crew),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class ExternalAppUrlResponse {
  ExternalAppUrlResponse({
    required this.deviceCode,
    required this.url,
    required this.name,
    required this.storeUrl,
  });

  factory ExternalAppUrlResponse.fromJson(Map<String, dynamic> json) =>
      _$ExternalAppUrlResponseFromJson(json);

  static const toJsonFactory = _$ExternalAppUrlResponseToJson;
  Map<String, dynamic> toJson() => _$ExternalAppUrlResponseToJson(this);

  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String deviceCode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'storeUrl', includeIfNull: false, defaultValue: '')
  final String storeUrl;
  static const fromJsonFactory = _$ExternalAppUrlResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ExternalAppUrlResponse &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.storeUrl, storeUrl) ||
                const DeepCollectionEquality()
                    .equals(other.storeUrl, storeUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(storeUrl) ^
      runtimeType.hashCode;
}

extension $ExternalAppUrlResponseExtension on ExternalAppUrlResponse {
  ExternalAppUrlResponse copyWith(
      {String? deviceCode, String? url, String? name, String? storeUrl}) {
    return ExternalAppUrlResponse(
        deviceCode: deviceCode ?? this.deviceCode,
        url: url ?? this.url,
        name: name ?? this.name,
        storeUrl: storeUrl ?? this.storeUrl);
  }

  ExternalAppUrlResponse copyWithWrapped(
      {Wrapped<String>? deviceCode,
      Wrapped<String>? url,
      Wrapped<String>? name,
      Wrapped<String>? storeUrl}) {
    return ExternalAppUrlResponse(
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        url: (url != null ? url.value : this.url),
        name: (name != null ? name.value : this.name),
        storeUrl: (storeUrl != null ? storeUrl.value : this.storeUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingSourcesSourceObjectResponse {
  RecordingSourcesSourceObjectResponse({
    this.channelId,
    this.channelName,
    this.containsLatestEpisode,
    this.seedEvent,
  });

  factory RecordingSourcesSourceObjectResponse.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingSourcesSourceObjectResponseFromJson(json);

  static const toJsonFactory = _$RecordingSourcesSourceObjectResponseToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingSourcesSourceObjectResponseToJson(this);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'containsLatestEpisode', includeIfNull: false)
  final bool? containsLatestEpisode;
  @JsonKey(name: 'seedEvent', includeIfNull: false)
  final SeedEventResponse? seedEvent;
  static const fromJsonFactory = _$RecordingSourcesSourceObjectResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingSourcesSourceObjectResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.containsLatestEpisode, containsLatestEpisode) ||
                const DeepCollectionEquality().equals(
                    other.containsLatestEpisode, containsLatestEpisode)) &&
            (identical(other.seedEvent, seedEvent) ||
                const DeepCollectionEquality()
                    .equals(other.seedEvent, seedEvent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(containsLatestEpisode) ^
      const DeepCollectionEquality().hash(seedEvent) ^
      runtimeType.hashCode;
}

extension $RecordingSourcesSourceObjectResponseExtension
    on RecordingSourcesSourceObjectResponse {
  RecordingSourcesSourceObjectResponse copyWith(
      {String? channelId,
      String? channelName,
      bool? containsLatestEpisode,
      SeedEventResponse? seedEvent}) {
    return RecordingSourcesSourceObjectResponse(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName,
        containsLatestEpisode:
            containsLatestEpisode ?? this.containsLatestEpisode,
        seedEvent: seedEvent ?? this.seedEvent);
  }

  RecordingSourcesSourceObjectResponse copyWithWrapped(
      {Wrapped<String?>? channelId,
      Wrapped<String?>? channelName,
      Wrapped<bool?>? containsLatestEpisode,
      Wrapped<SeedEventResponse?>? seedEvent}) {
    return RecordingSourcesSourceObjectResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        containsLatestEpisode: (containsLatestEpisode != null
            ? containsLatestEpisode.value
            : this.containsLatestEpisode),
        seedEvent: (seedEvent != null ? seedEvent.value : this.seedEvent));
  }
}

@JsonSerializable(explicitToJson: true)
class SeedEventResponse {
  SeedEventResponse({
    required this.id,
    required this.eventId,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    required this.broadcastDate,
  });

  factory SeedEventResponse.fromJson(Map<String, dynamic> json) =>
      _$SeedEventResponseFromJson(json);

  static const toJsonFactory = _$SeedEventResponseToJson;
  Map<String, dynamic> toJson() => _$SeedEventResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  static const fromJsonFactory = _$SeedEventResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeedEventResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      runtimeType.hashCode;
}

extension $SeedEventResponseExtension on SeedEventResponse {
  SeedEventResponse copyWith(
      {String? id,
      String? eventId,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      String? broadcastDate}) {
    return SeedEventResponse(
        id: id ?? this.id,
        eventId: eventId ?? this.eventId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        broadcastDate: broadcastDate ?? this.broadcastDate);
  }

  SeedEventResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? eventId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<String>? broadcastDate}) {
    return SeedEventResponse(
        id: (id != null ? id.value : this.id),
        eventId: (eventId != null ? eventId.value : this.eventId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate));
  }
}

@JsonSerializable(explicitToJson: true)
class SpaResponse$Response {
  SpaResponse$Response({
    this.id,
    required this.showPageAvailable,
  });

  factory SpaResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$SpaResponse$ResponseFromJson(json);

  static const toJsonFactory = _$SpaResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$SpaResponse$ResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'showPageAvailable', includeIfNull: false)
  final bool showPageAvailable;
  static const fromJsonFactory = _$SpaResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpaResponse$Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.showPageAvailable, showPageAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.showPageAvailable, showPageAvailable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(showPageAvailable) ^
      runtimeType.hashCode;
}

extension $SpaResponse$ResponseExtension on SpaResponse$Response {
  SpaResponse$Response copyWith({String? id, bool? showPageAvailable}) {
    return SpaResponse$Response(
        id: id ?? this.id,
        showPageAvailable: showPageAvailable ?? this.showPageAvailable);
  }

  SpaResponse$Response copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<bool>? showPageAvailable}) {
    return SpaResponse$Response(
        id: (id != null ? id.value : this.id),
        showPageAvailable: (showPageAvailable != null
            ? showPageAvailable.value
            : this.showPageAvailable));
  }
}

@JsonSerializable(explicitToJson: true)
class SaaoResponse$Response {
  SaaoResponse$Response({
    this.selectedSources,
    required this.sources,
  });

  factory SaaoResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$SaaoResponse$ResponseFromJson(json);

  static const toJsonFactory = _$SaaoResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$SaaoResponse$ResponseToJson(this);

  @JsonKey(name: 'selectedSources', includeIfNull: false)
  final SaaoSourceResponse? selectedSources;
  @JsonKey(
      name: 'sources',
      includeIfNull: false,
      defaultValue: <SaaoSourceResponse>[])
  final List<SaaoSourceResponse> sources;
  static const fromJsonFactory = _$SaaoResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SaaoResponse$Response &&
            (identical(other.selectedSources, selectedSources) ||
                const DeepCollectionEquality()
                    .equals(other.selectedSources, selectedSources)) &&
            (identical(other.sources, sources) ||
                const DeepCollectionEquality().equals(other.sources, sources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(selectedSources) ^
      const DeepCollectionEquality().hash(sources) ^
      runtimeType.hashCode;
}

extension $SaaoResponse$ResponseExtension on SaaoResponse$Response {
  SaaoResponse$Response copyWith(
      {SaaoSourceResponse? selectedSources,
      List<SaaoSourceResponse>? sources}) {
    return SaaoResponse$Response(
        selectedSources: selectedSources ?? this.selectedSources,
        sources: sources ?? this.sources);
  }

  SaaoResponse$Response copyWithWrapped(
      {Wrapped<SaaoSourceResponse?>? selectedSources,
      Wrapped<List<SaaoSourceResponse>>? sources}) {
    return SaaoResponse$Response(
        selectedSources: (selectedSources != null
            ? selectedSources.value
            : this.selectedSources),
        sources: (sources != null ? sources.value : this.sources));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerResponse$Response {
  EpisodePickerResponse$Response({
    required this.id,
    required this.title,
    this.startYear,
    this.endYear,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.seasons,
    this.episodes,
    this.specials,
    this.selectedEpisode,
    this.imageVersion,
    this.mergedId,
  });

  factory EpisodePickerResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerResponse$ResponseFromJson(json);

  static const toJsonFactory = _$EpisodePickerResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerResponse$ResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startYear', includeIfNull: false)
  final int? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false)
  final int? endYear;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(
      name: 'seasons',
      includeIfNull: false,
      defaultValue: <EpisodePickerSeasonResponse>[])
  final List<EpisodePickerSeasonResponse>? seasons;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? episodes;
  @JsonKey(
      name: 'specials',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? specials;
  @JsonKey(name: 'selectedEpisode', includeIfNull: false, defaultValue: '')
  final String? selectedEpisode;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$EpisodePickerResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerResponse$Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.specials, specials) ||
                const DeepCollectionEquality()
                    .equals(other.specials, specials)) &&
            (identical(other.selectedEpisode, selectedEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEpisode, selectedEpisode)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(specials) ^
      const DeepCollectionEquality().hash(selectedEpisode) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $EpisodePickerResponse$ResponseExtension
    on EpisodePickerResponse$Response {
  EpisodePickerResponse$Response copyWith(
      {String? id,
      String? title,
      int? startYear,
      int? endYear,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      List<EpisodePickerSeasonResponse>? seasons,
      List<EpisodePickerEpisodeResponse>? episodes,
      List<EpisodePickerEpisodeResponse>? specials,
      String? selectedEpisode,
      String? imageVersion,
      String? mergedId}) {
    return EpisodePickerResponse$Response(
        id: id ?? this.id,
        title: title ?? this.title,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        specials: specials ?? this.specials,
        selectedEpisode: selectedEpisode ?? this.selectedEpisode,
        imageVersion: imageVersion ?? this.imageVersion,
        mergedId: mergedId ?? this.mergedId);
  }

  EpisodePickerResponse$Response copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<int?>? startYear,
      Wrapped<int?>? endYear,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<List<EpisodePickerSeasonResponse>?>? seasons,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? episodes,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? specials,
      Wrapped<String?>? selectedEpisode,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mergedId}) {
    return EpisodePickerResponse$Response(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        specials: (specials != null ? specials.value : this.specials),
        selectedEpisode: (selectedEpisode != null
            ? selectedEpisode.value
            : this.selectedEpisode),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerV2Response$Response {
  EpisodePickerV2Response$Response({
    required this.id,
    required this.title,
    this.startYear,
    this.endYear,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.groupedBy,
    this.mepSeriesFinale,
    this.premiereAirings,
    this.seasons,
    this.episodes,
    this.specials,
    this.others,
    this.yearOfProduction,
    this.selectedEpisode,
    this.imageVersion,
    this.mergedId,
  });

  factory EpisodePickerV2Response$Response.fromJson(
          Map<String, dynamic> json) =>
      _$EpisodePickerV2Response$ResponseFromJson(json);

  static const toJsonFactory = _$EpisodePickerV2Response$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$EpisodePickerV2Response$ResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startYear', includeIfNull: false)
  final int? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false)
  final int? endYear;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'groupedBy', includeIfNull: false, defaultValue: '')
  final String? groupedBy;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  @JsonKey(
      name: 'seasons',
      includeIfNull: false,
      defaultValue: <EpisodePickerSeasonResponse>[])
  final List<EpisodePickerSeasonResponse>? seasons;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? episodes;
  @JsonKey(
      name: 'specials',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? specials;
  @JsonKey(
      name: 'others',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? others;
  @JsonKey(
      name: 'yearOfProduction',
      includeIfNull: false,
      defaultValue: <EpisodePickerYearOfProductionResponse>[])
  final List<EpisodePickerYearOfProductionResponse>? yearOfProduction;
  @JsonKey(name: 'selectedEpisode', includeIfNull: false, defaultValue: '')
  final String? selectedEpisode;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$EpisodePickerV2Response$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerV2Response$Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.groupedBy, groupedBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupedBy, groupedBy)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.specials, specials) ||
                const DeepCollectionEquality()
                    .equals(other.specials, specials)) &&
            (identical(other.others, others) ||
                const DeepCollectionEquality().equals(other.others, others)) &&
            (identical(other.yearOfProduction, yearOfProduction) ||
                const DeepCollectionEquality()
                    .equals(other.yearOfProduction, yearOfProduction)) &&
            (identical(other.selectedEpisode, selectedEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEpisode, selectedEpisode)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(groupedBy) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(specials) ^
      const DeepCollectionEquality().hash(others) ^
      const DeepCollectionEquality().hash(yearOfProduction) ^
      const DeepCollectionEquality().hash(selectedEpisode) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $EpisodePickerV2Response$ResponseExtension
    on EpisodePickerV2Response$Response {
  EpisodePickerV2Response$Response copyWith(
      {String? id,
      String? title,
      int? startYear,
      int? endYear,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      String? groupedBy,
      String? mepSeriesFinale,
      bool? premiereAirings,
      List<EpisodePickerSeasonResponse>? seasons,
      List<EpisodePickerEpisodeResponse>? episodes,
      List<EpisodePickerEpisodeResponse>? specials,
      List<EpisodePickerEpisodeResponse>? others,
      List<EpisodePickerYearOfProductionResponse>? yearOfProduction,
      String? selectedEpisode,
      String? imageVersion,
      String? mergedId}) {
    return EpisodePickerV2Response$Response(
        id: id ?? this.id,
        title: title ?? this.title,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        groupedBy: groupedBy ?? this.groupedBy,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings,
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        specials: specials ?? this.specials,
        others: others ?? this.others,
        yearOfProduction: yearOfProduction ?? this.yearOfProduction,
        selectedEpisode: selectedEpisode ?? this.selectedEpisode,
        imageVersion: imageVersion ?? this.imageVersion,
        mergedId: mergedId ?? this.mergedId);
  }

  EpisodePickerV2Response$Response copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<int?>? startYear,
      Wrapped<int?>? endYear,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? groupedBy,
      Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings,
      Wrapped<List<EpisodePickerSeasonResponse>?>? seasons,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? episodes,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? specials,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? others,
      Wrapped<List<EpisodePickerYearOfProductionResponse>?>? yearOfProduction,
      Wrapped<String?>? selectedEpisode,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mergedId}) {
    return EpisodePickerV2Response$Response(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        groupedBy: (groupedBy != null ? groupedBy.value : this.groupedBy),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings),
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        specials: (specials != null ? specials.value : this.specials),
        others: (others != null ? others.value : this.others),
        yearOfProduction: (yearOfProduction != null
            ? yearOfProduction.value
            : this.yearOfProduction),
        selectedEpisode: (selectedEpisode != null
            ? selectedEpisode.value
            : this.selectedEpisode),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowPageResponse$Response {
  ShowPageResponse$Response({
    required this.id,
    required this.title,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.startYear,
    this.endYear,
    required this.previews,
    this.seasonCount,
    this.imageVersion,
    this.productionCountries,
    this.mergedId,
  });

  factory ShowPageResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$ShowPageResponse$ResponseFromJson(json);

  static const toJsonFactory = _$ShowPageResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$ShowPageResponse$ResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'startYear', includeIfNull: false, defaultValue: '')
  final String? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false, defaultValue: '')
  final String? endYear;
  @JsonKey(
      name: 'previews',
      includeIfNull: false,
      defaultValue: <TrailerInfoResponse>[])
  final List<TrailerInfoResponse> previews;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(
      name: 'productionCountries',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? productionCountries;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$ShowPageResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowPageResponse$Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.previews, previews) ||
                const DeepCollectionEquality()
                    .equals(other.previews, previews)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.productionCountries, productionCountries) ||
                const DeepCollectionEquality()
                    .equals(other.productionCountries, productionCountries)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(previews) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(productionCountries) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $ShowPageResponse$ResponseExtension on ShowPageResponse$Response {
  ShowPageResponse$Response copyWith(
      {String? id,
      String? title,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      String? startYear,
      String? endYear,
      List<TrailerInfoResponse>? previews,
      int? seasonCount,
      String? imageVersion,
      List<String>? productionCountries,
      String? mergedId}) {
    return ShowPageResponse$Response(
        id: id ?? this.id,
        title: title ?? this.title,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        previews: previews ?? this.previews,
        seasonCount: seasonCount ?? this.seasonCount,
        imageVersion: imageVersion ?? this.imageVersion,
        productionCountries: productionCountries ?? this.productionCountries,
        mergedId: mergedId ?? this.mergedId);
  }

  ShowPageResponse$Response copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? startYear,
      Wrapped<String?>? endYear,
      Wrapped<List<TrailerInfoResponse>>? previews,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? imageVersion,
      Wrapped<List<String>?>? productionCountries,
      Wrapped<String?>? mergedId}) {
    return ShowPageResponse$Response(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        previews: (previews != null ? previews.value : this.previews),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        productionCountries: (productionCountries != null
            ? productionCountries.value
            : this.productionCountries),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchDetailsResponse$Response {
  SearchDetailsResponse$Response({
    this.results,
  });

  factory SearchDetailsResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$SearchDetailsResponse$ResponseFromJson(json);

  static const toJsonFactory = _$SearchDetailsResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$SearchDetailsResponse$ResponseToJson(this);

  @JsonKey(
      name: 'results',
      includeIfNull: false,
      defaultValue: <SearchDetailsResponse$Response$Results$Item>[])
  final List<SearchDetailsResponse$Response$Results$Item>? results;
  static const fromJsonFactory = _$SearchDetailsResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchDetailsResponse$Response &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $SearchDetailsResponse$ResponseExtension
    on SearchDetailsResponse$Response {
  SearchDetailsResponse$Response copyWith(
      {List<SearchDetailsResponse$Response$Results$Item>? results}) {
    return SearchDetailsResponse$Response(results: results ?? this.results);
  }

  SearchDetailsResponse$Response copyWithWrapped(
      {Wrapped<List<SearchDetailsResponse$Response$Results$Item>?>? results}) {
    return SearchDetailsResponse$Response(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class EventDetailResponse$Response {
  EventDetailResponse$Response({
    required this.titleCrid,
    required this.eventId,
    required this.contentType,
    required this.channelId,
    this.broadcastDate,
    this.broadcastEndDate,
    this.bookmark,
    this.channel,
    this.replayAvailable,
    this.imageVersion,
  });

  factory EventDetailResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$EventDetailResponse$ResponseFromJson(json);

  static const toJsonFactory = _$EventDetailResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$EventDetailResponse$ResponseToJson(this);

  @JsonKey(name: 'titleCrid', includeIfNull: false, defaultValue: '')
  final String titleCrid;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'channelId', includeIfNull: false)
  final int channelId;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'broadcastEndDate', includeIfNull: false, defaultValue: '')
  final String? broadcastEndDate;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(
      name: 'channel',
      includeIfNull: false,
      defaultValue: <ChannelEventDetailResponse>[])
  final List<ChannelEventDetailResponse>? channel;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EventDetailResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventDetailResponse$Response &&
            (identical(other.titleCrid, titleCrid) ||
                const DeepCollectionEquality()
                    .equals(other.titleCrid, titleCrid)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.broadcastEndDate, broadcastEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastEndDate, broadcastEndDate)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleCrid) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(broadcastEndDate) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EventDetailResponse$ResponseExtension
    on EventDetailResponse$Response {
  EventDetailResponse$Response copyWith(
      {String? titleCrid,
      String? eventId,
      String? contentType,
      int? channelId,
      String? broadcastDate,
      String? broadcastEndDate,
      int? bookmark,
      List<ChannelEventDetailResponse>? channel,
      bool? replayAvailable,
      String? imageVersion}) {
    return EventDetailResponse$Response(
        titleCrid: titleCrid ?? this.titleCrid,
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType,
        channelId: channelId ?? this.channelId,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        broadcastEndDate: broadcastEndDate ?? this.broadcastEndDate,
        bookmark: bookmark ?? this.bookmark,
        channel: channel ?? this.channel,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EventDetailResponse$Response copyWithWrapped(
      {Wrapped<String>? titleCrid,
      Wrapped<String>? eventId,
      Wrapped<String>? contentType,
      Wrapped<int>? channelId,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? broadcastEndDate,
      Wrapped<int?>? bookmark,
      Wrapped<List<ChannelEventDetailResponse>?>? channel,
      Wrapped<bool?>? replayAvailable,
      Wrapped<String?>? imageVersion}) {
    return EventDetailResponse$Response(
        titleCrid: (titleCrid != null ? titleCrid.value : this.titleCrid),
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        channelId: (channelId != null ? channelId.value : this.channelId),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        broadcastEndDate: (broadcastEndDate != null
            ? broadcastEndDate.value
            : this.broadcastEndDate),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        channel: (channel != null ? channel.value : this.channel),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesDetailResponse$Response {
  SeriesDetailResponse$Response({
    required this.id,
    required this.title,
    this.startYear,
    this.endYear,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.image,
    this.seasons,
    this.episodes,
    this.imageVersion,
  });

  factory SeriesDetailResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$SeriesDetailResponse$ResponseFromJson(json);

  static const toJsonFactory = _$SeriesDetailResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$SeriesDetailResponse$ResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startYear', includeIfNull: false, defaultValue: '')
  final String? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false, defaultValue: '')
  final String? endYear;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'seasons', includeIfNull: false)
  final SeasonResponse? seasons;
  @JsonKey(name: 'episodes', includeIfNull: false)
  final EpisodeResponse? episodes;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$SeriesDetailResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesDetailResponse$Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $SeriesDetailResponse$ResponseExtension
    on SeriesDetailResponse$Response {
  SeriesDetailResponse$Response copyWith(
      {String? id,
      String? title,
      String? startYear,
      String? endYear,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      String? image,
      SeasonResponse? seasons,
      EpisodeResponse? episodes,
      String? imageVersion}) {
    return SeriesDetailResponse$Response(
        id: id ?? this.id,
        title: title ?? this.title,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        image: image ?? this.image,
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  SeriesDetailResponse$Response copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<String?>? startYear,
      Wrapped<String?>? endYear,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? image,
      Wrapped<SeasonResponse?>? seasons,
      Wrapped<EpisodeResponse?>? episodes,
      Wrapped<String?>? imageVersion}) {
    return SeriesDetailResponse$Response(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        image: (image != null ? image.value : this.image),
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeResponse$Response {
  MostRelevantEpisodeResponse$Response({
    required this.titleId,
    required this.seriesId,
    this.seasonId,
    this.episodeNumber,
    this.seasonNumber,
    this.instanceId,
    this.contentType,
    this.contentSource,
    this.includesVOD,
    this.hasInteracted,
    this.recordingId,
    this.brandingProviderId,
    this.isGoPlayable,
    this.viewProgress,
    this.channelId,
    this.imageVersion,
  });

  factory MostRelevantEpisodeResponse$Response.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeResponse$ResponseFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeResponse$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeResponse$ResponseToJson(this);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String seriesId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'instanceId', includeIfNull: false, defaultValue: '')
  final String? instanceId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: mostRelevantEpisodeResponse$ResponseContentTypeToJson,
    fromJson: mostRelevantEpisodeResponse$ResponseContentTypeFromJson,
  )
  final enums.MostRelevantEpisodeResponse$ResponseContentType? contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int? contentSource;
  @JsonKey(name: 'includesVOD', includeIfNull: false)
  final bool? includesVOD;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool? hasInteracted;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String? recordingId;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$MostRelevantEpisodeResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeResponse$Response &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.instanceId, instanceId) ||
                const DeepCollectionEquality()
                    .equals(other.instanceId, instanceId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.includesVOD, includesVOD) ||
                const DeepCollectionEquality()
                    .equals(other.includesVOD, includesVOD)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(instanceId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(includesVOD) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeResponse$ResponseExtension
    on MostRelevantEpisodeResponse$Response {
  MostRelevantEpisodeResponse$Response copyWith(
      {String? titleId,
      String? seriesId,
      String? seasonId,
      int? episodeNumber,
      int? seasonNumber,
      String? instanceId,
      enums.MostRelevantEpisodeResponse$ResponseContentType? contentType,
      int? contentSource,
      bool? includesVOD,
      bool? hasInteracted,
      String? recordingId,
      String? brandingProviderId,
      bool? isGoPlayable,
      ViewProgressResponse? viewProgress,
      String? channelId,
      String? imageVersion}) {
    return MostRelevantEpisodeResponse$Response(
        titleId: titleId ?? this.titleId,
        seriesId: seriesId ?? this.seriesId,
        seasonId: seasonId ?? this.seasonId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        instanceId: instanceId ?? this.instanceId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        includesVOD: includesVOD ?? this.includesVOD,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        recordingId: recordingId ?? this.recordingId,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        viewProgress: viewProgress ?? this.viewProgress,
        channelId: channelId ?? this.channelId,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  MostRelevantEpisodeResponse$Response copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? seriesId,
      Wrapped<String?>? seasonId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? instanceId,
      Wrapped<enums.MostRelevantEpisodeResponse$ResponseContentType?>?
          contentType,
      Wrapped<int?>? contentSource,
      Wrapped<bool?>? includesVOD,
      Wrapped<bool?>? hasInteracted,
      Wrapped<String?>? recordingId,
      Wrapped<String?>? brandingProviderId,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<String?>? channelId,
      Wrapped<String?>? imageVersion}) {
    return MostRelevantEpisodeResponse$Response(
        titleId: (titleId != null ? titleId.value : this.titleId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        instanceId: (instanceId != null ? instanceId.value : this.instanceId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        includesVOD:
            (includesVOD != null ? includesVOD.value : this.includesVOD),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        channelId: (channelId != null ? channelId.value : this.channelId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeV2Response$Response {
  MostRelevantEpisodeV2Response$Response();

  factory MostRelevantEpisodeV2Response$Response.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeV2Response$ResponseFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeV2Response$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeV2Response$ResponseToJson(this);

  static const fromJsonFactory =
      _$MostRelevantEpisodeV2Response$ResponseFromJson;

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeBulkResponse$Response {
  MostRelevantEpisodeBulkResponse$Response({
    required this.response,
  });

  factory MostRelevantEpisodeBulkResponse$Response.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeBulkResponse$ResponseFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeBulkResponse$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeBulkResponse$ResponseToJson(this);

  @JsonKey(
      name: 'response',
      includeIfNull: false,
      defaultValue: <MostRelevantEpisodeBulkResponse>[])
  final List<MostRelevantEpisodeBulkResponse> response;
  static const fromJsonFactory =
      _$MostRelevantEpisodeBulkResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeBulkResponse$Response &&
            (identical(other.response, response) ||
                const DeepCollectionEquality()
                    .equals(other.response, response)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(response) ^ runtimeType.hashCode;
}

extension $MostRelevantEpisodeBulkResponse$ResponseExtension
    on MostRelevantEpisodeBulkResponse$Response {
  MostRelevantEpisodeBulkResponse$Response copyWith(
      {List<MostRelevantEpisodeBulkResponse>? response}) {
    return MostRelevantEpisodeBulkResponse$Response(
        response: response ?? this.response);
  }

  MostRelevantEpisodeBulkResponse$Response copyWithWrapped(
      {Wrapped<List<MostRelevantEpisodeBulkResponse>>? response}) {
    return MostRelevantEpisodeBulkResponse$Response(
        response: (response != null ? response.value : this.response));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantSourceResponse$Response {
  MostRelevantSourceResponse$Response({
    required this.titleId,
    this.seriesId,
    this.seasonId,
    this.episodeNumber,
    this.episodePart,
    this.seasonNumber,
    required this.instanceId,
    this.recordingId,
    required this.contentType,
    required this.contentSource,
    this.brandingProviderId,
    this.channelId,
    this.isGoPlayable,
    this.broadcastDate,
    this.imageVersion,
    this.goPlayableViaExternalApp,
    this.externalAppUrls,
    this.mergedId,
  });

  factory MostRelevantSourceResponse$Response.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantSourceResponse$ResponseFromJson(json);

  static const toJsonFactory = _$MostRelevantSourceResponse$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantSourceResponse$ResponseToJson(this);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'instanceId', includeIfNull: false, defaultValue: '')
  final String instanceId;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String? recordingId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: mostRelevantSourceResponse$ResponseContentTypeToJson,
    fromJson: mostRelevantSourceResponse$ResponseContentTypeFromJson,
  )
  final enums.MostRelevantSourceResponse$ResponseContentType contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool? goPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrlResponse>[])
  final List<ExternalAppUrlResponse>? externalAppUrls;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$MostRelevantSourceResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantSourceResponse$Response &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.instanceId, instanceId) ||
                const DeepCollectionEquality()
                    .equals(other.instanceId, instanceId)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) ||
                const DeepCollectionEquality()
                    .equals(other.externalAppUrls, externalAppUrls)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(instanceId) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $MostRelevantSourceResponse$ResponseExtension
    on MostRelevantSourceResponse$Response {
  MostRelevantSourceResponse$Response copyWith(
      {String? titleId,
      String? seriesId,
      String? seasonId,
      int? episodeNumber,
      int? episodePart,
      int? seasonNumber,
      String? instanceId,
      String? recordingId,
      enums.MostRelevantSourceResponse$ResponseContentType? contentType,
      int? contentSource,
      String? brandingProviderId,
      String? channelId,
      bool? isGoPlayable,
      String? broadcastDate,
      String? imageVersion,
      bool? goPlayableViaExternalApp,
      List<ExternalAppUrlResponse>? externalAppUrls,
      String? mergedId}) {
    return MostRelevantSourceResponse$Response(
        titleId: titleId ?? this.titleId,
        seriesId: seriesId ?? this.seriesId,
        seasonId: seasonId ?? this.seasonId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        instanceId: instanceId ?? this.instanceId,
        recordingId: recordingId ?? this.recordingId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        channelId: channelId ?? this.channelId,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        imageVersion: imageVersion ?? this.imageVersion,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls,
        mergedId: mergedId ?? this.mergedId);
  }

  MostRelevantSourceResponse$Response copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? seasonId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? seasonNumber,
      Wrapped<String>? instanceId,
      Wrapped<String?>? recordingId,
      Wrapped<enums.MostRelevantSourceResponse$ResponseContentType>?
          contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? channelId,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? goPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrlResponse>?>? externalAppUrls,
      Wrapped<String?>? mergedId}) {
    return MostRelevantSourceResponse$Response(
        titleId: (titleId != null ? titleId.value : this.titleId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        instanceId: (instanceId != null ? instanceId.value : this.instanceId),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class RreResponse$Response {
  RreResponse$Response({
    required this.id,
    required this.eventId,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    required this.broadcastDate,
  });

  factory RreResponse$Response.fromJson(Map<String, dynamic> json) =>
      _$RreResponse$ResponseFromJson(json);

  static const toJsonFactory = _$RreResponse$ResponseToJson;
  Map<String, dynamic> toJson() => _$RreResponse$ResponseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  static const fromJsonFactory = _$RreResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RreResponse$Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      runtimeType.hashCode;
}

extension $RreResponse$ResponseExtension on RreResponse$Response {
  RreResponse$Response copyWith(
      {String? id,
      String? eventId,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      String? broadcastDate}) {
    return RreResponse$Response(
        id: id ?? this.id,
        eventId: eventId ?? this.eventId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        broadcastDate: broadcastDate ?? this.broadcastDate);
  }

  RreResponse$Response copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? eventId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<String>? broadcastDate}) {
    return RreResponse$Response(
        id: (id != null ? id.value : this.id),
        eventId: (eventId != null ? eventId.value : this.eventId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingSourcesResponse$Response {
  RecordingSourcesResponse$Response({
    required this.sources,
  });

  factory RecordingSourcesResponse$Response.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingSourcesResponse$ResponseFromJson(json);

  static const toJsonFactory = _$RecordingSourcesResponse$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingSourcesResponse$ResponseToJson(this);

  @JsonKey(
      name: 'sources',
      includeIfNull: false,
      defaultValue: <RecordingSourcesSourceObjectResponse>[])
  final List<RecordingSourcesSourceObjectResponse> sources;
  static const fromJsonFactory = _$RecordingSourcesResponse$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingSourcesResponse$Response &&
            (identical(other.sources, sources) ||
                const DeepCollectionEquality().equals(other.sources, sources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sources) ^ runtimeType.hashCode;
}

extension $RecordingSourcesResponse$ResponseExtension
    on RecordingSourcesResponse$Response {
  RecordingSourcesResponse$Response copyWith(
      {List<RecordingSourcesSourceObjectResponse>? sources}) {
    return RecordingSourcesResponse$Response(sources: sources ?? this.sources);
  }

  RecordingSourcesResponse$Response copyWithWrapped(
      {Wrapped<List<RecordingSourcesSourceObjectResponse>>? sources}) {
    return RecordingSourcesResponse$Response(
        sources: (sources != null ? sources.value : this.sources));
  }
}

@JsonSerializable(explicitToJson: true)
class Error$Response {
  Error$Response({
    this.error,
  });

  factory Error$Response.fromJson(Map<String, dynamic> json) =>
      _$Error$ResponseFromJson(json);

  static const toJsonFactory = _$Error$ResponseToJson;
  Map<String, dynamic> toJson() => _$Error$ResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$Error$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error$Response &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $Error$ResponseExtension on Error$Response {
  Error$Response copyWith({KrakenError? error}) {
    return Error$Response(error: error ?? this.error);
  }

  Error$Response copyWithWrapped({Wrapped<KrakenError?>? error}) {
    return Error$Response(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchDetails$RequestBody {
  SearchDetails$RequestBody({
    this.seriesIds,
    this.multisourceIds,
    this.replayOptedInTime,
    this.cityId,
  });

  factory SearchDetails$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$SearchDetails$RequestBodyFromJson(json);

  static const toJsonFactory = _$SearchDetails$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$SearchDetails$RequestBodyToJson(this);

  @JsonKey(name: 'seriesIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesIds;
  @JsonKey(
      name: 'multisourceIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? multisourceIds;
  @JsonKey(name: 'replayOptedInTime', includeIfNull: false)
  final int? replayOptedInTime;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  static const fromJsonFactory = _$SearchDetails$RequestBodyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchDetails$RequestBody &&
            (identical(other.seriesIds, seriesIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesIds, seriesIds)) &&
            (identical(other.multisourceIds, multisourceIds) ||
                const DeepCollectionEquality()
                    .equals(other.multisourceIds, multisourceIds)) &&
            (identical(other.replayOptedInTime, replayOptedInTime) ||
                const DeepCollectionEquality()
                    .equals(other.replayOptedInTime, replayOptedInTime)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesIds) ^
      const DeepCollectionEquality().hash(multisourceIds) ^
      const DeepCollectionEquality().hash(replayOptedInTime) ^
      const DeepCollectionEquality().hash(cityId) ^
      runtimeType.hashCode;
}

extension $SearchDetails$RequestBodyExtension on SearchDetails$RequestBody {
  SearchDetails$RequestBody copyWith(
      {List<String>? seriesIds,
      List<String>? multisourceIds,
      int? replayOptedInTime,
      int? cityId}) {
    return SearchDetails$RequestBody(
        seriesIds: seriesIds ?? this.seriesIds,
        multisourceIds: multisourceIds ?? this.multisourceIds,
        replayOptedInTime: replayOptedInTime ?? this.replayOptedInTime,
        cityId: cityId ?? this.cityId);
  }

  SearchDetails$RequestBody copyWithWrapped(
      {Wrapped<List<String>?>? seriesIds,
      Wrapped<List<String>?>? multisourceIds,
      Wrapped<int?>? replayOptedInTime,
      Wrapped<int?>? cityId}) {
    return SearchDetails$RequestBody(
        seriesIds: (seriesIds != null ? seriesIds.value : this.seriesIds),
        multisourceIds: (multisourceIds != null
            ? multisourceIds.value
            : this.multisourceIds),
        replayOptedInTime: (replayOptedInTime != null
            ? replayOptedInTime.value
            : this.replayOptedInTime),
        cityId: (cityId != null ? cityId.value : this.cityId));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeBulk$RequestBody {
  MostRelevantEpisodeBulk$RequestBody({
    required this.seriesId,
    required this.language,
    required this.country,
    this.cityId,
    required this.profileId,
    this.brandingProviderId,
    this.replayOptedInTime,
    this.maxRes,
    this.includeExternalProvider,
    this.mergingOn,
    this.filterOnDemand,
    this.goPlayableOnly,
  });

  factory MostRelevantEpisodeBulk$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$MostRelevantEpisodeBulk$RequestBodyFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeBulk$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeBulk$RequestBodyToJson(this);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: <String>[])
  final List<String> seriesId;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String language;
  @JsonKey(name: 'country', includeIfNull: false, defaultValue: '')
  final String country;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'replayOptedInTime', includeIfNull: false)
  final int? replayOptedInTime;
  @JsonKey(
    name: 'maxRes',
    includeIfNull: false,
    toJson: mostRelevantEpisodeBulk$RequestBodyMaxResToJson,
    fromJson: mostRelevantEpisodeBulk$RequestBodyMaxResFromJson,
  )
  final enums.MostRelevantEpisodeBulk$RequestBodyMaxRes? maxRes;
  @JsonKey(
      name: 'includeExternalProvider',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? includeExternalProvider;
  @JsonKey(name: 'mergingOn', includeIfNull: false)
  final bool? mergingOn;
  @JsonKey(
    name: 'filterOnDemand',
    includeIfNull: false,
    toJson: mostRelevantEpisodeBulk$RequestBodyFilterOnDemandToJson,
    fromJson: mostRelevantEpisodeBulk$RequestBodyFilterOnDemandFromJson,
  )
  final enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand? filterOnDemand;
  @JsonKey(name: 'goPlayableOnly', includeIfNull: false)
  final bool? goPlayableOnly;
  static const fromJsonFactory = _$MostRelevantEpisodeBulk$RequestBodyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeBulk$RequestBody &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.country, country) ||
                const DeepCollectionEquality()
                    .equals(other.country, country)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.replayOptedInTime, replayOptedInTime) ||
                const DeepCollectionEquality()
                    .equals(other.replayOptedInTime, replayOptedInTime)) &&
            (identical(other.maxRes, maxRes) ||
                const DeepCollectionEquality().equals(other.maxRes, maxRes)) &&
            (identical(
                    other.includeExternalProvider, includeExternalProvider) ||
                const DeepCollectionEquality().equals(
                    other.includeExternalProvider, includeExternalProvider)) &&
            (identical(other.mergingOn, mergingOn) ||
                const DeepCollectionEquality()
                    .equals(other.mergingOn, mergingOn)) &&
            (identical(other.filterOnDemand, filterOnDemand) ||
                const DeepCollectionEquality()
                    .equals(other.filterOnDemand, filterOnDemand)) &&
            (identical(other.goPlayableOnly, goPlayableOnly) ||
                const DeepCollectionEquality()
                    .equals(other.goPlayableOnly, goPlayableOnly)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(country) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(replayOptedInTime) ^
      const DeepCollectionEquality().hash(maxRes) ^
      const DeepCollectionEquality().hash(includeExternalProvider) ^
      const DeepCollectionEquality().hash(mergingOn) ^
      const DeepCollectionEquality().hash(filterOnDemand) ^
      const DeepCollectionEquality().hash(goPlayableOnly) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeBulk$RequestBodyExtension
    on MostRelevantEpisodeBulk$RequestBody {
  MostRelevantEpisodeBulk$RequestBody copyWith(
      {List<String>? seriesId,
      String? language,
      String? country,
      int? cityId,
      String? profileId,
      String? brandingProviderId,
      int? replayOptedInTime,
      enums.MostRelevantEpisodeBulk$RequestBodyMaxRes? maxRes,
      List<String>? includeExternalProvider,
      bool? mergingOn,
      enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand? filterOnDemand,
      bool? goPlayableOnly}) {
    return MostRelevantEpisodeBulk$RequestBody(
        seriesId: seriesId ?? this.seriesId,
        language: language ?? this.language,
        country: country ?? this.country,
        cityId: cityId ?? this.cityId,
        profileId: profileId ?? this.profileId,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        replayOptedInTime: replayOptedInTime ?? this.replayOptedInTime,
        maxRes: maxRes ?? this.maxRes,
        includeExternalProvider:
            includeExternalProvider ?? this.includeExternalProvider,
        mergingOn: mergingOn ?? this.mergingOn,
        filterOnDemand: filterOnDemand ?? this.filterOnDemand,
        goPlayableOnly: goPlayableOnly ?? this.goPlayableOnly);
  }

  MostRelevantEpisodeBulk$RequestBody copyWithWrapped(
      {Wrapped<List<String>>? seriesId,
      Wrapped<String>? language,
      Wrapped<String>? country,
      Wrapped<int?>? cityId,
      Wrapped<String>? profileId,
      Wrapped<String?>? brandingProviderId,
      Wrapped<int?>? replayOptedInTime,
      Wrapped<enums.MostRelevantEpisodeBulk$RequestBodyMaxRes?>? maxRes,
      Wrapped<List<String>?>? includeExternalProvider,
      Wrapped<bool?>? mergingOn,
      Wrapped<enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand?>?
          filterOnDemand,
      Wrapped<bool?>? goPlayableOnly}) {
    return MostRelevantEpisodeBulk$RequestBody(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        language: (language != null ? language.value : this.language),
        country: (country != null ? country.value : this.country),
        cityId: (cityId != null ? cityId.value : this.cityId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        replayOptedInTime: (replayOptedInTime != null
            ? replayOptedInTime.value
            : this.replayOptedInTime),
        maxRes: (maxRes != null ? maxRes.value : this.maxRes),
        includeExternalProvider: (includeExternalProvider != null
            ? includeExternalProvider.value
            : this.includeExternalProvider),
        mergingOn: (mergingOn != null ? mergingOn.value : this.mergingOn),
        filterOnDemand: (filterOnDemand != null
            ? filterOnDemand.value
            : this.filterOnDemand),
        goPlayableOnly: (goPlayableOnly != null
            ? goPlayableOnly.value
            : this.goPlayableOnly));
  }
}

typedef SearchDetailsResponse$Response$Results
    = List<SearchDetailsResponse$Response$Results$Item>;

@JsonSerializable(explicitToJson: true)
class SearchDetailsResponse$Response$Results$Item {
  SearchDetailsResponse$Response$Results$Item({
    required this.series,
    required this.multisource,
  });

  factory SearchDetailsResponse$Response$Results$Item.fromJson(
          Map<String, dynamic> json) =>
      _$SearchDetailsResponse$Response$Results$ItemFromJson(json);

  static const toJsonFactory =
      _$SearchDetailsResponse$Response$Results$ItemToJson;
  Map<String, dynamic> toJson() =>
      _$SearchDetailsResponse$Response$Results$ItemToJson(this);

  @JsonKey(name: 'series', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> series;
  @JsonKey(name: 'multisource', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> multisource;
  static const fromJsonFactory =
      _$SearchDetailsResponse$Response$Results$ItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchDetailsResponse$Response$Results$Item &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.multisource, multisource) ||
                const DeepCollectionEquality()
                    .equals(other.multisource, multisource)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(multisource) ^
      runtimeType.hashCode;
}

extension $SearchDetailsResponse$Response$Results$ItemExtension
    on SearchDetailsResponse$Response$Results$Item {
  SearchDetailsResponse$Response$Results$Item copyWith(
      {List<Object>? series, List<Object>? multisource}) {
    return SearchDetailsResponse$Response$Results$Item(
        series: series ?? this.series,
        multisource: multisource ?? this.multisource);
  }

  SearchDetailsResponse$Response$Results$Item copyWithWrapped(
      {Wrapped<List<Object>>? series, Wrapped<List<Object>>? multisource}) {
    return SearchDetailsResponse$Response$Results$Item(
        series: (series != null ? series.value : this.series),
        multisource:
            (multisource != null ? multisource.value : this.multisource));
  }
}

String? vodResponseTypeToJson(enums.VodResponseType? vodResponseType) {
  return vodResponseType?.value;
}

enums.VodResponseType vodResponseTypeFromJson(
  Object? vodResponseType, [
  enums.VodResponseType? defaultValue,
]) {
  return enums.VodResponseType.values
          .firstWhereOrNull((e) => e.value == vodResponseType) ??
      defaultValue ??
      enums.VodResponseType.swaggerGeneratedUnknown;
}

List<String> vodResponseTypeListToJson(
    List<enums.VodResponseType>? vodResponseType) {
  if (vodResponseType == null) {
    return [];
  }

  return vodResponseType.map((e) => e.value!).toList();
}

List<enums.VodResponseType> vodResponseTypeListFromJson(
  List? vodResponseType, [
  List<enums.VodResponseType>? defaultValue,
]) {
  if (vodResponseType == null) {
    return defaultValue ?? [];
  }

  return vodResponseType
      .map((e) => vodResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.VodResponseType>? vodResponseTypeNullableListFromJson(
  List? vodResponseType, [
  List<enums.VodResponseType>? defaultValue,
]) {
  if (vodResponseType == null) {
    return defaultValue;
  }

  return vodResponseType
      .map((e) => vodResponseTypeFromJson(e.toString()))
      .toList();
}

String? vodResponseEntitlementStateToJson(
    enums.VodResponseEntitlementState? vodResponseEntitlementState) {
  return vodResponseEntitlementState?.value;
}

enums.VodResponseEntitlementState vodResponseEntitlementStateFromJson(
  Object? vodResponseEntitlementState, [
  enums.VodResponseEntitlementState? defaultValue,
]) {
  return enums.VodResponseEntitlementState.values
          .firstWhereOrNull((e) => e.value == vodResponseEntitlementState) ??
      defaultValue ??
      enums.VodResponseEntitlementState.swaggerGeneratedUnknown;
}

List<String> vodResponseEntitlementStateListToJson(
    List<enums.VodResponseEntitlementState>? vodResponseEntitlementState) {
  if (vodResponseEntitlementState == null) {
    return [];
  }

  return vodResponseEntitlementState.map((e) => e.value!).toList();
}

List<enums.VodResponseEntitlementState> vodResponseEntitlementStateListFromJson(
  List? vodResponseEntitlementState, [
  List<enums.VodResponseEntitlementState>? defaultValue,
]) {
  if (vodResponseEntitlementState == null) {
    return defaultValue ?? [];
  }

  return vodResponseEntitlementState
      .map((e) => vodResponseEntitlementStateFromJson(e.toString()))
      .toList();
}

List<enums.VodResponseEntitlementState>?
    vodResponseEntitlementStateNullableListFromJson(
  List? vodResponseEntitlementState, [
  List<enums.VodResponseEntitlementState>? defaultValue,
]) {
  if (vodResponseEntitlementState == null) {
    return defaultValue;
  }

  return vodResponseEntitlementState
      .map((e) => vodResponseEntitlementStateFromJson(e.toString()))
      .toList();
}

String? viewProgressResponseViewStateToJson(
    enums.ViewProgressResponseViewState? viewProgressResponseViewState) {
  return viewProgressResponseViewState?.value;
}

enums.ViewProgressResponseViewState viewProgressResponseViewStateFromJson(
  Object? viewProgressResponseViewState, [
  enums.ViewProgressResponseViewState? defaultValue,
]) {
  return enums.ViewProgressResponseViewState.values
          .firstWhereOrNull((e) => e.value == viewProgressResponseViewState) ??
      defaultValue ??
      enums.ViewProgressResponseViewState.swaggerGeneratedUnknown;
}

List<String> viewProgressResponseViewStateListToJson(
    List<enums.ViewProgressResponseViewState>? viewProgressResponseViewState) {
  if (viewProgressResponseViewState == null) {
    return [];
  }

  return viewProgressResponseViewState.map((e) => e.value!).toList();
}

List<enums.ViewProgressResponseViewState>
    viewProgressResponseViewStateListFromJson(
  List? viewProgressResponseViewState, [
  List<enums.ViewProgressResponseViewState>? defaultValue,
]) {
  if (viewProgressResponseViewState == null) {
    return defaultValue ?? [];
  }

  return viewProgressResponseViewState
      .map((e) => viewProgressResponseViewStateFromJson(e.toString()))
      .toList();
}

List<enums.ViewProgressResponseViewState>?
    viewProgressResponseViewStateNullableListFromJson(
  List? viewProgressResponseViewState, [
  List<enums.ViewProgressResponseViewState>? defaultValue,
]) {
  if (viewProgressResponseViewState == null) {
    return defaultValue;
  }

  return viewProgressResponseViewState
      .map((e) => viewProgressResponseViewStateFromJson(e.toString()))
      .toList();
}

String? sourceTypeResponseToJson(enums.SourceTypeResponse? sourceTypeResponse) {
  return sourceTypeResponse?.value;
}

enums.SourceTypeResponse sourceTypeResponseFromJson(
  Object? sourceTypeResponse, [
  enums.SourceTypeResponse? defaultValue,
]) {
  return enums.SourceTypeResponse.values
          .firstWhereOrNull((e) => e.value == sourceTypeResponse) ??
      defaultValue ??
      enums.SourceTypeResponse.swaggerGeneratedUnknown;
}

List<String> sourceTypeResponseListToJson(
    List<enums.SourceTypeResponse>? sourceTypeResponse) {
  if (sourceTypeResponse == null) {
    return [];
  }

  return sourceTypeResponse.map((e) => e.value!).toList();
}

List<enums.SourceTypeResponse> sourceTypeResponseListFromJson(
  List? sourceTypeResponse, [
  List<enums.SourceTypeResponse>? defaultValue,
]) {
  if (sourceTypeResponse == null) {
    return defaultValue ?? [];
  }

  return sourceTypeResponse
      .map((e) => sourceTypeResponseFromJson(e.toString()))
      .toList();
}

List<enums.SourceTypeResponse>? sourceTypeResponseNullableListFromJson(
  List? sourceTypeResponse, [
  List<enums.SourceTypeResponse>? defaultValue,
]) {
  if (sourceTypeResponse == null) {
    return defaultValue;
  }

  return sourceTypeResponse
      .map((e) => sourceTypeResponseFromJson(e.toString()))
      .toList();
}

String? recordingSourceResponseRecordingStateToJson(
    enums.RecordingSourceResponseRecordingState?
        recordingSourceResponseRecordingState) {
  return recordingSourceResponseRecordingState?.value;
}

enums.RecordingSourceResponseRecordingState
    recordingSourceResponseRecordingStateFromJson(
  Object? recordingSourceResponseRecordingState, [
  enums.RecordingSourceResponseRecordingState? defaultValue,
]) {
  return enums.RecordingSourceResponseRecordingState.values.firstWhereOrNull(
          (e) => e.value == recordingSourceResponseRecordingState) ??
      defaultValue ??
      enums.RecordingSourceResponseRecordingState.swaggerGeneratedUnknown;
}

List<String> recordingSourceResponseRecordingStateListToJson(
    List<enums.RecordingSourceResponseRecordingState>?
        recordingSourceResponseRecordingState) {
  if (recordingSourceResponseRecordingState == null) {
    return [];
  }

  return recordingSourceResponseRecordingState.map((e) => e.value!).toList();
}

List<enums.RecordingSourceResponseRecordingState>
    recordingSourceResponseRecordingStateListFromJson(
  List? recordingSourceResponseRecordingState, [
  List<enums.RecordingSourceResponseRecordingState>? defaultValue,
]) {
  if (recordingSourceResponseRecordingState == null) {
    return defaultValue ?? [];
  }

  return recordingSourceResponseRecordingState
      .map((e) => recordingSourceResponseRecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.RecordingSourceResponseRecordingState>?
    recordingSourceResponseRecordingStateNullableListFromJson(
  List? recordingSourceResponseRecordingState, [
  List<enums.RecordingSourceResponseRecordingState>? defaultValue,
]) {
  if (recordingSourceResponseRecordingState == null) {
    return defaultValue;
  }

  return recordingSourceResponseRecordingState
      .map((e) => recordingSourceResponseRecordingStateFromJson(e.toString()))
      .toList();
}

String? vodSourceResponseTypeToJson(
    enums.VodSourceResponseType? vodSourceResponseType) {
  return vodSourceResponseType?.value;
}

enums.VodSourceResponseType vodSourceResponseTypeFromJson(
  Object? vodSourceResponseType, [
  enums.VodSourceResponseType? defaultValue,
]) {
  return enums.VodSourceResponseType.values
          .firstWhereOrNull((e) => e.value == vodSourceResponseType) ??
      defaultValue ??
      enums.VodSourceResponseType.swaggerGeneratedUnknown;
}

List<String> vodSourceResponseTypeListToJson(
    List<enums.VodSourceResponseType>? vodSourceResponseType) {
  if (vodSourceResponseType == null) {
    return [];
  }

  return vodSourceResponseType.map((e) => e.value!).toList();
}

List<enums.VodSourceResponseType> vodSourceResponseTypeListFromJson(
  List? vodSourceResponseType, [
  List<enums.VodSourceResponseType>? defaultValue,
]) {
  if (vodSourceResponseType == null) {
    return defaultValue ?? [];
  }

  return vodSourceResponseType
      .map((e) => vodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.VodSourceResponseType>? vodSourceResponseTypeNullableListFromJson(
  List? vodSourceResponseType, [
  List<enums.VodSourceResponseType>? defaultValue,
]) {
  if (vodSourceResponseType == null) {
    return defaultValue;
  }

  return vodSourceResponseType
      .map((e) => vodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

String? episodePickerVodSourceResponseTypeToJson(
    enums.EpisodePickerVodSourceResponseType?
        episodePickerVodSourceResponseType) {
  return episodePickerVodSourceResponseType?.value;
}

enums.EpisodePickerVodSourceResponseType
    episodePickerVodSourceResponseTypeFromJson(
  Object? episodePickerVodSourceResponseType, [
  enums.EpisodePickerVodSourceResponseType? defaultValue,
]) {
  return enums.EpisodePickerVodSourceResponseType.values.firstWhereOrNull(
          (e) => e.value == episodePickerVodSourceResponseType) ??
      defaultValue ??
      enums.EpisodePickerVodSourceResponseType.swaggerGeneratedUnknown;
}

List<String> episodePickerVodSourceResponseTypeListToJson(
    List<enums.EpisodePickerVodSourceResponseType>?
        episodePickerVodSourceResponseType) {
  if (episodePickerVodSourceResponseType == null) {
    return [];
  }

  return episodePickerVodSourceResponseType.map((e) => e.value!).toList();
}

List<enums.EpisodePickerVodSourceResponseType>
    episodePickerVodSourceResponseTypeListFromJson(
  List? episodePickerVodSourceResponseType, [
  List<enums.EpisodePickerVodSourceResponseType>? defaultValue,
]) {
  if (episodePickerVodSourceResponseType == null) {
    return defaultValue ?? [];
  }

  return episodePickerVodSourceResponseType
      .map((e) => episodePickerVodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.EpisodePickerVodSourceResponseType>?
    episodePickerVodSourceResponseTypeNullableListFromJson(
  List? episodePickerVodSourceResponseType, [
  List<enums.EpisodePickerVodSourceResponseType>? defaultValue,
]) {
  if (episodePickerVodSourceResponseType == null) {
    return defaultValue;
  }

  return episodePickerVodSourceResponseType
      .map((e) => episodePickerVodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

String? episodePickerEpisodeResponseTypeToJson(
    enums.EpisodePickerEpisodeResponseType? episodePickerEpisodeResponseType) {
  return episodePickerEpisodeResponseType?.value;
}

enums.EpisodePickerEpisodeResponseType episodePickerEpisodeResponseTypeFromJson(
  Object? episodePickerEpisodeResponseType, [
  enums.EpisodePickerEpisodeResponseType? defaultValue,
]) {
  return enums.EpisodePickerEpisodeResponseType.values.firstWhereOrNull(
          (e) => e.value == episodePickerEpisodeResponseType) ??
      defaultValue ??
      enums.EpisodePickerEpisodeResponseType.swaggerGeneratedUnknown;
}

List<String> episodePickerEpisodeResponseTypeListToJson(
    List<enums.EpisodePickerEpisodeResponseType>?
        episodePickerEpisodeResponseType) {
  if (episodePickerEpisodeResponseType == null) {
    return [];
  }

  return episodePickerEpisodeResponseType.map((e) => e.value!).toList();
}

List<enums.EpisodePickerEpisodeResponseType>
    episodePickerEpisodeResponseTypeListFromJson(
  List? episodePickerEpisodeResponseType, [
  List<enums.EpisodePickerEpisodeResponseType>? defaultValue,
]) {
  if (episodePickerEpisodeResponseType == null) {
    return defaultValue ?? [];
  }

  return episodePickerEpisodeResponseType
      .map((e) => episodePickerEpisodeResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.EpisodePickerEpisodeResponseType>?
    episodePickerEpisodeResponseTypeNullableListFromJson(
  List? episodePickerEpisodeResponseType, [
  List<enums.EpisodePickerEpisodeResponseType>? defaultValue,
]) {
  if (episodePickerEpisodeResponseType == null) {
    return defaultValue;
  }

  return episodePickerEpisodeResponseType
      .map((e) => episodePickerEpisodeResponseTypeFromJson(e.toString()))
      .toList();
}

String? saaoSourceResponseContentTypeToJson(
    enums.SaaoSourceResponseContentType? saaoSourceResponseContentType) {
  return saaoSourceResponseContentType?.value;
}

enums.SaaoSourceResponseContentType saaoSourceResponseContentTypeFromJson(
  Object? saaoSourceResponseContentType, [
  enums.SaaoSourceResponseContentType? defaultValue,
]) {
  return enums.SaaoSourceResponseContentType.values
          .firstWhereOrNull((e) => e.value == saaoSourceResponseContentType) ??
      defaultValue ??
      enums.SaaoSourceResponseContentType.swaggerGeneratedUnknown;
}

List<String> saaoSourceResponseContentTypeListToJson(
    List<enums.SaaoSourceResponseContentType>? saaoSourceResponseContentType) {
  if (saaoSourceResponseContentType == null) {
    return [];
  }

  return saaoSourceResponseContentType.map((e) => e.value!).toList();
}

List<enums.SaaoSourceResponseContentType>
    saaoSourceResponseContentTypeListFromJson(
  List? saaoSourceResponseContentType, [
  List<enums.SaaoSourceResponseContentType>? defaultValue,
]) {
  if (saaoSourceResponseContentType == null) {
    return defaultValue ?? [];
  }

  return saaoSourceResponseContentType
      .map((e) => saaoSourceResponseContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.SaaoSourceResponseContentType>?
    saaoSourceResponseContentTypeNullableListFromJson(
  List? saaoSourceResponseContentType, [
  List<enums.SaaoSourceResponseContentType>? defaultValue,
]) {
  if (saaoSourceResponseContentType == null) {
    return defaultValue;
  }

  return saaoSourceResponseContentType
      .map((e) => saaoSourceResponseContentTypeFromJson(e.toString()))
      .toList();
}

String? linearContentSourceTypeToJson(
    enums.LinearContentSourceType? linearContentSourceType) {
  return linearContentSourceType?.value;
}

enums.LinearContentSourceType linearContentSourceTypeFromJson(
  Object? linearContentSourceType, [
  enums.LinearContentSourceType? defaultValue,
]) {
  return enums.LinearContentSourceType.values
          .firstWhereOrNull((e) => e.value == linearContentSourceType) ??
      defaultValue ??
      enums.LinearContentSourceType.swaggerGeneratedUnknown;
}

List<String> linearContentSourceTypeListToJson(
    List<enums.LinearContentSourceType>? linearContentSourceType) {
  if (linearContentSourceType == null) {
    return [];
  }

  return linearContentSourceType.map((e) => e.value!).toList();
}

List<enums.LinearContentSourceType> linearContentSourceTypeListFromJson(
  List? linearContentSourceType, [
  List<enums.LinearContentSourceType>? defaultValue,
]) {
  if (linearContentSourceType == null) {
    return defaultValue ?? [];
  }

  return linearContentSourceType
      .map((e) => linearContentSourceTypeFromJson(e.toString()))
      .toList();
}

List<enums.LinearContentSourceType>?
    linearContentSourceTypeNullableListFromJson(
  List? linearContentSourceType, [
  List<enums.LinearContentSourceType>? defaultValue,
]) {
  if (linearContentSourceType == null) {
    return defaultValue;
  }

  return linearContentSourceType
      .map((e) => linearContentSourceTypeFromJson(e.toString()))
      .toList();
}

String? maxResToJson(enums.MaxRes? maxRes) {
  return maxRes?.value;
}

enums.MaxRes maxResFromJson(
  Object? maxRes, [
  enums.MaxRes? defaultValue,
]) {
  return enums.MaxRes.values.firstWhereOrNull((e) => e.value == maxRes) ??
      defaultValue ??
      enums.MaxRes.swaggerGeneratedUnknown;
}

List<String> maxResListToJson(List<enums.MaxRes>? maxRes) {
  if (maxRes == null) {
    return [];
  }

  return maxRes.map((e) => e.value!).toList();
}

List<enums.MaxRes> maxResListFromJson(
  List? maxRes, [
  List<enums.MaxRes>? defaultValue,
]) {
  if (maxRes == null) {
    return defaultValue ?? [];
  }

  return maxRes.map((e) => maxResFromJson(e.toString())).toList();
}

List<enums.MaxRes>? maxResNullableListFromJson(
  List? maxRes, [
  List<enums.MaxRes>? defaultValue,
]) {
  if (maxRes == null) {
    return defaultValue;
  }

  return maxRes.map((e) => maxResFromJson(e.toString())).toList();
}

String? filterOnDemandToJson(enums.FilterOnDemand? filterOnDemand) {
  return filterOnDemand?.value;
}

enums.FilterOnDemand filterOnDemandFromJson(
  Object? filterOnDemand, [
  enums.FilterOnDemand? defaultValue,
]) {
  return enums.FilterOnDemand.values
          .firstWhereOrNull((e) => e.value == filterOnDemand) ??
      defaultValue ??
      enums.FilterOnDemand.swaggerGeneratedUnknown;
}

List<String> filterOnDemandListToJson(
    List<enums.FilterOnDemand>? filterOnDemand) {
  if (filterOnDemand == null) {
    return [];
  }

  return filterOnDemand.map((e) => e.value!).toList();
}

List<enums.FilterOnDemand> filterOnDemandListFromJson(
  List? filterOnDemand, [
  List<enums.FilterOnDemand>? defaultValue,
]) {
  if (filterOnDemand == null) {
    return defaultValue ?? [];
  }

  return filterOnDemand
      .map((e) => filterOnDemandFromJson(e.toString()))
      .toList();
}

List<enums.FilterOnDemand>? filterOnDemandNullableListFromJson(
  List? filterOnDemand, [
  List<enums.FilterOnDemand>? defaultValue,
]) {
  if (filterOnDemand == null) {
    return defaultValue;
  }

  return filterOnDemand
      .map((e) => filterOnDemandFromJson(e.toString()))
      .toList();
}

String? v1RecordingSourcesTypeCridLanguageGetTypeToJson(
    enums.V1RecordingSourcesTypeCridLanguageGetType?
        v1RecordingSourcesTypeCridLanguageGetType) {
  return v1RecordingSourcesTypeCridLanguageGetType?.value;
}

enums.V1RecordingSourcesTypeCridLanguageGetType
    v1RecordingSourcesTypeCridLanguageGetTypeFromJson(
  Object? v1RecordingSourcesTypeCridLanguageGetType, [
  enums.V1RecordingSourcesTypeCridLanguageGetType? defaultValue,
]) {
  return enums.V1RecordingSourcesTypeCridLanguageGetType.values
          .firstWhereOrNull(
              (e) => e.value == v1RecordingSourcesTypeCridLanguageGetType) ??
      defaultValue ??
      enums.V1RecordingSourcesTypeCridLanguageGetType.swaggerGeneratedUnknown;
}

List<String> v1RecordingSourcesTypeCridLanguageGetTypeListToJson(
    List<enums.V1RecordingSourcesTypeCridLanguageGetType>?
        v1RecordingSourcesTypeCridLanguageGetType) {
  if (v1RecordingSourcesTypeCridLanguageGetType == null) {
    return [];
  }

  return v1RecordingSourcesTypeCridLanguageGetType
      .map((e) => e.value!)
      .toList();
}

List<enums.V1RecordingSourcesTypeCridLanguageGetType>
    v1RecordingSourcesTypeCridLanguageGetTypeListFromJson(
  List? v1RecordingSourcesTypeCridLanguageGetType, [
  List<enums.V1RecordingSourcesTypeCridLanguageGetType>? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetType == null) {
    return defaultValue ?? [];
  }

  return v1RecordingSourcesTypeCridLanguageGetType
      .map((e) =>
          v1RecordingSourcesTypeCridLanguageGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.V1RecordingSourcesTypeCridLanguageGetType>?
    v1RecordingSourcesTypeCridLanguageGetTypeNullableListFromJson(
  List? v1RecordingSourcesTypeCridLanguageGetType, [
  List<enums.V1RecordingSourcesTypeCridLanguageGetType>? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetType == null) {
    return defaultValue;
  }

  return v1RecordingSourcesTypeCridLanguageGetType
      .map((e) =>
          v1RecordingSourcesTypeCridLanguageGetTypeFromJson(e.toString()))
      .toList();
}

String? mostRelevantEpisodeResponse$ResponseContentTypeToJson(
    enums.MostRelevantEpisodeResponse$ResponseContentType?
        mostRelevantEpisodeResponse$ResponseContentType) {
  return mostRelevantEpisodeResponse$ResponseContentType?.value;
}

enums.MostRelevantEpisodeResponse$ResponseContentType
    mostRelevantEpisodeResponse$ResponseContentTypeFromJson(
  Object? mostRelevantEpisodeResponse$ResponseContentType, [
  enums.MostRelevantEpisodeResponse$ResponseContentType? defaultValue,
]) {
  return enums.MostRelevantEpisodeResponse$ResponseContentType.values
          .firstWhereOrNull((e) =>
              e.value == mostRelevantEpisodeResponse$ResponseContentType) ??
      defaultValue ??
      enums.MostRelevantEpisodeResponse$ResponseContentType
          .swaggerGeneratedUnknown;
}

List<String> mostRelevantEpisodeResponse$ResponseContentTypeListToJson(
    List<enums.MostRelevantEpisodeResponse$ResponseContentType>?
        mostRelevantEpisodeResponse$ResponseContentType) {
  if (mostRelevantEpisodeResponse$ResponseContentType == null) {
    return [];
  }

  return mostRelevantEpisodeResponse$ResponseContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.MostRelevantEpisodeResponse$ResponseContentType>
    mostRelevantEpisodeResponse$ResponseContentTypeListFromJson(
  List? mostRelevantEpisodeResponse$ResponseContentType, [
  List<enums.MostRelevantEpisodeResponse$ResponseContentType>? defaultValue,
]) {
  if (mostRelevantEpisodeResponse$ResponseContentType == null) {
    return defaultValue ?? [];
  }

  return mostRelevantEpisodeResponse$ResponseContentType
      .map((e) =>
          mostRelevantEpisodeResponse$ResponseContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.MostRelevantEpisodeResponse$ResponseContentType>?
    mostRelevantEpisodeResponse$ResponseContentTypeNullableListFromJson(
  List? mostRelevantEpisodeResponse$ResponseContentType, [
  List<enums.MostRelevantEpisodeResponse$ResponseContentType>? defaultValue,
]) {
  if (mostRelevantEpisodeResponse$ResponseContentType == null) {
    return defaultValue;
  }

  return mostRelevantEpisodeResponse$ResponseContentType
      .map((e) =>
          mostRelevantEpisodeResponse$ResponseContentTypeFromJson(e.toString()))
      .toList();
}

String? mostRelevantSourceResponse$ResponseContentTypeToJson(
    enums.MostRelevantSourceResponse$ResponseContentType?
        mostRelevantSourceResponse$ResponseContentType) {
  return mostRelevantSourceResponse$ResponseContentType?.value;
}

enums.MostRelevantSourceResponse$ResponseContentType
    mostRelevantSourceResponse$ResponseContentTypeFromJson(
  Object? mostRelevantSourceResponse$ResponseContentType, [
  enums.MostRelevantSourceResponse$ResponseContentType? defaultValue,
]) {
  return enums.MostRelevantSourceResponse$ResponseContentType.values
          .firstWhereOrNull((e) =>
              e.value == mostRelevantSourceResponse$ResponseContentType) ??
      defaultValue ??
      enums.MostRelevantSourceResponse$ResponseContentType
          .swaggerGeneratedUnknown;
}

List<String> mostRelevantSourceResponse$ResponseContentTypeListToJson(
    List<enums.MostRelevantSourceResponse$ResponseContentType>?
        mostRelevantSourceResponse$ResponseContentType) {
  if (mostRelevantSourceResponse$ResponseContentType == null) {
    return [];
  }

  return mostRelevantSourceResponse$ResponseContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.MostRelevantSourceResponse$ResponseContentType>
    mostRelevantSourceResponse$ResponseContentTypeListFromJson(
  List? mostRelevantSourceResponse$ResponseContentType, [
  List<enums.MostRelevantSourceResponse$ResponseContentType>? defaultValue,
]) {
  if (mostRelevantSourceResponse$ResponseContentType == null) {
    return defaultValue ?? [];
  }

  return mostRelevantSourceResponse$ResponseContentType
      .map((e) =>
          mostRelevantSourceResponse$ResponseContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.MostRelevantSourceResponse$ResponseContentType>?
    mostRelevantSourceResponse$ResponseContentTypeNullableListFromJson(
  List? mostRelevantSourceResponse$ResponseContentType, [
  List<enums.MostRelevantSourceResponse$ResponseContentType>? defaultValue,
]) {
  if (mostRelevantSourceResponse$ResponseContentType == null) {
    return defaultValue;
  }

  return mostRelevantSourceResponse$ResponseContentType
      .map((e) =>
          mostRelevantSourceResponse$ResponseContentTypeFromJson(e.toString()))
      .toList();
}

String? mostRelevantEpisodeBulk$RequestBodyMaxResToJson(
    enums.MostRelevantEpisodeBulk$RequestBodyMaxRes?
        mostRelevantEpisodeBulk$RequestBodyMaxRes) {
  return mostRelevantEpisodeBulk$RequestBodyMaxRes?.value;
}

enums.MostRelevantEpisodeBulk$RequestBodyMaxRes
    mostRelevantEpisodeBulk$RequestBodyMaxResFromJson(
  Object? mostRelevantEpisodeBulk$RequestBodyMaxRes, [
  enums.MostRelevantEpisodeBulk$RequestBodyMaxRes? defaultValue,
]) {
  return enums.MostRelevantEpisodeBulk$RequestBodyMaxRes.values
          .firstWhereOrNull(
              (e) => e.value == mostRelevantEpisodeBulk$RequestBodyMaxRes) ??
      defaultValue ??
      enums.MostRelevantEpisodeBulk$RequestBodyMaxRes.swaggerGeneratedUnknown;
}

List<String> mostRelevantEpisodeBulk$RequestBodyMaxResListToJson(
    List<enums.MostRelevantEpisodeBulk$RequestBodyMaxRes>?
        mostRelevantEpisodeBulk$RequestBodyMaxRes) {
  if (mostRelevantEpisodeBulk$RequestBodyMaxRes == null) {
    return [];
  }

  return mostRelevantEpisodeBulk$RequestBodyMaxRes
      .map((e) => e.value!)
      .toList();
}

List<enums.MostRelevantEpisodeBulk$RequestBodyMaxRes>
    mostRelevantEpisodeBulk$RequestBodyMaxResListFromJson(
  List? mostRelevantEpisodeBulk$RequestBodyMaxRes, [
  List<enums.MostRelevantEpisodeBulk$RequestBodyMaxRes>? defaultValue,
]) {
  if (mostRelevantEpisodeBulk$RequestBodyMaxRes == null) {
    return defaultValue ?? [];
  }

  return mostRelevantEpisodeBulk$RequestBodyMaxRes
      .map((e) =>
          mostRelevantEpisodeBulk$RequestBodyMaxResFromJson(e.toString()))
      .toList();
}

List<enums.MostRelevantEpisodeBulk$RequestBodyMaxRes>?
    mostRelevantEpisodeBulk$RequestBodyMaxResNullableListFromJson(
  List? mostRelevantEpisodeBulk$RequestBodyMaxRes, [
  List<enums.MostRelevantEpisodeBulk$RequestBodyMaxRes>? defaultValue,
]) {
  if (mostRelevantEpisodeBulk$RequestBodyMaxRes == null) {
    return defaultValue;
  }

  return mostRelevantEpisodeBulk$RequestBodyMaxRes
      .map((e) =>
          mostRelevantEpisodeBulk$RequestBodyMaxResFromJson(e.toString()))
      .toList();
}

String? mostRelevantEpisodeBulk$RequestBodyFilterOnDemandToJson(
    enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand?
        mostRelevantEpisodeBulk$RequestBodyFilterOnDemand) {
  return mostRelevantEpisodeBulk$RequestBodyFilterOnDemand?.value;
}

enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand
    mostRelevantEpisodeBulk$RequestBodyFilterOnDemandFromJson(
  Object? mostRelevantEpisodeBulk$RequestBodyFilterOnDemand, [
  enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand? defaultValue,
]) {
  return enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand.values
          .firstWhereOrNull((e) =>
              e.value == mostRelevantEpisodeBulk$RequestBodyFilterOnDemand) ??
      defaultValue ??
      enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand
          .swaggerGeneratedUnknown;
}

List<String> mostRelevantEpisodeBulk$RequestBodyFilterOnDemandListToJson(
    List<enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand>?
        mostRelevantEpisodeBulk$RequestBodyFilterOnDemand) {
  if (mostRelevantEpisodeBulk$RequestBodyFilterOnDemand == null) {
    return [];
  }

  return mostRelevantEpisodeBulk$RequestBodyFilterOnDemand
      .map((e) => e.value!)
      .toList();
}

List<enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand>
    mostRelevantEpisodeBulk$RequestBodyFilterOnDemandListFromJson(
  List? mostRelevantEpisodeBulk$RequestBodyFilterOnDemand, [
  List<enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand>? defaultValue,
]) {
  if (mostRelevantEpisodeBulk$RequestBodyFilterOnDemand == null) {
    return defaultValue ?? [];
  }

  return mostRelevantEpisodeBulk$RequestBodyFilterOnDemand
      .map((e) => mostRelevantEpisodeBulk$RequestBodyFilterOnDemandFromJson(
          e.toString()))
      .toList();
}

List<enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand>?
    mostRelevantEpisodeBulk$RequestBodyFilterOnDemandNullableListFromJson(
  List? mostRelevantEpisodeBulk$RequestBodyFilterOnDemand, [
  List<enums.MostRelevantEpisodeBulk$RequestBodyFilterOnDemand>? defaultValue,
]) {
  if (mostRelevantEpisodeBulk$RequestBodyFilterOnDemand == null) {
    return defaultValue;
  }

  return mostRelevantEpisodeBulk$RequestBodyFilterOnDemand
      .map((e) => mostRelevantEpisodeBulk$RequestBodyFilterOnDemandFromJson(
          e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
