// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'recording_service.enums.swagger.dart' as enums;
export 'recording_service.enums.swagger.dart';

part 'recording_service.swagger.chopper.dart';
part 'recording_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class RecordingService extends ChopperService {
  static RecordingService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$RecordingService(client);
    }

    final newClient = ChopperClient(
        services: [_$RecordingService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$RecordingService(newClient);
  }

  ///Delete all recordings and bookings related with the specified customer
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Delete all recordings and bookings related with the specified customer
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}')
  Future<chopper.Response> _customersCustomerIdDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get a status of a single recording or booking
  ///@param customerId customer identifier
  ///@param singleId Identifier of a single recording or booking
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<SingleRecordingState>>
      customersCustomerIdStatusSingleIdGet({
    required String? customerId,
    required String? singleId,
    String? cpeId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SingleRecordingState, () => SingleRecordingState.fromJsonFactory);

    return _customersCustomerIdStatusSingleIdGet(
        customerId: customerId,
        singleId: singleId,
        cpeId: cpeId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get a status of a single recording or booking
  ///@param customerId customer identifier
  ///@param singleId Identifier of a single recording or booking
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/status/{singleId}')
  Future<chopper.Response<SingleRecordingState>>
      _customersCustomerIdStatusSingleIdGet({
    @Path('customerId')
        required String? customerId,
    @Path('singleId')
        required String? singleId,
    @Query('cpeId')
        String? cpeId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Returns an overview of recordings and bookings for a customer
  ///@param customerId customer identifier
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<TileCollectionResponse>>
      customersCustomerIdCollectionGet({
    required String? customerId,
    String? profileId,
    String? cpeId,
    String? language,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TileCollectionResponse, () => TileCollectionResponse.fromJsonFactory);

    return _customersCustomerIdCollectionGet(
        customerId: customerId,
        profileId: profileId,
        cpeId: cpeId,
        language: language,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Returns an overview of recordings and bookings for a customer
  ///@param customerId customer identifier
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/collection')
  Future<chopper.Response<TileCollectionResponse>>
      _customersCustomerIdCollectionGet({
    @Path('customerId')
        required String? customerId,
    @Query('profileId')
        String? profileId,
    @Query('cpeId')
        String? cpeId,
    @Query('language')
        String? language,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of booked recordings (single events/episodes, seasons, or shows)
  ///@param customerId customer identifier
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param sort Contains the name of a field which should be used in sorting entities - either time or title.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time is used for sorting
  ///@param cpeCollapsing Flag which specifies if collapsed recordings should additionally use cpe collapsing
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<Bookings>> customersCustomerIdBookingsGet({
    required String? customerId,
    bool? isAdult,
    int? offset,
    int? limit,
    enums.CustomersCustomerIdBookingsGetSort? sort,
    enums.CustomersCustomerIdBookingsGetSortOrder? sortOrder,
    bool? cpeCollapsing,
    String? cpeId,
    String? language,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Bookings, () => Bookings.fromJsonFactory);

    return _customersCustomerIdBookingsGet(
        customerId: customerId,
        isAdult: isAdult,
        offset: offset,
        limit: limit,
        sort: sort?.value?.toString(),
        sortOrder: sortOrder?.value?.toString(),
        cpeCollapsing: cpeCollapsing,
        cpeId: cpeId,
        language: language,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of booked recordings (single events/episodes, seasons, or shows)
  ///@param customerId customer identifier
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param sort Contains the name of a field which should be used in sorting entities - either time or title.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time is used for sorting
  ///@param cpeCollapsing Flag which specifies if collapsed recordings should additionally use cpe collapsing
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/bookings')
  Future<chopper.Response<Bookings>> _customersCustomerIdBookingsGet({
    @Path('customerId')
        required String? customerId,
    @Query('isAdult')
        bool? isAdult,
    @Query('offset')
        int? offset,
    @Query('limit')
        int? limit,
    @Query('sort')
        String? sort,
    @Query('sortOrder')
        String? sortOrder,
    @Query('cpeCollapsing')
        bool? cpeCollapsing,
    @Query('cpeId')
        String? cpeId,
    @Query('language')
        String? language,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Removes all planned bookings. Ongoing recordings are removed if payload is provided or stopped otherwise.
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdBookingsDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required DeleteAllParams? body,
  }) {
    return _customersCustomerIdBookingsDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Removes all planned bookings. Ongoing recordings are removed if payload is provided or stopped otherwise.
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/bookings')
  Future<chopper.Response> _customersCustomerIdBookingsDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required DeleteAllParams? body,
  });

  ///Cancel and delete all past, ongoing and future items for this show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdShowDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required ShowCancelParams? body,
  }) {
    return _customersCustomerIdShowDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Cancel and delete all past, ongoing and future items for this show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/show')
  Future<chopper.Response> _customersCustomerIdShowDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required ShowCancelParams? body,
  });

  ///Schedule a recording of a single event or episode
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdBookingsSinglePost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required SingleBookingParams? body,
  }) {
    return _customersCustomerIdBookingsSinglePost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Schedule a recording of a single event or episode
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Post(
    path: '/customers/{customerId}/bookings/single',
    optionalBody: true,
  )
  Future<chopper.Response> _customersCustomerIdBookingsSinglePost({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required SingleBookingParams? body,
  });

  ///Cancel a booking for a single episode or an event, alternatively also to cancel ongoing item
  ///@param customerId customer identifier
  ///@param eventId Identifier of a booked episode or single event
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdBookingsSingleEventIdDelete({
    required String? customerId,
    required String? eventId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdBookingsSingleEventIdDelete(
        customerId: customerId,
        eventId: eventId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Cancel a booking for a single episode or an event, alternatively also to cancel ongoing item
  ///@param customerId customer identifier
  ///@param eventId Identifier of a booked episode or single event
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/bookings/single/{eventId}')
  Future<chopper.Response> _customersCustomerIdBookingsSingleEventIdDelete({
    @Path('customerId')
        required String? customerId,
    @Path('eventId')
        required String? eventId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Schedule a recording of a show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdBookingsShowPost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required ShowBookingParams? body,
  }) {
    return _customersCustomerIdBookingsShowPost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Schedule a recording of a show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Post(
    path: '/customers/{customerId}/bookings/show',
    optionalBody: true,
  )
  Future<chopper.Response> _customersCustomerIdBookingsShowPost({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required ShowBookingParams? body,
  });

  ///Cancels show booking
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdBookingsShowDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required ShowCancelParams? body,
  }) {
    return _customersCustomerIdBookingsShowDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Cancels show booking
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/bookings/show')
  Future<chopper.Response> _customersCustomerIdBookingsShowDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required ShowCancelParams? body,
  });

  ///!Deprecated! since R4.18, use DELETE /customers/{customerId}/bookings/show instead.
  ///@param customerId customer identifier
  ///@param showId Identifier of a booked show
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdBookingsShowShowIdDelete({
    required String? customerId,
    required String? showId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdBookingsShowShowIdDelete(
        customerId: customerId,
        showId: showId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///!Deprecated! since R4.18, use DELETE /customers/{customerId}/bookings/show instead.
  ///@param customerId customer identifier
  ///@param showId Identifier of a booked show
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/bookings/show/{showId}')
  Future<chopper.Response> _customersCustomerIdBookingsShowShowIdDelete({
    @Path('customerId')
        required String? customerId,
    @Path('showId')
        required String? showId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of recordings (single events/episodes, seasons, or shows)
  ///@param customerId customer identifier
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param sort Contains the name of a field which should be used in sorting entities - either time or title.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is not taken into account when title is used for sorting
  ///@param profileId profile identifier - for future use
  ///@param cpeCollapsing Flag which specifies if collapsed recordings should additionally use cpe collapsing
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<Recordings>> customersCustomerIdRecordingsGet({
    required String? customerId,
    bool? isAdult,
    int? offset,
    int? limit,
    enums.CustomersCustomerIdRecordingsGetSort? sort,
    enums.CustomersCustomerIdRecordingsGetSortOrder? sortOrder,
    String? profileId,
    bool? cpeCollapsing,
    String? cpeId,
    String? language,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Recordings, () => Recordings.fromJsonFactory);

    return _customersCustomerIdRecordingsGet(
        customerId: customerId,
        isAdult: isAdult,
        offset: offset,
        limit: limit,
        sort: sort?.value?.toString(),
        sortOrder: sortOrder?.value?.toString(),
        profileId: profileId,
        cpeCollapsing: cpeCollapsing,
        cpeId: cpeId,
        language: language,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of recordings (single events/episodes, seasons, or shows)
  ///@param customerId customer identifier
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param sort Contains the name of a field which should be used in sorting entities - either time or title.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is not taken into account when title is used for sorting
  ///@param profileId profile identifier - for future use
  ///@param cpeCollapsing Flag which specifies if collapsed recordings should additionally use cpe collapsing
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/recordings')
  Future<chopper.Response<Recordings>> _customersCustomerIdRecordingsGet({
    @Path('customerId')
        required String? customerId,
    @Query('isAdult')
        bool? isAdult,
    @Query('offset')
        int? offset,
    @Query('limit')
        int? limit,
    @Query('sort')
        String? sort,
    @Query('sortOrder')
        String? sortOrder,
    @Query('profileId')
        String? profileId,
    @Query('cpeCollapsing')
        bool? cpeCollapsing,
    @Query('cpeId')
        String? cpeId,
    @Query('language')
        String? language,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Removes all existing recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdRecordingsDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required DeleteAllParams? body,
  }) {
    return _customersCustomerIdRecordingsDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Removes all existing recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/recordings')
  Future<chopper.Response> _customersCustomerIdRecordingsDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required DeleteAllParams? body,
  });

  ///Patches the customer recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdRecordingsPatch({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required PatchRecordingsParams? body,
  }) {
    return _customersCustomerIdRecordingsPatch(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Patches the customer recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Patch(
    path: '/customers/{customerId}/recordings',
    optionalBody: true,
  )
  Future<chopper.Response> _customersCustomerIdRecordingsPatch({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required PatchRecordingsParams? body,
  });

  ///Get list of contextual recordings (single events/episodes)
  ///@param customerId customer identifier
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<ContextualRecordings>>
      customersCustomerIdRecordingsContextualGet({
    required String? customerId,
    String? profileId,
    String? cpeId,
    String? language,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContextualRecordings, () => ContextualRecordings.fromJsonFactory);

    return _customersCustomerIdRecordingsContextualGet(
        customerId: customerId,
        profileId: profileId,
        cpeId: cpeId,
        language: language,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of contextual recordings (single events/episodes)
  ///@param customerId customer identifier
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/recordings/contextual')
  Future<chopper.Response<ContextualRecordings>>
      _customersCustomerIdRecordingsContextualGet({
    @Path('customerId')
        required String? customerId,
    @Query('profileId')
        String? profileId,
    @Query('cpeId')
        String? cpeId,
    @Query('language')
        String? language,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of simplified recordings for the sole purpose of consuming them by RENG
  ///@param customerId customer identifier
  ///@param status Used to filter the recordings by their status, either 'planned', or 'recorded'.
  ///@param profileId profile identifier - for future use
  ///@param showId Identifier of a show used to return only recordings associated with the given show.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<SimpleRecordings>>
      customersCustomerIdRecordingsSimpleGet({
    required String? customerId,
    enums.CustomersCustomerIdRecordingsSimpleGetStatus? status,
    String? profileId,
    String? showId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimpleRecordings, () => SimpleRecordings.fromJsonFactory);

    return _customersCustomerIdRecordingsSimpleGet(
        customerId: customerId,
        status: status?.value?.toString(),
        profileId: profileId,
        showId: showId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of simplified recordings for the sole purpose of consuming them by RENG
  ///@param customerId customer identifier
  ///@param status Used to filter the recordings by their status, either 'planned', or 'recorded'.
  ///@param profileId profile identifier - for future use
  ///@param showId Identifier of a show used to return only recordings associated with the given show.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/recordings/simple')
  Future<chopper.Response<SimpleRecordings>>
      _customersCustomerIdRecordingsSimpleGet({
    @Path('customerId')
        required String? customerId,
    @Query('status')
        String? status,
    @Query('profileId')
        String? profileId,
    @Query('showId')
        String? showId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get recording state for events, in order to show them in the EPG Grid
  ///@param customerId customer identifier
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param channelIds channelIds which are used to filter only the matching events. If not provided, data for all channels is returned.
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param startTime Used to filter the events, to return only these which are on, or after the startTime.
  ///@param endTime Used to filter the events, to return only these which are before the endTime.
  ///@param User-Agent !Deprecated! Used to filter the parameters, for OESP use "Orion\sOESP/\d.\d.*"
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<EpgRecordingStates>>
      customersCustomerIdRecordingsStateGet({
    required String? customerId,
    bool? isAdult,
    String? channelIds,
    String? cpeId,
    String? startTime,
    String? endTime,
    String? userAgent,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EpgRecordingStates, () => EpgRecordingStates.fromJsonFactory);

    return _customersCustomerIdRecordingsStateGet(
        customerId: customerId,
        isAdult: isAdult,
        channelIds: channelIds,
        cpeId: cpeId,
        startTime: startTime,
        endTime: endTime,
        userAgent: userAgent,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get recording state for events, in order to show them in the EPG Grid
  ///@param customerId customer identifier
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param channelIds channelIds which are used to filter only the matching events. If not provided, data for all channels is returned.
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param startTime Used to filter the events, to return only these which are on, or after the startTime.
  ///@param endTime Used to filter the events, to return only these which are before the endTime.
  ///@param User-Agent !Deprecated! Used to filter the parameters, for OESP use "Orion\sOESP/\d.\d.*"
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/recordings/state')
  Future<chopper.Response<EpgRecordingStates>>
      _customersCustomerIdRecordingsStateGet({
    @Path('customerId')
        required String? customerId,
    @Query('isAdult')
        bool? isAdult,
    @Query('channelIds')
        String? channelIds,
    @Query('cpeId')
        String? cpeId,
    @Query('startTime')
        String? startTime,
    @Query('endTime')
        String? endTime,
    @Header('User-Agent')
        String? userAgent,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Remove specified recorded episode or a single event
  ///@param customerId customer identifier
  ///@param recordingId Identifier of a recorded episode or single event
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response>
      customersCustomerIdRecordingsSingleRecordingIdDelete({
    required String? customerId,
    required String? recordingId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdRecordingsSingleRecordingIdDelete(
        customerId: customerId,
        recordingId: recordingId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Remove specified recorded episode or a single event
  ///@param customerId customer identifier
  ///@param recordingId Identifier of a recorded episode or single event
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/recordings/single/{recordingId}')
  Future<chopper.Response>
      _customersCustomerIdRecordingsSingleRecordingIdDelete({
    @Path('customerId')
        required String? customerId,
    @Path('recordingId')
        required String? recordingId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///!Deprecated! since R4.22. Cancels specified ongoing episode or a single event, operation for delete bookings/single is currently used instead
  ///@param customerId customer identifier
  ///@param recordingId Identifier of a ongoing episode or single event
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response>
      customersCustomerIdRecordingsSingleCancelRecordingIdPut({
    required String? customerId,
    required String? recordingId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdRecordingsSingleCancelRecordingIdPut(
        customerId: customerId,
        recordingId: recordingId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///!Deprecated! since R4.22. Cancels specified ongoing episode or a single event, operation for delete bookings/single is currently used instead
  ///@param customerId customer identifier
  ///@param recordingId Identifier of a ongoing episode or single event
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Put(
    path: '/customers/{customerId}/recordings/single/cancel/{recordingId}',
    optionalBody: true,
  )
  Future<chopper.Response>
      _customersCustomerIdRecordingsSingleCancelRecordingIdPut({
    @Path('customerId')
        required String? customerId,
    @Path('recordingId')
        required String? recordingId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Deletes all past episodes of this season
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdRecordingsSeasonDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required SeasonDeleteParams? body,
  }) {
    return _customersCustomerIdRecordingsSeasonDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Deletes all past episodes of this season
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/recordings/season')
  Future<chopper.Response> _customersCustomerIdRecordingsSeasonDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required SeasonDeleteParams? body,
  });

  ///Get list of the recorded shows. In this endpoint expansionType premiere is returned as fromThisSeason. Expansion type premiere is available in V2
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param channelId Channel identifier
  ///@param showId Show identifier
  ///@param autoDeletionProtected Filter if the show is protected to be autodeleted
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<ShowRecordings>>
      customersCustomerIdRecordingsShowGet({
    required String? customerId,
    String? cpeId,
    String? channelId,
    String? showId,
    bool? autoDeletionProtected,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ShowRecordings, () => ShowRecordings.fromJsonFactory);

    return _customersCustomerIdRecordingsShowGet(
        customerId: customerId,
        cpeId: cpeId,
        channelId: channelId,
        showId: showId,
        autoDeletionProtected: autoDeletionProtected,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of the recorded shows. In this endpoint expansionType premiere is returned as fromThisSeason. Expansion type premiere is available in V2
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param channelId Channel identifier
  ///@param showId Show identifier
  ///@param autoDeletionProtected Filter if the show is protected to be autodeleted
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/recordings/show')
  Future<chopper.Response<ShowRecordings>>
      _customersCustomerIdRecordingsShowGet({
    @Path('customerId')
        required String? customerId,
    @Query('cpeId')
        String? cpeId,
    @Query('channelId')
        String? channelId,
    @Query('showId')
        String? showId,
    @Query('autoDeletionProtected')
        bool? autoDeletionProtected,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Deletes all recorded episodes of this show. This call do not cancel scheduled recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdRecordingsShowDelete({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required ShowDeleteParams? body,
  }) {
    return _customersCustomerIdRecordingsShowDelete(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Deletes all recorded episodes of this show. This call do not cancel scheduled recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/recordings/show')
  Future<chopper.Response> _customersCustomerIdRecordingsShowDelete({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required ShowDeleteParams? body,
  });

  ///Patches the customer recordings from show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdRecordingsShowPatch({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required PatchShowsParams? body,
  }) {
    return _customersCustomerIdRecordingsShowPatch(
        customerId: customerId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Patches the customer recordings from show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Patch(
    path: '/customers/{customerId}/recordings/show',
    optionalBody: true,
  )
  Future<chopper.Response> _customersCustomerIdRecordingsShowPatch({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required PatchShowsParams? body,
  });

  ///Get list of the recorded shows
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param channelId Channel identifier
  ///@param showId Show identifier
  ///@param autoDeletionProtected Filter if the show is protected to be autodeleted
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<ShowRecordings>>
      v2CustomersCustomerIdRecordingsShowGet({
    required String? customerId,
    String? cpeId,
    String? channelId,
    String? showId,
    bool? autoDeletionProtected,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ShowRecordings, () => ShowRecordings.fromJsonFactory);

    return _v2CustomersCustomerIdRecordingsShowGet(
        customerId: customerId,
        cpeId: cpeId,
        channelId: channelId,
        showId: showId,
        autoDeletionProtected: autoDeletionProtected,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of the recorded shows
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param channelId Channel identifier
  ///@param showId Show identifier
  ///@param autoDeletionProtected Filter if the show is protected to be autodeleted
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/v2/customers/{customerId}/recordings/show')
  Future<chopper.Response<ShowRecordings>>
      _v2CustomersCustomerIdRecordingsShowGet({
    @Path('customerId')
        required String? customerId,
    @Query('cpeId')
        String? cpeId,
    @Query('channelId')
        String? channelId,
    @Query('showId')
        String? showId,
    @Query('autoDeletionProtected')
        bool? autoDeletionProtected,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of episodes for a season
  ///@param customerId customer identifier
  ///@param seasonId season idenfifier (CRID)
  ///@param source
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param sort Contains the name of a field which should be used in sorting entities - either time, title or episode.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time or episode is used for sorting
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<Episodes>>
      customersCustomerIdEpisodesSeasonsSeasonIdGet({
    required String? customerId,
    required String? seasonId,
    required enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource? source,
    bool? isAdult,
    int? offset,
    int? limit,
    String? profileId,
    String? cpeId,
    String? language,
    enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort? sort,
    enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder? sortOrder,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Episodes, () => Episodes.fromJsonFactory);

    return _customersCustomerIdEpisodesSeasonsSeasonIdGet(
        customerId: customerId,
        seasonId: seasonId,
        source: source?.value?.toString(),
        isAdult: isAdult,
        offset: offset,
        limit: limit,
        profileId: profileId,
        cpeId: cpeId,
        language: language,
        sort: sort?.value?.toString(),
        sortOrder: sortOrder?.value?.toString(),
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of episodes for a season
  ///@param customerId customer identifier
  ///@param seasonId season idenfifier (CRID)
  ///@param source
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param sort Contains the name of a field which should be used in sorting entities - either time, title or episode.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time or episode is used for sorting
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/episodes/seasons/{seasonId}')
  Future<chopper.Response<Episodes>>
      _customersCustomerIdEpisodesSeasonsSeasonIdGet({
    @Path('customerId')
        required String? customerId,
    @Path('seasonId')
        required String? seasonId,
    @Query('source')
        required String? source,
    @Query('isAdult')
        bool? isAdult,
    @Query('offset')
        int? offset,
    @Query('limit')
        int? limit,
    @Query('profileId')
        String? profileId,
    @Query('cpeId')
        String? cpeId,
    @Query('language')
        String? language,
    @Query('sort')
        String? sort,
    @Query('sortOrder')
        String? sortOrder,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of episodes for a show
  ///@param customerId customer identifier
  ///@param showId show idenfifier (CRID)
  ///@param source
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param profileId profile identifier - for future use
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param channelId Channel identifier
  ///@param sort Contains the name of a field which should be used in sorting entities - either time, title or episode.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time or episode is used for sorting
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<Episodes>> customersCustomerIdEpisodesShowsShowIdGet({
    required String? customerId,
    required String? showId,
    required enums.CustomersCustomerIdEpisodesShowsShowIdGetSource? source,
    bool? isAdult,
    int? offset,
    int? limit,
    String? profileId,
    String? language,
    String? cpeId,
    String? channelId,
    enums.CustomersCustomerIdEpisodesShowsShowIdGetSort? sort,
    enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder? sortOrder,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Episodes, () => Episodes.fromJsonFactory);

    return _customersCustomerIdEpisodesShowsShowIdGet(
        customerId: customerId,
        showId: showId,
        source: source?.value?.toString(),
        isAdult: isAdult,
        offset: offset,
        limit: limit,
        profileId: profileId,
        language: language,
        cpeId: cpeId,
        channelId: channelId,
        sort: sort?.value?.toString(),
        sortOrder: sortOrder?.value?.toString(),
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of episodes for a show
  ///@param customerId customer identifier
  ///@param showId show idenfifier (CRID)
  ///@param source
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param profileId profile identifier - for future use
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param channelId Channel identifier
  ///@param sort Contains the name of a field which should be used in sorting entities - either time, title or episode.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time or episode is used for sorting
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/episodes/shows/{showId}')
  Future<chopper.Response<Episodes>>
      _customersCustomerIdEpisodesShowsShowIdGet({
    @Path('customerId')
        required String? customerId,
    @Path('showId')
        required String? showId,
    @Query('source')
        required String? source,
    @Query('isAdult')
        bool? isAdult,
    @Query('offset')
        int? offset,
    @Query('limit')
        int? limit,
    @Query('profileId')
        String? profileId,
    @Query('language')
        String? language,
    @Query('cpeId')
        String? cpeId,
    @Query('channelId')
        String? channelId,
    @Query('sort')
        String? sort,
    @Query('sortOrder')
        String? sortOrder,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get details of single event or episode
  ///@param customerId customer identifier
  ///@param recordingId episode or single event identifer
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<RecordingDetails>>
      customersCustomerIdDetailsSingleRecordingIdGet({
    required String? customerId,
    required String? recordingId,
    String? profileId,
    String? cpeId,
    String? language,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingDetails, () => RecordingDetails.fromJsonFactory);

    return _customersCustomerIdDetailsSingleRecordingIdGet(
        customerId: customerId,
        recordingId: recordingId,
        profileId: profileId,
        cpeId: cpeId,
        language: language,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get details of single event or episode
  ///@param customerId customer identifier
  ///@param recordingId episode or single event identifer
  ///@param profileId profile identifier - for future use
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/details/single/{recordingId}')
  Future<chopper.Response<RecordingDetails>>
      _customersCustomerIdDetailsSingleRecordingIdGet({
    @Path('customerId')
        required String? customerId,
    @Path('recordingId')
        required String? recordingId,
    @Query('profileId')
        String? profileId,
    @Query('cpeId')
        String? cpeId,
    @Query('language')
        String? language,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get all the recording candidates to be deleted
  ///@param customerId customer identifier
  ///@param cpeId client identifier
  ///@param startTimeFrom Used to filter the records, to return only these which have startTime after startTimeFrom
  ///@param startTimeTo Used to filter the records, to return only these which have startTime before startTimeTo
  ///@param viewState Filter by Viewstate
  ///@param autoDeletionProtected Filter if the *recording* is protected to be autodeleted
  ///@param isAdult
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<Object>> customersCustomerIdRecordingsCleanupGet({
    required String? customerId,
    String? cpeId,
    String? startTimeFrom,
    String? startTimeTo,
    List<enums.ViewState>? viewState,
    bool? autoDeletionProtected,
    bool? isAdult,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdRecordingsCleanupGet(
        customerId: customerId,
        cpeId: cpeId,
        startTimeFrom: startTimeFrom,
        startTimeTo: startTimeTo,
        viewState: viewStateListToJson(viewState),
        autoDeletionProtected: autoDeletionProtected,
        isAdult: isAdult,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get all the recording candidates to be deleted
  ///@param customerId customer identifier
  ///@param cpeId client identifier
  ///@param startTimeFrom Used to filter the records, to return only these which have startTime after startTimeFrom
  ///@param startTimeTo Used to filter the records, to return only these which have startTime before startTimeTo
  ///@param viewState Filter by Viewstate
  ///@param autoDeletionProtected Filter if the *recording* is protected to be autodeleted
  ///@param isAdult
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/recordings/cleanup')
  Future<chopper.Response<Object>> _customersCustomerIdRecordingsCleanupGet({
    @Path('customerId')
        required String? customerId,
    @Query('cpeId')
        String? cpeId,
    @Query('startTimeFrom')
        String? startTimeFrom,
    @Query('startTimeTo')
        String? startTimeTo,
    @Query('viewState')
        List<Object?>? viewState,
    @Query('autoDeletionProtected')
        bool? autoDeletionProtected,
    @Query('isAdult')
        bool? isAdult,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Confirm deletion of list of recordings
  ///@param customerId customer identifier
  ///@param startTimeFrom filter by older then startTime
  ///@param startTimeTo filter by younger then startTime
  ///@param viewState Filter by Viewstate
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response> customersCustomerIdRecordingsCleanupDelete({
    required String? customerId,
    String? startTimeFrom,
    String? startTimeTo,
    List<enums.ViewState>? viewState,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    return _customersCustomerIdRecordingsCleanupDelete(
        customerId: customerId,
        startTimeFrom: startTimeFrom,
        startTimeTo: startTimeTo,
        viewState: viewStateListToJson(viewState),
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Confirm deletion of list of recordings
  ///@param customerId customer identifier
  ///@param startTimeFrom filter by older then startTime
  ///@param startTimeTo filter by younger then startTime
  ///@param viewState Filter by Viewstate
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Delete(path: '/customers/{customerId}/recordings/cleanup')
  Future<chopper.Response> _customersCustomerIdRecordingsCleanupDelete({
    @Path('customerId')
        required String? customerId,
    @Query('startTimeFrom')
        String? startTimeFrom,
    @Query('startTimeTo')
        String? startTimeTo,
    @Query('viewState')
        List<Object?>? viewState,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get a quota limit for a specified customer
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<Quota>> customersCustomerIdQuotaGet({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Quota, () => Quota.fromJsonFactory);

    return _customersCustomerIdQuotaGet(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get a quota limit for a specified customer
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/customers/{customerId}/quota')
  Future<chopper.Response<Quota>> _customersCustomerIdQuotaGet({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Get list of simplified recordings for the sole purpose of consuming them by discovery service
  ///@param customerId customer identifier
  ///@param status Used to filter the recordings by their status, either 'planned', or 'recorded'.
  ///@param showId Identifier of a show used to return only recordings associated with the given show.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<SimpleRecordingsDS>>
      discoveryServiceCustomersCustomerIdRecordingsSimpleGet({
    required String? customerId,
    enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus? status,
    String? showId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimpleRecordingsDS, () => SimpleRecordingsDS.fromJsonFactory);

    return _discoveryServiceCustomersCustomerIdRecordingsSimpleGet(
        customerId: customerId,
        status: status?.value?.toString(),
        showId: showId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of simplified recordings for the sole purpose of consuming them by discovery service
  ///@param customerId customer identifier
  ///@param status Used to filter the recordings by their status, either 'planned', or 'recorded'.
  ///@param showId Identifier of a show used to return only recordings associated with the given show.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/discovery-service/customers/{customerId}/recordings/simple')
  Future<chopper.Response<SimpleRecordingsDS>>
      _discoveryServiceCustomersCustomerIdRecordingsSimpleGet({
    @Path('customerId')
        required String? customerId,
    @Query('status')
        String? status,
    @Query('showId')
        String? showId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Search for recordings for given event ids or group ids or title ids
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  ///@param X-RS-Explicit-Logging If set to 'true', DEBUG level logs from this request will appear as INFO level. Might be helpful for quick debugging.
  Future<chopper.Response<List<SearchRecording>>>
      customersCustomerIdRecordingsSearchPost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xRSExplicitLogging,
    String? cacheControl,
    required SearchParams? body,
  }) {
    generatedMapping.putIfAbsent(
        SearchRecording, () => SearchRecording.fromJsonFactory);

    return _customersCustomerIdRecordingsSearchPost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        xRSExplicitLogging: xRSExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search for recordings for given event ids or group ids or title ids
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  ///@param X-RS-Explicit-Logging If set to 'true', DEBUG level logs from this request will appear as INFO level. Might be helpful for quick debugging.
  @Post(
    path: '/customers/{customerId}/recordings/search',
    optionalBody: true,
  )
  Future<chopper.Response<List<SearchRecording>>>
      _customersCustomerIdRecordingsSearchPost({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-RS-Explicit-Logging')
        String? xRSExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required SearchParams? body,
  });

  ///Search for recordings for given titles or series - for picker service
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  ///@param X-RS-Explicit-Logging If set to 'true', DEBUG level logs from this request will appear as INFO level. Might be helpful for quick debugging.
  Future<chopper.Response<List<SearchRecording>>>
      pickerServiceCustomersCustomerIdRecordingsSearchPost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xRSExplicitLogging,
    String? cacheControl,
    required PickerSearchParams? body,
  }) {
    generatedMapping.putIfAbsent(
        SearchRecording, () => SearchRecording.fromJsonFactory);

    return _pickerServiceCustomersCustomerIdRecordingsSearchPost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        xRSExplicitLogging: xRSExplicitLogging,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search for recordings for given titles or series - for picker service
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  ///@param X-RS-Explicit-Logging If set to 'true', DEBUG level logs from this request will appear as INFO level. Might be helpful for quick debugging.
  @Post(
    path: '/picker-service/customers/{customerId}/recordings/search',
    optionalBody: true,
  )
  Future<chopper.Response<List<SearchRecording>>>
      _pickerServiceCustomersCustomerIdRecordingsSearchPost({
    @Path('customerId')
        required String? customerId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-RS-Explicit-Logging')
        String? xRSExplicitLogging,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required PickerSearchParams? body,
  });

  ///Get list of recordings for the sole purpose of consuming them by inspection service
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param startTime Used to filter the events, to return only these which are on, or after the startTime.
  ///@param endTime Used to filter the events, to return only these which are before the endTime.
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<RecordingsIS>>
      inspectionServiceCustomersCustomerIdRecordingsGet({
    required String? customerId,
    String? cpeId,
    bool? isAdult,
    String? startTime,
    String? endTime,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingsIS, () => RecordingsIS.fromJsonFactory);

    return _inspectionServiceCustomersCustomerIdRecordingsGet(
        customerId: customerId,
        cpeId: cpeId,
        isAdult: isAdult,
        startTime: startTime,
        endTime: endTime,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Get list of recordings for the sole purpose of consuming them by inspection service
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier is only available for LDVR.
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param startTime Used to filter the events, to return only these which are on, or after the startTime.
  ///@param endTime Used to filter the events, to return only these which are before the endTime.
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/inspection-service/customers/{customerId}/recordings')
  Future<chopper.Response<RecordingsIS>>
      _inspectionServiceCustomersCustomerIdRecordingsGet({
    @Path('customerId')
        required String? customerId,
    @Query('cpeId')
        String? cpeId,
    @Query('isAdult')
        bool? isAdult,
    @Query('startTime')
        String? startTime,
    @Query('endTime')
        String? endTime,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Endpoint to retrieve recordings data for personal home service
  ///@param customerId Customer Identifier
  ///@param limit Used to limit the amount of results returned
  ///@param language Used to return the data in a given language
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<RecordingPHS>>
      personalHomeServiceCustomersCustomerIdRecordingsGet({
    required String? customerId,
    int? limit,
    String? language,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingPHS, () => RecordingPHS.fromJsonFactory);

    return _personalHomeServiceCustomersCustomerIdRecordingsGet(
        customerId: customerId,
        limit: limit,
        language: language,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Endpoint to retrieve recordings data for personal home service
  ///@param customerId Customer Identifier
  ///@param limit Used to limit the amount of results returned
  ///@param language Used to return the data in a given language
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  @Get(path: '/personal-home-service/customers/{customerId}/recordings')
  Future<chopper.Response<RecordingPHS>>
      _personalHomeServiceCustomersCustomerIdRecordingsGet({
    @Path('customerId')
        required String? customerId,
    @Query('limit')
        int? limit,
    @Query('language')
        String? language,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class SingleBookingParams {
  SingleBookingParams({
    required this.eventId,
    this.retentionLimit,
    this.autoDeletionProtected,
  });

  factory SingleBookingParams.fromJson(Map<String, dynamic> json) =>
      _$SingleBookingParamsFromJson(json);

  static const toJsonFactory = _$SingleBookingParamsToJson;
  Map<String, dynamic> toJson() => _$SingleBookingParamsToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  static const fromJsonFactory = _$SingleBookingParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SingleBookingParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      runtimeType.hashCode;
}

extension $SingleBookingParamsExtension on SingleBookingParams {
  SingleBookingParams copyWith(
      {String? eventId, int? retentionLimit, bool? autoDeletionProtected}) {
    return SingleBookingParams(
        eventId: eventId ?? this.eventId,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected);
  }

  SingleBookingParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<int?>? retentionLimit,
      Wrapped<bool?>? autoDeletionProtected}) {
    return SingleBookingParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowBookingParams {
  ShowBookingParams({
    required this.eventId,
    required this.channelId,
    this.retentionLimit,
    this.maxEpisodes,
    this.replayRecordingsFrom,
    this.autoDeletionProtected,
    this.expansionType,
  });

  factory ShowBookingParams.fromJson(Map<String, dynamic> json) =>
      _$ShowBookingParamsFromJson(json);

  static const toJsonFactory = _$ShowBookingParamsToJson;
  Map<String, dynamic> toJson() => _$ShowBookingParamsToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'replayRecordingsFrom', includeIfNull: false)
  final DateTime? replayRecordingsFrom;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  static const fromJsonFactory = _$ShowBookingParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowBookingParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.replayRecordingsFrom, replayRecordingsFrom) ||
                const DeepCollectionEquality().equals(
                    other.replayRecordingsFrom, replayRecordingsFrom)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(replayRecordingsFrom) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(expansionType) ^
      runtimeType.hashCode;
}

extension $ShowBookingParamsExtension on ShowBookingParams {
  ShowBookingParams copyWith(
      {String? eventId,
      String? channelId,
      int? retentionLimit,
      int? maxEpisodes,
      DateTime? replayRecordingsFrom,
      bool? autoDeletionProtected,
      enums.ExpansionType? expansionType}) {
    return ShowBookingParams(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        replayRecordingsFrom: replayRecordingsFrom ?? this.replayRecordingsFrom,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        expansionType: expansionType ?? this.expansionType);
  }

  ShowBookingParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<int?>? retentionLimit,
      Wrapped<int?>? maxEpisodes,
      Wrapped<DateTime?>? replayRecordingsFrom,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<enums.ExpansionType?>? expansionType}) {
    return ShowBookingParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        replayRecordingsFrom: (replayRecordingsFrom != null
            ? replayRecordingsFrom.value
            : this.replayRecordingsFrom),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowDeleteParams {
  ShowDeleteParams({
    required this.showId,
    required this.channelId,
  });

  factory ShowDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$ShowDeleteParamsFromJson(json);

  static const toJsonFactory = _$ShowDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$ShowDeleteParamsToJson(this);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  static const fromJsonFactory = _$ShowDeleteParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowDeleteParams &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $ShowDeleteParamsExtension on ShowDeleteParams {
  ShowDeleteParams copyWith({String? showId, String? channelId}) {
    return ShowDeleteParams(
        showId: showId ?? this.showId, channelId: channelId ?? this.channelId);
  }

  ShowDeleteParams copyWithWrapped(
      {Wrapped<String>? showId, Wrapped<String>? channelId}) {
    return ShowDeleteParams(
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class EventDeleteParams {
  EventDeleteParams({
    required this.eventId,
  });

  factory EventDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$EventDeleteParamsFromJson(json);

  static const toJsonFactory = _$EventDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$EventDeleteParamsToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  static const fromJsonFactory = _$EventDeleteParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventDeleteParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality().equals(other.eventId, eventId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^ runtimeType.hashCode;
}

extension $EventDeleteParamsExtension on EventDeleteParams {
  EventDeleteParams copyWith({String? eventId}) {
    return EventDeleteParams(eventId: eventId ?? this.eventId);
  }

  EventDeleteParams copyWithWrapped({Wrapped<String>? eventId}) {
    return EventDeleteParams(
        eventId: (eventId != null ? eventId.value : this.eventId));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteAllParams {
  DeleteAllParams({
    this.events,
    this.shows,
  });

  factory DeleteAllParams.fromJson(Map<String, dynamic> json) =>
      _$DeleteAllParamsFromJson(json);

  static const toJsonFactory = _$DeleteAllParamsToJson;
  Map<String, dynamic> toJson() => _$DeleteAllParamsToJson(this);

  @JsonKey(
      name: 'events', includeIfNull: false, defaultValue: <EventDeleteParams>[])
  final List<EventDeleteParams>? events;
  @JsonKey(
      name: 'shows', includeIfNull: false, defaultValue: <ShowDeleteParams>[])
  final List<ShowDeleteParams>? shows;
  static const fromJsonFactory = _$DeleteAllParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteAllParams &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)) &&
            (identical(other.shows, shows) ||
                const DeepCollectionEquality().equals(other.shows, shows)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(events) ^
      const DeepCollectionEquality().hash(shows) ^
      runtimeType.hashCode;
}

extension $DeleteAllParamsExtension on DeleteAllParams {
  DeleteAllParams copyWith(
      {List<EventDeleteParams>? events, List<ShowDeleteParams>? shows}) {
    return DeleteAllParams(
        events: events ?? this.events, shows: shows ?? this.shows);
  }

  DeleteAllParams copyWithWrapped(
      {Wrapped<List<EventDeleteParams>?>? events,
      Wrapped<List<ShowDeleteParams>?>? shows}) {
    return DeleteAllParams(
        events: (events != null ? events.value : this.events),
        shows: (shows != null ? shows.value : this.shows));
  }
}

@JsonSerializable(explicitToJson: true)
class SeasonDeleteParams {
  SeasonDeleteParams({
    required this.seasonId,
    required this.channelId,
  });

  factory SeasonDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$SeasonDeleteParamsFromJson(json);

  static const toJsonFactory = _$SeasonDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$SeasonDeleteParamsToJson(this);

  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String seasonId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  static const fromJsonFactory = _$SeasonDeleteParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeasonDeleteParams &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $SeasonDeleteParamsExtension on SeasonDeleteParams {
  SeasonDeleteParams copyWith({String? seasonId, String? channelId}) {
    return SeasonDeleteParams(
        seasonId: seasonId ?? this.seasonId,
        channelId: channelId ?? this.channelId);
  }

  SeasonDeleteParams copyWithWrapped(
      {Wrapped<String>? seasonId, Wrapped<String>? channelId}) {
    return SeasonDeleteParams(
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class PatchRecordingsParams {
  PatchRecordingsParams({
    required this.op,
    required this.events,
  });

  factory PatchRecordingsParams.fromJson(Map<String, dynamic> json) =>
      _$PatchRecordingsParamsFromJson(json);

  static const toJsonFactory = _$PatchRecordingsParamsToJson;
  Map<String, dynamic> toJson() => _$PatchRecordingsParamsToJson(this);

  @JsonKey(
    name: 'op',
    includeIfNull: false,
    toJson: opToJson,
    fromJson: opFromJson,
  )
  final enums.Op op;
  @JsonKey(
      name: 'events', includeIfNull: false, defaultValue: <PatchEventParam>[])
  final List<PatchEventParam> events;
  static const fromJsonFactory = _$PatchRecordingsParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PatchRecordingsParams &&
            (identical(other.op, op) ||
                const DeepCollectionEquality().equals(other.op, op)) &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(op) ^
      const DeepCollectionEquality().hash(events) ^
      runtimeType.hashCode;
}

extension $PatchRecordingsParamsExtension on PatchRecordingsParams {
  PatchRecordingsParams copyWith(
      {enums.Op? op, List<PatchEventParam>? events}) {
    return PatchRecordingsParams(
        op: op ?? this.op, events: events ?? this.events);
  }

  PatchRecordingsParams copyWithWrapped(
      {Wrapped<enums.Op>? op, Wrapped<List<PatchEventParam>>? events}) {
    return PatchRecordingsParams(
        op: (op != null ? op.value : this.op),
        events: (events != null ? events.value : this.events));
  }
}

@JsonSerializable(explicitToJson: true)
class PatchShowsParams {
  PatchShowsParams({
    required this.op,
    required this.shows,
  });

  factory PatchShowsParams.fromJson(Map<String, dynamic> json) =>
      _$PatchShowsParamsFromJson(json);

  static const toJsonFactory = _$PatchShowsParamsToJson;
  Map<String, dynamic> toJson() => _$PatchShowsParamsToJson(this);

  @JsonKey(
    name: 'op',
    includeIfNull: false,
    toJson: opToJson,
    fromJson: opFromJson,
  )
  final enums.Op op;
  @JsonKey(
      name: 'shows', includeIfNull: false, defaultValue: <PatchShowParam>[])
  final List<PatchShowParam> shows;
  static const fromJsonFactory = _$PatchShowsParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PatchShowsParams &&
            (identical(other.op, op) ||
                const DeepCollectionEquality().equals(other.op, op)) &&
            (identical(other.shows, shows) ||
                const DeepCollectionEquality().equals(other.shows, shows)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(op) ^
      const DeepCollectionEquality().hash(shows) ^
      runtimeType.hashCode;
}

extension $PatchShowsParamsExtension on PatchShowsParams {
  PatchShowsParams copyWith({enums.Op? op, List<PatchShowParam>? shows}) {
    return PatchShowsParams(op: op ?? this.op, shows: shows ?? this.shows);
  }

  PatchShowsParams copyWithWrapped(
      {Wrapped<enums.Op>? op, Wrapped<List<PatchShowParam>>? shows}) {
    return PatchShowsParams(
        op: (op != null ? op.value : this.op),
        shows: (shows != null ? shows.value : this.shows));
  }
}

@JsonSerializable(explicitToJson: true)
class PatchEventParam {
  PatchEventParam({
    required this.eventId,
    this.retentionPeriod,
    this.autoDeletionProtected,
  });

  factory PatchEventParam.fromJson(Map<String, dynamic> json) =>
      _$PatchEventParamFromJson(json);

  static const toJsonFactory = _$PatchEventParamToJson;
  Map<String, dynamic> toJson() => _$PatchEventParamToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  static const fromJsonFactory = _$PatchEventParamFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PatchEventParam &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      runtimeType.hashCode;
}

extension $PatchEventParamExtension on PatchEventParam {
  PatchEventParam copyWith(
      {String? eventId, int? retentionPeriod, bool? autoDeletionProtected}) {
    return PatchEventParam(
        eventId: eventId ?? this.eventId,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected);
  }

  PatchEventParam copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected}) {
    return PatchEventParam(
        eventId: (eventId != null ? eventId.value : this.eventId),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected));
  }
}

@JsonSerializable(explicitToJson: true)
class PatchShowParam {
  PatchShowParam({
    required this.showId,
    required this.channelId,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.expansionType,
    this.maxEpisodes,
    this.replayRecordingsFrom,
  });

  factory PatchShowParam.fromJson(Map<String, dynamic> json) =>
      _$PatchShowParamFromJson(json);

  static const toJsonFactory = _$PatchShowParamToJson;
  Map<String, dynamic> toJson() => _$PatchShowParamToJson(this);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'replayRecordingsFrom', includeIfNull: false)
  final DateTime? replayRecordingsFrom;
  static const fromJsonFactory = _$PatchShowParamFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PatchShowParam &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.replayRecordingsFrom, replayRecordingsFrom) ||
                const DeepCollectionEquality()
                    .equals(other.replayRecordingsFrom, replayRecordingsFrom)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(replayRecordingsFrom) ^
      runtimeType.hashCode;
}

extension $PatchShowParamExtension on PatchShowParam {
  PatchShowParam copyWith(
      {String? showId,
      String? channelId,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      enums.ExpansionType? expansionType,
      int? maxEpisodes,
      DateTime? replayRecordingsFrom}) {
    return PatchShowParam(
        showId: showId ?? this.showId,
        channelId: channelId ?? this.channelId,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        expansionType: expansionType ?? this.expansionType,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        replayRecordingsFrom:
            replayRecordingsFrom ?? this.replayRecordingsFrom);
  }

  PatchShowParam copyWithWrapped(
      {Wrapped<String>? showId,
      Wrapped<String>? channelId,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? maxEpisodes,
      Wrapped<DateTime?>? replayRecordingsFrom}) {
    return PatchShowParam(
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        replayRecordingsFrom: (replayRecordingsFrom != null
            ? replayRecordingsFrom.value
            : this.replayRecordingsFrom));
  }
}

@JsonSerializable(explicitToJson: true)
class Quota {
  Quota({
    this.quota,
    this.occupied,
  });

  factory Quota.fromJson(Map<String, dynamic> json) => _$QuotaFromJson(json);

  static const toJsonFactory = _$QuotaToJson;
  Map<String, dynamic> toJson() => _$QuotaToJson(this);

  @JsonKey(name: 'quota', includeIfNull: false)
  final int? quota;
  @JsonKey(name: 'occupied', includeIfNull: false)
  final int? occupied;
  static const fromJsonFactory = _$QuotaFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Quota &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.occupied, occupied) ||
                const DeepCollectionEquality()
                    .equals(other.occupied, occupied)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(occupied) ^
      runtimeType.hashCode;
}

extension $QuotaExtension on Quota {
  Quota copyWith({int? quota, int? occupied}) {
    return Quota(
        quota: quota ?? this.quota, occupied: occupied ?? this.occupied);
  }

  Quota copyWithWrapped({Wrapped<int?>? quota, Wrapped<int?>? occupied}) {
    return Quota(
        quota: (quota != null ? quota.value : this.quota),
        occupied: (occupied != null ? occupied.value : this.occupied));
  }
}

@JsonSerializable(explicitToJson: true)
class ContextualRecordings {
  ContextualRecordings({
    required this.total,
    required this.data,
  });

  factory ContextualRecordings.fromJson(Map<String, dynamic> json) =>
      _$ContextualRecordingsFromJson(json);

  static const toJsonFactory = _$ContextualRecordingsToJson;
  Map<String, dynamic> toJson() => _$ContextualRecordingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <ContextualRecording>[])
  final List<ContextualRecording> data;
  static const fromJsonFactory = _$ContextualRecordingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContextualRecordings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $ContextualRecordingsExtension on ContextualRecordings {
  ContextualRecordings copyWith({int? total, List<ContextualRecording>? data}) {
    return ContextualRecordings(
        total: total ?? this.total, data: data ?? this.data);
  }

  ContextualRecordings copyWithWrapped(
      {Wrapped<int>? total, Wrapped<List<ContextualRecording>>? data}) {
    return ContextualRecordings(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class Recordings {
  Recordings({
    this.total,
    required this.size,
    this.quota,
    required this.data,
  });

  factory Recordings.fromJson(Map<String, dynamic> json) =>
      _$RecordingsFromJson(json);

  static const toJsonFactory = _$RecordingsToJson;
  Map<String, dynamic> toJson() => _$RecordingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(name: 'quota', includeIfNull: false)
  final Quota? quota;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <Recording>[])
  final List<Recording> data;
  static const fromJsonFactory = _$RecordingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Recordings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $RecordingsExtension on Recordings {
  Recordings copyWith(
      {int? total, int? size, Quota? quota, List<Recording>? data}) {
    return Recordings(
        total: total ?? this.total,
        size: size ?? this.size,
        quota: quota ?? this.quota,
        data: data ?? this.data);
  }

  Recordings copyWithWrapped(
      {Wrapped<int?>? total,
      Wrapped<int>? size,
      Wrapped<Quota?>? quota,
      Wrapped<List<Recording>>? data}) {
    return Recordings(
        total: (total != null ? total.value : this.total),
        size: (size != null ? size.value : this.size),
        quota: (quota != null ? quota.value : this.quota),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class Recording {
  Recording({
    required this.id,
    this.title,
    this.type,
    this.seasons,
    this.noOfEpisodes,
    required this.channelId,
    this.startTime,
    this.endTime,
    this.recordingState,
    this.privateCopy,
    this.viewState,
    this.bookmark,
    this.duration,
    this.technicalDuration,
    this.expirationDate,
    this.showId,
    this.mostRelevantEpisode,
    this.episodeNumber,
    this.seasonNumber,
    this.episodeTitle,
    this.seasonTitle,
    this.source,
    this.poster,
    this.minimumAge,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.failureReason,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.restrictCpeStreaming,
    this.ottMarkers,
    this.ottPaddingsBlackout,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.imageVersion,
    this.isOttBlackout,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.isSplitProgram,
    this.episodePart,
    this.effectiveContentDuration,
  });

  factory Recording.fromJson(Map<String, dynamic> json) =>
      _$RecordingFromJson(json);

  static const toJsonFactory = _$RecordingToJson;
  Map<String, dynamic> toJson() => _$RecordingToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: itemTypeToJson,
    fromJson: itemTypeFromJson,
  )
  final enums.ItemType? type;
  @JsonKey(name: 'seasons', includeIfNull: false, defaultValue: <Season>[])
  final List<Season>? seasons;
  @JsonKey(name: 'noOfEpisodes', includeIfNull: false)
  final int? noOfEpisodes;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'privateCopy', includeIfNull: false)
  final bool? privateCopy;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false)
  final MostRelevantEpisodeForRecording? mostRelevantEpisode;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'seasonTitle', includeIfNull: false, defaultValue: '')
  final String? seasonTitle;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(name: 'poster', includeIfNull: false)
  final Image? poster;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'ottMarkers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ottMarkers;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool? ottPaddingsBlackout;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$RecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Recording &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.noOfEpisodes, noOfEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.noOfEpisodes, noOfEpisodes)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.privateCopy, privateCopy) ||
                const DeepCollectionEquality()
                    .equals(other.privateCopy, privateCopy)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.seasonTitle, seasonTitle) ||
                const DeepCollectionEquality()
                    .equals(other.seasonTitle, seasonTitle)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality().equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) || const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) || const DeepCollectionEquality().equals(other.recordingType, recordingType)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.ottMarkers, ottMarkers) || const DeepCollectionEquality().equals(other.ottMarkers, ottMarkers)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isOttBlackout, isOttBlackout) || const DeepCollectionEquality().equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(noOfEpisodes) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(privateCopy) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(seasonTitle) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(ottMarkers) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $RecordingExtension on Recording {
  Recording copyWith(
      {String? id,
      String? title,
      enums.ItemType? type,
      List<Season>? seasons,
      int? noOfEpisodes,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      enums.RecordingState? recordingState,
      bool? privateCopy,
      enums.ViewState? viewState,
      int? bookmark,
      int? duration,
      int? technicalDuration,
      DateTime? expirationDate,
      String? showId,
      MostRelevantEpisodeForRecording? mostRelevantEpisode,
      int? episodeNumber,
      int? seasonNumber,
      String? episodeTitle,
      String? seasonTitle,
      enums.SourceType? source,
      Image? poster,
      int? minimumAge,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      enums.FailureReason? failureReason,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      bool? restrictCpeStreaming,
      List<String>? ottMarkers,
      bool? ottPaddingsBlackout,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      String? imageVersion,
      bool? isOttBlackout,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      bool? isSplitProgram,
      int? episodePart,
      int? effectiveContentDuration}) {
    return Recording(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        seasons: seasons ?? this.seasons,
        noOfEpisodes: noOfEpisodes ?? this.noOfEpisodes,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        recordingState: recordingState ?? this.recordingState,
        privateCopy: privateCopy ?? this.privateCopy,
        viewState: viewState ?? this.viewState,
        bookmark: bookmark ?? this.bookmark,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        expirationDate: expirationDate ?? this.expirationDate,
        showId: showId ?? this.showId,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        seasonTitle: seasonTitle ?? this.seasonTitle,
        source: source ?? this.source,
        poster: poster ?? this.poster,
        minimumAge: minimumAge ?? this.minimumAge,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        failureReason: failureReason ?? this.failureReason,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        ottMarkers: ottMarkers ?? this.ottMarkers,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        imageVersion: imageVersion ?? this.imageVersion,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodePart: episodePart ?? this.episodePart,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  Recording copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? title,
      Wrapped<enums.ItemType?>? type,
      Wrapped<List<Season>?>? seasons,
      Wrapped<int?>? noOfEpisodes,
      Wrapped<String>? channelId,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<bool?>? privateCopy,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<int?>? bookmark,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<String?>? showId,
      Wrapped<MostRelevantEpisodeForRecording?>? mostRelevantEpisode,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? episodeTitle,
      Wrapped<String?>? seasonTitle,
      Wrapped<enums.SourceType?>? source,
      Wrapped<Image?>? poster,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<List<String>?>? ottMarkers,
      Wrapped<bool?>? ottPaddingsBlackout,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? effectiveContentDuration}) {
    return Recording(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        seasons: (seasons != null ? seasons.value : this.seasons),
        noOfEpisodes:
            (noOfEpisodes != null ? noOfEpisodes.value : this.noOfEpisodes),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        privateCopy:
            (privateCopy != null ? privateCopy.value : this.privateCopy),
        viewState: (viewState != null ? viewState.value : this.viewState),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        showId: (showId != null ? showId.value : this.showId),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        seasonTitle:
            (seasonTitle != null ? seasonTitle.value : this.seasonTitle),
        source: (source != null ? source.value : this.source),
        poster: (poster != null ? poster.value : this.poster),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        ottMarkers: (ottMarkers != null ? ottMarkers.value : this.ottMarkers),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleRecordings {
  SimpleRecordings({
    required this.total,
    required this.data,
  });

  factory SimpleRecordings.fromJson(Map<String, dynamic> json) =>
      _$SimpleRecordingsFromJson(json);

  static const toJsonFactory = _$SimpleRecordingsToJson;
  Map<String, dynamic> toJson() => _$SimpleRecordingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <SimpleRecording>[])
  final List<SimpleRecording> data;
  static const fromJsonFactory = _$SimpleRecordingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleRecordings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $SimpleRecordingsExtension on SimpleRecordings {
  SimpleRecordings copyWith({int? total, List<SimpleRecording>? data}) {
    return SimpleRecordings(
        total: total ?? this.total, data: data ?? this.data);
  }

  SimpleRecordings copyWithWrapped(
      {Wrapped<int>? total, Wrapped<List<SimpleRecording>>? data}) {
    return SimpleRecordings(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleRecording {
  SimpleRecording({
    required this.recordingId,
    required this.title,
    required this.recordingState,
    this.seriesId,
    required this.channelId,
    this.channelBasedAuthorization,
    this.restricted,
    this.isPremiere,
  });

  factory SimpleRecording.fromJson(Map<String, dynamic> json) =>
      _$SimpleRecordingFromJson(json);

  static const toJsonFactory = _$SimpleRecordingToJson;
  Map<String, dynamic> toJson() => _$SimpleRecordingToJson(this);

  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String recordingId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  static const fromJsonFactory = _$SimpleRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleRecording &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelBasedAuthorization,
                    channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.isPremiere, isPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.isPremiere, isPremiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      runtimeType.hashCode;
}

extension $SimpleRecordingExtension on SimpleRecording {
  SimpleRecording copyWith(
      {String? recordingId,
      String? title,
      enums.RecordingState? recordingState,
      String? seriesId,
      String? channelId,
      bool? channelBasedAuthorization,
      bool? restricted,
      bool? isPremiere}) {
    return SimpleRecording(
        recordingId: recordingId ?? this.recordingId,
        title: title ?? this.title,
        recordingState: recordingState ?? this.recordingState,
        seriesId: seriesId ?? this.seriesId,
        channelId: channelId ?? this.channelId,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        isPremiere: isPremiere ?? this.isPremiere);
  }

  SimpleRecording copyWithWrapped(
      {Wrapped<String>? recordingId,
      Wrapped<String>? title,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<String?>? seriesId,
      Wrapped<String>? channelId,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? isPremiere}) {
    return SimpleRecording(
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        title: (title != null ? title.value : this.title),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowRecording {
  ShowRecording({
    required this.showId,
    required this.channelId,
    this.cpeId,
    this.seasonNumber,
    this.episodeNumber,
    this.recordingType,
    this.expansionType,
    this.prePadding,
    this.postPadding,
    this.maxEpisodes,
    this.autoDeletionProtected,
    this.retentionPeriod,
    this.seedEventId,
    this.seedStartTime,
    this.seedPartNumber,
  });

  factory ShowRecording.fromJson(Map<String, dynamic> json) =>
      _$ShowRecordingFromJson(json);

  static const toJsonFactory = _$ShowRecordingToJson;
  Map<String, dynamic> toJson() => _$ShowRecordingToJson(this);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'seedEventId', includeIfNull: false, defaultValue: '')
  final String? seedEventId;
  @JsonKey(name: 'seedStartTime', includeIfNull: false)
  final DateTime? seedStartTime;
  @JsonKey(name: 'seedPartNumber', includeIfNull: false)
  final int? seedPartNumber;
  static const fromJsonFactory = _$ShowRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowRecording &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.seedEventId, seedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.seedEventId, seedEventId)) &&
            (identical(other.seedStartTime, seedStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.seedStartTime, seedStartTime)) &&
            (identical(other.seedPartNumber, seedPartNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seedPartNumber, seedPartNumber)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(seedEventId) ^
      const DeepCollectionEquality().hash(seedStartTime) ^
      const DeepCollectionEquality().hash(seedPartNumber) ^
      runtimeType.hashCode;
}

extension $ShowRecordingExtension on ShowRecording {
  ShowRecording copyWith(
      {String? showId,
      String? channelId,
      String? cpeId,
      int? seasonNumber,
      int? episodeNumber,
      enums.RecordingType? recordingType,
      enums.ExpansionType? expansionType,
      int? prePadding,
      int? postPadding,
      int? maxEpisodes,
      bool? autoDeletionProtected,
      int? retentionPeriod,
      String? seedEventId,
      DateTime? seedStartTime,
      int? seedPartNumber}) {
    return ShowRecording(
        showId: showId ?? this.showId,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        recordingType: recordingType ?? this.recordingType,
        expansionType: expansionType ?? this.expansionType,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        seedEventId: seedEventId ?? this.seedEventId,
        seedStartTime: seedStartTime ?? this.seedStartTime,
        seedPartNumber: seedPartNumber ?? this.seedPartNumber);
  }

  ShowRecording copyWithWrapped(
      {Wrapped<String>? showId,
      Wrapped<String>? channelId,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<int?>? maxEpisodes,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<int?>? retentionPeriod,
      Wrapped<String?>? seedEventId,
      Wrapped<DateTime?>? seedStartTime,
      Wrapped<int?>? seedPartNumber}) {
    return ShowRecording(
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        seedEventId:
            (seedEventId != null ? seedEventId.value : this.seedEventId),
        seedStartTime:
            (seedStartTime != null ? seedStartTime.value : this.seedStartTime),
        seedPartNumber: (seedPartNumber != null
            ? seedPartNumber.value
            : this.seedPartNumber));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowRecordings {
  ShowRecordings({
    required this.total,
    required this.data,
  });

  factory ShowRecordings.fromJson(Map<String, dynamic> json) =>
      _$ShowRecordingsFromJson(json);

  static const toJsonFactory = _$ShowRecordingsToJson;
  Map<String, dynamic> toJson() => _$ShowRecordingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <ShowRecording>[])
  final List<ShowRecording> data;
  static const fromJsonFactory = _$ShowRecordingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowRecordings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $ShowRecordingsExtension on ShowRecordings {
  ShowRecordings copyWith({int? total, List<ShowRecording>? data}) {
    return ShowRecordings(total: total ?? this.total, data: data ?? this.data);
  }

  ShowRecordings copyWithWrapped(
      {Wrapped<int>? total, Wrapped<List<ShowRecording>>? data}) {
    return ShowRecordings(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleRecordingsDS {
  SimpleRecordingsDS({
    required this.total,
    required this.data,
  });

  factory SimpleRecordingsDS.fromJson(Map<String, dynamic> json) =>
      _$SimpleRecordingsDSFromJson(json);

  static const toJsonFactory = _$SimpleRecordingsDSToJson;
  Map<String, dynamic> toJson() => _$SimpleRecordingsDSToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <SimpleRecordingDS>[])
  final List<SimpleRecordingDS> data;
  static const fromJsonFactory = _$SimpleRecordingsDSFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleRecordingsDS &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $SimpleRecordingsDSExtension on SimpleRecordingsDS {
  SimpleRecordingsDS copyWith({int? total, List<SimpleRecordingDS>? data}) {
    return SimpleRecordingsDS(
        total: total ?? this.total, data: data ?? this.data);
  }

  SimpleRecordingsDS copyWithWrapped(
      {Wrapped<int>? total, Wrapped<List<SimpleRecordingDS>>? data}) {
    return SimpleRecordingsDS(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleRecordingDS {
  SimpleRecordingDS({
    required this.recordingId,
    required this.title,
    required this.recordingState,
    this.seasonId,
    this.seriesId,
    required this.technicalDuration,
    this.minimumAge,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.channelBasedAuthorization,
    this.restricted,
  });

  factory SimpleRecordingDS.fromJson(Map<String, dynamic> json) =>
      _$SimpleRecordingDSFromJson(json);

  static const toJsonFactory = _$SimpleRecordingDSToJson;
  Map<String, dynamic> toJson() => _$SimpleRecordingDSToJson(this);

  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String recordingId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int technicalDuration;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  static const fromJsonFactory = _$SimpleRecordingDSFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleRecordingDS &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.channelBasedAuthorization,
                    channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      runtimeType.hashCode;
}

extension $SimpleRecordingDSExtension on SimpleRecordingDS {
  SimpleRecordingDS copyWith(
      {String? recordingId,
      String? title,
      enums.RecordingState? recordingState,
      String? seasonId,
      String? seriesId,
      int? technicalDuration,
      int? minimumAge,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      bool? channelBasedAuthorization,
      bool? restricted}) {
    return SimpleRecordingDS(
        recordingId: recordingId ?? this.recordingId,
        title: title ?? this.title,
        recordingState: recordingState ?? this.recordingState,
        seasonId: seasonId ?? this.seasonId,
        seriesId: seriesId ?? this.seriesId,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        minimumAge: minimumAge ?? this.minimumAge,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted);
  }

  SimpleRecordingDS copyWithWrapped(
      {Wrapped<String>? recordingId,
      Wrapped<String>? title,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seriesId,
      Wrapped<int>? technicalDuration,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted}) {
    return SimpleRecordingDS(
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        title: (title != null ? title.value : this.title),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingsIS {
  RecordingsIS({
    required this.total,
    required this.data,
    required this.isAdultContentAvailable,
  });

  factory RecordingsIS.fromJson(Map<String, dynamic> json) =>
      _$RecordingsISFromJson(json);

  static const toJsonFactory = _$RecordingsISToJson;
  Map<String, dynamic> toJson() => _$RecordingsISToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <RecordingIS>[])
  final List<RecordingIS> data;
  @JsonKey(name: 'isAdultContentAvailable', includeIfNull: false)
  final bool isAdultContentAvailable;
  static const fromJsonFactory = _$RecordingsISFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingsIS &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(
                    other.isAdultContentAvailable, isAdultContentAvailable) ||
                const DeepCollectionEquality().equals(
                    other.isAdultContentAvailable, isAdultContentAvailable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(isAdultContentAvailable) ^
      runtimeType.hashCode;
}

extension $RecordingsISExtension on RecordingsIS {
  RecordingsIS copyWith(
      {int? total, List<RecordingIS>? data, bool? isAdultContentAvailable}) {
    return RecordingsIS(
        total: total ?? this.total,
        data: data ?? this.data,
        isAdultContentAvailable:
            isAdultContentAvailable ?? this.isAdultContentAvailable);
  }

  RecordingsIS copyWithWrapped(
      {Wrapped<int>? total,
      Wrapped<List<RecordingIS>>? data,
      Wrapped<bool>? isAdultContentAvailable}) {
    return RecordingsIS(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data),
        isAdultContentAvailable: (isAdultContentAvailable != null
            ? isAdultContentAvailable.value
            : this.isAdultContentAvailable));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingIS {
  RecordingIS({
    required this.id,
    this.source,
    this.recordingState,
    this.cpeId,
    this.isAdult,
    this.startTime,
    this.endTime,
    this.recStartTime,
    this.recEndTime,
    this.expirationDate,
    this.showId,
    this.title,
    this.channelId,
    this.originDeviceId,
    this.failureReason,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.seasonNumber,
    this.episodeNumber,
    this.seasonName,
    this.showName,
    this.bookingTime,
    this.isPremiere,
    this.episodePart,
  });

  factory RecordingIS.fromJson(Map<String, dynamic> json) =>
      _$RecordingISFromJson(json);

  static const toJsonFactory = _$RecordingISToJson;
  Map<String, dynamic> toJson() => _$RecordingISToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStatePendingToJson,
    fromJson: recordingStatePendingFromJson,
  )
  final enums.RecordingStatePending? recordingState;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'originDeviceId', includeIfNull: false, defaultValue: '')
  final String? originDeviceId;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  static const fromJsonFactory = _$RecordingISFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingIS &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.originDeviceId, originDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceId, originDeviceId)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.bookingTime, bookingTime) ||
                const DeepCollectionEquality()
                    .equals(other.bookingTime, bookingTime)) &&
            (identical(other.isPremiere, isPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.isPremiere, isPremiere)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(originDeviceId) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(episodePart) ^
      runtimeType.hashCode;
}

extension $RecordingISExtension on RecordingIS {
  RecordingIS copyWith(
      {String? id,
      enums.SourceType? source,
      enums.RecordingStatePending? recordingState,
      String? cpeId,
      bool? isAdult,
      DateTime? startTime,
      DateTime? endTime,
      DateTime? recStartTime,
      DateTime? recEndTime,
      DateTime? expirationDate,
      String? showId,
      String? title,
      String? channelId,
      String? originDeviceId,
      enums.FailureReason? failureReason,
      int? prePaddingOffset,
      int? postPaddingOffset,
      int? seasonNumber,
      int? episodeNumber,
      String? seasonName,
      String? showName,
      DateTime? bookingTime,
      bool? isPremiere,
      int? episodePart}) {
    return RecordingIS(
        id: id ?? this.id,
        source: source ?? this.source,
        recordingState: recordingState ?? this.recordingState,
        cpeId: cpeId ?? this.cpeId,
        isAdult: isAdult ?? this.isAdult,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        expirationDate: expirationDate ?? this.expirationDate,
        showId: showId ?? this.showId,
        title: title ?? this.title,
        channelId: channelId ?? this.channelId,
        originDeviceId: originDeviceId ?? this.originDeviceId,
        failureReason: failureReason ?? this.failureReason,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonName: seasonName ?? this.seasonName,
        showName: showName ?? this.showName,
        bookingTime: bookingTime ?? this.bookingTime,
        isPremiere: isPremiere ?? this.isPremiere,
        episodePart: episodePart ?? this.episodePart);
  }

  RecordingIS copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.SourceType?>? source,
      Wrapped<enums.RecordingStatePending?>? recordingState,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? isAdult,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<String?>? showId,
      Wrapped<String?>? title,
      Wrapped<String?>? channelId,
      Wrapped<String?>? originDeviceId,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? seasonName,
      Wrapped<String?>? showName,
      Wrapped<DateTime?>? bookingTime,
      Wrapped<bool?>? isPremiere,
      Wrapped<int?>? episodePart}) {
    return RecordingIS(
        id: (id != null ? id.value : this.id),
        source: (source != null ? source.value : this.source),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        showId: (showId != null ? showId.value : this.showId),
        title: (title != null ? title.value : this.title),
        channelId: (channelId != null ? channelId.value : this.channelId),
        originDeviceId: (originDeviceId != null
            ? originDeviceId.value
            : this.originDeviceId),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        showName: (showName != null ? showName.value : this.showName),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingsPHS {
  RecordingsPHS({
    this.data,
  });

  factory RecordingsPHS.fromJson(Map<String, dynamic> json) =>
      _$RecordingsPHSFromJson(json);

  static const toJsonFactory = _$RecordingsPHSToJson;
  Map<String, dynamic> toJson() => _$RecordingsPHSToJson(this);

  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <RecordingPHS>[])
  final List<RecordingPHS>? data;
  static const fromJsonFactory = _$RecordingsPHSFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingsPHS &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^ runtimeType.hashCode;
}

extension $RecordingsPHSExtension on RecordingsPHS {
  RecordingsPHS copyWith({List<RecordingPHS>? data}) {
    return RecordingsPHS(data: data ?? this.data);
  }

  RecordingsPHS copyWithWrapped({Wrapped<List<RecordingPHS>?>? data}) {
    return RecordingsPHS(data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingPHS {
  RecordingPHS({
    this.id,
    this.title,
    this.type,
    this.channelId,
    this.startTime,
    this.recordingState,
    this.duration,
    this.expirationDate,
    this.showId,
    this.mostRelevantEpisode,
    this.episodeNumber,
    this.seasonNumber,
    this.episodeTitle,
    this.minimumAge,
    this.imageVersion,
    this.isPremiere,
    this.episodePart,
    this.bookmark,
  });

  factory RecordingPHS.fromJson(Map<String, dynamic> json) =>
      _$RecordingPHSFromJson(json);

  static const toJsonFactory = _$RecordingPHSToJson;
  Map<String, dynamic> toJson() => _$RecordingPHSToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false)
  final MostRelevantEpisodePHS? mostRelevantEpisode;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  static const fromJsonFactory = _$RecordingPHSFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingPHS &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.isPremiere, isPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.isPremiere, isPremiere)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(bookmark) ^
      runtimeType.hashCode;
}

extension $RecordingPHSExtension on RecordingPHS {
  RecordingPHS copyWith(
      {String? id,
      String? title,
      enums.RecordingType? type,
      String? channelId,
      DateTime? startTime,
      enums.RecordingState? recordingState,
      int? duration,
      DateTime? expirationDate,
      String? showId,
      MostRelevantEpisodePHS? mostRelevantEpisode,
      int? episodeNumber,
      int? seasonNumber,
      String? episodeTitle,
      int? minimumAge,
      String? imageVersion,
      bool? isPremiere,
      int? episodePart,
      int? bookmark}) {
    return RecordingPHS(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        recordingState: recordingState ?? this.recordingState,
        duration: duration ?? this.duration,
        expirationDate: expirationDate ?? this.expirationDate,
        showId: showId ?? this.showId,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        minimumAge: minimumAge ?? this.minimumAge,
        imageVersion: imageVersion ?? this.imageVersion,
        isPremiere: isPremiere ?? this.isPremiere,
        episodePart: episodePart ?? this.episodePart,
        bookmark: bookmark ?? this.bookmark);
  }

  RecordingPHS copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<enums.RecordingType?>? type,
      Wrapped<String?>? channelId,
      Wrapped<DateTime?>? startTime,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<int?>? duration,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<String?>? showId,
      Wrapped<MostRelevantEpisodePHS?>? mostRelevantEpisode,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? episodeTitle,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isPremiere,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? bookmark}) {
    return RecordingPHS(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        duration: (duration != null ? duration.value : this.duration),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        showId: (showId != null ? showId.value : this.showId),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodePHS {
  MostRelevantEpisodePHS({
    this.id,
    this.startTime,
    this.seasonNumber,
    this.episodeNumber,
    this.duration,
    this.recordingState,
    this.minimumAge,
    this.episodeTitle,
    this.expirationDate,
    this.imageVersion,
    this.isPremiere,
  });

  factory MostRelevantEpisodePHS.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantEpisodePHSFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodePHSToJson;
  Map<String, dynamic> toJson() => _$MostRelevantEpisodePHSToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  static const fromJsonFactory = _$MostRelevantEpisodePHSFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodePHS &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.isPremiere, isPremiere) ||
                const DeepCollectionEquality()
                    .equals(other.isPremiere, isPremiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodePHSExtension on MostRelevantEpisodePHS {
  MostRelevantEpisodePHS copyWith(
      {String? id,
      DateTime? startTime,
      int? seasonNumber,
      int? episodeNumber,
      int? duration,
      enums.RecordingState? recordingState,
      int? minimumAge,
      String? episodeTitle,
      DateTime? expirationDate,
      String? imageVersion,
      bool? isPremiere}) {
    return MostRelevantEpisodePHS(
        id: id ?? this.id,
        startTime: startTime ?? this.startTime,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        duration: duration ?? this.duration,
        recordingState: recordingState ?? this.recordingState,
        minimumAge: minimumAge ?? this.minimumAge,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        expirationDate: expirationDate ?? this.expirationDate,
        imageVersion: imageVersion ?? this.imageVersion,
        isPremiere: isPremiere ?? this.isPremiere);
  }

  MostRelevantEpisodePHS copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<DateTime?>? startTime,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? duration,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? episodeTitle,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isPremiere}) {
    return MostRelevantEpisodePHS(
        id: (id != null ? id.value : this.id),
        startTime: (startTime != null ? startTime.value : this.startTime),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        duration: (duration != null ? duration.value : this.duration),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere));
  }
}

@JsonSerializable(explicitToJson: true)
class EpgRecordingStates {
  EpgRecordingStates({
    required this.total,
    required this.size,
    required this.data,
    required this.isAdultContentAvailable,
  });

  factory EpgRecordingStates.fromJson(Map<String, dynamic> json) =>
      _$EpgRecordingStatesFromJson(json);

  static const toJsonFactory = _$EpgRecordingStatesToJson;
  Map<String, dynamic> toJson() => _$EpgRecordingStatesToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <EpgRecordingState>[])
  final List<EpgRecordingState> data;
  @JsonKey(name: 'isAdultContentAvailable', includeIfNull: false)
  final bool isAdultContentAvailable;
  static const fromJsonFactory = _$EpgRecordingStatesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpgRecordingStates &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(
                    other.isAdultContentAvailable, isAdultContentAvailable) ||
                const DeepCollectionEquality().equals(
                    other.isAdultContentAvailable, isAdultContentAvailable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(isAdultContentAvailable) ^
      runtimeType.hashCode;
}

extension $EpgRecordingStatesExtension on EpgRecordingStates {
  EpgRecordingStates copyWith(
      {int? total,
      int? size,
      List<EpgRecordingState>? data,
      bool? isAdultContentAvailable}) {
    return EpgRecordingStates(
        total: total ?? this.total,
        size: size ?? this.size,
        data: data ?? this.data,
        isAdultContentAvailable:
            isAdultContentAvailable ?? this.isAdultContentAvailable);
  }

  EpgRecordingStates copyWithWrapped(
      {Wrapped<int>? total,
      Wrapped<int>? size,
      Wrapped<List<EpgRecordingState>>? data,
      Wrapped<bool>? isAdultContentAvailable}) {
    return EpgRecordingStates(
        total: (total != null ? total.value : this.total),
        size: (size != null ? size.value : this.size),
        data: (data != null ? data.value : this.data),
        isAdultContentAvailable: (isAdultContentAvailable != null
            ? isAdultContentAvailable.value
            : this.isAdultContentAvailable));
  }
}

@JsonSerializable(explicitToJson: true)
class EpgRecordingState {
  EpgRecordingState({
    required this.eventId,
    required this.recordingState,
    this.source,
    this.startTime,
    this.endTime,
    this.minimumAge,
    this.showId,
    this.channelId,
    this.expirationDate,
    this.containsAdult,
    this.isAdult,
    this.channelBasedAuthorization,
    this.restricted,
    this.cpeId,
    this.restrictCpeStreaming,
    this.recStartTime,
    this.recEndTime,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.autoDeletionProtected,
    this.retentionPeriod,
    this.isPremiere,
  });

  factory EpgRecordingState.fromJson(Map<String, dynamic> json) =>
      _$EpgRecordingStateFromJson(json);

  static const toJsonFactory = _$EpgRecordingStateToJson;
  Map<String, dynamic> toJson() => _$EpgRecordingStateToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStatePendingToJson,
    fromJson: recordingStatePendingFromJson,
  )
  final enums.RecordingStatePending recordingState;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  static const fromJsonFactory = _$EpgRecordingStateFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpgRecordingState &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) ||
                const DeepCollectionEquality().equals(
                    other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      runtimeType.hashCode;
}

extension $EpgRecordingStateExtension on EpgRecordingState {
  EpgRecordingState copyWith(
      {String? eventId,
      enums.RecordingStatePending? recordingState,
      enums.SourceType? source,
      DateTime? startTime,
      DateTime? endTime,
      int? minimumAge,
      String? showId,
      String? channelId,
      DateTime? expirationDate,
      bool? containsAdult,
      bool? isAdult,
      bool? channelBasedAuthorization,
      bool? restricted,
      String? cpeId,
      bool? restrictCpeStreaming,
      DateTime? recStartTime,
      DateTime? recEndTime,
      int? prePaddingOffset,
      int? postPaddingOffset,
      bool? autoDeletionProtected,
      int? retentionPeriod,
      bool? isPremiere}) {
    return EpgRecordingState(
        eventId: eventId ?? this.eventId,
        recordingState: recordingState ?? this.recordingState,
        source: source ?? this.source,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        minimumAge: minimumAge ?? this.minimumAge,
        showId: showId ?? this.showId,
        channelId: channelId ?? this.channelId,
        expirationDate: expirationDate ?? this.expirationDate,
        containsAdult: containsAdult ?? this.containsAdult,
        isAdult: isAdult ?? this.isAdult,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        cpeId: cpeId ?? this.cpeId,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        isPremiere: isPremiere ?? this.isPremiere);
  }

  EpgRecordingState copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<enums.RecordingStatePending>? recordingState,
      Wrapped<enums.SourceType?>? source,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? showId,
      Wrapped<String?>? channelId,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? isPremiere}) {
    return EpgRecordingState(
        eventId: (eventId != null ? eventId.value : this.eventId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        source: (source != null ? source.value : this.source),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere));
  }
}

@JsonSerializable(explicitToJson: true)
class Episodes {
  Episodes({
    this.images,
    this.genres,
    this.shortSynopsis,
    required this.total,
    required this.size,
    required this.data,
    this.seasons,
    this.imageVersion,
  });

  factory Episodes.fromJson(Map<String, dynamic> json) =>
      _$EpisodesFromJson(json);

  static const toJsonFactory = _$EpisodesToJson;
  Map<String, dynamic> toJson() => _$EpisodesToJson(this);

  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <EpisodeImage>[])
  final List<EpisodeImage>? images;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'shortSynopsis', includeIfNull: false, defaultValue: '')
  final String? shortSynopsis;
  @JsonKey(name: 'total', includeIfNull: false)
  final int total;
  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <Episode>[])
  final List<Episode> data;
  @JsonKey(
      name: 'seasons', includeIfNull: false, defaultValue: <EpisodeSeason>[])
  final List<EpisodeSeason>? seasons;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Episodes &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.shortSynopsis, shortSynopsis) ||
                const DeepCollectionEquality()
                    .equals(other.shortSynopsis, shortSynopsis)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(shortSynopsis) ^
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodesExtension on Episodes {
  Episodes copyWith(
      {List<EpisodeImage>? images,
      List<String>? genres,
      String? shortSynopsis,
      int? total,
      int? size,
      List<Episode>? data,
      List<EpisodeSeason>? seasons,
      String? imageVersion}) {
    return Episodes(
        images: images ?? this.images,
        genres: genres ?? this.genres,
        shortSynopsis: shortSynopsis ?? this.shortSynopsis,
        total: total ?? this.total,
        size: size ?? this.size,
        data: data ?? this.data,
        seasons: seasons ?? this.seasons,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  Episodes copyWithWrapped(
      {Wrapped<List<EpisodeImage>?>? images,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? shortSynopsis,
      Wrapped<int>? total,
      Wrapped<int>? size,
      Wrapped<List<Episode>>? data,
      Wrapped<List<EpisodeSeason>?>? seasons,
      Wrapped<String?>? imageVersion}) {
    return Episodes(
        images: (images != null ? images.value : this.images),
        genres: (genres != null ? genres.value : this.genres),
        shortSynopsis:
            (shortSynopsis != null ? shortSynopsis.value : this.shortSynopsis),
        total: (total != null ? total.value : this.total),
        size: (size != null ? size.value : this.size),
        data: (data != null ? data.value : this.data),
        seasons: (seasons != null ? seasons.value : this.seasons),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class Episode {
  Episode({
    required this.episodeId,
    required this.viewState,
    required this.recordingState,
    this.bookmark,
    this.episodeNumber,
    this.episodeTitle,
    required this.mostRelevant,
    this.startTime,
    this.endTime,
    this.duration,
    this.technicalDuration,
    this.synopsis,
    this.isAdult,
    this.minimumAge,
    this.poster,
    this.titleTreatment,
    required this.showTitle,
    this.seasonNumber,
    this.seasonId,
    this.background,
    this.source,
    this.expirationDate,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.isContinuous,
    this.failureReason,
    this.channelBasedAuthorization,
    this.restricted,
    this.restrictCpeStreaming,
    this.imageVersion,
    this.productionYear,
    this.isOttBlackout,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.episodePart,
    this.effectiveContentDuration,
  });

  factory Episode.fromJson(Map<String, dynamic> json) =>
      _$EpisodeFromJson(json);

  static const toJsonFactory = _$EpisodeToJson;
  Map<String, dynamic> toJson() => _$EpisodeToJson(this);

  @JsonKey(name: 'episodeId', includeIfNull: false, defaultValue: '')
  final String episodeId;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState viewState;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'mostRelevant', includeIfNull: false)
  final bool mostRelevant;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'poster', includeIfNull: false)
  final EpisodeImage? poster;
  @JsonKey(name: 'titleTreatment', includeIfNull: false)
  final EpisodeImage? titleTreatment;
  @JsonKey(name: 'showTitle', includeIfNull: false, defaultValue: '')
  final String showTitle;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'background', includeIfNull: false)
  final Image? background;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'productionYear', includeIfNull: false)
  final int? productionYear;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$EpisodeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Episode &&
            (identical(other.episodeId, episodeId) ||
                const DeepCollectionEquality()
                    .equals(other.episodeId, episodeId)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.mostRelevant, mostRelevant) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevant, mostRelevant)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.titleTreatment, titleTreatment) ||
                const DeepCollectionEquality()
                    .equals(other.titleTreatment, titleTreatment)) &&
            (identical(other.showTitle, showTitle) ||
                const DeepCollectionEquality()
                    .equals(other.showTitle, showTitle)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality().equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) || const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) || const DeepCollectionEquality().equals(other.recordingType, recordingType)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.productionYear, productionYear) || const DeepCollectionEquality().equals(other.productionYear, productionYear)) &&
            (identical(other.isOttBlackout, isOttBlackout) || const DeepCollectionEquality().equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(episodeId) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(mostRelevant) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(titleTreatment) ^
      const DeepCollectionEquality().hash(showTitle) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(productionYear) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $EpisodeExtension on Episode {
  Episode copyWith(
      {String? episodeId,
      enums.ViewState? viewState,
      enums.RecordingState? recordingState,
      int? bookmark,
      int? episodeNumber,
      String? episodeTitle,
      bool? mostRelevant,
      DateTime? startTime,
      DateTime? endTime,
      int? duration,
      int? technicalDuration,
      String? synopsis,
      bool? isAdult,
      int? minimumAge,
      EpisodeImage? poster,
      EpisodeImage? titleTreatment,
      String? showTitle,
      int? seasonNumber,
      String? seasonId,
      Image? background,
      enums.SourceType? source,
      DateTime? expirationDate,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      bool? isContinuous,
      enums.FailureReason? failureReason,
      bool? channelBasedAuthorization,
      bool? restricted,
      bool? restrictCpeStreaming,
      String? imageVersion,
      int? productionYear,
      bool? isOttBlackout,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      int? episodePart,
      int? effectiveContentDuration}) {
    return Episode(
        episodeId: episodeId ?? this.episodeId,
        viewState: viewState ?? this.viewState,
        recordingState: recordingState ?? this.recordingState,
        bookmark: bookmark ?? this.bookmark,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        mostRelevant: mostRelevant ?? this.mostRelevant,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        synopsis: synopsis ?? this.synopsis,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        poster: poster ?? this.poster,
        titleTreatment: titleTreatment ?? this.titleTreatment,
        showTitle: showTitle ?? this.showTitle,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        seasonId: seasonId ?? this.seasonId,
        background: background ?? this.background,
        source: source ?? this.source,
        expirationDate: expirationDate ?? this.expirationDate,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        isContinuous: isContinuous ?? this.isContinuous,
        failureReason: failureReason ?? this.failureReason,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        imageVersion: imageVersion ?? this.imageVersion,
        productionYear: productionYear ?? this.productionYear,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        episodePart: episodePart ?? this.episodePart,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  Episode copyWithWrapped(
      {Wrapped<String>? episodeId,
      Wrapped<enums.ViewState>? viewState,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<int?>? bookmark,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? episodeTitle,
      Wrapped<bool>? mostRelevant,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<String?>? synopsis,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? minimumAge,
      Wrapped<EpisodeImage?>? poster,
      Wrapped<EpisodeImage?>? titleTreatment,
      Wrapped<String>? showTitle,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? seasonId,
      Wrapped<Image?>? background,
      Wrapped<enums.SourceType?>? source,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? isContinuous,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<String?>? imageVersion,
      Wrapped<int?>? productionYear,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? effectiveContentDuration}) {
    return Episode(
        episodeId: (episodeId != null ? episodeId.value : this.episodeId),
        viewState: (viewState != null ? viewState.value : this.viewState),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        mostRelevant:
            (mostRelevant != null ? mostRelevant.value : this.mostRelevant),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        poster: (poster != null ? poster.value : this.poster),
        titleTreatment: (titleTreatment != null
            ? titleTreatment.value
            : this.titleTreatment),
        showTitle: (showTitle != null ? showTitle.value : this.showTitle),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        background: (background != null ? background.value : this.background),
        source: (source != null ? source.value : this.source),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        productionYear: (productionYear != null
            ? productionYear.value
            : this.productionYear),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class Bookings {
  Bookings({
    this.total,
    required this.size,
    this.quota,
    required this.data,
  });

  factory Bookings.fromJson(Map<String, dynamic> json) =>
      _$BookingsFromJson(json);

  static const toJsonFactory = _$BookingsToJson;
  Map<String, dynamic> toJson() => _$BookingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(name: 'quota', includeIfNull: false)
  final Quota? quota;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <Booking>[])
  final List<Booking> data;
  static const fromJsonFactory = _$BookingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Bookings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $BookingsExtension on Bookings {
  Bookings copyWith(
      {int? total, int? size, Quota? quota, List<Booking>? data}) {
    return Bookings(
        total: total ?? this.total,
        size: size ?? this.size,
        quota: quota ?? this.quota,
        data: data ?? this.data);
  }

  Bookings copyWithWrapped(
      {Wrapped<int?>? total,
      Wrapped<int>? size,
      Wrapped<Quota?>? quota,
      Wrapped<List<Booking>>? data}) {
    return Bookings(
        total: (total != null ? total.value : this.total),
        size: (size != null ? size.value : this.size),
        quota: (quota != null ? quota.value : this.quota),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class Booking {
  Booking({
    required this.id,
    this.title,
    this.type,
    required this.source,
    this.seasons,
    this.noOfEpisodes,
    this.minimumAge,
    required this.channelId,
    this.startTime,
    this.endTime,
    this.showId,
    this.recordingState,
    this.mostRelevantEpisode,
    this.episodeNumber,
    this.seasonNumber,
    this.episodeTitle,
    this.seasonTitle,
    this.poster,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.failureReason,
    this.channelBasedAuthorization,
    this.restricted,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.restrictCpeStreaming,
    this.ottMarkers,
    this.ottPaddingsBlackout,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.imageVersion,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.isSplitProgram,
    this.episodePart,
  });

  factory Booking.fromJson(Map<String, dynamic> json) =>
      _$BookingFromJson(json);

  static const toJsonFactory = _$BookingToJson;
  Map<String, dynamic> toJson() => _$BookingToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: itemTypeToJson,
    fromJson: itemTypeFromJson,
  )
  final enums.ItemType? type;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType source;
  @JsonKey(name: 'seasons', includeIfNull: false, defaultValue: <Season>[])
  final List<Season>? seasons;
  @JsonKey(name: 'noOfEpisodes', includeIfNull: false)
  final int? noOfEpisodes;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false)
  final MostRelevantEpisode? mostRelevantEpisode;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'seasonTitle', includeIfNull: false, defaultValue: '')
  final String? seasonTitle;
  @JsonKey(name: 'poster', includeIfNull: false)
  final Image? poster;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'ottMarkers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ottMarkers;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool? ottPaddingsBlackout;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  static const fromJsonFactory = _$BookingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Booking &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.noOfEpisodes, noOfEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.noOfEpisodes, noOfEpisodes)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.seasonTitle, seasonTitle) ||
                const DeepCollectionEquality()
                    .equals(other.seasonTitle, seasonTitle)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) || const DeepCollectionEquality().equals(other.recordingType, recordingType)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.ottMarkers, ottMarkers) || const DeepCollectionEquality().equals(other.ottMarkers, ottMarkers)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(noOfEpisodes) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(seasonTitle) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(ottMarkers) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodePart) ^
      runtimeType.hashCode;
}

extension $BookingExtension on Booking {
  Booking copyWith(
      {String? id,
      String? title,
      enums.ItemType? type,
      enums.SourceType? source,
      List<Season>? seasons,
      int? noOfEpisodes,
      int? minimumAge,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      String? showId,
      enums.RecordingState? recordingState,
      MostRelevantEpisode? mostRelevantEpisode,
      int? episodeNumber,
      int? seasonNumber,
      String? episodeTitle,
      String? seasonTitle,
      Image? poster,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      enums.FailureReason? failureReason,
      bool? channelBasedAuthorization,
      bool? restricted,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      bool? restrictCpeStreaming,
      List<String>? ottMarkers,
      bool? ottPaddingsBlackout,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      String? imageVersion,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      bool? isSplitProgram,
      int? episodePart}) {
    return Booking(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        source: source ?? this.source,
        seasons: seasons ?? this.seasons,
        noOfEpisodes: noOfEpisodes ?? this.noOfEpisodes,
        minimumAge: minimumAge ?? this.minimumAge,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        showId: showId ?? this.showId,
        recordingState: recordingState ?? this.recordingState,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        seasonTitle: seasonTitle ?? this.seasonTitle,
        poster: poster ?? this.poster,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        failureReason: failureReason ?? this.failureReason,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        ottMarkers: ottMarkers ?? this.ottMarkers,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        imageVersion: imageVersion ?? this.imageVersion,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodePart: episodePart ?? this.episodePart);
  }

  Booking copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? title,
      Wrapped<enums.ItemType?>? type,
      Wrapped<enums.SourceType>? source,
      Wrapped<List<Season>?>? seasons,
      Wrapped<int?>? noOfEpisodes,
      Wrapped<int?>? minimumAge,
      Wrapped<String>? channelId,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<String?>? showId,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<MostRelevantEpisode?>? mostRelevantEpisode,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? episodeTitle,
      Wrapped<String?>? seasonTitle,
      Wrapped<Image?>? poster,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<List<String>?>? ottMarkers,
      Wrapped<bool?>? ottPaddingsBlackout,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodePart}) {
    return Booking(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        source: (source != null ? source.value : this.source),
        seasons: (seasons != null ? seasons.value : this.seasons),
        noOfEpisodes:
            (noOfEpisodes != null ? noOfEpisodes.value : this.noOfEpisodes),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        showId: (showId != null ? showId.value : this.showId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        seasonTitle:
            (seasonTitle != null ? seasonTitle.value : this.seasonTitle),
        poster: (poster != null ? poster.value : this.poster),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        ottMarkers: (ottMarkers != null ? ottMarkers.value : this.ottMarkers),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingDetails {
  RecordingDetails({
    required this.id,
    required this.title,
    required this.type,
    required this.source,
    this.seasonNumber,
    this.episodeNumber,
    this.episodeTitle,
    required this.channelId,
    this.startTime,
    this.recStartTime,
    this.recEndTime,
    required this.recordingState,
    required this.viewState,
    required this.bookmark,
    this.duration,
    this.technicalDuration,
    this.leadGuardTime,
    this.trailGuardTime,
    this.poster,
    this.background,
    this.titleTreatment,
    this.yearOfProduction,
    this.genres,
    this.minimumAge,
    this.isAdult,
    this.countriesOfOrigin,
    this.directors,
    this.cast,
    this.synopsis,
    this.shortSynopsis,
    this.showId,
    this.seasonId,
    this.endTime,
    this.expirationDate,
    this.bookingOffset,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.failureReason,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.restrictCpeStreaming,
    this.ageRating,
    this.parentalGuidanceText,
    this.ottMarkers,
    this.ottPaddingsBlackout,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.imageVersion,
    this.isOttBlackout,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.isSplitProgram,
    this.episodePart,
    this.effectiveContentDuration,
  });

  factory RecordingDetails.fromJson(Map<String, dynamic> json) =>
      _$RecordingDetailsFromJson(json);

  static const toJsonFactory = _$RecordingDetailsToJson;
  Map<String, dynamic> toJson() => _$RecordingDetailsToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: itemTypeToJson,
    fromJson: itemTypeFromJson,
  )
  final enums.ItemType type;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType source;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStatePendingToJson,
    fromJson: recordingStatePendingFromJson,
  )
  final enums.RecordingStatePending recordingState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState viewState;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'leadGuardTime', includeIfNull: false)
  final int? leadGuardTime;
  @JsonKey(name: 'trailGuardTime', includeIfNull: false)
  final int? trailGuardTime;
  @JsonKey(name: 'poster', includeIfNull: false)
  final Image? poster;
  @JsonKey(name: 'background', includeIfNull: false)
  final Image? background;
  @JsonKey(name: 'titleTreatment', includeIfNull: false)
  final Image? titleTreatment;
  @JsonKey(name: 'yearOfProduction', includeIfNull: false)
  final int? yearOfProduction;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
      name: 'countriesOfOrigin', includeIfNull: false, defaultValue: <String>[])
  final List<String>? countriesOfOrigin;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'cast', includeIfNull: false, defaultValue: <String>[])
  final List<String>? cast;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'shortSynopsis', includeIfNull: false, defaultValue: '')
  final String? shortSynopsis;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'bookingOffset', includeIfNull: false)
  final int? bookingOffset;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'parentalGuidanceText', includeIfNull: false, defaultValue: '')
  final String? parentalGuidanceText;
  @JsonKey(name: 'ottMarkers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ottMarkers;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool? ottPaddingsBlackout;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$RecordingDetailsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingDetails &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.leadGuardTime, leadGuardTime) ||
                const DeepCollectionEquality()
                    .equals(other.leadGuardTime, leadGuardTime)) &&
            (identical(other.trailGuardTime, trailGuardTime) ||
                const DeepCollectionEquality()
                    .equals(other.trailGuardTime, trailGuardTime)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.titleTreatment, titleTreatment) ||
                const DeepCollectionEquality()
                    .equals(other.titleTreatment, titleTreatment)) &&
            (identical(other.yearOfProduction, yearOfProduction) ||
                const DeepCollectionEquality()
                    .equals(other.yearOfProduction, yearOfProduction)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality().equals(other.isAdult, isAdult)) &&
            (identical(other.countriesOfOrigin, countriesOfOrigin) || const DeepCollectionEquality().equals(other.countriesOfOrigin, countriesOfOrigin)) &&
            (identical(other.directors, directors) || const DeepCollectionEquality().equals(other.directors, directors)) &&
            (identical(other.cast, cast) || const DeepCollectionEquality().equals(other.cast, cast)) &&
            (identical(other.synopsis, synopsis) || const DeepCollectionEquality().equals(other.synopsis, synopsis)) &&
            (identical(other.shortSynopsis, shortSynopsis) || const DeepCollectionEquality().equals(other.shortSynopsis, shortSynopsis)) &&
            (identical(other.showId, showId) || const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.seasonId, seasonId) || const DeepCollectionEquality().equals(other.seasonId, seasonId)) &&
            (identical(other.endTime, endTime) || const DeepCollectionEquality().equals(other.endTime, endTime)) &&
            (identical(other.expirationDate, expirationDate) || const DeepCollectionEquality().equals(other.expirationDate, expirationDate)) &&
            (identical(other.bookingOffset, bookingOffset) || const DeepCollectionEquality().equals(other.bookingOffset, bookingOffset)) &&
            (identical(other.localRecordingId, localRecordingId) || const DeepCollectionEquality().equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) || const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.ageRating, ageRating) || const DeepCollectionEquality().equals(other.ageRating, ageRating)) &&
            (identical(other.parentalGuidanceText, parentalGuidanceText) || const DeepCollectionEquality().equals(other.parentalGuidanceText, parentalGuidanceText)) &&
            (identical(other.ottMarkers, ottMarkers) || const DeepCollectionEquality().equals(other.ottMarkers, ottMarkers)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isOttBlackout, isOttBlackout) || const DeepCollectionEquality().equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(leadGuardTime) ^
      const DeepCollectionEquality().hash(trailGuardTime) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(titleTreatment) ^
      const DeepCollectionEquality().hash(yearOfProduction) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(countriesOfOrigin) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(cast) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(shortSynopsis) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(bookingOffset) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(parentalGuidanceText) ^
      const DeepCollectionEquality().hash(ottMarkers) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $RecordingDetailsExtension on RecordingDetails {
  RecordingDetails copyWith(
      {String? id,
      String? title,
      enums.ItemType? type,
      enums.SourceType? source,
      int? seasonNumber,
      int? episodeNumber,
      String? episodeTitle,
      String? channelId,
      DateTime? startTime,
      DateTime? recStartTime,
      DateTime? recEndTime,
      enums.RecordingStatePending? recordingState,
      enums.ViewState? viewState,
      int? bookmark,
      int? duration,
      int? technicalDuration,
      int? leadGuardTime,
      int? trailGuardTime,
      Image? poster,
      Image? background,
      Image? titleTreatment,
      int? yearOfProduction,
      List<String>? genres,
      int? minimumAge,
      bool? isAdult,
      List<String>? countriesOfOrigin,
      List<String>? directors,
      List<String>? cast,
      String? synopsis,
      String? shortSynopsis,
      String? showId,
      String? seasonId,
      DateTime? endTime,
      DateTime? expirationDate,
      int? bookingOffset,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.FailureReason? failureReason,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      bool? restrictCpeStreaming,
      int? ageRating,
      String? parentalGuidanceText,
      List<String>? ottMarkers,
      bool? ottPaddingsBlackout,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      String? imageVersion,
      bool? isOttBlackout,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      bool? isSplitProgram,
      int? episodePart,
      int? effectiveContentDuration}) {
    return RecordingDetails(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        source: source ?? this.source,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        recordingState: recordingState ?? this.recordingState,
        viewState: viewState ?? this.viewState,
        bookmark: bookmark ?? this.bookmark,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        leadGuardTime: leadGuardTime ?? this.leadGuardTime,
        trailGuardTime: trailGuardTime ?? this.trailGuardTime,
        poster: poster ?? this.poster,
        background: background ?? this.background,
        titleTreatment: titleTreatment ?? this.titleTreatment,
        yearOfProduction: yearOfProduction ?? this.yearOfProduction,
        genres: genres ?? this.genres,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        countriesOfOrigin: countriesOfOrigin ?? this.countriesOfOrigin,
        directors: directors ?? this.directors,
        cast: cast ?? this.cast,
        synopsis: synopsis ?? this.synopsis,
        shortSynopsis: shortSynopsis ?? this.shortSynopsis,
        showId: showId ?? this.showId,
        seasonId: seasonId ?? this.seasonId,
        endTime: endTime ?? this.endTime,
        expirationDate: expirationDate ?? this.expirationDate,
        bookingOffset: bookingOffset ?? this.bookingOffset,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        failureReason: failureReason ?? this.failureReason,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        ageRating: ageRating ?? this.ageRating,
        parentalGuidanceText: parentalGuidanceText ?? this.parentalGuidanceText,
        ottMarkers: ottMarkers ?? this.ottMarkers,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        imageVersion: imageVersion ?? this.imageVersion,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodePart: episodePart ?? this.episodePart,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  RecordingDetails copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<enums.ItemType>? type,
      Wrapped<enums.SourceType>? source,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? episodeTitle,
      Wrapped<String>? channelId,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<enums.RecordingStatePending>? recordingState,
      Wrapped<enums.ViewState>? viewState,
      Wrapped<int>? bookmark,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<int?>? leadGuardTime,
      Wrapped<int?>? trailGuardTime,
      Wrapped<Image?>? poster,
      Wrapped<Image?>? background,
      Wrapped<Image?>? titleTreatment,
      Wrapped<int?>? yearOfProduction,
      Wrapped<List<String>?>? genres,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<List<String>?>? countriesOfOrigin,
      Wrapped<List<String>?>? directors,
      Wrapped<List<String>?>? cast,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? shortSynopsis,
      Wrapped<String?>? showId,
      Wrapped<String?>? seasonId,
      Wrapped<DateTime?>? endTime,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<int?>? bookingOffset,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<int?>? ageRating,
      Wrapped<String?>? parentalGuidanceText,
      Wrapped<List<String>?>? ottMarkers,
      Wrapped<bool?>? ottPaddingsBlackout,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? effectiveContentDuration}) {
    return RecordingDetails(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        source: (source != null ? source.value : this.source),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        leadGuardTime:
            (leadGuardTime != null ? leadGuardTime.value : this.leadGuardTime),
        trailGuardTime: (trailGuardTime != null
            ? trailGuardTime.value
            : this.trailGuardTime),
        poster: (poster != null ? poster.value : this.poster),
        background: (background != null ? background.value : this.background),
        titleTreatment: (titleTreatment != null
            ? titleTreatment.value
            : this.titleTreatment),
        yearOfProduction: (yearOfProduction != null
            ? yearOfProduction.value
            : this.yearOfProduction),
        genres: (genres != null ? genres.value : this.genres),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        countriesOfOrigin: (countriesOfOrigin != null
            ? countriesOfOrigin.value
            : this.countriesOfOrigin),
        directors: (directors != null ? directors.value : this.directors),
        cast: (cast != null ? cast.value : this.cast),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        shortSynopsis:
            (shortSynopsis != null ? shortSynopsis.value : this.shortSynopsis),
        showId: (showId != null ? showId.value : this.showId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        endTime: (endTime != null ? endTime.value : this.endTime),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        bookingOffset:
            (bookingOffset != null ? bookingOffset.value : this.bookingOffset),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        parentalGuidanceText: (parentalGuidanceText != null
            ? parentalGuidanceText.value
            : this.parentalGuidanceText),
        ottMarkers: (ottMarkers != null ? ottMarkers.value : this.ottMarkers),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class SingleRecordingState {
  SingleRecordingState({
    required this.id,
    required this.status,
    required this.source,
    this.showId,
    required this.channelId,
    this.recordingState,
  });

  factory SingleRecordingState.fromJson(Map<String, dynamic> json) =>
      _$SingleRecordingStateFromJson(json);

  static const toJsonFactory = _$SingleRecordingStateToJson;
  Map<String, dynamic> toJson() => _$SingleRecordingStateToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState status;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType source;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  static const fromJsonFactory = _$SingleRecordingStateFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SingleRecordingState &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      runtimeType.hashCode;
}

extension $SingleRecordingStateExtension on SingleRecordingState {
  SingleRecordingState copyWith(
      {String? id,
      enums.RecordingState? status,
      enums.SourceType? source,
      String? showId,
      String? channelId,
      enums.RecordingState? recordingState}) {
    return SingleRecordingState(
        id: id ?? this.id,
        status: status ?? this.status,
        source: source ?? this.source,
        showId: showId ?? this.showId,
        channelId: channelId ?? this.channelId,
        recordingState: recordingState ?? this.recordingState);
  }

  SingleRecordingState copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.RecordingState>? status,
      Wrapped<enums.SourceType>? source,
      Wrapped<String?>? showId,
      Wrapped<String>? channelId,
      Wrapped<enums.RecordingState?>? recordingState}) {
    return SingleRecordingState(
        id: (id != null ? id.value : this.id),
        status: (status != null ? status.value : this.status),
        source: (source != null ? source.value : this.source),
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  static const fromJsonFactory = _$ErrorResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error?>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    required this.type,
    required this.url,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: imageTypeToJson,
    fromJson: imageTypeFromJson,
  )
  final enums.ImageType type;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$ImageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({enums.ImageType? type, String? url}) {
    return Image(type: type ?? this.type, url: url ?? this.url);
  }

  Image copyWithWrapped(
      {Wrapped<enums.ImageType>? type, Wrapped<String>? url}) {
    return Image(
        type: (type != null ? type.value : this.type),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodeImage {
  EpisodeImage({
    required this.type,
    required this.url,
  });

  factory EpisodeImage.fromJson(Map<String, dynamic> json) =>
      _$EpisodeImageFromJson(json);

  static const toJsonFactory = _$EpisodeImageToJson;
  Map<String, dynamic> toJson() => _$EpisodeImageToJson(this);

  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: episodeImageTypeToJson,
    fromJson: episodeImageTypeFromJson,
  )
  final enums.EpisodeImageType type;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$EpisodeImageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodeImage &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $EpisodeImageExtension on EpisodeImage {
  EpisodeImage copyWith({enums.EpisodeImageType? type, String? url}) {
    return EpisodeImage(type: type ?? this.type, url: url ?? this.url);
  }

  EpisodeImage copyWithWrapped(
      {Wrapped<enums.EpisodeImageType>? type, Wrapped<String>? url}) {
    return EpisodeImage(
        type: (type != null ? type.value : this.type),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class Season {
  Season({
    required this.seasonId,
    required this.name,
    this.$number,
  });

  factory Season.fromJson(Map<String, dynamic> json) => _$SeasonFromJson(json);

  static const toJsonFactory = _$SeasonToJson;
  Map<String, dynamic> toJson() => _$SeasonToJson(this);

  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String seasonId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'number', includeIfNull: false)
  final int? $number;
  static const fromJsonFactory = _$SeasonFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Season &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.$number, $number) ||
                const DeepCollectionEquality().equals(other.$number, $number)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash($number) ^
      runtimeType.hashCode;
}

extension $SeasonExtension on Season {
  Season copyWith({String? seasonId, String? name, int? $number}) {
    return Season(
        seasonId: seasonId ?? this.seasonId,
        name: name ?? this.name,
        $number: $number ?? this.$number);
  }

  Season copyWithWrapped(
      {Wrapped<String>? seasonId,
      Wrapped<String>? name,
      Wrapped<int?>? $number}) {
    return Season(
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        name: (name != null ? name.value : this.name),
        $number: ($number != null ? $number.value : this.$number));
  }
}

@JsonSerializable(explicitToJson: true)
class TileCollectionResponse {
  TileCollectionResponse({
    required this.recordings,
    required this.bookings,
    required this.isAdultContentAvailable,
  });

  factory TileCollectionResponse.fromJson(Map<String, dynamic> json) =>
      _$TileCollectionResponseFromJson(json);

  static const toJsonFactory = _$TileCollectionResponseToJson;
  Map<String, dynamic> toJson() => _$TileCollectionResponseToJson(this);

  @JsonKey(name: 'recordings', includeIfNull: false)
  final TileCollectionRecordings recordings;
  @JsonKey(name: 'bookings', includeIfNull: false)
  final TileCollectionBookings bookings;
  @JsonKey(name: 'isAdultContentAvailable', includeIfNull: false)
  final bool isAdultContentAvailable;
  static const fromJsonFactory = _$TileCollectionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileCollectionResponse &&
            (identical(other.recordings, recordings) ||
                const DeepCollectionEquality()
                    .equals(other.recordings, recordings)) &&
            (identical(other.bookings, bookings) ||
                const DeepCollectionEquality()
                    .equals(other.bookings, bookings)) &&
            (identical(
                    other.isAdultContentAvailable, isAdultContentAvailable) ||
                const DeepCollectionEquality().equals(
                    other.isAdultContentAvailable, isAdultContentAvailable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordings) ^
      const DeepCollectionEquality().hash(bookings) ^
      const DeepCollectionEquality().hash(isAdultContentAvailable) ^
      runtimeType.hashCode;
}

extension $TileCollectionResponseExtension on TileCollectionResponse {
  TileCollectionResponse copyWith(
      {TileCollectionRecordings? recordings,
      TileCollectionBookings? bookings,
      bool? isAdultContentAvailable}) {
    return TileCollectionResponse(
        recordings: recordings ?? this.recordings,
        bookings: bookings ?? this.bookings,
        isAdultContentAvailable:
            isAdultContentAvailable ?? this.isAdultContentAvailable);
  }

  TileCollectionResponse copyWithWrapped(
      {Wrapped<TileCollectionRecordings>? recordings,
      Wrapped<TileCollectionBookings>? bookings,
      Wrapped<bool>? isAdultContentAvailable}) {
    return TileCollectionResponse(
        recordings: (recordings != null ? recordings.value : this.recordings),
        bookings: (bookings != null ? bookings.value : this.bookings),
        isAdultContentAvailable: (isAdultContentAvailable != null
            ? isAdultContentAvailable.value
            : this.isAdultContentAvailable));
  }
}

@JsonSerializable(explicitToJson: true)
class TileCollectionBookings {
  TileCollectionBookings({
    this.total,
    required this.size,
    required this.data,
  });

  factory TileCollectionBookings.fromJson(Map<String, dynamic> json) =>
      _$TileCollectionBookingsFromJson(json);

  static const toJsonFactory = _$TileCollectionBookingsToJson;
  Map<String, dynamic> toJson() => _$TileCollectionBookingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <TileBooking>[])
  final List<TileBooking> data;
  static const fromJsonFactory = _$TileCollectionBookingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileCollectionBookings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $TileCollectionBookingsExtension on TileCollectionBookings {
  TileCollectionBookings copyWith(
      {int? total, int? size, List<TileBooking>? data}) {
    return TileCollectionBookings(
        total: total ?? this.total,
        size: size ?? this.size,
        data: data ?? this.data);
  }

  TileCollectionBookings copyWithWrapped(
      {Wrapped<int?>? total,
      Wrapped<int>? size,
      Wrapped<List<TileBooking>>? data}) {
    return TileCollectionBookings(
        total: (total != null ? total.value : this.total),
        size: (size != null ? size.value : this.size),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class TileCollectionRecordings {
  TileCollectionRecordings({
    this.total,
    required this.size,
    required this.data,
  });

  factory TileCollectionRecordings.fromJson(Map<String, dynamic> json) =>
      _$TileCollectionRecordingsFromJson(json);

  static const toJsonFactory = _$TileCollectionRecordingsToJson;
  Map<String, dynamic> toJson() => _$TileCollectionRecordingsToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <TileRecording>[])
  final List<TileRecording> data;
  static const fromJsonFactory = _$TileCollectionRecordingsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileCollectionRecordings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $TileCollectionRecordingsExtension on TileCollectionRecordings {
  TileCollectionRecordings copyWith(
      {int? total, int? size, List<TileRecording>? data}) {
    return TileCollectionRecordings(
        total: total ?? this.total,
        size: size ?? this.size,
        data: data ?? this.data);
  }

  TileCollectionRecordings copyWithWrapped(
      {Wrapped<int?>? total,
      Wrapped<int>? size,
      Wrapped<List<TileRecording>>? data}) {
    return TileCollectionRecordings(
        total: (total != null ? total.value : this.total),
        size: (size != null ? size.value : this.size),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class TileBooking {
  TileBooking({
    required this.id,
    required this.title,
    this.poster,
    this.isAdult,
    this.duration,
    this.seasonNumber,
    this.episodeNumber,
    this.recordingState,
    this.type,
    required this.channelId,
    this.showId,
    this.startTime,
    this.minimumAge,
    this.episodeTitle,
    this.seasons,
    this.mostRelevantEpisode,
    this.expirationDate,
    this.source,
    this.viewState,
    this.endTime,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.failureReason,
    this.channelBasedAuthorization,
    this.restricted,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.restrictCpeStreaming,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.imageVersion,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.isSplitProgram,
    this.episodePart,
  });

  factory TileBooking.fromJson(Map<String, dynamic> json) =>
      _$TileBookingFromJson(json);

  static const toJsonFactory = _$TileBookingToJson;
  Map<String, dynamic> toJson() => _$TileBookingToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'poster', includeIfNull: false)
  final Image? poster;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: tileBookingRecordingStateToJson,
    fromJson: tileBookingRecordingStateFromJson,
  )
  final enums.TileBookingRecordingState? recordingState;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: tileBookingTypeToJson,
    fromJson: tileBookingTypeFromJson,
  )
  final enums.TileBookingType? type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'seasons', includeIfNull: false, defaultValue: <Season>[])
  final List<Season>? seasons;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false)
  final MostRelevantEpisode? mostRelevantEpisode;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  static const fromJsonFactory = _$TileBookingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileBooking &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) || const DeepCollectionEquality().equals(other.recordingType, recordingType)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodePart) ^
      runtimeType.hashCode;
}

extension $TileBookingExtension on TileBooking {
  TileBooking copyWith(
      {String? id,
      String? title,
      Image? poster,
      bool? isAdult,
      int? duration,
      int? seasonNumber,
      int? episodeNumber,
      enums.TileBookingRecordingState? recordingState,
      enums.TileBookingType? type,
      String? channelId,
      String? showId,
      DateTime? startTime,
      int? minimumAge,
      String? episodeTitle,
      List<Season>? seasons,
      MostRelevantEpisode? mostRelevantEpisode,
      DateTime? expirationDate,
      enums.SourceType? source,
      enums.ViewState? viewState,
      DateTime? endTime,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      enums.FailureReason? failureReason,
      bool? channelBasedAuthorization,
      bool? restricted,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      bool? restrictCpeStreaming,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      String? imageVersion,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      bool? isSplitProgram,
      int? episodePart}) {
    return TileBooking(
        id: id ?? this.id,
        title: title ?? this.title,
        poster: poster ?? this.poster,
        isAdult: isAdult ?? this.isAdult,
        duration: duration ?? this.duration,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        recordingState: recordingState ?? this.recordingState,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        showId: showId ?? this.showId,
        startTime: startTime ?? this.startTime,
        minimumAge: minimumAge ?? this.minimumAge,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        seasons: seasons ?? this.seasons,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        expirationDate: expirationDate ?? this.expirationDate,
        source: source ?? this.source,
        viewState: viewState ?? this.viewState,
        endTime: endTime ?? this.endTime,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        failureReason: failureReason ?? this.failureReason,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        imageVersion: imageVersion ?? this.imageVersion,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodePart: episodePart ?? this.episodePart);
  }

  TileBooking copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<Image?>? poster,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? duration,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.TileBookingRecordingState?>? recordingState,
      Wrapped<enums.TileBookingType?>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? showId,
      Wrapped<DateTime?>? startTime,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? episodeTitle,
      Wrapped<List<Season>?>? seasons,
      Wrapped<MostRelevantEpisode?>? mostRelevantEpisode,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<enums.SourceType?>? source,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? endTime,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodePart}) {
    return TileBooking(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        poster: (poster != null ? poster.value : this.poster),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        duration: (duration != null ? duration.value : this.duration),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        showId: (showId != null ? showId.value : this.showId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        seasons: (seasons != null ? seasons.value : this.seasons),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        source: (source != null ? source.value : this.source),
        viewState: (viewState != null ? viewState.value : this.viewState),
        endTime: (endTime != null ? endTime.value : this.endTime),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart));
  }
}

@JsonSerializable(explicitToJson: true)
class ContextualRecording {
  ContextualRecording({
    required this.id,
    required this.title,
    this.poster,
    this.background,
    required this.isAdult,
    this.duration,
    this.technicalDuration,
    this.position,
    this.seasonNumber,
    this.episodeNumber,
    this.recordingState,
    required this.type,
    required this.channelId,
    this.showId,
    this.startTime,
    this.minimumAge,
    this.episodeTitle,
    this.expirationDate,
    this.source,
    this.endTime,
    this.viewState,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.failureReason,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.restrictCpeStreaming,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.imageVersion,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.isSplitProgram,
    this.episodePart,
    this.effectiveContentDuration,
  });

  factory ContextualRecording.fromJson(Map<String, dynamic> json) =>
      _$ContextualRecordingFromJson(json);

  static const toJsonFactory = _$ContextualRecordingToJson;
  Map<String, dynamic> toJson() => _$ContextualRecordingToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'poster', includeIfNull: false)
  final Image? poster;
  @JsonKey(name: 'background', includeIfNull: false)
  final Image? background;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'position', includeIfNull: false)
  final int? position;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: contextualRecordingRecordingStateToJson,
    fromJson: contextualRecordingRecordingStateFromJson,
  )
  final enums.ContextualRecordingRecordingState? recordingState;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: contextualRecordingTypeToJson,
    fromJson: contextualRecordingTypeFromJson,
  )
  final enums.ContextualRecordingType type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$ContextualRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContextualRecording &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) || const DeepCollectionEquality().equals(other.recordingType, recordingType)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $ContextualRecordingExtension on ContextualRecording {
  ContextualRecording copyWith(
      {String? id,
      String? title,
      Image? poster,
      Image? background,
      bool? isAdult,
      int? duration,
      int? technicalDuration,
      int? position,
      int? seasonNumber,
      int? episodeNumber,
      enums.ContextualRecordingRecordingState? recordingState,
      enums.ContextualRecordingType? type,
      String? channelId,
      String? showId,
      DateTime? startTime,
      int? minimumAge,
      String? episodeTitle,
      DateTime? expirationDate,
      enums.SourceType? source,
      DateTime? endTime,
      enums.ViewState? viewState,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      enums.FailureReason? failureReason,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      bool? restrictCpeStreaming,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      String? imageVersion,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      bool? isSplitProgram,
      int? episodePart,
      int? effectiveContentDuration}) {
    return ContextualRecording(
        id: id ?? this.id,
        title: title ?? this.title,
        poster: poster ?? this.poster,
        background: background ?? this.background,
        isAdult: isAdult ?? this.isAdult,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        position: position ?? this.position,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        recordingState: recordingState ?? this.recordingState,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        showId: showId ?? this.showId,
        startTime: startTime ?? this.startTime,
        minimumAge: minimumAge ?? this.minimumAge,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        expirationDate: expirationDate ?? this.expirationDate,
        source: source ?? this.source,
        endTime: endTime ?? this.endTime,
        viewState: viewState ?? this.viewState,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        failureReason: failureReason ?? this.failureReason,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        imageVersion: imageVersion ?? this.imageVersion,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodePart: episodePart ?? this.episodePart,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  ContextualRecording copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<Image?>? poster,
      Wrapped<Image?>? background,
      Wrapped<bool>? isAdult,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<int?>? position,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.ContextualRecordingRecordingState?>? recordingState,
      Wrapped<enums.ContextualRecordingType>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? showId,
      Wrapped<DateTime?>? startTime,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? episodeTitle,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<enums.SourceType?>? source,
      Wrapped<DateTime?>? endTime,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? effectiveContentDuration}) {
    return ContextualRecording(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        poster: (poster != null ? poster.value : this.poster),
        background: (background != null ? background.value : this.background),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        position: (position != null ? position.value : this.position),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        showId: (showId != null ? showId.value : this.showId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        source: (source != null ? source.value : this.source),
        endTime: (endTime != null ? endTime.value : this.endTime),
        viewState: (viewState != null ? viewState.value : this.viewState),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class TileRecording {
  TileRecording({
    required this.id,
    required this.title,
    this.poster,
    this.isAdult,
    this.duration,
    this.technicalDuration,
    this.position,
    this.seasonNumber,
    this.episodeNumber,
    this.recordingState,
    this.type,
    required this.channelId,
    this.showId,
    this.startTime,
    this.minimumAge,
    this.episodeTitle,
    this.seasons,
    this.mostRelevantEpisode,
    this.expirationDate,
    this.source,
    this.endTime,
    this.viewState,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.isContinuous,
    this.failureReason,
    this.channelBasedAuthorization,
    this.restricted,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.restrictCpeStreaming,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.imageVersion,
    this.isPremiere,
    this.isPremiereAirings,
    this.mepSeriesFinale,
    this.isSplitProgram,
    this.episodePart,
    this.effectiveContentDuration,
  });

  factory TileRecording.fromJson(Map<String, dynamic> json) =>
      _$TileRecordingFromJson(json);

  static const toJsonFactory = _$TileRecordingToJson;
  Map<String, dynamic> toJson() => _$TileRecordingToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'poster', includeIfNull: false)
  final Image? poster;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'position', includeIfNull: false)
  final int? position;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: tileRecordingRecordingStateToJson,
    fromJson: tileRecordingRecordingStateFromJson,
  )
  final enums.TileRecordingRecordingState? recordingState;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: tileRecordingTypeToJson,
    fromJson: tileRecordingTypeFromJson,
  )
  final enums.TileRecordingType? type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'episodeTitle', includeIfNull: false, defaultValue: '')
  final String? episodeTitle;
  @JsonKey(name: 'seasons', includeIfNull: false, defaultValue: <Season>[])
  final List<Season>? seasons;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false)
  final MostRelevantEpisode? mostRelevantEpisode;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? source;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isPremiereAirings', includeIfNull: false)
  final bool? isPremiereAirings;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final dynamic mepSeriesFinale;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$TileRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TileRecording &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.episodeTitle, episodeTitle) ||
                const DeepCollectionEquality()
                    .equals(other.episodeTitle, episodeTitle)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) || const DeepCollectionEquality().equals(other.recordingType, recordingType)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isPremiereAirings, isPremiereAirings) || const DeepCollectionEquality().equals(other.isPremiereAirings, isPremiereAirings)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(episodeTitle) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isPremiereAirings) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $TileRecordingExtension on TileRecording {
  TileRecording copyWith(
      {String? id,
      String? title,
      Image? poster,
      bool? isAdult,
      int? duration,
      int? technicalDuration,
      int? position,
      int? seasonNumber,
      int? episodeNumber,
      enums.TileRecordingRecordingState? recordingState,
      enums.TileRecordingType? type,
      String? channelId,
      String? showId,
      DateTime? startTime,
      int? minimumAge,
      String? episodeTitle,
      List<Season>? seasons,
      MostRelevantEpisode? mostRelevantEpisode,
      DateTime? expirationDate,
      enums.SourceType? source,
      DateTime? endTime,
      enums.ViewState? viewState,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      bool? isContinuous,
      enums.FailureReason? failureReason,
      bool? channelBasedAuthorization,
      bool? restricted,
      List<AudioLanguage>? audioLanguages,
      List<CaptionLanguage>? captionLanguages,
      List<SignLanguage>? signLanguages,
      bool? restrictCpeStreaming,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      String? imageVersion,
      bool? isPremiere,
      bool? isPremiereAirings,
      dynamic mepSeriesFinale,
      bool? isSplitProgram,
      int? episodePart,
      int? effectiveContentDuration}) {
    return TileRecording(
        id: id ?? this.id,
        title: title ?? this.title,
        poster: poster ?? this.poster,
        isAdult: isAdult ?? this.isAdult,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        position: position ?? this.position,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        recordingState: recordingState ?? this.recordingState,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        showId: showId ?? this.showId,
        startTime: startTime ?? this.startTime,
        minimumAge: minimumAge ?? this.minimumAge,
        episodeTitle: episodeTitle ?? this.episodeTitle,
        seasons: seasons ?? this.seasons,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        expirationDate: expirationDate ?? this.expirationDate,
        source: source ?? this.source,
        endTime: endTime ?? this.endTime,
        viewState: viewState ?? this.viewState,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        isContinuous: isContinuous ?? this.isContinuous,
        failureReason: failureReason ?? this.failureReason,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        imageVersion: imageVersion ?? this.imageVersion,
        isPremiere: isPremiere ?? this.isPremiere,
        isPremiereAirings: isPremiereAirings ?? this.isPremiereAirings,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodePart: episodePart ?? this.episodePart,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  TileRecording copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<Image?>? poster,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<int?>? position,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.TileRecordingRecordingState?>? recordingState,
      Wrapped<enums.TileRecordingType?>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? showId,
      Wrapped<DateTime?>? startTime,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? episodeTitle,
      Wrapped<List<Season>?>? seasons,
      Wrapped<MostRelevantEpisode?>? mostRelevantEpisode,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<enums.SourceType?>? source,
      Wrapped<DateTime?>? endTime,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? isContinuous,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isPremiereAirings,
      Wrapped<dynamic>? mepSeriesFinale,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? effectiveContentDuration}) {
    return TileRecording(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        poster: (poster != null ? poster.value : this.poster),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        position: (position != null ? position.value : this.position),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        showId: (showId != null ? showId.value : this.showId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        episodeTitle:
            (episodeTitle != null ? episodeTitle.value : this.episodeTitle),
        seasons: (seasons != null ? seasons.value : this.seasons),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        source: (source != null ? source.value : this.source),
        endTime: (endTime != null ? endTime.value : this.endTime),
        viewState: (viewState != null ? viewState.value : this.viewState),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isPremiereAirings: (isPremiereAirings != null
            ? isPremiereAirings.value
            : this.isPremiereAirings),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisode {
  MostRelevantEpisode({
    required this.id,
    required this.startTime,
    required this.endTime,
    this.seasonNumber,
    this.episodeNumber,
    this.duration,
    this.technicalDuration,
    required this.recordingState,
    required this.viewState,
    this.minimumAge,
    this.seasonId,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.isContinuous,
    this.failureReason,
    this.channelBasedAuthorization,
    this.restricted,
    this.restrictCpeStreaming,
    this.ottMarkers,
    this.ottPaddingsBlackout,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.isPremiere,
    this.effectiveContentDuration,
  });

  factory MostRelevantEpisode.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantEpisodeFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeToJson;
  Map<String, dynamic> toJson() => _$MostRelevantEpisodeToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState viewState;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'ottMarkers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ottMarkers;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool? ottPaddingsBlackout;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$MostRelevantEpisodeFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisode &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.isContinuous, isContinuous) ||
                const DeepCollectionEquality()
                    .equals(other.isContinuous, isContinuous)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.ottMarkers, ottMarkers) || const DeepCollectionEquality().equals(other.ottMarkers, ottMarkers)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(ottMarkers) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeExtension on MostRelevantEpisode {
  MostRelevantEpisode copyWith(
      {String? id,
      DateTime? startTime,
      DateTime? endTime,
      int? seasonNumber,
      int? episodeNumber,
      int? duration,
      int? technicalDuration,
      enums.RecordingState? recordingState,
      enums.ViewState? viewState,
      int? minimumAge,
      String? seasonId,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      bool? isContinuous,
      enums.FailureReason? failureReason,
      bool? channelBasedAuthorization,
      bool? restricted,
      bool? restrictCpeStreaming,
      List<String>? ottMarkers,
      bool? ottPaddingsBlackout,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      bool? isPremiere,
      int? effectiveContentDuration}) {
    return MostRelevantEpisode(
        id: id ?? this.id,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        recordingState: recordingState ?? this.recordingState,
        viewState: viewState ?? this.viewState,
        minimumAge: minimumAge ?? this.minimumAge,
        seasonId: seasonId ?? this.seasonId,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        isContinuous: isContinuous ?? this.isContinuous,
        failureReason: failureReason ?? this.failureReason,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        ottMarkers: ottMarkers ?? this.ottMarkers,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        isPremiere: isPremiere ?? this.isPremiere,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  MostRelevantEpisode copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<enums.ViewState>? viewState,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? isContinuous,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<List<String>?>? ottMarkers,
      Wrapped<bool?>? ottPaddingsBlackout,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<bool?>? isPremiere,
      Wrapped<int?>? effectiveContentDuration}) {
    return MostRelevantEpisode(
        id: (id != null ? id.value : this.id),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        ottMarkers: (ottMarkers != null ? ottMarkers.value : this.ottMarkers),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeForRecording {
  MostRelevantEpisodeForRecording({
    required this.id,
    required this.startTime,
    required this.endTime,
    this.seasonNumber,
    this.episodeNumber,
    this.duration,
    this.technicalDuration,
    required this.recordingState,
    required this.viewState,
    this.minimumAge,
    this.seasonId,
    this.localRecordingId,
    this.cpeId,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.recordingType,
    this.isContinuous,
    this.failureReason,
    this.channelBasedAuthorization,
    this.restricted,
    this.restrictCpeStreaming,
    this.ottMarkers,
    this.ottPaddingsBlackout,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.isOttBlackout,
    this.isPremiere,
    this.effectiveContentDuration,
  });

  factory MostRelevantEpisodeForRecording.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantEpisodeForRecordingFromJson(json);

  static const toJsonFactory = _$MostRelevantEpisodeForRecordingToJson;
  Map<String, dynamic> toJson() =>
      _$MostRelevantEpisodeForRecordingToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState viewState;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'ottMarkers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ottMarkers;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool? ottPaddingsBlackout;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'effectiveContentDuration', includeIfNull: false)
  final int? effectiveContentDuration;
  static const fromJsonFactory = _$MostRelevantEpisodeForRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeForRecording &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.isContinuous, isContinuous) ||
                const DeepCollectionEquality()
                    .equals(other.isContinuous, isContinuous)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.ottMarkers, ottMarkers) || const DeepCollectionEquality().equals(other.ottMarkers, ottMarkers)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.isOttBlackout, isOttBlackout) || const DeepCollectionEquality().equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.effectiveContentDuration, effectiveContentDuration) || const DeepCollectionEquality().equals(other.effectiveContentDuration, effectiveContentDuration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(ottMarkers) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(effectiveContentDuration) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeForRecordingExtension
    on MostRelevantEpisodeForRecording {
  MostRelevantEpisodeForRecording copyWith(
      {String? id,
      DateTime? startTime,
      DateTime? endTime,
      int? seasonNumber,
      int? episodeNumber,
      int? duration,
      int? technicalDuration,
      enums.RecordingState? recordingState,
      enums.ViewState? viewState,
      int? minimumAge,
      String? seasonId,
      String? localRecordingId,
      String? cpeId,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      enums.RecordingType? recordingType,
      bool? isContinuous,
      enums.FailureReason? failureReason,
      bool? channelBasedAuthorization,
      bool? restricted,
      bool? restrictCpeStreaming,
      List<String>? ottMarkers,
      bool? ottPaddingsBlackout,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      bool? isOttBlackout,
      bool? isPremiere,
      int? effectiveContentDuration}) {
    return MostRelevantEpisodeForRecording(
        id: id ?? this.id,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        recordingState: recordingState ?? this.recordingState,
        viewState: viewState ?? this.viewState,
        minimumAge: minimumAge ?? this.minimumAge,
        seasonId: seasonId ?? this.seasonId,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        recordingType: recordingType ?? this.recordingType,
        isContinuous: isContinuous ?? this.isContinuous,
        failureReason: failureReason ?? this.failureReason,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        ottMarkers: ottMarkers ?? this.ottMarkers,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        effectiveContentDuration:
            effectiveContentDuration ?? this.effectiveContentDuration);
  }

  MostRelevantEpisodeForRecording copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<enums.ViewState>? viewState,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? isContinuous,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<List<String>?>? ottMarkers,
      Wrapped<bool?>? ottPaddingsBlackout,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<int?>? effectiveContentDuration}) {
    return MostRelevantEpisodeForRecording(
        id: (id != null ? id.value : this.id),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        ottMarkers: (ottMarkers != null ? ottMarkers.value : this.ottMarkers),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        effectiveContentDuration: (effectiveContentDuration != null
            ? effectiveContentDuration.value
            : this.effectiveContentDuration));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodeSeason {
  EpisodeSeason({
    this.$number,
    this.shortSynopsis,
    this.poster,
    this.imageVersion,
  });

  factory EpisodeSeason.fromJson(Map<String, dynamic> json) =>
      _$EpisodeSeasonFromJson(json);

  static const toJsonFactory = _$EpisodeSeasonToJson;
  Map<String, dynamic> toJson() => _$EpisodeSeasonToJson(this);

  @JsonKey(name: 'number', includeIfNull: false)
  final int? $number;
  @JsonKey(name: 'shortSynopsis', includeIfNull: false, defaultValue: '')
  final String? shortSynopsis;
  @JsonKey(name: 'poster', includeIfNull: false)
  final EpisodeImage? poster;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodeSeasonFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodeSeason &&
            (identical(other.$number, $number) ||
                const DeepCollectionEquality()
                    .equals(other.$number, $number)) &&
            (identical(other.shortSynopsis, shortSynopsis) ||
                const DeepCollectionEquality()
                    .equals(other.shortSynopsis, shortSynopsis)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash($number) ^
      const DeepCollectionEquality().hash(shortSynopsis) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodeSeasonExtension on EpisodeSeason {
  EpisodeSeason copyWith(
      {int? $number,
      String? shortSynopsis,
      EpisodeImage? poster,
      String? imageVersion}) {
    return EpisodeSeason(
        $number: $number ?? this.$number,
        shortSynopsis: shortSynopsis ?? this.shortSynopsis,
        poster: poster ?? this.poster,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodeSeason copyWithWrapped(
      {Wrapped<int?>? $number,
      Wrapped<String?>? shortSynopsis,
      Wrapped<EpisodeImage?>? poster,
      Wrapped<String?>? imageVersion}) {
    return EpisodeSeason(
        $number: ($number != null ? $number.value : this.$number),
        shortSynopsis:
            (shortSynopsis != null ? shortSynopsis.value : this.shortSynopsis),
        poster: (poster != null ? poster.value : this.poster),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchParams {
  SearchParams({
    this.eventIds,
    this.groupIds,
    this.titleIds,
    this.titleMergedIds,
    this.seriesMergedIds,
    this.recordingStates,
    this.includeRestricted,
  });

  factory SearchParams.fromJson(Map<String, dynamic> json) =>
      _$SearchParamsFromJson(json);

  static const toJsonFactory = _$SearchParamsToJson;
  Map<String, dynamic> toJson() => _$SearchParamsToJson(this);

  @JsonKey(name: 'eventIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? eventIds;
  @JsonKey(name: 'groupIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? groupIds;
  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(
      name: 'titleMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleMergedIds;
  @JsonKey(
      name: 'seriesMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesMergedIds;
  @JsonKey(
    name: 'recordingStates',
    includeIfNull: false,
    toJson: recordingStateListToJson,
    fromJson: recordingStateListFromJson,
  )
  final List<enums.RecordingState>? recordingStates;
  @JsonKey(name: 'includeRestricted', includeIfNull: false)
  final bool? includeRestricted;
  static const fromJsonFactory = _$SearchParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchParams &&
            (identical(other.eventIds, eventIds) ||
                const DeepCollectionEquality()
                    .equals(other.eventIds, eventIds)) &&
            (identical(other.groupIds, groupIds) ||
                const DeepCollectionEquality()
                    .equals(other.groupIds, groupIds)) &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.titleMergedIds, titleMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleMergedIds, titleMergedIds)) &&
            (identical(other.seriesMergedIds, seriesMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesMergedIds, seriesMergedIds)) &&
            (identical(other.recordingStates, recordingStates) ||
                const DeepCollectionEquality()
                    .equals(other.recordingStates, recordingStates)) &&
            (identical(other.includeRestricted, includeRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.includeRestricted, includeRestricted)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventIds) ^
      const DeepCollectionEquality().hash(groupIds) ^
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(titleMergedIds) ^
      const DeepCollectionEquality().hash(seriesMergedIds) ^
      const DeepCollectionEquality().hash(recordingStates) ^
      const DeepCollectionEquality().hash(includeRestricted) ^
      runtimeType.hashCode;
}

extension $SearchParamsExtension on SearchParams {
  SearchParams copyWith(
      {List<String>? eventIds,
      List<String>? groupIds,
      List<String>? titleIds,
      List<String>? titleMergedIds,
      List<String>? seriesMergedIds,
      List<enums.RecordingState>? recordingStates,
      bool? includeRestricted}) {
    return SearchParams(
        eventIds: eventIds ?? this.eventIds,
        groupIds: groupIds ?? this.groupIds,
        titleIds: titleIds ?? this.titleIds,
        titleMergedIds: titleMergedIds ?? this.titleMergedIds,
        seriesMergedIds: seriesMergedIds ?? this.seriesMergedIds,
        recordingStates: recordingStates ?? this.recordingStates,
        includeRestricted: includeRestricted ?? this.includeRestricted);
  }

  SearchParams copyWithWrapped(
      {Wrapped<List<String>?>? eventIds,
      Wrapped<List<String>?>? groupIds,
      Wrapped<List<String>?>? titleIds,
      Wrapped<List<String>?>? titleMergedIds,
      Wrapped<List<String>?>? seriesMergedIds,
      Wrapped<List<enums.RecordingState>?>? recordingStates,
      Wrapped<bool?>? includeRestricted}) {
    return SearchParams(
        eventIds: (eventIds != null ? eventIds.value : this.eventIds),
        groupIds: (groupIds != null ? groupIds.value : this.groupIds),
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        titleMergedIds: (titleMergedIds != null
            ? titleMergedIds.value
            : this.titleMergedIds),
        seriesMergedIds: (seriesMergedIds != null
            ? seriesMergedIds.value
            : this.seriesMergedIds),
        recordingStates: (recordingStates != null
            ? recordingStates.value
            : this.recordingStates),
        includeRestricted: (includeRestricted != null
            ? includeRestricted.value
            : this.includeRestricted));
  }
}

@JsonSerializable(explicitToJson: true)
class PickerSearchParams {
  PickerSearchParams({
    this.titles,
    this.series,
    this.recordingStates,
    this.includeRestricted,
  });

  factory PickerSearchParams.fromJson(Map<String, dynamic> json) =>
      _$PickerSearchParamsFromJson(json);

  static const toJsonFactory = _$PickerSearchParamsToJson;
  Map<String, dynamic> toJson() => _$PickerSearchParamsToJson(this);

  @JsonKey(name: 'titles', includeIfNull: false)
  final Titles? titles;
  @JsonKey(name: 'series', includeIfNull: false)
  final Series? series;
  @JsonKey(
    name: 'recordingStates',
    includeIfNull: false,
    toJson: recordingStateListToJson,
    fromJson: recordingStateListFromJson,
  )
  final List<enums.RecordingState>? recordingStates;
  @JsonKey(name: 'includeRestricted', includeIfNull: false)
  final bool? includeRestricted;
  static const fromJsonFactory = _$PickerSearchParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PickerSearchParams &&
            (identical(other.titles, titles) ||
                const DeepCollectionEquality().equals(other.titles, titles)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.recordingStates, recordingStates) ||
                const DeepCollectionEquality()
                    .equals(other.recordingStates, recordingStates)) &&
            (identical(other.includeRestricted, includeRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.includeRestricted, includeRestricted)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titles) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(recordingStates) ^
      const DeepCollectionEquality().hash(includeRestricted) ^
      runtimeType.hashCode;
}

extension $PickerSearchParamsExtension on PickerSearchParams {
  PickerSearchParams copyWith(
      {Titles? titles,
      Series? series,
      List<enums.RecordingState>? recordingStates,
      bool? includeRestricted}) {
    return PickerSearchParams(
        titles: titles ?? this.titles,
        series: series ?? this.series,
        recordingStates: recordingStates ?? this.recordingStates,
        includeRestricted: includeRestricted ?? this.includeRestricted);
  }

  PickerSearchParams copyWithWrapped(
      {Wrapped<Titles?>? titles,
      Wrapped<Series?>? series,
      Wrapped<List<enums.RecordingState>?>? recordingStates,
      Wrapped<bool?>? includeRestricted}) {
    return PickerSearchParams(
        titles: (titles != null ? titles.value : this.titles),
        series: (series != null ? series.value : this.series),
        recordingStates: (recordingStates != null
            ? recordingStates.value
            : this.recordingStates),
        includeRestricted: (includeRestricted != null
            ? includeRestricted.value
            : this.includeRestricted));
  }
}

@JsonSerializable(explicitToJson: true)
class Titles {
  Titles({
    this.titleIds,
    this.titleMergedIds,
  });

  factory Titles.fromJson(Map<String, dynamic> json) => _$TitlesFromJson(json);

  static const toJsonFactory = _$TitlesToJson;
  Map<String, dynamic> toJson() => _$TitlesToJson(this);

  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(
      name: 'titleMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleMergedIds;
  static const fromJsonFactory = _$TitlesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Titles &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.titleMergedIds, titleMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleMergedIds, titleMergedIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(titleMergedIds) ^
      runtimeType.hashCode;
}

extension $TitlesExtension on Titles {
  Titles copyWith({List<String>? titleIds, List<String>? titleMergedIds}) {
    return Titles(
        titleIds: titleIds ?? this.titleIds,
        titleMergedIds: titleMergedIds ?? this.titleMergedIds);
  }

  Titles copyWithWrapped(
      {Wrapped<List<String>?>? titleIds,
      Wrapped<List<String>?>? titleMergedIds}) {
    return Titles(
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        titleMergedIds: (titleMergedIds != null
            ? titleMergedIds.value
            : this.titleMergedIds));
  }
}

@JsonSerializable(explicitToJson: true)
class Series {
  Series({
    this.seriesIds,
    this.seriesMergedIds,
  });

  factory Series.fromJson(Map<String, dynamic> json) => _$SeriesFromJson(json);

  static const toJsonFactory = _$SeriesToJson;
  Map<String, dynamic> toJson() => _$SeriesToJson(this);

  @JsonKey(name: 'seriesIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesIds;
  @JsonKey(
      name: 'seriesMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesMergedIds;
  static const fromJsonFactory = _$SeriesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Series &&
            (identical(other.seriesIds, seriesIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesIds, seriesIds)) &&
            (identical(other.seriesMergedIds, seriesMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesMergedIds, seriesMergedIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesIds) ^
      const DeepCollectionEquality().hash(seriesMergedIds) ^
      runtimeType.hashCode;
}

extension $SeriesExtension on Series {
  Series copyWith({List<String>? seriesIds, List<String>? seriesMergedIds}) {
    return Series(
        seriesIds: seriesIds ?? this.seriesIds,
        seriesMergedIds: seriesMergedIds ?? this.seriesMergedIds);
  }

  Series copyWithWrapped(
      {Wrapped<List<String>?>? seriesIds,
      Wrapped<List<String>?>? seriesMergedIds}) {
    return Series(
        seriesIds: (seriesIds != null ? seriesIds.value : this.seriesIds),
        seriesMergedIds: (seriesMergedIds != null
            ? seriesMergedIds.value
            : this.seriesMergedIds));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchRecording {
  SearchRecording({
    required this.eventId,
    this.recordingState,
    this.technicalDuration,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    this.localRecordingId,
    this.cpeId,
    this.restrictCpeStreaming,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.episodeNumber,
    this.seasonNumber,
    this.showId,
    this.seasonId,
    this.recordingType,
    this.channelId,
    this.channelBasedAuthorization,
    this.restricted,
    this.isOttBlackout,
    this.isPremiere,
    this.episodePart,
  });

  factory SearchRecording.fromJson(Map<String, dynamic> json) =>
      _$SearchRecordingFromJson(json);

  static const toJsonFactory = _$SearchRecordingToJson;
  Map<String, dynamic> toJson() => _$SearchRecordingToJson(this);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  static const fromJsonFactory = _$SearchRecordingFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchRecording &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) ||
                const DeepCollectionEquality().equals(
                    other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.isOttBlackout, isOttBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(episodePart) ^
      runtimeType.hashCode;
}

extension $SearchRecordingExtension on SearchRecording {
  SearchRecording copyWith(
      {String? eventId,
      enums.RecordingState? recordingState,
      int? technicalDuration,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      String? localRecordingId,
      String? cpeId,
      bool? restrictCpeStreaming,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      int? episodeNumber,
      int? seasonNumber,
      String? showId,
      String? seasonId,
      enums.RecordingType? recordingType,
      String? channelId,
      bool? channelBasedAuthorization,
      bool? restricted,
      bool? isOttBlackout,
      bool? isPremiere,
      int? episodePart}) {
    return SearchRecording(
        eventId: eventId ?? this.eventId,
        recordingState: recordingState ?? this.recordingState,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        showId: showId ?? this.showId,
        seasonId: seasonId ?? this.seasonId,
        recordingType: recordingType ?? this.recordingType,
        channelId: channelId ?? this.channelId,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        episodePart: episodePart ?? this.episodePart);
  }

  SearchRecording copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<int?>? technicalDuration,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? seasonId,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<String?>? channelId,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<int?>? episodePart}) {
    return SearchRecording(
        eventId: (eventId != null ? eventId.value : this.eventId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        showId: (showId != null ? showId.value : this.showId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart));
  }
}

@JsonSerializable(explicitToJson: true)
class AudioLanguage {
  AudioLanguage({
    required this.lang,
    this.purpose,
  });

  factory AudioLanguage.fromJson(Map<String, dynamic> json) =>
      _$AudioLanguageFromJson(json);

  static const toJsonFactory = _$AudioLanguageToJson;
  Map<String, dynamic> toJson() => _$AudioLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$AudioLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AudioLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $AudioLanguageExtension on AudioLanguage {
  AudioLanguage copyWith({String? lang, int? purpose}) {
    return AudioLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  AudioLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return AudioLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class CaptionLanguage {
  CaptionLanguage({
    required this.lang,
    this.purpose,
  });

  factory CaptionLanguage.fromJson(Map<String, dynamic> json) =>
      _$CaptionLanguageFromJson(json);

  static const toJsonFactory = _$CaptionLanguageToJson;
  Map<String, dynamic> toJson() => _$CaptionLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$CaptionLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CaptionLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $CaptionLanguageExtension on CaptionLanguage {
  CaptionLanguage copyWith({String? lang, int? purpose}) {
    return CaptionLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  CaptionLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return CaptionLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class SignLanguage {
  SignLanguage({
    required this.lang,
    this.purpose,
  });

  factory SignLanguage.fromJson(Map<String, dynamic> json) =>
      _$SignLanguageFromJson(json);

  static const toJsonFactory = _$SignLanguageToJson;
  Map<String, dynamic> toJson() => _$SignLanguageToJson(this);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$SignLanguageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SignLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $SignLanguageExtension on SignLanguage {
  SignLanguage copyWith({String? lang, int? purpose}) {
    return SignLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  SignLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return SignLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowCancelParams {
  ShowCancelParams({
    required this.showId,
    required this.channelId,
  });

  factory ShowCancelParams.fromJson(Map<String, dynamic> json) =>
      _$ShowCancelParamsFromJson(json);

  static const toJsonFactory = _$ShowCancelParamsToJson;
  Map<String, dynamic> toJson() => _$ShowCancelParamsToJson(this);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  static const fromJsonFactory = _$ShowCancelParamsFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowCancelParams &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $ShowCancelParamsExtension on ShowCancelParams {
  ShowCancelParams copyWith({String? showId, String? channelId}) {
    return ShowCancelParams(
        showId: showId ?? this.showId, channelId: channelId ?? this.channelId);
  }

  ShowCancelParams copyWithWrapped(
      {Wrapped<String>? showId, Wrapped<String>? channelId}) {
    return ShowCancelParams(
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomersCustomerIdRecordingsCleanupGet$Response {
  CustomersCustomerIdRecordingsCleanupGet$Response({
    this.total,
    this.data,
    this.uuid,
  });

  factory CustomersCustomerIdRecordingsCleanupGet$Response.fromJson(
          Map<String, dynamic> json) =>
      _$CustomersCustomerIdRecordingsCleanupGet$ResponseFromJson(json);

  static const toJsonFactory =
      _$CustomersCustomerIdRecordingsCleanupGet$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$CustomersCustomerIdRecordingsCleanupGet$ResponseToJson(this);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(
      name: 'data',
      includeIfNull: false,
      defaultValue: <CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item>[])
  final List<CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item>? data;
  @JsonKey(name: 'uuid', includeIfNull: false, defaultValue: '')
  final String? uuid;
  static const fromJsonFactory =
      _$CustomersCustomerIdRecordingsCleanupGet$ResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomersCustomerIdRecordingsCleanupGet$Response &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.uuid, uuid) ||
                const DeepCollectionEquality().equals(other.uuid, uuid)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(uuid) ^
      runtimeType.hashCode;
}

extension $CustomersCustomerIdRecordingsCleanupGet$ResponseExtension
    on CustomersCustomerIdRecordingsCleanupGet$Response {
  CustomersCustomerIdRecordingsCleanupGet$Response copyWith(
      {int? total,
      List<CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item>? data,
      String? uuid}) {
    return CustomersCustomerIdRecordingsCleanupGet$Response(
        total: total ?? this.total,
        data: data ?? this.data,
        uuid: uuid ?? this.uuid);
  }

  CustomersCustomerIdRecordingsCleanupGet$Response copyWithWrapped(
      {Wrapped<int?>? total,
      Wrapped<
              List<
                  CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item>?>?
          data,
      Wrapped<String?>? uuid}) {
    return CustomersCustomerIdRecordingsCleanupGet$Response(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data),
        uuid: (uuid != null ? uuid.value : this.uuid));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

typedef CustomersCustomerIdRecordingsCleanupGet$Response$Data
    = List<CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item>;

@JsonSerializable(explicitToJson: true)
class CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item {
  CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item({
    this.id,
  });

  factory CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item.fromJson(
          Map<String, dynamic> json) =>
      _$CustomersCustomerIdRecordingsCleanupGet$Response$Data$ItemFromJson(
          json);

  static const toJsonFactory =
      _$CustomersCustomerIdRecordingsCleanupGet$Response$Data$ItemToJson;
  Map<String, dynamic> toJson() =>
      _$CustomersCustomerIdRecordingsCleanupGet$Response$Data$ItemToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory =
      _$CustomersCustomerIdRecordingsCleanupGet$Response$Data$ItemFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $CustomersCustomerIdRecordingsCleanupGet$Response$Data$ItemExtension
    on CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item {
  CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item copyWith(
      {String? id}) {
    return CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item(
        id: id ?? this.id);
  }

  CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item copyWithWrapped(
      {Wrapped<String?>? id}) {
    return CustomersCustomerIdRecordingsCleanupGet$Response$Data$Item(
        id: (id != null ? id.value : this.id));
  }
}

String? sourceTypeToJson(enums.SourceType? sourceType) {
  return sourceType?.value;
}

enums.SourceType sourceTypeFromJson(
  Object? sourceType, [
  enums.SourceType? defaultValue,
]) {
  return enums.SourceType.values
          .firstWhereOrNull((e) => e.value == sourceType) ??
      defaultValue ??
      enums.SourceType.swaggerGeneratedUnknown;
}

List<String> sourceTypeListToJson(List<enums.SourceType>? sourceType) {
  if (sourceType == null) {
    return [];
  }

  return sourceType.map((e) => e.value!).toList();
}

List<enums.SourceType> sourceTypeListFromJson(
  List? sourceType, [
  List<enums.SourceType>? defaultValue,
]) {
  if (sourceType == null) {
    return defaultValue ?? [];
  }

  return sourceType.map((e) => sourceTypeFromJson(e.toString())).toList();
}

List<enums.SourceType>? sourceTypeNullableListFromJson(
  List? sourceType, [
  List<enums.SourceType>? defaultValue,
]) {
  if (sourceType == null) {
    return defaultValue;
  }

  return sourceType.map((e) => sourceTypeFromJson(e.toString())).toList();
}

String? itemTypeToJson(enums.ItemType? itemType) {
  return itemType?.value;
}

enums.ItemType itemTypeFromJson(
  Object? itemType, [
  enums.ItemType? defaultValue,
]) {
  return enums.ItemType.values.firstWhereOrNull((e) => e.value == itemType) ??
      defaultValue ??
      enums.ItemType.swaggerGeneratedUnknown;
}

List<String> itemTypeListToJson(List<enums.ItemType>? itemType) {
  if (itemType == null) {
    return [];
  }

  return itemType.map((e) => e.value!).toList();
}

List<enums.ItemType> itemTypeListFromJson(
  List? itemType, [
  List<enums.ItemType>? defaultValue,
]) {
  if (itemType == null) {
    return defaultValue ?? [];
  }

  return itemType.map((e) => itemTypeFromJson(e.toString())).toList();
}

List<enums.ItemType>? itemTypeNullableListFromJson(
  List? itemType, [
  List<enums.ItemType>? defaultValue,
]) {
  if (itemType == null) {
    return defaultValue;
  }

  return itemType.map((e) => itemTypeFromJson(e.toString())).toList();
}

String? recordingStateToJson(enums.RecordingState? recordingState) {
  return recordingState?.value;
}

enums.RecordingState recordingStateFromJson(
  Object? recordingState, [
  enums.RecordingState? defaultValue,
]) {
  return enums.RecordingState.values
          .firstWhereOrNull((e) => e.value == recordingState) ??
      defaultValue ??
      enums.RecordingState.swaggerGeneratedUnknown;
}

List<String> recordingStateListToJson(
    List<enums.RecordingState>? recordingState) {
  if (recordingState == null) {
    return [];
  }

  return recordingState.map((e) => e.value!).toList();
}

List<enums.RecordingState> recordingStateListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue ?? [];
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

List<enums.RecordingState>? recordingStateNullableListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue;
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

String? recordingStatePendingToJson(
    enums.RecordingStatePending? recordingStatePending) {
  return recordingStatePending?.value;
}

enums.RecordingStatePending recordingStatePendingFromJson(
  Object? recordingStatePending, [
  enums.RecordingStatePending? defaultValue,
]) {
  return enums.RecordingStatePending.values
          .firstWhereOrNull((e) => e.value == recordingStatePending) ??
      defaultValue ??
      enums.RecordingStatePending.swaggerGeneratedUnknown;
}

List<String> recordingStatePendingListToJson(
    List<enums.RecordingStatePending>? recordingStatePending) {
  if (recordingStatePending == null) {
    return [];
  }

  return recordingStatePending.map((e) => e.value!).toList();
}

List<enums.RecordingStatePending> recordingStatePendingListFromJson(
  List? recordingStatePending, [
  List<enums.RecordingStatePending>? defaultValue,
]) {
  if (recordingStatePending == null) {
    return defaultValue ?? [];
  }

  return recordingStatePending
      .map((e) => recordingStatePendingFromJson(e.toString()))
      .toList();
}

List<enums.RecordingStatePending>? recordingStatePendingNullableListFromJson(
  List? recordingStatePending, [
  List<enums.RecordingStatePending>? defaultValue,
]) {
  if (recordingStatePending == null) {
    return defaultValue;
  }

  return recordingStatePending
      .map((e) => recordingStatePendingFromJson(e.toString()))
      .toList();
}

String? viewStateToJson(enums.ViewState? viewState) {
  return viewState?.value;
}

enums.ViewState viewStateFromJson(
  Object? viewState, [
  enums.ViewState? defaultValue,
]) {
  return enums.ViewState.values.firstWhereOrNull((e) => e.value == viewState) ??
      defaultValue ??
      enums.ViewState.swaggerGeneratedUnknown;
}

List<String> viewStateListToJson(List<enums.ViewState>? viewState) {
  if (viewState == null) {
    return [];
  }

  return viewState.map((e) => e.value!).toList();
}

List<enums.ViewState> viewStateListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue ?? [];
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

List<enums.ViewState>? viewStateNullableListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue;
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

String? imageTypeToJson(enums.ImageType? imageType) {
  return imageType?.value;
}

enums.ImageType imageTypeFromJson(
  Object? imageType, [
  enums.ImageType? defaultValue,
]) {
  return enums.ImageType.values.firstWhereOrNull((e) => e.value == imageType) ??
      defaultValue ??
      enums.ImageType.swaggerGeneratedUnknown;
}

List<String> imageTypeListToJson(List<enums.ImageType>? imageType) {
  if (imageType == null) {
    return [];
  }

  return imageType.map((e) => e.value!).toList();
}

List<enums.ImageType> imageTypeListFromJson(
  List? imageType, [
  List<enums.ImageType>? defaultValue,
]) {
  if (imageType == null) {
    return defaultValue ?? [];
  }

  return imageType.map((e) => imageTypeFromJson(e.toString())).toList();
}

List<enums.ImageType>? imageTypeNullableListFromJson(
  List? imageType, [
  List<enums.ImageType>? defaultValue,
]) {
  if (imageType == null) {
    return defaultValue;
  }

  return imageType.map((e) => imageTypeFromJson(e.toString())).toList();
}

String? episodeImageTypeToJson(enums.EpisodeImageType? episodeImageType) {
  return episodeImageType?.value;
}

enums.EpisodeImageType episodeImageTypeFromJson(
  Object? episodeImageType, [
  enums.EpisodeImageType? defaultValue,
]) {
  return enums.EpisodeImageType.values
          .firstWhereOrNull((e) => e.value == episodeImageType) ??
      defaultValue ??
      enums.EpisodeImageType.swaggerGeneratedUnknown;
}

List<String> episodeImageTypeListToJson(
    List<enums.EpisodeImageType>? episodeImageType) {
  if (episodeImageType == null) {
    return [];
  }

  return episodeImageType.map((e) => e.value!).toList();
}

List<enums.EpisodeImageType> episodeImageTypeListFromJson(
  List? episodeImageType, [
  List<enums.EpisodeImageType>? defaultValue,
]) {
  if (episodeImageType == null) {
    return defaultValue ?? [];
  }

  return episodeImageType
      .map((e) => episodeImageTypeFromJson(e.toString()))
      .toList();
}

List<enums.EpisodeImageType>? episodeImageTypeNullableListFromJson(
  List? episodeImageType, [
  List<enums.EpisodeImageType>? defaultValue,
]) {
  if (episodeImageType == null) {
    return defaultValue;
  }

  return episodeImageType
      .map((e) => episodeImageTypeFromJson(e.toString()))
      .toList();
}

String? tileBookingRecordingStateToJson(
    enums.TileBookingRecordingState? tileBookingRecordingState) {
  return tileBookingRecordingState?.value;
}

enums.TileBookingRecordingState tileBookingRecordingStateFromJson(
  Object? tileBookingRecordingState, [
  enums.TileBookingRecordingState? defaultValue,
]) {
  return enums.TileBookingRecordingState.values
          .firstWhereOrNull((e) => e.value == tileBookingRecordingState) ??
      defaultValue ??
      enums.TileBookingRecordingState.swaggerGeneratedUnknown;
}

List<String> tileBookingRecordingStateListToJson(
    List<enums.TileBookingRecordingState>? tileBookingRecordingState) {
  if (tileBookingRecordingState == null) {
    return [];
  }

  return tileBookingRecordingState.map((e) => e.value!).toList();
}

List<enums.TileBookingRecordingState> tileBookingRecordingStateListFromJson(
  List? tileBookingRecordingState, [
  List<enums.TileBookingRecordingState>? defaultValue,
]) {
  if (tileBookingRecordingState == null) {
    return defaultValue ?? [];
  }

  return tileBookingRecordingState
      .map((e) => tileBookingRecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.TileBookingRecordingState>?
    tileBookingRecordingStateNullableListFromJson(
  List? tileBookingRecordingState, [
  List<enums.TileBookingRecordingState>? defaultValue,
]) {
  if (tileBookingRecordingState == null) {
    return defaultValue;
  }

  return tileBookingRecordingState
      .map((e) => tileBookingRecordingStateFromJson(e.toString()))
      .toList();
}

String? tileBookingTypeToJson(enums.TileBookingType? tileBookingType) {
  return tileBookingType?.value;
}

enums.TileBookingType tileBookingTypeFromJson(
  Object? tileBookingType, [
  enums.TileBookingType? defaultValue,
]) {
  return enums.TileBookingType.values
          .firstWhereOrNull((e) => e.value == tileBookingType) ??
      defaultValue ??
      enums.TileBookingType.swaggerGeneratedUnknown;
}

List<String> tileBookingTypeListToJson(
    List<enums.TileBookingType>? tileBookingType) {
  if (tileBookingType == null) {
    return [];
  }

  return tileBookingType.map((e) => e.value!).toList();
}

List<enums.TileBookingType> tileBookingTypeListFromJson(
  List? tileBookingType, [
  List<enums.TileBookingType>? defaultValue,
]) {
  if (tileBookingType == null) {
    return defaultValue ?? [];
  }

  return tileBookingType
      .map((e) => tileBookingTypeFromJson(e.toString()))
      .toList();
}

List<enums.TileBookingType>? tileBookingTypeNullableListFromJson(
  List? tileBookingType, [
  List<enums.TileBookingType>? defaultValue,
]) {
  if (tileBookingType == null) {
    return defaultValue;
  }

  return tileBookingType
      .map((e) => tileBookingTypeFromJson(e.toString()))
      .toList();
}

String? contextualRecordingRecordingStateToJson(
    enums.ContextualRecordingRecordingState?
        contextualRecordingRecordingState) {
  return contextualRecordingRecordingState?.value;
}

enums.ContextualRecordingRecordingState
    contextualRecordingRecordingStateFromJson(
  Object? contextualRecordingRecordingState, [
  enums.ContextualRecordingRecordingState? defaultValue,
]) {
  return enums.ContextualRecordingRecordingState.values.firstWhereOrNull(
          (e) => e.value == contextualRecordingRecordingState) ??
      defaultValue ??
      enums.ContextualRecordingRecordingState.swaggerGeneratedUnknown;
}

List<String> contextualRecordingRecordingStateListToJson(
    List<enums.ContextualRecordingRecordingState>?
        contextualRecordingRecordingState) {
  if (contextualRecordingRecordingState == null) {
    return [];
  }

  return contextualRecordingRecordingState.map((e) => e.value!).toList();
}

List<enums.ContextualRecordingRecordingState>
    contextualRecordingRecordingStateListFromJson(
  List? contextualRecordingRecordingState, [
  List<enums.ContextualRecordingRecordingState>? defaultValue,
]) {
  if (contextualRecordingRecordingState == null) {
    return defaultValue ?? [];
  }

  return contextualRecordingRecordingState
      .map((e) => contextualRecordingRecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.ContextualRecordingRecordingState>?
    contextualRecordingRecordingStateNullableListFromJson(
  List? contextualRecordingRecordingState, [
  List<enums.ContextualRecordingRecordingState>? defaultValue,
]) {
  if (contextualRecordingRecordingState == null) {
    return defaultValue;
  }

  return contextualRecordingRecordingState
      .map((e) => contextualRecordingRecordingStateFromJson(e.toString()))
      .toList();
}

String? contextualRecordingTypeToJson(
    enums.ContextualRecordingType? contextualRecordingType) {
  return contextualRecordingType?.value;
}

enums.ContextualRecordingType contextualRecordingTypeFromJson(
  Object? contextualRecordingType, [
  enums.ContextualRecordingType? defaultValue,
]) {
  return enums.ContextualRecordingType.values
          .firstWhereOrNull((e) => e.value == contextualRecordingType) ??
      defaultValue ??
      enums.ContextualRecordingType.swaggerGeneratedUnknown;
}

List<String> contextualRecordingTypeListToJson(
    List<enums.ContextualRecordingType>? contextualRecordingType) {
  if (contextualRecordingType == null) {
    return [];
  }

  return contextualRecordingType.map((e) => e.value!).toList();
}

List<enums.ContextualRecordingType> contextualRecordingTypeListFromJson(
  List? contextualRecordingType, [
  List<enums.ContextualRecordingType>? defaultValue,
]) {
  if (contextualRecordingType == null) {
    return defaultValue ?? [];
  }

  return contextualRecordingType
      .map((e) => contextualRecordingTypeFromJson(e.toString()))
      .toList();
}

List<enums.ContextualRecordingType>?
    contextualRecordingTypeNullableListFromJson(
  List? contextualRecordingType, [
  List<enums.ContextualRecordingType>? defaultValue,
]) {
  if (contextualRecordingType == null) {
    return defaultValue;
  }

  return contextualRecordingType
      .map((e) => contextualRecordingTypeFromJson(e.toString()))
      .toList();
}

String? tileRecordingRecordingStateToJson(
    enums.TileRecordingRecordingState? tileRecordingRecordingState) {
  return tileRecordingRecordingState?.value;
}

enums.TileRecordingRecordingState tileRecordingRecordingStateFromJson(
  Object? tileRecordingRecordingState, [
  enums.TileRecordingRecordingState? defaultValue,
]) {
  return enums.TileRecordingRecordingState.values
          .firstWhereOrNull((e) => e.value == tileRecordingRecordingState) ??
      defaultValue ??
      enums.TileRecordingRecordingState.swaggerGeneratedUnknown;
}

List<String> tileRecordingRecordingStateListToJson(
    List<enums.TileRecordingRecordingState>? tileRecordingRecordingState) {
  if (tileRecordingRecordingState == null) {
    return [];
  }

  return tileRecordingRecordingState.map((e) => e.value!).toList();
}

List<enums.TileRecordingRecordingState> tileRecordingRecordingStateListFromJson(
  List? tileRecordingRecordingState, [
  List<enums.TileRecordingRecordingState>? defaultValue,
]) {
  if (tileRecordingRecordingState == null) {
    return defaultValue ?? [];
  }

  return tileRecordingRecordingState
      .map((e) => tileRecordingRecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.TileRecordingRecordingState>?
    tileRecordingRecordingStateNullableListFromJson(
  List? tileRecordingRecordingState, [
  List<enums.TileRecordingRecordingState>? defaultValue,
]) {
  if (tileRecordingRecordingState == null) {
    return defaultValue;
  }

  return tileRecordingRecordingState
      .map((e) => tileRecordingRecordingStateFromJson(e.toString()))
      .toList();
}

String? tileRecordingTypeToJson(enums.TileRecordingType? tileRecordingType) {
  return tileRecordingType?.value;
}

enums.TileRecordingType tileRecordingTypeFromJson(
  Object? tileRecordingType, [
  enums.TileRecordingType? defaultValue,
]) {
  return enums.TileRecordingType.values
          .firstWhereOrNull((e) => e.value == tileRecordingType) ??
      defaultValue ??
      enums.TileRecordingType.swaggerGeneratedUnknown;
}

List<String> tileRecordingTypeListToJson(
    List<enums.TileRecordingType>? tileRecordingType) {
  if (tileRecordingType == null) {
    return [];
  }

  return tileRecordingType.map((e) => e.value!).toList();
}

List<enums.TileRecordingType> tileRecordingTypeListFromJson(
  List? tileRecordingType, [
  List<enums.TileRecordingType>? defaultValue,
]) {
  if (tileRecordingType == null) {
    return defaultValue ?? [];
  }

  return tileRecordingType
      .map((e) => tileRecordingTypeFromJson(e.toString()))
      .toList();
}

List<enums.TileRecordingType>? tileRecordingTypeNullableListFromJson(
  List? tileRecordingType, [
  List<enums.TileRecordingType>? defaultValue,
]) {
  if (tileRecordingType == null) {
    return defaultValue;
  }

  return tileRecordingType
      .map((e) => tileRecordingTypeFromJson(e.toString()))
      .toList();
}

String? recordingTypeToJson(enums.RecordingType? recordingType) {
  return recordingType?.value;
}

enums.RecordingType recordingTypeFromJson(
  Object? recordingType, [
  enums.RecordingType? defaultValue,
]) {
  return enums.RecordingType.values
          .firstWhereOrNull((e) => e.value == recordingType) ??
      defaultValue ??
      enums.RecordingType.swaggerGeneratedUnknown;
}

List<String> recordingTypeListToJson(List<enums.RecordingType>? recordingType) {
  if (recordingType == null) {
    return [];
  }

  return recordingType.map((e) => e.value!).toList();
}

List<enums.RecordingType> recordingTypeListFromJson(
  List? recordingType, [
  List<enums.RecordingType>? defaultValue,
]) {
  if (recordingType == null) {
    return defaultValue ?? [];
  }

  return recordingType.map((e) => recordingTypeFromJson(e.toString())).toList();
}

List<enums.RecordingType>? recordingTypeNullableListFromJson(
  List? recordingType, [
  List<enums.RecordingType>? defaultValue,
]) {
  if (recordingType == null) {
    return defaultValue;
  }

  return recordingType.map((e) => recordingTypeFromJson(e.toString())).toList();
}

String? opToJson(enums.Op? op) {
  return op?.value;
}

enums.Op opFromJson(
  Object? op, [
  enums.Op? defaultValue,
]) {
  return enums.Op.values.firstWhereOrNull((e) => e.value == op) ??
      defaultValue ??
      enums.Op.swaggerGeneratedUnknown;
}

List<String> opListToJson(List<enums.Op>? op) {
  if (op == null) {
    return [];
  }

  return op.map((e) => e.value!).toList();
}

List<enums.Op> opListFromJson(
  List? op, [
  List<enums.Op>? defaultValue,
]) {
  if (op == null) {
    return defaultValue ?? [];
  }

  return op.map((e) => opFromJson(e.toString())).toList();
}

List<enums.Op>? opNullableListFromJson(
  List? op, [
  List<enums.Op>? defaultValue,
]) {
  if (op == null) {
    return defaultValue;
  }

  return op.map((e) => opFromJson(e.toString())).toList();
}

String? expansionTypeToJson(enums.ExpansionType? expansionType) {
  return expansionType?.value;
}

enums.ExpansionType expansionTypeFromJson(
  Object? expansionType, [
  enums.ExpansionType? defaultValue,
]) {
  return enums.ExpansionType.values
          .firstWhereOrNull((e) => e.value == expansionType) ??
      defaultValue ??
      enums.ExpansionType.swaggerGeneratedUnknown;
}

List<String> expansionTypeListToJson(List<enums.ExpansionType>? expansionType) {
  if (expansionType == null) {
    return [];
  }

  return expansionType.map((e) => e.value!).toList();
}

List<enums.ExpansionType> expansionTypeListFromJson(
  List? expansionType, [
  List<enums.ExpansionType>? defaultValue,
]) {
  if (expansionType == null) {
    return defaultValue ?? [];
  }

  return expansionType.map((e) => expansionTypeFromJson(e.toString())).toList();
}

List<enums.ExpansionType>? expansionTypeNullableListFromJson(
  List? expansionType, [
  List<enums.ExpansionType>? defaultValue,
]) {
  if (expansionType == null) {
    return defaultValue;
  }

  return expansionType.map((e) => expansionTypeFromJson(e.toString())).toList();
}

String? failureReasonToJson(enums.FailureReason? failureReason) {
  return failureReason?.value;
}

enums.FailureReason failureReasonFromJson(
  Object? failureReason, [
  enums.FailureReason? defaultValue,
]) {
  return enums.FailureReason.values
          .firstWhereOrNull((e) => e.value == failureReason) ??
      defaultValue ??
      enums.FailureReason.swaggerGeneratedUnknown;
}

List<String> failureReasonListToJson(List<enums.FailureReason>? failureReason) {
  if (failureReason == null) {
    return [];
  }

  return failureReason.map((e) => e.value!).toList();
}

List<enums.FailureReason> failureReasonListFromJson(
  List? failureReason, [
  List<enums.FailureReason>? defaultValue,
]) {
  if (failureReason == null) {
    return defaultValue ?? [];
  }

  return failureReason.map((e) => failureReasonFromJson(e.toString())).toList();
}

List<enums.FailureReason>? failureReasonNullableListFromJson(
  List? failureReason, [
  List<enums.FailureReason>? defaultValue,
]) {
  if (failureReason == null) {
    return defaultValue;
  }

  return failureReason.map((e) => failureReasonFromJson(e.toString())).toList();
}

String? customersCustomerIdBookingsGetSortToJson(
    enums.CustomersCustomerIdBookingsGetSort?
        customersCustomerIdBookingsGetSort) {
  return customersCustomerIdBookingsGetSort?.value;
}

enums.CustomersCustomerIdBookingsGetSort
    customersCustomerIdBookingsGetSortFromJson(
  Object? customersCustomerIdBookingsGetSort, [
  enums.CustomersCustomerIdBookingsGetSort? defaultValue,
]) {
  return enums.CustomersCustomerIdBookingsGetSort.values.firstWhereOrNull(
          (e) => e.value == customersCustomerIdBookingsGetSort) ??
      defaultValue ??
      enums.CustomersCustomerIdBookingsGetSort.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdBookingsGetSortListToJson(
    List<enums.CustomersCustomerIdBookingsGetSort>?
        customersCustomerIdBookingsGetSort) {
  if (customersCustomerIdBookingsGetSort == null) {
    return [];
  }

  return customersCustomerIdBookingsGetSort.map((e) => e.value!).toList();
}

List<enums.CustomersCustomerIdBookingsGetSort>
    customersCustomerIdBookingsGetSortListFromJson(
  List? customersCustomerIdBookingsGetSort, [
  List<enums.CustomersCustomerIdBookingsGetSort>? defaultValue,
]) {
  if (customersCustomerIdBookingsGetSort == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdBookingsGetSort
      .map((e) => customersCustomerIdBookingsGetSortFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdBookingsGetSort>?
    customersCustomerIdBookingsGetSortNullableListFromJson(
  List? customersCustomerIdBookingsGetSort, [
  List<enums.CustomersCustomerIdBookingsGetSort>? defaultValue,
]) {
  if (customersCustomerIdBookingsGetSort == null) {
    return defaultValue;
  }

  return customersCustomerIdBookingsGetSort
      .map((e) => customersCustomerIdBookingsGetSortFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdBookingsGetSortOrderToJson(
    enums.CustomersCustomerIdBookingsGetSortOrder?
        customersCustomerIdBookingsGetSortOrder) {
  return customersCustomerIdBookingsGetSortOrder?.value;
}

enums.CustomersCustomerIdBookingsGetSortOrder
    customersCustomerIdBookingsGetSortOrderFromJson(
  Object? customersCustomerIdBookingsGetSortOrder, [
  enums.CustomersCustomerIdBookingsGetSortOrder? defaultValue,
]) {
  return enums.CustomersCustomerIdBookingsGetSortOrder.values.firstWhereOrNull(
          (e) => e.value == customersCustomerIdBookingsGetSortOrder) ??
      defaultValue ??
      enums.CustomersCustomerIdBookingsGetSortOrder.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdBookingsGetSortOrderListToJson(
    List<enums.CustomersCustomerIdBookingsGetSortOrder>?
        customersCustomerIdBookingsGetSortOrder) {
  if (customersCustomerIdBookingsGetSortOrder == null) {
    return [];
  }

  return customersCustomerIdBookingsGetSortOrder.map((e) => e.value!).toList();
}

List<enums.CustomersCustomerIdBookingsGetSortOrder>
    customersCustomerIdBookingsGetSortOrderListFromJson(
  List? customersCustomerIdBookingsGetSortOrder, [
  List<enums.CustomersCustomerIdBookingsGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdBookingsGetSortOrder == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdBookingsGetSortOrder
      .map((e) => customersCustomerIdBookingsGetSortOrderFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdBookingsGetSortOrder>?
    customersCustomerIdBookingsGetSortOrderNullableListFromJson(
  List? customersCustomerIdBookingsGetSortOrder, [
  List<enums.CustomersCustomerIdBookingsGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdBookingsGetSortOrder == null) {
    return defaultValue;
  }

  return customersCustomerIdBookingsGetSortOrder
      .map((e) => customersCustomerIdBookingsGetSortOrderFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsGetSortToJson(
    enums.CustomersCustomerIdRecordingsGetSort?
        customersCustomerIdRecordingsGetSort) {
  return customersCustomerIdRecordingsGetSort?.value;
}

enums.CustomersCustomerIdRecordingsGetSort
    customersCustomerIdRecordingsGetSortFromJson(
  Object? customersCustomerIdRecordingsGetSort, [
  enums.CustomersCustomerIdRecordingsGetSort? defaultValue,
]) {
  return enums.CustomersCustomerIdRecordingsGetSort.values.firstWhereOrNull(
          (e) => e.value == customersCustomerIdRecordingsGetSort) ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsGetSort.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsGetSortListToJson(
    List<enums.CustomersCustomerIdRecordingsGetSort>?
        customersCustomerIdRecordingsGetSort) {
  if (customersCustomerIdRecordingsGetSort == null) {
    return [];
  }

  return customersCustomerIdRecordingsGetSort.map((e) => e.value!).toList();
}

List<enums.CustomersCustomerIdRecordingsGetSort>
    customersCustomerIdRecordingsGetSortListFromJson(
  List? customersCustomerIdRecordingsGetSort, [
  List<enums.CustomersCustomerIdRecordingsGetSort>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSort == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsGetSort
      .map((e) => customersCustomerIdRecordingsGetSortFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSort>?
    customersCustomerIdRecordingsGetSortNullableListFromJson(
  List? customersCustomerIdRecordingsGetSort, [
  List<enums.CustomersCustomerIdRecordingsGetSort>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSort == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsGetSort
      .map((e) => customersCustomerIdRecordingsGetSortFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsGetSortOrderToJson(
    enums.CustomersCustomerIdRecordingsGetSortOrder?
        customersCustomerIdRecordingsGetSortOrder) {
  return customersCustomerIdRecordingsGetSortOrder?.value;
}

enums.CustomersCustomerIdRecordingsGetSortOrder
    customersCustomerIdRecordingsGetSortOrderFromJson(
  Object? customersCustomerIdRecordingsGetSortOrder, [
  enums.CustomersCustomerIdRecordingsGetSortOrder? defaultValue,
]) {
  return enums.CustomersCustomerIdRecordingsGetSortOrder.values
          .firstWhereOrNull(
              (e) => e.value == customersCustomerIdRecordingsGetSortOrder) ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsGetSortOrder.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsGetSortOrderListToJson(
    List<enums.CustomersCustomerIdRecordingsGetSortOrder>?
        customersCustomerIdRecordingsGetSortOrder) {
  if (customersCustomerIdRecordingsGetSortOrder == null) {
    return [];
  }

  return customersCustomerIdRecordingsGetSortOrder
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSortOrder>
    customersCustomerIdRecordingsGetSortOrderListFromJson(
  List? customersCustomerIdRecordingsGetSortOrder, [
  List<enums.CustomersCustomerIdRecordingsGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSortOrder == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsGetSortOrder
      .map((e) =>
          customersCustomerIdRecordingsGetSortOrderFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSortOrder>?
    customersCustomerIdRecordingsGetSortOrderNullableListFromJson(
  List? customersCustomerIdRecordingsGetSortOrder, [
  List<enums.CustomersCustomerIdRecordingsGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSortOrder == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsGetSortOrder
      .map((e) =>
          customersCustomerIdRecordingsGetSortOrderFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsSimpleGetStatusToJson(
    enums.CustomersCustomerIdRecordingsSimpleGetStatus?
        customersCustomerIdRecordingsSimpleGetStatus) {
  return customersCustomerIdRecordingsSimpleGetStatus?.value;
}

enums.CustomersCustomerIdRecordingsSimpleGetStatus
    customersCustomerIdRecordingsSimpleGetStatusFromJson(
  Object? customersCustomerIdRecordingsSimpleGetStatus, [
  enums.CustomersCustomerIdRecordingsSimpleGetStatus? defaultValue,
]) {
  return enums.CustomersCustomerIdRecordingsSimpleGetStatus.values
          .firstWhereOrNull(
              (e) => e.value == customersCustomerIdRecordingsSimpleGetStatus) ??
      defaultValue ??
      enums
          .CustomersCustomerIdRecordingsSimpleGetStatus.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsSimpleGetStatusListToJson(
    List<enums.CustomersCustomerIdRecordingsSimpleGetStatus>?
        customersCustomerIdRecordingsSimpleGetStatus) {
  if (customersCustomerIdRecordingsSimpleGetStatus == null) {
    return [];
  }

  return customersCustomerIdRecordingsSimpleGetStatus
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsSimpleGetStatus>
    customersCustomerIdRecordingsSimpleGetStatusListFromJson(
  List? customersCustomerIdRecordingsSimpleGetStatus, [
  List<enums.CustomersCustomerIdRecordingsSimpleGetStatus>? defaultValue,
]) {
  if (customersCustomerIdRecordingsSimpleGetStatus == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsSimpleGetStatus
      .map((e) =>
          customersCustomerIdRecordingsSimpleGetStatusFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsSimpleGetStatus>?
    customersCustomerIdRecordingsSimpleGetStatusNullableListFromJson(
  List? customersCustomerIdRecordingsSimpleGetStatus, [
  List<enums.CustomersCustomerIdRecordingsSimpleGetStatus>? defaultValue,
]) {
  if (customersCustomerIdRecordingsSimpleGetStatus == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsSimpleGetStatus
      .map((e) =>
          customersCustomerIdRecordingsSimpleGetStatusFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdEpisodesSeasonsSeasonIdGetSourceToJson(
    enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource?
        customersCustomerIdEpisodesSeasonsSeasonIdGetSource) {
  return customersCustomerIdEpisodesSeasonsSeasonIdGetSource?.value;
}

enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource
    customersCustomerIdEpisodesSeasonsSeasonIdGetSourceFromJson(
  Object? customersCustomerIdEpisodesSeasonsSeasonIdGetSource, [
  enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource? defaultValue,
]) {
  return enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource.values
          .firstWhereOrNull((e) =>
              e.value == customersCustomerIdEpisodesSeasonsSeasonIdGetSource) ??
      defaultValue ??
      enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdEpisodesSeasonsSeasonIdGetSourceListToJson(
    List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource>?
        customersCustomerIdEpisodesSeasonsSeasonIdGetSource) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSource == null) {
    return [];
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSource
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource>
    customersCustomerIdEpisodesSeasonsSeasonIdGetSourceListFromJson(
  List? customersCustomerIdEpisodesSeasonsSeasonIdGetSource, [
  List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource>? defaultValue,
]) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSource == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSource
      .map((e) => customersCustomerIdEpisodesSeasonsSeasonIdGetSourceFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource>?
    customersCustomerIdEpisodesSeasonsSeasonIdGetSourceNullableListFromJson(
  List? customersCustomerIdEpisodesSeasonsSeasonIdGetSource, [
  List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSource>? defaultValue,
]) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSource == null) {
    return defaultValue;
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSource
      .map((e) => customersCustomerIdEpisodesSeasonsSeasonIdGetSourceFromJson(
          e.toString()))
      .toList();
}

String? customersCustomerIdEpisodesSeasonsSeasonIdGetSortToJson(
    enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort?
        customersCustomerIdEpisodesSeasonsSeasonIdGetSort) {
  return customersCustomerIdEpisodesSeasonsSeasonIdGetSort?.value;
}

enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort
    customersCustomerIdEpisodesSeasonsSeasonIdGetSortFromJson(
  Object? customersCustomerIdEpisodesSeasonsSeasonIdGetSort, [
  enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort? defaultValue,
]) {
  return enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort.values
          .firstWhereOrNull((e) =>
              e.value == customersCustomerIdEpisodesSeasonsSeasonIdGetSort) ??
      defaultValue ??
      enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdEpisodesSeasonsSeasonIdGetSortListToJson(
    List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort>?
        customersCustomerIdEpisodesSeasonsSeasonIdGetSort) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSort == null) {
    return [];
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSort
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort>
    customersCustomerIdEpisodesSeasonsSeasonIdGetSortListFromJson(
  List? customersCustomerIdEpisodesSeasonsSeasonIdGetSort, [
  List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort>? defaultValue,
]) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSort == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSort
      .map((e) => customersCustomerIdEpisodesSeasonsSeasonIdGetSortFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort>?
    customersCustomerIdEpisodesSeasonsSeasonIdGetSortNullableListFromJson(
  List? customersCustomerIdEpisodesSeasonsSeasonIdGetSort, [
  List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSort>? defaultValue,
]) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSort == null) {
    return defaultValue;
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSort
      .map((e) => customersCustomerIdEpisodesSeasonsSeasonIdGetSortFromJson(
          e.toString()))
      .toList();
}

String? customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderToJson(
    enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder?
        customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder) {
  return customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder?.value;
}

enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder
    customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderFromJson(
  Object? customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder, [
  enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder? defaultValue,
]) {
  return enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder.values
          .firstWhereOrNull((e) =>
              e.value ==
              customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder) ??
      defaultValue ??
      enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderListToJson(
    List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder>?
        customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder == null) {
    return [];
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder>
    customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderListFromJson(
  List? customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder, [
  List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder>?
      defaultValue,
]) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder
      .map((e) =>
          customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderFromJson(
              e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder>?
    customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderNullableListFromJson(
  List? customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder, [
  List<enums.CustomersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder>?
      defaultValue,
]) {
  if (customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder == null) {
    return defaultValue;
  }

  return customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrder
      .map((e) =>
          customersCustomerIdEpisodesSeasonsSeasonIdGetSortOrderFromJson(
              e.toString()))
      .toList();
}

String? customersCustomerIdEpisodesShowsShowIdGetSourceToJson(
    enums.CustomersCustomerIdEpisodesShowsShowIdGetSource?
        customersCustomerIdEpisodesShowsShowIdGetSource) {
  return customersCustomerIdEpisodesShowsShowIdGetSource?.value;
}

enums.CustomersCustomerIdEpisodesShowsShowIdGetSource
    customersCustomerIdEpisodesShowsShowIdGetSourceFromJson(
  Object? customersCustomerIdEpisodesShowsShowIdGetSource, [
  enums.CustomersCustomerIdEpisodesShowsShowIdGetSource? defaultValue,
]) {
  return enums.CustomersCustomerIdEpisodesShowsShowIdGetSource.values
          .firstWhereOrNull((e) =>
              e.value == customersCustomerIdEpisodesShowsShowIdGetSource) ??
      defaultValue ??
      enums.CustomersCustomerIdEpisodesShowsShowIdGetSource
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdEpisodesShowsShowIdGetSourceListToJson(
    List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSource>?
        customersCustomerIdEpisodesShowsShowIdGetSource) {
  if (customersCustomerIdEpisodesShowsShowIdGetSource == null) {
    return [];
  }

  return customersCustomerIdEpisodesShowsShowIdGetSource
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSource>
    customersCustomerIdEpisodesShowsShowIdGetSourceListFromJson(
  List? customersCustomerIdEpisodesShowsShowIdGetSource, [
  List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSource>? defaultValue,
]) {
  if (customersCustomerIdEpisodesShowsShowIdGetSource == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdEpisodesShowsShowIdGetSource
      .map((e) =>
          customersCustomerIdEpisodesShowsShowIdGetSourceFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSource>?
    customersCustomerIdEpisodesShowsShowIdGetSourceNullableListFromJson(
  List? customersCustomerIdEpisodesShowsShowIdGetSource, [
  List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSource>? defaultValue,
]) {
  if (customersCustomerIdEpisodesShowsShowIdGetSource == null) {
    return defaultValue;
  }

  return customersCustomerIdEpisodesShowsShowIdGetSource
      .map((e) =>
          customersCustomerIdEpisodesShowsShowIdGetSourceFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdEpisodesShowsShowIdGetSortToJson(
    enums.CustomersCustomerIdEpisodesShowsShowIdGetSort?
        customersCustomerIdEpisodesShowsShowIdGetSort) {
  return customersCustomerIdEpisodesShowsShowIdGetSort?.value;
}

enums.CustomersCustomerIdEpisodesShowsShowIdGetSort
    customersCustomerIdEpisodesShowsShowIdGetSortFromJson(
  Object? customersCustomerIdEpisodesShowsShowIdGetSort, [
  enums.CustomersCustomerIdEpisodesShowsShowIdGetSort? defaultValue,
]) {
  return enums.CustomersCustomerIdEpisodesShowsShowIdGetSort.values
          .firstWhereOrNull((e) =>
              e.value == customersCustomerIdEpisodesShowsShowIdGetSort) ??
      defaultValue ??
      enums.CustomersCustomerIdEpisodesShowsShowIdGetSort
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdEpisodesShowsShowIdGetSortListToJson(
    List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSort>?
        customersCustomerIdEpisodesShowsShowIdGetSort) {
  if (customersCustomerIdEpisodesShowsShowIdGetSort == null) {
    return [];
  }

  return customersCustomerIdEpisodesShowsShowIdGetSort
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSort>
    customersCustomerIdEpisodesShowsShowIdGetSortListFromJson(
  List? customersCustomerIdEpisodesShowsShowIdGetSort, [
  List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSort>? defaultValue,
]) {
  if (customersCustomerIdEpisodesShowsShowIdGetSort == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdEpisodesShowsShowIdGetSort
      .map((e) =>
          customersCustomerIdEpisodesShowsShowIdGetSortFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSort>?
    customersCustomerIdEpisodesShowsShowIdGetSortNullableListFromJson(
  List? customersCustomerIdEpisodesShowsShowIdGetSort, [
  List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSort>? defaultValue,
]) {
  if (customersCustomerIdEpisodesShowsShowIdGetSort == null) {
    return defaultValue;
  }

  return customersCustomerIdEpisodesShowsShowIdGetSort
      .map((e) =>
          customersCustomerIdEpisodesShowsShowIdGetSortFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdEpisodesShowsShowIdGetSortOrderToJson(
    enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder?
        customersCustomerIdEpisodesShowsShowIdGetSortOrder) {
  return customersCustomerIdEpisodesShowsShowIdGetSortOrder?.value;
}

enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder
    customersCustomerIdEpisodesShowsShowIdGetSortOrderFromJson(
  Object? customersCustomerIdEpisodesShowsShowIdGetSortOrder, [
  enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder? defaultValue,
]) {
  return enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder.values
          .firstWhereOrNull((e) =>
              e.value == customersCustomerIdEpisodesShowsShowIdGetSortOrder) ??
      defaultValue ??
      enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdEpisodesShowsShowIdGetSortOrderListToJson(
    List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder>?
        customersCustomerIdEpisodesShowsShowIdGetSortOrder) {
  if (customersCustomerIdEpisodesShowsShowIdGetSortOrder == null) {
    return [];
  }

  return customersCustomerIdEpisodesShowsShowIdGetSortOrder
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder>
    customersCustomerIdEpisodesShowsShowIdGetSortOrderListFromJson(
  List? customersCustomerIdEpisodesShowsShowIdGetSortOrder, [
  List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdEpisodesShowsShowIdGetSortOrder == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdEpisodesShowsShowIdGetSortOrder
      .map((e) => customersCustomerIdEpisodesShowsShowIdGetSortOrderFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder>?
    customersCustomerIdEpisodesShowsShowIdGetSortOrderNullableListFromJson(
  List? customersCustomerIdEpisodesShowsShowIdGetSortOrder, [
  List<enums.CustomersCustomerIdEpisodesShowsShowIdGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdEpisodesShowsShowIdGetSortOrder == null) {
    return defaultValue;
  }

  return customersCustomerIdEpisodesShowsShowIdGetSortOrder
      .map((e) => customersCustomerIdEpisodesShowsShowIdGetSortOrderFromJson(
          e.toString()))
      .toList();
}

String? discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusToJson(
    enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus?
        discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus) {
  return discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus?.value;
}

enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus
    discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusFromJson(
  Object? discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus, [
  enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus?
      defaultValue,
]) {
  return enums
          .DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus.values
          .firstWhereOrNull((e) =>
              e.value ==
              discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus) ??
      defaultValue ??
      enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus
          .swaggerGeneratedUnknown;
}

List<String>
    discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusListToJson(
        List<enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus>?
            discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus) {
  if (discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus == null) {
    return [];
  }

  return discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus
      .map((e) => e.value!)
      .toList();
}

List<enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus>
    discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusListFromJson(
  List? discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus, [
  List<enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus>?
      defaultValue,
]) {
  if (discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus == null) {
    return defaultValue ?? [];
  }

  return discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus
      .map((e) =>
          discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusFromJson(
              e.toString()))
      .toList();
}

List<enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus>?
    discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusNullableListFromJson(
  List? discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus, [
  List<enums.DiscoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus>?
      defaultValue,
]) {
  if (discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus == null) {
    return defaultValue;
  }

  return discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatus
      .map((e) =>
          discoveryServiceCustomersCustomerIdRecordingsSimpleGetStatusFromJson(
              e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
