// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'session_service.enums.swagger.dart' as enums;
export 'session_service.enums.swagger.dart';

part 'session_service.swagger.chopper.dart';
part 'session_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class SessionService extends ChopperService {
  static SessionService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$SessionService(client);
    }

    final newClient = ChopperClient(
        services: [_$SessionService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$SessionService(newClient);
  }

  ///Returns Playready license for STB.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param x-entitlements-token Entitlements token
  ///@param CrmId Customer id.
  ///@param AccountId Account Id.
  ///@param ContentId Content Id.
  ///@param DeviceID Device Id.
  ///@param SubContentType SubContent Type.
  Future<chopper.Response> customplayreadyRightsmanagerAsmxPost({
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? crmId,
    required String? accountId,
    required String? contentId,
    required String? deviceID,
    required enums.CustomplayreadyRightsmanagerAsmxPostSubContentType?
        subContentType,
    String? cacheControl,
    required String? body,
  }) {
    return _customplayreadyRightsmanagerAsmxPost(
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        crmId: crmId,
        accountId: accountId,
        contentId: contentId,
        deviceID: deviceID,
        subContentType: subContentType?.value?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Returns Playready license for STB.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param x-entitlements-token Entitlements token
  ///@param CrmId Customer id.
  ///@param AccountId Account Id.
  ///@param ContentId Content Id.
  ///@param DeviceID Device Id.
  ///@param SubContentType SubContent Type.
  @Post(
    path: '/customplayready/rightsmanager.asmx',
    optionalBody: true,
  )
  Future<chopper.Response> _customplayreadyRightsmanagerAsmxPost({
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('CrmId')
        required String? crmId,
    @Query('AccountId')
        required String? accountId,
    @Query('ContentId')
        required String? contentId,
    @Query('DeviceID')
        required String? deviceID,
    @Query('SubContentType')
        required String? subContentType,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required String? body,
  });

  ///Resolve content id to the channel, start_time and end_time.
  Future<chopper.Response<TsbResolveContentReply>>
      vsppAdapterTsbResolveContentPost({
    String? cacheControl,
    required TsbResolveContentRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        TsbResolveContentReply, () => TsbResolveContentReply.fromJsonFactory);

    return _vsppAdapterTsbResolveContentPost(
        cacheControl: cacheControl, body: body);
  }

  ///Resolve content id to the channel, start_time and end_time.
  @Post(
    path: '/vspp-adapter/tsb_resolve_content',
    optionalBody: true,
  )
  Future<chopper.Response<TsbResolveContentReply>>
      _vsppAdapterTsbResolveContentPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TsbResolveContentRequest? body,
  });

  ///Get thumbnail service url for CPE.
  ///@param legacyId Customer ID.
  ///@param recordingId Recording ID in a form of Traxis Event's CRID+IMI.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  Future<chopper.Response<LocalRecordingResponse>>
      sessionCustomersLegacyIdLocalRecordingsRecordingIdPost({
    required String? legacyId,
    required String? recordingId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LocalRecordingResponse, () => LocalRecordingResponse.fromJsonFactory);

    return _sessionCustomersLegacyIdLocalRecordingsRecordingIdPost(
        legacyId: legacyId,
        recordingId: recordingId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Get thumbnail service url for CPE.
  ///@param legacyId Customer ID.
  ///@param recordingId Recording ID in a form of Traxis Event's CRID+IMI.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  @Post(
    path: '/session/customers/{legacyId}/local_recordings/{recordingId}',
    optionalBody: true,
  )
  Future<chopper.Response<LocalRecordingResponse>>
      _sessionCustomersLegacyIdLocalRecordingsRecordingIdPost({
    @Path('legacyId') required String? legacyId,
    @Path('recordingId') required String? recordingId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///It creates session for nDVR recording.
  ///@param legacyId
  ///@param recordingId Id of the Event used to schedule recording (CRID+IMI).
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  Future<chopper.Response<RecordingResponse>>
      sessionCustomersLegacyIdRecordingsRecordingIdPost({
    required String? legacyId,
    required String? recordingId,
    String? xDev,
    String? userAgent,
    String? abrType,
    String? advertisementDeviceId,
    String? regionId,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingResponse, () => RecordingResponse.fromJsonFactory);

    return _sessionCustomersLegacyIdRecordingsRecordingIdPost(
        legacyId: legacyId,
        recordingId: recordingId,
        xDev: xDev,
        userAgent: userAgent,
        abrType: abrType,
        advertisementDeviceId: advertisementDeviceId,
        regionId: regionId,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///It creates session for nDVR recording.
  ///@param legacyId
  ///@param recordingId Id of the Event used to schedule recording (CRID+IMI).
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  @Post(
    path: '/session/customers/{legacyId}/recordings/{recordingId}',
    optionalBody: true,
  )
  Future<chopper.Response<RecordingResponse>>
      _sessionCustomersLegacyIdRecordingsRecordingIdPost({
    @Path('legacyId')
        required String? legacyId,
    @Path('recordingId')
        required String? recordingId,
    @Header('X-Dev')
        String? xDev,
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('regionId')
        String? regionId,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create replay session for STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  Future<chopper.Response<ReplaySessionResponse>>
      sessionCpesCpeIdReplayEventsEventIdPost({
    required String? cpeId,
    required String? eventId,
    String? userAgent,
    String? abrType,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? advertisementDeviceId,
    String? regionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplaySessionResponse, () => ReplaySessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdReplayEventsEventIdPost(
        cpeId: cpeId,
        eventId: eventId,
        userAgent: userAgent,
        abrType: abrType,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        advertisementDeviceId: advertisementDeviceId,
        regionId: regionId,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Create replay session for STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  @Post(
    path: '/session/cpes/{cpeId}/replay/events/{eventId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReplaySessionResponse>>
      _sessionCpesCpeIdReplayEventsEventIdPost({
    @Path('cpeId')
        required String? cpeId,
    @Path('eventId')
        required String? eventId,
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Query('profileId')
        String? profileId,
    @Query('language')
        String? language,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('regionId')
        String? regionId,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Delete replay session for STB
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the session in Traxis.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<DeleteSessionResponse>>
      sessionCpesCpeIdReplaySessionsSessionIdDelete({
    required String? cpeId,
    required String? sessionId,
    required int? sessionEndCode,
    String? additionalInfo,
    required String? timeOffset,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeleteSessionResponse, () => DeleteSessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdReplaySessionsSessionIdDelete(
        cpeId: cpeId,
        sessionId: sessionId,
        sessionEndCode: sessionEndCode,
        additionalInfo: additionalInfo,
        timeOffset: timeOffset,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Delete replay session for STB
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the session in Traxis.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Delete(path: '/session/cpes/{cpeId}/replay/sessions/{sessionId}')
  Future<chopper.Response<DeleteSessionResponse>>
      _sessionCpesCpeIdReplaySessionsSessionIdDelete({
    @Path('cpeId') required String? cpeId,
    @Path('sessionId') required String? sessionId,
    @Query('sessionEndCode') required int? sessionEndCode,
    @Query('additionalInfo') String? additionalInfo,
    @Query('timeOffset') required String? timeOffset,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create replay session for HZN-GO (OESP).
  ///@param legacyId Id of the customer
  ///@param assetId Crid of the asset taken from offers.alternativeIdentifiers from MAG
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param x-entitlements-token Entitlements token
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  Future<chopper.Response<ReplaySessionOespResponse>>
      sessionCustomersLegacyIdReplayAssetsAssetIdPost({
    required String? legacyId,
    required String? assetId,
    String? userAgent,
    required String? abrType,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? profileId,
    String? language,
    enums.SessionMode? sessionMode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ReplaySessionOespResponse,
        () => ReplaySessionOespResponse.fromJsonFactory);

    return _sessionCustomersLegacyIdReplayAssetsAssetIdPost(
        legacyId: legacyId,
        assetId: assetId,
        userAgent: userAgent,
        abrType: abrType,
        xEntitlementsToken: xEntitlementsToken,
        profileId: profileId,
        language: language,
        sessionMode: sessionMode?.value?.toString(),
        cacheControl: cacheControl);
  }

  ///Create replay session for HZN-GO (OESP).
  ///@param legacyId Id of the customer
  ///@param assetId Crid of the asset taken from offers.alternativeIdentifiers from MAG
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param x-entitlements-token Entitlements token
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  @Post(
    path: '/session/customers/{legacyId}/replay/assets/{assetId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReplaySessionOespResponse>>
      _sessionCustomersLegacyIdReplayAssetsAssetIdPost({
    @Path('legacyId')
        required String? legacyId,
    @Path('assetId')
        required String? assetId,
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        required String? abrType,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('profileId')
        String? profileId,
    @Query('language')
        String? language,
    @Query('sessionMode')
        String? sessionMode,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create session to replay from external resource.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<ReplayExternalResponse>>
      sessionCpesCpeIdReplayExternalEventsEventIdPost({
    required String? cpeId,
    required String? eventId,
    enums.SessionMode? sessionMode,
    String? userAgent,
    String? abrType,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayExternalResponse, () => ReplayExternalResponse.fromJsonFactory);

    return _sessionCpesCpeIdReplayExternalEventsEventIdPost(
        cpeId: cpeId,
        eventId: eventId,
        sessionMode: sessionMode?.value?.toString(),
        userAgent: userAgent,
        abrType: abrType,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Create session to replay from external resource.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/cpes/{cpeId}/replay_external/events/{eventId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReplayExternalResponse>>
      _sessionCpesCpeIdReplayExternalEventsEventIdPost({
    @Path('cpeId') required String? cpeId,
    @Path('eventId') required String? eventId,
    @Query('sessionMode') String? sessionMode,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Playback from the review buffer.
  ///@param channelId ID of a channel
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE' to view the Live streaming of the channel.
  ///@param source Additional parameter to drive the selection of the thumbnail source
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  Future<chopper.Response<ReviewBufferResponse>>
      sessionV1ChannelsChannelIdPost({
    required String? channelId,
    required String? startTime,
    enums.SessionV1ChannelsChannelIdPostSource? source,
    String? userAgent,
    String? abrType,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? advertisementDeviceId,
    String? regionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReviewBufferResponse, () => ReviewBufferResponse.fromJsonFactory);

    return _sessionV1ChannelsChannelIdPost(
        channelId: channelId,
        startTime: startTime,
        source: source?.value?.toString(),
        userAgent: userAgent,
        abrType: abrType,
        xEntitlementsToken: xEntitlementsToken,
        advertisementDeviceId: advertisementDeviceId,
        regionId: regionId,
        cacheControl: cacheControl);
  }

  ///Playback from the review buffer.
  ///@param channelId ID of a channel
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE' to view the Live streaming of the channel.
  ///@param source Additional parameter to drive the selection of the thumbnail source
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  @Post(
    path: '/session/v1/channels/{channelId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReviewBufferResponse>>
      _sessionV1ChannelsChannelIdPost({
    @Path('channelId')
        required String? channelId,
    @Query('startTime')
        required String? startTime,
    @Query('source')
        String? source,
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('regionId')
        String? regionId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create VoD session to replay on STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param contentId CRID+IMI of the content (instance id from vod-service) - provided by the client apps. e.g.: crid://e2e-si.lgi.com/597-titanic,imi:597-titanic-stb'
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param isCustomerOptedOut
  Future<chopper.Response<VodSessionResponse>>
      sessionCpesCpeIdVodContentsContentIdPost({
    required String? cpeId,
    required String? contentId,
    String? userAgent,
    String? abrType,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? advertisementDeviceId,
    bool? isCustomerOptedOut,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        VodSessionResponse, () => VodSessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdVodContentsContentIdPost(
        cpeId: cpeId,
        contentId: contentId,
        userAgent: userAgent,
        abrType: abrType,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        advertisementDeviceId: advertisementDeviceId,
        isCustomerOptedOut: isCustomerOptedOut,
        cacheControl: cacheControl);
  }

  ///Create VoD session to replay on STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param contentId CRID+IMI of the content (instance id from vod-service) - provided by the client apps. e.g.: crid://e2e-si.lgi.com/597-titanic,imi:597-titanic-stb'
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param isCustomerOptedOut
  @Post(
    path: '/session/cpes/{cpeId}/vod/contents/{contentId}',
    optionalBody: true,
  )
  Future<chopper.Response<VodSessionResponse>>
      _sessionCpesCpeIdVodContentsContentIdPost({
    @Path('cpeId') required String? cpeId,
    @Path('contentId') required String? contentId,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Query('advertisementDeviceId') String? advertisementDeviceId,
    @Query('isCustomerOptedOut') bool? isCustomerOptedOut,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete VoD session.
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the VoD session returned during creation.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3'
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<DeleteSessionResponse>>
      sessionCpesCpeIdVodSessionsSessionIdDelete({
    required String? cpeId,
    required String? sessionId,
    required int? sessionEndCode,
    String? additionalInfo,
    required String? timeOffset,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeleteSessionResponse, () => DeleteSessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdVodSessionsSessionIdDelete(
        cpeId: cpeId,
        sessionId: sessionId,
        sessionEndCode: sessionEndCode,
        additionalInfo: additionalInfo,
        timeOffset: timeOffset,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Delete VoD session.
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the VoD session returned during creation.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3'
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Delete(path: '/session/cpes/{cpeId}/vod/sessions/{sessionId}')
  Future<chopper.Response<DeleteSessionResponse>>
      _sessionCpesCpeIdVodSessionsSessionIdDelete({
    @Path('cpeId') required String? cpeId,
    @Path('sessionId') required String? sessionId,
    @Query('sessionEndCode') required int? sessionEndCode,
    @Query('additionalInfo') String? additionalInfo,
    @Query('timeOffset') required String? timeOffset,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create URL to the manifest to play VOD content on HZ-GO.
  ///@param legacyId Identification of the customer.
  ///@param crid Alternative identifier (crid) of the content. Crid with Imi for specific content is also accepted.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<VodSessionForHznGoResponse>>
      sessionCustomersLegacyIdVodContentsCridPost({
    required String? legacyId,
    required String? crid,
    String? userAgent,
    String? abrType,
    String? profileId,
    String? language,
    enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode? sessionMode,
    String? advertisementDeviceId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(VodSessionForHznGoResponse,
        () => VodSessionForHznGoResponse.fromJsonFactory);

    return _sessionCustomersLegacyIdVodContentsCridPost(
        legacyId: legacyId,
        crid: crid,
        userAgent: userAgent,
        abrType: abrType,
        profileId: profileId,
        language: language,
        sessionMode: sessionMode?.value?.toString(),
        advertisementDeviceId: advertisementDeviceId,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Create URL to the manifest to play VOD content on HZ-GO.
  ///@param legacyId Identification of the customer.
  ///@param crid Alternative identifier (crid) of the content. Crid with Imi for specific content is also accepted.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param x-entitlements-token Entitlements token
  @Post(
    path: '/session/customers/{legacyId}/vod/contents/{crid}',
    optionalBody: true,
  )
  Future<chopper.Response<VodSessionForHznGoResponse>>
      _sessionCustomersLegacyIdVodContentsCridPost({
    @Path('legacyId')
        required String? legacyId,
    @Path('crid')
        required String? crid,
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Query('profileId')
        String? profileId,
    @Query('language')
        String? language,
    @Query('sessionMode')
        String? sessionMode,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Verify if the requesting client is authorized to access the recording.
  ///@param LegacyId The customer ID for which the authorization is checked.
  ///@param RecordingId Identifies the resource for which authorization is checked.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  Future<chopper.Response<AuthorizedForAssetResponse>>
      sessionAuthorizationRecordingsGet({
    required String? legacyId,
    required String? recordingId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AuthorizedForAssetResponse,
        () => AuthorizedForAssetResponse.fromJsonFactory);

    return _sessionAuthorizationRecordingsGet(
        legacyId: legacyId,
        recordingId: recordingId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Verify if the requesting client is authorized to access the recording.
  ///@param LegacyId The customer ID for which the authorization is checked.
  ///@param RecordingId Identifies the resource for which authorization is checked.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  @Get(path: '/session/authorization/recordings')
  Future<chopper.Response<AuthorizedForAssetResponse>>
      _sessionAuthorizationRecordingsGet({
    @Query('LegacyId') required String? legacyId,
    @Query('RecordingId') required String? recordingId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create replay session for Perseus.
  ///@param eventId Event for which the session should be created. Accepts both ~~2F and // encodings.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  Future<chopper.Response<ReplayPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdReplayPost({
    required String? eventId,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? abrType,
    String? xDrmDeviceId,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? advertisementDeviceId,
    String? regionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ReplayPerseusSessionResponse,
        () => ReplayPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdReplayPost(
        eventId: eventId,
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        advertisementDeviceId: advertisementDeviceId,
        regionId: regionId,
        cacheControl: cacheControl);
  }

  ///Create replay session for Perseus.
  ///@param eventId Event for which the session should be created. Accepts both ~~2F and // encodings.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/replay',
    optionalBody: true,
  )
  Future<chopper.Response<ReplayPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdReplayPost({
    @Query('eventId')
        required String? eventId,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Header('X-Drm-Device-Id')
        String? xDrmDeviceId,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('regionId')
        String? regionId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create replay session for Yelo Booking Service.
  ///@param eventId Event for which the session should be created. Accepts both ~~2F and // encodings.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<ReplayYeloSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdYeloReplayPost({
    required String? eventId,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? abrType,
    String? xDrmDeviceId,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? cacheControl,
    required String? body,
  }) {
    generatedMapping.putIfAbsent(ReplayYeloSessionResponse,
        () => ReplayYeloSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdYeloReplayPost(
        eventId: eventId,
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create replay session for Yelo Booking Service.
  ///@param eventId Event for which the session should be created. Accepts both ~~2F and // encodings.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/yeloReplay',
    optionalBody: true,
  )
  Future<chopper.Response<ReplayYeloSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdYeloReplayPost({
    @Query('eventId')
        required String? eventId,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Header('X-Drm-Device-Id')
        String? xDrmDeviceId,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Header('Cache-Control')
        String? cacheControl,
    @Body()
        required String? body,
  });

  ///Create VOD session for Perseus.
  ///@param contentId Id of the Content for which the session is created.<br> <b>Hollow:</b> Content -> contentId. Example: crid:~~2F~~2Fperf.e2e-si.lgi.com~~2F76203-12-years-a-slave,imi:76203-12-years-a-slave-stb
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param isCustomerOptedOut
  Future<chopper.Response<VodPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdVodPost({
    required String? contentId,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? xDrmDeviceId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? abrType,
    String? advertisementDeviceId,
    bool? isCustomerOptedOut,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(VodPerseusSessionResponse,
        () => VodPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdVodPost(
        contentId: contentId,
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        xDrmDeviceId: xDrmDeviceId,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        advertisementDeviceId: advertisementDeviceId,
        isCustomerOptedOut: isCustomerOptedOut,
        cacheControl: cacheControl);
  }

  ///Create VOD session for Perseus.
  ///@param contentId Id of the Content for which the session is created.<br> <b>Hollow:</b> Content -> contentId. Example: crid:~~2F~~2Fperf.e2e-si.lgi.com~~2F76203-12-years-a-slave,imi:76203-12-years-a-slave-stb
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param isCustomerOptedOut
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/vod',
    optionalBody: true,
  )
  Future<chopper.Response<VodPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdVodPost({
    @Query('contentId')
        required String? contentId,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Header('X-Drm-Device-Id')
        String? xDrmDeviceId,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('isCustomerOptedOut')
        bool? isCustomerOptedOut,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create nDVR session
  ///@param recordingId Id of the recording for which the session is created. It should be take from recording-management-service.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  Future<chopper.Response<RecordingPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdRecordingPost({
    required String? recordingId,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? abrType,
    String? xDrmDeviceId,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? advertisementDeviceId,
    String? regionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(RecordingPerseusSessionResponse,
        () => RecordingPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdRecordingPost(
        recordingId: recordingId,
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        advertisementDeviceId: advertisementDeviceId,
        regionId: regionId,
        cacheControl: cacheControl);
  }

  ///Create nDVR session
  ///@param recordingId Id of the recording for which the session is created. It should be take from recording-management-service.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/recording',
    optionalBody: true,
  )
  Future<chopper.Response<RecordingPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdRecordingPost({
    @Query('recordingId')
        required String? recordingId,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Header('X-Drm-Device-Id')
        String? xDrmDeviceId,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('regionId')
        String? regionId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create session for review buffer.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE'
  ///@param source Additional parameter to drive the selection of the thumbnailsource
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<ReviewBufferPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPost({
    required String? channelId,
    required String? startTime,
    enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource? source,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? abrType,
    String? xDrmDeviceId,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ReviewBufferPerseusSessionResponse,
        () => ReviewBufferPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPost(
        channelId: channelId,
        startTime: startTime,
        source: source?.value?.toString(),
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl);
  }

  ///Create session for review buffer.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE'
  ///@param source Additional parameter to drive the selection of the thumbnailsource
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/reviewBuffer',
    optionalBody: true,
  )
  Future<chopper.Response<ReviewBufferPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPost({
    @Query('channelId')
        required String? channelId,
    @Query('startTime')
        required String? startTime,
    @Query('source')
        String? source,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('abrType')
        String? abrType,
    @Header('X-Drm-Device-Id')
        String? xDrmDeviceId,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create a live session.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param eventId CRID+IMI of the LIVE event - provided by the client apps.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param assetType The AssetType is used to identify the ChannelIpLocation and distinguish the HLS request. The expected values for this parameter are Orion-DASH, STB-DASH, Orion-HSS, Orion-HLS, Orion-HLS-HEVC, Orion-DASH-HEVC.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  ///@param liveContentTimestamp Timestamp of current time for LIVE events in format <yyyy-MM-dd'T'HH:mm:ss'Z'>.  If discoverEventFromLiveContentTimestamp flag is on, then it is used (together with channelId) to discover LIVE event from Hollow (instead of eventId).
  Future<chopper.Response<LivePerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdLivePost({
    required String? channelId,
    String? eventId,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    required String? assetType,
    String? xDrmDeviceId,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? advertisementDeviceId,
    String? regionId,
    String? liveContentTimestamp,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(LivePerseusSessionResponse,
        () => LivePerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdLivePost(
        channelId: channelId,
        eventId: eventId,
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        assetType: assetType,
        xDrmDeviceId: xDrmDeviceId,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        advertisementDeviceId: advertisementDeviceId,
        regionId: regionId,
        liveContentTimestamp: liveContentTimestamp,
        cacheControl: cacheControl);
  }

  ///Create a live session.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param eventId CRID+IMI of the LIVE event - provided by the client apps.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param assetType The AssetType is used to identify the ChannelIpLocation and distinguish the HLS request. The expected values for this parameter are Orion-DASH, STB-DASH, Orion-HSS, Orion-HLS, Orion-HLS-HEVC, Orion-DASH-HEVC.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param advertisementDeviceId Send to the AVAD system to identify the device which receives the ads
  ///@param regionId AVAD only parameter, if provided will be added to the manifest url
  ///@param liveContentTimestamp Timestamp of current time for LIVE events in format <yyyy-MM-dd'T'HH:mm:ss'Z'>.  If discoverEventFromLiveContentTimestamp flag is on, then it is used (together with channelId) to discover LIVE event from Hollow (instead of eventId).
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/live',
    optionalBody: true,
  )
  Future<chopper.Response<LivePerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdLivePost({
    @Query('channelId')
        required String? channelId,
    @Query('eventId')
        String? eventId,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Dev')
        String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent')
        String? userAgent,
    @Query('assetType')
        required String? assetType,
    @Header('X-Drm-Device-Id')
        String? xDrmDeviceId,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Query('advertisementDeviceId')
        String? advertisementDeviceId,
    @Query('regionId')
        String? regionId,
    @Query('liveContentTimestamp')
        String? liveContentTimestamp,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create a local recording session.
  ///@param recordingId Recording ID in a form of Traxis Event's CRID+IMI.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<LocalRecordingPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersLegacyIdLocalRecordingPost({
    required String? recordingId,
    required String? legacyId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDev,
    String? userAgent,
    String? cookie,
    String? profileId,
    String? xUiLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(LocalRecordingPerseusSessionResponse,
        () => LocalRecordingPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersLegacyIdLocalRecordingPost(
        recordingId: recordingId,
        legacyId: legacyId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xDev: xDev,
        userAgent: userAgent,
        cookie: cookie,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl);
  }

  ///Create a local recording session.
  ///@param recordingId Recording ID in a form of Traxis Event's CRID+IMI.
  ///@param legacyId LegacyId for which the session should be created. It should contain country code
  ///@param deviceFamily The type of the device: could be stb, web, ios, android, firetv... etc. It is used during registration of the device in personalization service.
  ///@param X-Cus HTTP header containing a customer number. It is sent to all upstream systems as header parameters which implement sticky session based on it.
  ///@param X-Entitlements-Token <a href="http://purchase-service.labe2esi.ecx.appdev.io/swagger/#/OMW/get_v2_customers__customerId__entitlements">Token from purchase-service with entitlements and rentals.</a><br> Call the purchase-service for token: <a href><pre>http://purchase-service.labe2esi.ecx.appdev.io/v2/customers/{{customerId}}/entitlements</pre></a>
  ///@param X-Dev HTTP header containing a device id. It is sent to ALL upstream systems as header parameters.
  ///@param User-Agent The User-Agent parameter in the http header is used to identify a device type.
  ///@param Cookie Devices registered for the customer as a token. It is the personalization-service CLAIMSTOKEN (cookie). Call personalization-service for the cookie: <a href><pre>http://personalization-service.labci.ecx.appdev.io/v1/customer/{{customerId}}</pre></a>
  ///@param profileId Profile consisting of customerId, country code and ''MasterProfile'' (eg: ''C001869_pl~~23MasterProfile''). For the future usage.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{legacyId}/localRecording',
    optionalBody: true,
  )
  Future<chopper.Response<LocalRecordingPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersLegacyIdLocalRecordingPost({
    @Query('recordingId')
        required String? recordingId,
    @Path('legacyId')
        required String? legacyId,
    @Path('deviceFamily')
        required String? deviceFamily,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Dev')
        String? xDev,
    @Header('User-Agent')
        String? userAgent,
    @Header('Cookie')
        String? cookie,
    @Query('profileId')
        String? profileId,
    @Header('x-ui-language')
        String? xUiLanguage,
    @Header('Cache-Control')
        String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Error400 {
  Error400({
    required this.error,
  });

  factory Error400.fromJson(Map<String, dynamic> json) =>
      _$Error400FromJson(json);

  static const toJsonFactory = _$Error400ToJson;
  Map<String, dynamic> toJson() => _$Error400ToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$Error400FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error400 &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $Error400Extension on Error400 {
  Error400 copyWith({KrakenError? error}) {
    return Error400(error: error ?? this.error);
  }

  Error400 copyWithWrapped({Wrapped<KrakenError>? error}) {
    return Error400(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class Error403 {
  Error403({
    required this.error,
  });

  factory Error403.fromJson(Map<String, dynamic> json) =>
      _$Error403FromJson(json);

  static const toJsonFactory = _$Error403ToJson;
  Map<String, dynamic> toJson() => _$Error403ToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$Error403FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error403 &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $Error403Extension on Error403 {
  Error403 copyWith({KrakenError? error}) {
    return Error403(error: error ?? this.error);
  }

  Error403 copyWithWrapped({Wrapped<KrakenError>? error}) {
    return Error403(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewBufferResponse {
  ReviewBufferResponse({
    required this.url,
    required this.latency,
    this.thumbnailServiceUrl,
    this.uidInfo,
    this.pauseAdUrl,
  });

  factory ReviewBufferResponse.fromJson(Map<String, dynamic> json) =>
      _$ReviewBufferResponseFromJson(json);

  static const toJsonFactory = _$ReviewBufferResponseToJson;
  Map<String, dynamic> toJson() => _$ReviewBufferResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'latency', includeIfNull: false)
  final int latency;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(
      name: 'uidInfo', includeIfNull: false, defaultValue: <UidInfoResponse>[])
  final List<UidInfoResponse>? uidInfo;
  @JsonKey(name: 'pauseAdUrl', includeIfNull: false)
  final String? pauseAdUrl;
  static const fromJsonFactory = _$ReviewBufferResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewBufferResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.latency, latency) ||
                const DeepCollectionEquality()
                    .equals(other.latency, latency)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.uidInfo, uidInfo) ||
                const DeepCollectionEquality()
                    .equals(other.uidInfo, uidInfo)) &&
            (identical(other.pauseAdUrl, pauseAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pauseAdUrl, pauseAdUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(latency) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(uidInfo) ^
      const DeepCollectionEquality().hash(pauseAdUrl) ^
      runtimeType.hashCode;
}

extension $ReviewBufferResponseExtension on ReviewBufferResponse {
  ReviewBufferResponse copyWith(
      {String? url,
      int? latency,
      String? thumbnailServiceUrl,
      List<UidInfoResponse>? uidInfo,
      String? pauseAdUrl}) {
    return ReviewBufferResponse(
        url: url ?? this.url,
        latency: latency ?? this.latency,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        uidInfo: uidInfo ?? this.uidInfo,
        pauseAdUrl: pauseAdUrl ?? this.pauseAdUrl);
  }

  ReviewBufferResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<int>? latency,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<List<UidInfoResponse>?>? uidInfo,
      Wrapped<String?>? pauseAdUrl}) {
    return ReviewBufferResponse(
        url: (url != null ? url.value : this.url),
        latency: (latency != null ? latency.value : this.latency),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        uidInfo: (uidInfo != null ? uidInfo.value : this.uidInfo),
        pauseAdUrl: (pauseAdUrl != null ? pauseAdUrl.value : this.pauseAdUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayExternalResponse {
  ReplayExternalResponse({
    this.replayId,
  });

  factory ReplayExternalResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayExternalResponseFromJson(json);

  static const toJsonFactory = _$ReplayExternalResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayExternalResponseToJson(this);

  @JsonKey(name: 'replayId', includeIfNull: false, defaultValue: '')
  final String? replayId;
  static const fromJsonFactory = _$ReplayExternalResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayExternalResponse &&
            (identical(other.replayId, replayId) ||
                const DeepCollectionEquality()
                    .equals(other.replayId, replayId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayId) ^ runtimeType.hashCode;
}

extension $ReplayExternalResponseExtension on ReplayExternalResponse {
  ReplayExternalResponse copyWith({String? replayId}) {
    return ReplayExternalResponse(replayId: replayId ?? this.replayId);
  }

  ReplayExternalResponse copyWithWrapped({Wrapped<String?>? replayId}) {
    return ReplayExternalResponse(
        replayId: (replayId != null ? replayId.value : this.replayId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplaySessionResponse {
  ReplaySessionResponse({
    required this.url,
    this.ffwdAdUrl,
    this.sessionId,
    this.prePaddingTime,
    this.postPaddingTime,
    required this.trickPlayControl,
    this.trickPlayControl2,
    this.thumbnailServiceUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.uidInfo,
    this.scteOffset,
    this.actualProgramStartOffset,
    this.scteTrickPlayControl,
    this.pauseAdUrl,
    this.fallbackUrl,
    this.isAvad,
  });

  factory ReplaySessionResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplaySessionResponseFromJson(json);

  static const toJsonFactory = _$ReplaySessionResponseToJson;
  Map<String, dynamic> toJson() => _$ReplaySessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'ffwdAdUrl', includeIfNull: false)
  final String? ffwdAdUrl;
  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String? sessionId;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'trickPlayControl2', includeIfNull: false)
  final TrickPlayControls2? trickPlayControl2;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  @JsonKey(
      name: 'uidInfo', includeIfNull: false, defaultValue: <UidInfoResponse>[])
  final List<UidInfoResponse>? uidInfo;
  @JsonKey(name: 'scteOffset', includeIfNull: false)
  final int? scteOffset;
  @JsonKey(name: 'actualProgramStartOffset', includeIfNull: false)
  final int? actualProgramStartOffset;
  @JsonKey(
    name: 'scteTrickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? scteTrickPlayControl;
  @JsonKey(name: 'pauseAdUrl', includeIfNull: false)
  final String? pauseAdUrl;
  @JsonKey(name: 'fallbackUrl', includeIfNull: false)
  final String? fallbackUrl;
  @JsonKey(name: 'isAvad', includeIfNull: false)
  final bool? isAvad;
  static const fromJsonFactory = _$ReplaySessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplaySessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.ffwdAdUrl, ffwdAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.ffwdAdUrl, ffwdAdUrl)) &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.trickPlayControl2, trickPlayControl2) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl2, trickPlayControl2)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.uidInfo, uidInfo) ||
                const DeepCollectionEquality()
                    .equals(other.uidInfo, uidInfo)) &&
            (identical(other.scteOffset, scteOffset) ||
                const DeepCollectionEquality()
                    .equals(other.scteOffset, scteOffset)) &&
            (identical(
                    other.actualProgramStartOffset, actualProgramStartOffset) ||
                const DeepCollectionEquality().equals(
                    other.actualProgramStartOffset,
                    actualProgramStartOffset)) &&
            (identical(other.scteTrickPlayControl, scteTrickPlayControl) ||
                const DeepCollectionEquality().equals(
                    other.scteTrickPlayControl, scteTrickPlayControl)) &&
            (identical(other.pauseAdUrl, pauseAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pauseAdUrl, pauseAdUrl)) &&
            (identical(other.fallbackUrl, fallbackUrl) ||
                const DeepCollectionEquality()
                    .equals(other.fallbackUrl, fallbackUrl)) &&
            (identical(other.isAvad, isAvad) ||
                const DeepCollectionEquality().equals(other.isAvad, isAvad)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(ffwdAdUrl) ^
      const DeepCollectionEquality().hash(sessionId) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(trickPlayControl2) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(uidInfo) ^
      const DeepCollectionEquality().hash(scteOffset) ^
      const DeepCollectionEquality().hash(actualProgramStartOffset) ^
      const DeepCollectionEquality().hash(scteTrickPlayControl) ^
      const DeepCollectionEquality().hash(pauseAdUrl) ^
      const DeepCollectionEquality().hash(fallbackUrl) ^
      const DeepCollectionEquality().hash(isAvad) ^
      runtimeType.hashCode;
}

extension $ReplaySessionResponseExtension on ReplaySessionResponse {
  ReplaySessionResponse copyWith(
      {String? url,
      String? ffwdAdUrl,
      String? sessionId,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      TrickPlayControls2? trickPlayControl2,
      String? thumbnailServiceUrl,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime,
      List<UidInfoResponse>? uidInfo,
      int? scteOffset,
      int? actualProgramStartOffset,
      List<enums.TrickPlayControl>? scteTrickPlayControl,
      String? pauseAdUrl,
      String? fallbackUrl,
      bool? isAvad}) {
    return ReplaySessionResponse(
        url: url ?? this.url,
        ffwdAdUrl: ffwdAdUrl ?? this.ffwdAdUrl,
        sessionId: sessionId ?? this.sessionId,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        trickPlayControl2: trickPlayControl2 ?? this.trickPlayControl2,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        uidInfo: uidInfo ?? this.uidInfo,
        scteOffset: scteOffset ?? this.scteOffset,
        actualProgramStartOffset:
            actualProgramStartOffset ?? this.actualProgramStartOffset,
        scteTrickPlayControl: scteTrickPlayControl ?? this.scteTrickPlayControl,
        pauseAdUrl: pauseAdUrl ?? this.pauseAdUrl,
        fallbackUrl: fallbackUrl ?? this.fallbackUrl,
        isAvad: isAvad ?? this.isAvad);
  }

  ReplaySessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? ffwdAdUrl,
      Wrapped<String?>? sessionId,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<TrickPlayControls2?>? trickPlayControl2,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime,
      Wrapped<List<UidInfoResponse>?>? uidInfo,
      Wrapped<int?>? scteOffset,
      Wrapped<int?>? actualProgramStartOffset,
      Wrapped<List<enums.TrickPlayControl>?>? scteTrickPlayControl,
      Wrapped<String?>? pauseAdUrl,
      Wrapped<String?>? fallbackUrl,
      Wrapped<bool?>? isAvad}) {
    return ReplaySessionResponse(
        url: (url != null ? url.value : this.url),
        ffwdAdUrl: (ffwdAdUrl != null ? ffwdAdUrl.value : this.ffwdAdUrl),
        sessionId: (sessionId != null ? sessionId.value : this.sessionId),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        trickPlayControl2: (trickPlayControl2 != null
            ? trickPlayControl2.value
            : this.trickPlayControl2),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        uidInfo: (uidInfo != null ? uidInfo.value : this.uidInfo),
        scteOffset: (scteOffset != null ? scteOffset.value : this.scteOffset),
        actualProgramStartOffset: (actualProgramStartOffset != null
            ? actualProgramStartOffset.value
            : this.actualProgramStartOffset),
        scteTrickPlayControl: (scteTrickPlayControl != null
            ? scteTrickPlayControl.value
            : this.scteTrickPlayControl),
        pauseAdUrl: (pauseAdUrl != null ? pauseAdUrl.value : this.pauseAdUrl),
        fallbackUrl:
            (fallbackUrl != null ? fallbackUrl.value : this.fallbackUrl),
        isAvad: (isAvad != null ? isAvad.value : this.isAvad));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplaySessionOespResponse {
  ReplaySessionOespResponse({
    required this.url,
    this.prePaddingTime,
    this.postPaddingTime,
    this.trickPlayControl,
    this.contentLocator,
    this.protectionKey,
    this.drmScheme,
    this.thumbnailServiceUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.drmContentId,
  });

  factory ReplaySessionOespResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplaySessionOespResponseFromJson(json);

  static const toJsonFactory = _$ReplaySessionOespResponseToJson;
  Map<String, dynamic> toJson() => _$ReplaySessionOespResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? trickPlayControl;
  @JsonKey(name: 'contentLocator', includeIfNull: false, defaultValue: '')
  final String? contentLocator;
  @JsonKey(name: 'protectionKey', includeIfNull: false, defaultValue: '')
  final String? protectionKey;
  @JsonKey(name: 'drmScheme', includeIfNull: false, defaultValue: '')
  final String? drmScheme;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(
      name: 'eventSessionStartTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionEndTime;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$ReplaySessionOespResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplaySessionOespResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.contentLocator, contentLocator) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocator, contentLocator)) &&
            (identical(other.protectionKey, protectionKey) ||
                const DeepCollectionEquality()
                    .equals(other.protectionKey, protectionKey)) &&
            (identical(other.drmScheme, drmScheme) ||
                const DeepCollectionEquality()
                    .equals(other.drmScheme, drmScheme)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(contentLocator) ^
      const DeepCollectionEquality().hash(protectionKey) ^
      const DeepCollectionEquality().hash(drmScheme) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $ReplaySessionOespResponseExtension on ReplaySessionOespResponse {
  ReplaySessionOespResponse copyWith(
      {String? url,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? contentLocator,
      String? protectionKey,
      String? drmScheme,
      String? thumbnailServiceUrl,
      String? eventSessionStartTime,
      String? eventSessionEndTime,
      String? drmContentId}) {
    return ReplaySessionOespResponse(
        url: url ?? this.url,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        contentLocator: contentLocator ?? this.contentLocator,
        protectionKey: protectionKey ?? this.protectionKey,
        drmScheme: drmScheme ?? this.drmScheme,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  ReplaySessionOespResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>?>? trickPlayControl,
      Wrapped<String?>? contentLocator,
      Wrapped<String?>? protectionKey,
      Wrapped<String?>? drmScheme,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? eventSessionStartTime,
      Wrapped<String?>? eventSessionEndTime,
      Wrapped<String?>? drmContentId}) {
    return ReplaySessionOespResponse(
        url: (url != null ? url.value : this.url),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        contentLocator: (contentLocator != null
            ? contentLocator.value
            : this.contentLocator),
        protectionKey:
            (protectionKey != null ? protectionKey.value : this.protectionKey),
        drmScheme: (drmScheme != null ? drmScheme.value : this.drmScheme),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayPerseusSessionResponse {
  ReplayPerseusSessionResponse({
    required this.url,
    this.ffwdAdUrl,
    this.prePaddingTime,
    this.postPaddingTime,
    required this.trickPlayControl,
    this.trickPlayControl2,
    this.thumbnailServiceUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.licenceDurationSeconds,
    this.drmContentId,
    this.deviceRegistrationRequired,
    this.scteOffset,
    this.actualProgramStartOffset,
    this.scteTrickPlayControl,
    this.pauseAdUrl,
    this.productExpiration,
    this.fallbackUrl,
    this.parentalGuidance,
    this.isAdult,
    this.ageRating,
    this.isAvad,
  });

  factory ReplayPerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayPerseusSessionResponseFromJson(json);

  static const toJsonFactory = _$ReplayPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayPerseusSessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'ffwdAdUrl', includeIfNull: false)
  final String? ffwdAdUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'trickPlayControl2', includeIfNull: false)
  final TrickPlayControls2? trickPlayControl2;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  @JsonKey(name: 'licenceDurationSeconds', includeIfNull: false)
  final int? licenceDurationSeconds;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool? deviceRegistrationRequired;
  @JsonKey(name: 'scteOffset', includeIfNull: false)
  final int? scteOffset;
  @JsonKey(name: 'actualProgramStartOffset', includeIfNull: false)
  final int? actualProgramStartOffset;
  @JsonKey(
    name: 'scteTrickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? scteTrickPlayControl;
  @JsonKey(name: 'pauseAdUrl', includeIfNull: false)
  final String? pauseAdUrl;
  @JsonKey(name: 'productExpiration', includeIfNull: false)
  final DateTime? productExpiration;
  @JsonKey(name: 'fallbackUrl', includeIfNull: false)
  final String? fallbackUrl;
  @JsonKey(name: 'parentalGuidance', includeIfNull: false)
  final String? parentalGuidance;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAvad', includeIfNull: false)
  final bool? isAvad;
  static const fromJsonFactory = _$ReplayPerseusSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.ffwdAdUrl, ffwdAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.ffwdAdUrl, ffwdAdUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.trickPlayControl2, trickPlayControl2) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl2, trickPlayControl2)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.licenceDurationSeconds, licenceDurationSeconds) ||
                const DeepCollectionEquality().equals(
                    other.licenceDurationSeconds, licenceDurationSeconds)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.deviceRegistrationRequired, deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.scteOffset, scteOffset) ||
                const DeepCollectionEquality()
                    .equals(other.scteOffset, scteOffset)) &&
            (identical(other.actualProgramStartOffset, actualProgramStartOffset) ||
                const DeepCollectionEquality().equals(
                    other.actualProgramStartOffset,
                    actualProgramStartOffset)) &&
            (identical(other.scteTrickPlayControl, scteTrickPlayControl) ||
                const DeepCollectionEquality().equals(
                    other.scteTrickPlayControl, scteTrickPlayControl)) &&
            (identical(other.pauseAdUrl, pauseAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pauseAdUrl, pauseAdUrl)) &&
            (identical(other.productExpiration, productExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.productExpiration, productExpiration)) &&
            (identical(other.fallbackUrl, fallbackUrl) ||
                const DeepCollectionEquality()
                    .equals(other.fallbackUrl, fallbackUrl)) &&
            (identical(other.parentalGuidance, parentalGuidance) ||
                const DeepCollectionEquality().equals(other.parentalGuidance, parentalGuidance)) &&
            (identical(other.isAdult, isAdult) || const DeepCollectionEquality().equals(other.isAdult, isAdult)) &&
            (identical(other.ageRating, ageRating) || const DeepCollectionEquality().equals(other.ageRating, ageRating)) &&
            (identical(other.isAvad, isAvad) || const DeepCollectionEquality().equals(other.isAvad, isAvad)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(ffwdAdUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(trickPlayControl2) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(licenceDurationSeconds) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(scteOffset) ^
      const DeepCollectionEquality().hash(actualProgramStartOffset) ^
      const DeepCollectionEquality().hash(scteTrickPlayControl) ^
      const DeepCollectionEquality().hash(pauseAdUrl) ^
      const DeepCollectionEquality().hash(productExpiration) ^
      const DeepCollectionEquality().hash(fallbackUrl) ^
      const DeepCollectionEquality().hash(parentalGuidance) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAvad) ^
      runtimeType.hashCode;
}

extension $ReplayPerseusSessionResponseExtension
    on ReplayPerseusSessionResponse {
  ReplayPerseusSessionResponse copyWith(
      {String? url,
      String? ffwdAdUrl,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      TrickPlayControls2? trickPlayControl2,
      String? thumbnailServiceUrl,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime,
      int? licenceDurationSeconds,
      String? drmContentId,
      bool? deviceRegistrationRequired,
      int? scteOffset,
      int? actualProgramStartOffset,
      List<enums.TrickPlayControl>? scteTrickPlayControl,
      String? pauseAdUrl,
      DateTime? productExpiration,
      String? fallbackUrl,
      String? parentalGuidance,
      bool? isAdult,
      int? ageRating,
      bool? isAvad}) {
    return ReplayPerseusSessionResponse(
        url: url ?? this.url,
        ffwdAdUrl: ffwdAdUrl ?? this.ffwdAdUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        trickPlayControl2: trickPlayControl2 ?? this.trickPlayControl2,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        licenceDurationSeconds:
            licenceDurationSeconds ?? this.licenceDurationSeconds,
        drmContentId: drmContentId ?? this.drmContentId,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        scteOffset: scteOffset ?? this.scteOffset,
        actualProgramStartOffset:
            actualProgramStartOffset ?? this.actualProgramStartOffset,
        scteTrickPlayControl: scteTrickPlayControl ?? this.scteTrickPlayControl,
        pauseAdUrl: pauseAdUrl ?? this.pauseAdUrl,
        productExpiration: productExpiration ?? this.productExpiration,
        fallbackUrl: fallbackUrl ?? this.fallbackUrl,
        parentalGuidance: parentalGuidance ?? this.parentalGuidance,
        isAdult: isAdult ?? this.isAdult,
        ageRating: ageRating ?? this.ageRating,
        isAvad: isAvad ?? this.isAvad);
  }

  ReplayPerseusSessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? ffwdAdUrl,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<TrickPlayControls2?>? trickPlayControl2,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime,
      Wrapped<int?>? licenceDurationSeconds,
      Wrapped<String?>? drmContentId,
      Wrapped<bool?>? deviceRegistrationRequired,
      Wrapped<int?>? scteOffset,
      Wrapped<int?>? actualProgramStartOffset,
      Wrapped<List<enums.TrickPlayControl>?>? scteTrickPlayControl,
      Wrapped<String?>? pauseAdUrl,
      Wrapped<DateTime?>? productExpiration,
      Wrapped<String?>? fallbackUrl,
      Wrapped<String?>? parentalGuidance,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAvad}) {
    return ReplayPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        ffwdAdUrl: (ffwdAdUrl != null ? ffwdAdUrl.value : this.ffwdAdUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        trickPlayControl2: (trickPlayControl2 != null
            ? trickPlayControl2.value
            : this.trickPlayControl2),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        licenceDurationSeconds: (licenceDurationSeconds != null
            ? licenceDurationSeconds.value
            : this.licenceDurationSeconds),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        scteOffset: (scteOffset != null ? scteOffset.value : this.scteOffset),
        actualProgramStartOffset: (actualProgramStartOffset != null
            ? actualProgramStartOffset.value
            : this.actualProgramStartOffset),
        scteTrickPlayControl: (scteTrickPlayControl != null
            ? scteTrickPlayControl.value
            : this.scteTrickPlayControl),
        pauseAdUrl: (pauseAdUrl != null ? pauseAdUrl.value : this.pauseAdUrl),
        productExpiration: (productExpiration != null
            ? productExpiration.value
            : this.productExpiration),
        fallbackUrl:
            (fallbackUrl != null ? fallbackUrl.value : this.fallbackUrl),
        parentalGuidance: (parentalGuidance != null
            ? parentalGuidance.value
            : this.parentalGuidance),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAvad: (isAvad != null ? isAvad.value : this.isAvad));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayYeloSessionResponse {
  ReplayYeloSessionResponse({
    required this.url,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    required this.prePaddingTime,
    required this.postPaddingTime,
    this.thumbnailServiceUrl,
    this.drmContentId,
    required this.deviceRegistrationRequired,
    required this.trickPlayControl,
    this.scteOffset,
    this.scteTrickPlayControl,
  });

  factory ReplayYeloSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayYeloSessionResponseFromJson(json);

  static const toJsonFactory = _$ReplayYeloSessionResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayYeloSessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int postPaddingTime;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool deviceRegistrationRequired;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'scteOffset', includeIfNull: false)
  final int? scteOffset;
  @JsonKey(
    name: 'scteTrickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? scteTrickPlayControl;
  static const fromJsonFactory = _$ReplayYeloSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayYeloSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.deviceRegistrationRequired,
                    deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.scteOffset, scteOffset) ||
                const DeepCollectionEquality()
                    .equals(other.scteOffset, scteOffset)) &&
            (identical(other.scteTrickPlayControl, scteTrickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.scteTrickPlayControl, scteTrickPlayControl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(scteOffset) ^
      const DeepCollectionEquality().hash(scteTrickPlayControl) ^
      runtimeType.hashCode;
}

extension $ReplayYeloSessionResponseExtension on ReplayYeloSessionResponse {
  ReplayYeloSessionResponse copyWith(
      {String? url,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime,
      int? prePaddingTime,
      int? postPaddingTime,
      String? thumbnailServiceUrl,
      String? drmContentId,
      bool? deviceRegistrationRequired,
      List<enums.TrickPlayControl>? trickPlayControl,
      int? scteOffset,
      List<enums.TrickPlayControl>? scteTrickPlayControl}) {
    return ReplayYeloSessionResponse(
        url: url ?? this.url,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        drmContentId: drmContentId ?? this.drmContentId,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        scteOffset: scteOffset ?? this.scteOffset,
        scteTrickPlayControl:
            scteTrickPlayControl ?? this.scteTrickPlayControl);
  }

  ReplayYeloSessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime,
      Wrapped<int>? prePaddingTime,
      Wrapped<int>? postPaddingTime,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? drmContentId,
      Wrapped<bool>? deviceRegistrationRequired,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<int?>? scteOffset,
      Wrapped<List<enums.TrickPlayControl>?>? scteTrickPlayControl}) {
    return ReplayYeloSessionResponse(
        url: (url != null ? url.value : this.url),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        scteOffset: (scteOffset != null ? scteOffset.value : this.scteOffset),
        scteTrickPlayControl: (scteTrickPlayControl != null
            ? scteTrickPlayControl.value
            : this.scteTrickPlayControl));
  }
}

@JsonSerializable(explicitToJson: true)
class VodPerseusSessionResponse {
  VodPerseusSessionResponse({
    required this.url,
    this.thumbnailServiceUrl,
    this.drmContentId,
    this.licenceDurationSeconds,
    required this.trickPlayControl,
    this.trickPlayControl2,
    this.deviceRegistrationRequired,
    this.productExpiration,
    this.fallbackUrl,
    this.isAvad,
    this.contentProvider,
    this.contentProviderName,
    this.displayProvider,
    this.displayProviderName,
  });

  factory VodPerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$VodPerseusSessionResponseFromJson(json);

  static const toJsonFactory = _$VodPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() => _$VodPerseusSessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'licenceDurationSeconds', includeIfNull: false)
  final int? licenceDurationSeconds;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'trickPlayControl2', includeIfNull: false)
  final TrickPlayControls2? trickPlayControl2;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool? deviceRegistrationRequired;
  @JsonKey(name: 'productExpiration', includeIfNull: false)
  final DateTime? productExpiration;
  @JsonKey(name: 'fallbackUrl', includeIfNull: false)
  final String? fallbackUrl;
  @JsonKey(name: 'isAvad', includeIfNull: false)
  final bool? isAvad;
  @JsonKey(name: 'contentProvider', includeIfNull: false, defaultValue: '')
  final String? contentProvider;
  @JsonKey(name: 'contentProviderName', includeIfNull: false, defaultValue: '')
  final String? contentProviderName;
  @JsonKey(name: 'displayProvider', includeIfNull: false, defaultValue: '')
  final String? displayProvider;
  @JsonKey(name: 'displayProviderName', includeIfNull: false, defaultValue: '')
  final String? displayProviderName;
  static const fromJsonFactory = _$VodPerseusSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.licenceDurationSeconds, licenceDurationSeconds) ||
                const DeepCollectionEquality().equals(
                    other.licenceDurationSeconds, licenceDurationSeconds)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.trickPlayControl2, trickPlayControl2) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl2, trickPlayControl2)) &&
            (identical(other.deviceRegistrationRequired,
                    deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.productExpiration, productExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.productExpiration, productExpiration)) &&
            (identical(other.fallbackUrl, fallbackUrl) ||
                const DeepCollectionEquality()
                    .equals(other.fallbackUrl, fallbackUrl)) &&
            (identical(other.isAvad, isAvad) ||
                const DeepCollectionEquality().equals(other.isAvad, isAvad)) &&
            (identical(other.contentProvider, contentProvider) ||
                const DeepCollectionEquality()
                    .equals(other.contentProvider, contentProvider)) &&
            (identical(other.contentProviderName, contentProviderName) ||
                const DeepCollectionEquality()
                    .equals(other.contentProviderName, contentProviderName)) &&
            (identical(other.displayProvider, displayProvider) ||
                const DeepCollectionEquality()
                    .equals(other.displayProvider, displayProvider)) &&
            (identical(other.displayProviderName, displayProviderName) ||
                const DeepCollectionEquality()
                    .equals(other.displayProviderName, displayProviderName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(licenceDurationSeconds) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(trickPlayControl2) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(productExpiration) ^
      const DeepCollectionEquality().hash(fallbackUrl) ^
      const DeepCollectionEquality().hash(isAvad) ^
      const DeepCollectionEquality().hash(contentProvider) ^
      const DeepCollectionEquality().hash(contentProviderName) ^
      const DeepCollectionEquality().hash(displayProvider) ^
      const DeepCollectionEquality().hash(displayProviderName) ^
      runtimeType.hashCode;
}

extension $VodPerseusSessionResponseExtension on VodPerseusSessionResponse {
  VodPerseusSessionResponse copyWith(
      {String? url,
      String? thumbnailServiceUrl,
      String? drmContentId,
      int? licenceDurationSeconds,
      List<enums.TrickPlayControl>? trickPlayControl,
      TrickPlayControls2? trickPlayControl2,
      bool? deviceRegistrationRequired,
      DateTime? productExpiration,
      String? fallbackUrl,
      bool? isAvad,
      String? contentProvider,
      String? contentProviderName,
      String? displayProvider,
      String? displayProviderName}) {
    return VodPerseusSessionResponse(
        url: url ?? this.url,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        drmContentId: drmContentId ?? this.drmContentId,
        licenceDurationSeconds:
            licenceDurationSeconds ?? this.licenceDurationSeconds,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        trickPlayControl2: trickPlayControl2 ?? this.trickPlayControl2,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        productExpiration: productExpiration ?? this.productExpiration,
        fallbackUrl: fallbackUrl ?? this.fallbackUrl,
        isAvad: isAvad ?? this.isAvad,
        contentProvider: contentProvider ?? this.contentProvider,
        contentProviderName: contentProviderName ?? this.contentProviderName,
        displayProvider: displayProvider ?? this.displayProvider,
        displayProviderName: displayProviderName ?? this.displayProviderName);
  }

  VodPerseusSessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? drmContentId,
      Wrapped<int?>? licenceDurationSeconds,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<TrickPlayControls2?>? trickPlayControl2,
      Wrapped<bool?>? deviceRegistrationRequired,
      Wrapped<DateTime?>? productExpiration,
      Wrapped<String?>? fallbackUrl,
      Wrapped<bool?>? isAvad,
      Wrapped<String?>? contentProvider,
      Wrapped<String?>? contentProviderName,
      Wrapped<String?>? displayProvider,
      Wrapped<String?>? displayProviderName}) {
    return VodPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        licenceDurationSeconds: (licenceDurationSeconds != null
            ? licenceDurationSeconds.value
            : this.licenceDurationSeconds),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        trickPlayControl2: (trickPlayControl2 != null
            ? trickPlayControl2.value
            : this.trickPlayControl2),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        productExpiration: (productExpiration != null
            ? productExpiration.value
            : this.productExpiration),
        fallbackUrl:
            (fallbackUrl != null ? fallbackUrl.value : this.fallbackUrl),
        isAvad: (isAvad != null ? isAvad.value : this.isAvad),
        contentProvider: (contentProvider != null
            ? contentProvider.value
            : this.contentProvider),
        contentProviderName: (contentProviderName != null
            ? contentProviderName.value
            : this.contentProviderName),
        displayProvider: (displayProvider != null
            ? displayProvider.value
            : this.displayProvider),
        displayProviderName: (displayProviderName != null
            ? displayProviderName.value
            : this.displayProviderName));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingResponse {
  RecordingResponse({
    this.url,
    this.noAvadUrl,
    this.ffwdAdUrl,
    this.prePaddingTime,
    this.postPaddingTime,
    this.trickPlayControl,
    this.trickPlayControl2,
    this.thumbnailServiceUrl,
    this.contentLocator,
    this.protectionKey,
    this.drmScheme,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.drmContentId,
    this.scteOffset,
    this.actualProgramStartOffset,
    this.scteTrickPlayControl,
    this.pauseAdUrl,
    this.fallbackUrl,
    this.isAvad,
  });

  factory RecordingResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingResponseFromJson(json);

  static const toJsonFactory = _$RecordingResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'noAvadUrl', includeIfNull: false, defaultValue: '')
  final String? noAvadUrl;
  @JsonKey(name: 'ffwdAdUrl', includeIfNull: false)
  final String? ffwdAdUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? trickPlayControl;
  @JsonKey(name: 'trickPlayControl2', includeIfNull: false)
  final TrickPlayControls2? trickPlayControl2;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'contentLocator', includeIfNull: false, defaultValue: '')
  final String? contentLocator;
  @JsonKey(name: 'protectionKey', includeIfNull: false, defaultValue: '')
  final String? protectionKey;
  @JsonKey(name: 'drmScheme', includeIfNull: false, defaultValue: '')
  final String? drmScheme;
  @JsonKey(
      name: 'eventSessionStartTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionEndTime;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'scteOffset', includeIfNull: false)
  final int? scteOffset;
  @JsonKey(name: 'actualProgramStartOffset', includeIfNull: false)
  final int? actualProgramStartOffset;
  @JsonKey(
    name: 'scteTrickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? scteTrickPlayControl;
  @JsonKey(name: 'pauseAdUrl', includeIfNull: false)
  final String? pauseAdUrl;
  @JsonKey(name: 'fallbackUrl', includeIfNull: false)
  final String? fallbackUrl;
  @JsonKey(name: 'isAvad', includeIfNull: false)
  final bool? isAvad;
  static const fromJsonFactory = _$RecordingResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.noAvadUrl, noAvadUrl) ||
                const DeepCollectionEquality()
                    .equals(other.noAvadUrl, noAvadUrl)) &&
            (identical(other.ffwdAdUrl, ffwdAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.ffwdAdUrl, ffwdAdUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.trickPlayControl2, trickPlayControl2) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl2, trickPlayControl2)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.contentLocator, contentLocator) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocator, contentLocator)) &&
            (identical(other.protectionKey, protectionKey) ||
                const DeepCollectionEquality()
                    .equals(other.protectionKey, protectionKey)) &&
            (identical(other.drmScheme, drmScheme) ||
                const DeepCollectionEquality()
                    .equals(other.drmScheme, drmScheme)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.scteOffset, scteOffset) ||
                const DeepCollectionEquality()
                    .equals(other.scteOffset, scteOffset)) &&
            (identical(
                    other.actualProgramStartOffset, actualProgramStartOffset) ||
                const DeepCollectionEquality().equals(
                    other.actualProgramStartOffset,
                    actualProgramStartOffset)) &&
            (identical(other.scteTrickPlayControl, scteTrickPlayControl) ||
                const DeepCollectionEquality().equals(
                    other.scteTrickPlayControl, scteTrickPlayControl)) &&
            (identical(other.pauseAdUrl, pauseAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pauseAdUrl, pauseAdUrl)) &&
            (identical(other.fallbackUrl, fallbackUrl) ||
                const DeepCollectionEquality()
                    .equals(other.fallbackUrl, fallbackUrl)) &&
            (identical(other.isAvad, isAvad) ||
                const DeepCollectionEquality().equals(other.isAvad, isAvad)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(noAvadUrl) ^
      const DeepCollectionEquality().hash(ffwdAdUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(trickPlayControl2) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(contentLocator) ^
      const DeepCollectionEquality().hash(protectionKey) ^
      const DeepCollectionEquality().hash(drmScheme) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(scteOffset) ^
      const DeepCollectionEquality().hash(actualProgramStartOffset) ^
      const DeepCollectionEquality().hash(scteTrickPlayControl) ^
      const DeepCollectionEquality().hash(pauseAdUrl) ^
      const DeepCollectionEquality().hash(fallbackUrl) ^
      const DeepCollectionEquality().hash(isAvad) ^
      runtimeType.hashCode;
}

extension $RecordingResponseExtension on RecordingResponse {
  RecordingResponse copyWith(
      {String? url,
      String? noAvadUrl,
      String? ffwdAdUrl,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      TrickPlayControls2? trickPlayControl2,
      String? thumbnailServiceUrl,
      String? contentLocator,
      String? protectionKey,
      String? drmScheme,
      String? eventSessionStartTime,
      String? eventSessionEndTime,
      String? drmContentId,
      int? scteOffset,
      int? actualProgramStartOffset,
      List<enums.TrickPlayControl>? scteTrickPlayControl,
      String? pauseAdUrl,
      String? fallbackUrl,
      bool? isAvad}) {
    return RecordingResponse(
        url: url ?? this.url,
        noAvadUrl: noAvadUrl ?? this.noAvadUrl,
        ffwdAdUrl: ffwdAdUrl ?? this.ffwdAdUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        trickPlayControl2: trickPlayControl2 ?? this.trickPlayControl2,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        contentLocator: contentLocator ?? this.contentLocator,
        protectionKey: protectionKey ?? this.protectionKey,
        drmScheme: drmScheme ?? this.drmScheme,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        drmContentId: drmContentId ?? this.drmContentId,
        scteOffset: scteOffset ?? this.scteOffset,
        actualProgramStartOffset:
            actualProgramStartOffset ?? this.actualProgramStartOffset,
        scteTrickPlayControl: scteTrickPlayControl ?? this.scteTrickPlayControl,
        pauseAdUrl: pauseAdUrl ?? this.pauseAdUrl,
        fallbackUrl: fallbackUrl ?? this.fallbackUrl,
        isAvad: isAvad ?? this.isAvad);
  }

  RecordingResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<String?>? noAvadUrl,
      Wrapped<String?>? ffwdAdUrl,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>?>? trickPlayControl,
      Wrapped<TrickPlayControls2?>? trickPlayControl2,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? contentLocator,
      Wrapped<String?>? protectionKey,
      Wrapped<String?>? drmScheme,
      Wrapped<String?>? eventSessionStartTime,
      Wrapped<String?>? eventSessionEndTime,
      Wrapped<String?>? drmContentId,
      Wrapped<int?>? scteOffset,
      Wrapped<int?>? actualProgramStartOffset,
      Wrapped<List<enums.TrickPlayControl>?>? scteTrickPlayControl,
      Wrapped<String?>? pauseAdUrl,
      Wrapped<String?>? fallbackUrl,
      Wrapped<bool?>? isAvad}) {
    return RecordingResponse(
        url: (url != null ? url.value : this.url),
        noAvadUrl: (noAvadUrl != null ? noAvadUrl.value : this.noAvadUrl),
        ffwdAdUrl: (ffwdAdUrl != null ? ffwdAdUrl.value : this.ffwdAdUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        trickPlayControl2: (trickPlayControl2 != null
            ? trickPlayControl2.value
            : this.trickPlayControl2),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        contentLocator: (contentLocator != null
            ? contentLocator.value
            : this.contentLocator),
        protectionKey:
            (protectionKey != null ? protectionKey.value : this.protectionKey),
        drmScheme: (drmScheme != null ? drmScheme.value : this.drmScheme),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        scteOffset: (scteOffset != null ? scteOffset.value : this.scteOffset),
        actualProgramStartOffset: (actualProgramStartOffset != null
            ? actualProgramStartOffset.value
            : this.actualProgramStartOffset),
        scteTrickPlayControl: (scteTrickPlayControl != null
            ? scteTrickPlayControl.value
            : this.scteTrickPlayControl),
        pauseAdUrl: (pauseAdUrl != null ? pauseAdUrl.value : this.pauseAdUrl),
        fallbackUrl:
            (fallbackUrl != null ? fallbackUrl.value : this.fallbackUrl),
        isAvad: (isAvad != null ? isAvad.value : this.isAvad));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingPerseusSessionResponse {
  RecordingPerseusSessionResponse({
    this.url,
    this.noAvadUrl,
    this.ffwdAdUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.thumbnailServiceUrl,
    this.prePaddingTime,
    this.postPaddingTime,
    this.trickPlayControl,
    this.trickPlayControl2,
    this.drmContentId,
    this.scteOffset,
    this.actualProgramStartOffset,
    this.scteTrickPlayControl,
    this.deviceRegistrationRequired,
    this.pauseAdUrl,
    this.productExpiration,
    this.fallbackUrl,
    this.isAvad,
  });

  factory RecordingPerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingPerseusSessionResponseFromJson(json);

  static const toJsonFactory = _$RecordingPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingPerseusSessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'noAvadUrl', includeIfNull: false, defaultValue: '')
  final String? noAvadUrl;
  @JsonKey(name: 'ffwdAdUrl', includeIfNull: false)
  final String? ffwdAdUrl;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? trickPlayControl;
  @JsonKey(name: 'trickPlayControl2', includeIfNull: false)
  final TrickPlayControls2? trickPlayControl2;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'scteOffset', includeIfNull: false)
  final int? scteOffset;
  @JsonKey(name: 'actualProgramStartOffset', includeIfNull: false)
  final int? actualProgramStartOffset;
  @JsonKey(
    name: 'scteTrickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? scteTrickPlayControl;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool? deviceRegistrationRequired;
  @JsonKey(name: 'pauseAdUrl', includeIfNull: false)
  final String? pauseAdUrl;
  @JsonKey(name: 'productExpiration', includeIfNull: false)
  final DateTime? productExpiration;
  @JsonKey(name: 'fallbackUrl', includeIfNull: false)
  final String? fallbackUrl;
  @JsonKey(name: 'isAvad', includeIfNull: false)
  final bool? isAvad;
  static const fromJsonFactory = _$RecordingPerseusSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.noAvadUrl, noAvadUrl) ||
                const DeepCollectionEquality()
                    .equals(other.noAvadUrl, noAvadUrl)) &&
            (identical(other.ffwdAdUrl, ffwdAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.ffwdAdUrl, ffwdAdUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.trickPlayControl2, trickPlayControl2) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl2, trickPlayControl2)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.scteOffset, scteOffset) ||
                const DeepCollectionEquality()
                    .equals(other.scteOffset, scteOffset)) &&
            (identical(other.actualProgramStartOffset, actualProgramStartOffset) ||
                const DeepCollectionEquality().equals(
                    other.actualProgramStartOffset,
                    actualProgramStartOffset)) &&
            (identical(other.scteTrickPlayControl, scteTrickPlayControl) ||
                const DeepCollectionEquality().equals(
                    other.scteTrickPlayControl, scteTrickPlayControl)) &&
            (identical(other.deviceRegistrationRequired, deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.pauseAdUrl, pauseAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pauseAdUrl, pauseAdUrl)) &&
            (identical(other.productExpiration, productExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.productExpiration, productExpiration)) &&
            (identical(other.fallbackUrl, fallbackUrl) ||
                const DeepCollectionEquality()
                    .equals(other.fallbackUrl, fallbackUrl)) &&
            (identical(other.isAvad, isAvad) ||
                const DeepCollectionEquality().equals(other.isAvad, isAvad)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(noAvadUrl) ^
      const DeepCollectionEquality().hash(ffwdAdUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(trickPlayControl2) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(scteOffset) ^
      const DeepCollectionEquality().hash(actualProgramStartOffset) ^
      const DeepCollectionEquality().hash(scteTrickPlayControl) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(pauseAdUrl) ^
      const DeepCollectionEquality().hash(productExpiration) ^
      const DeepCollectionEquality().hash(fallbackUrl) ^
      const DeepCollectionEquality().hash(isAvad) ^
      runtimeType.hashCode;
}

extension $RecordingPerseusSessionResponseExtension
    on RecordingPerseusSessionResponse {
  RecordingPerseusSessionResponse copyWith(
      {String? url,
      String? noAvadUrl,
      String? ffwdAdUrl,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime,
      String? thumbnailServiceUrl,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      TrickPlayControls2? trickPlayControl2,
      String? drmContentId,
      int? scteOffset,
      int? actualProgramStartOffset,
      List<enums.TrickPlayControl>? scteTrickPlayControl,
      bool? deviceRegistrationRequired,
      String? pauseAdUrl,
      DateTime? productExpiration,
      String? fallbackUrl,
      bool? isAvad}) {
    return RecordingPerseusSessionResponse(
        url: url ?? this.url,
        noAvadUrl: noAvadUrl ?? this.noAvadUrl,
        ffwdAdUrl: ffwdAdUrl ?? this.ffwdAdUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        trickPlayControl2: trickPlayControl2 ?? this.trickPlayControl2,
        drmContentId: drmContentId ?? this.drmContentId,
        scteOffset: scteOffset ?? this.scteOffset,
        actualProgramStartOffset:
            actualProgramStartOffset ?? this.actualProgramStartOffset,
        scteTrickPlayControl: scteTrickPlayControl ?? this.scteTrickPlayControl,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        pauseAdUrl: pauseAdUrl ?? this.pauseAdUrl,
        productExpiration: productExpiration ?? this.productExpiration,
        fallbackUrl: fallbackUrl ?? this.fallbackUrl,
        isAvad: isAvad ?? this.isAvad);
  }

  RecordingPerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<String?>? noAvadUrl,
      Wrapped<String?>? ffwdAdUrl,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>?>? trickPlayControl,
      Wrapped<TrickPlayControls2?>? trickPlayControl2,
      Wrapped<String?>? drmContentId,
      Wrapped<int?>? scteOffset,
      Wrapped<int?>? actualProgramStartOffset,
      Wrapped<List<enums.TrickPlayControl>?>? scteTrickPlayControl,
      Wrapped<bool?>? deviceRegistrationRequired,
      Wrapped<String?>? pauseAdUrl,
      Wrapped<DateTime?>? productExpiration,
      Wrapped<String?>? fallbackUrl,
      Wrapped<bool?>? isAvad}) {
    return RecordingPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        noAvadUrl: (noAvadUrl != null ? noAvadUrl.value : this.noAvadUrl),
        ffwdAdUrl: (ffwdAdUrl != null ? ffwdAdUrl.value : this.ffwdAdUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        trickPlayControl2: (trickPlayControl2 != null
            ? trickPlayControl2.value
            : this.trickPlayControl2),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        scteOffset: (scteOffset != null ? scteOffset.value : this.scteOffset),
        actualProgramStartOffset: (actualProgramStartOffset != null
            ? actualProgramStartOffset.value
            : this.actualProgramStartOffset),
        scteTrickPlayControl: (scteTrickPlayControl != null
            ? scteTrickPlayControl.value
            : this.scteTrickPlayControl),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        pauseAdUrl: (pauseAdUrl != null ? pauseAdUrl.value : this.pauseAdUrl),
        productExpiration: (productExpiration != null
            ? productExpiration.value
            : this.productExpiration),
        fallbackUrl:
            (fallbackUrl != null ? fallbackUrl.value : this.fallbackUrl),
        isAvad: (isAvad != null ? isAvad.value : this.isAvad));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewBufferPerseusSessionResponse {
  ReviewBufferPerseusSessionResponse({
    this.url,
    this.thumbnailServiceUrl,
    this.drmContentId,
    this.deviceRegistrationRequired,
    this.productExpiration,
  });

  factory ReviewBufferPerseusSessionResponse.fromJson(
          Map<String, dynamic> json) =>
      _$ReviewBufferPerseusSessionResponseFromJson(json);

  static const toJsonFactory = _$ReviewBufferPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$ReviewBufferPerseusSessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool? deviceRegistrationRequired;
  @JsonKey(name: 'productExpiration', includeIfNull: false)
  final DateTime? productExpiration;
  static const fromJsonFactory = _$ReviewBufferPerseusSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewBufferPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.deviceRegistrationRequired,
                    deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.productExpiration, productExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.productExpiration, productExpiration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(productExpiration) ^
      runtimeType.hashCode;
}

extension $ReviewBufferPerseusSessionResponseExtension
    on ReviewBufferPerseusSessionResponse {
  ReviewBufferPerseusSessionResponse copyWith(
      {String? url,
      String? thumbnailServiceUrl,
      String? drmContentId,
      bool? deviceRegistrationRequired,
      DateTime? productExpiration}) {
    return ReviewBufferPerseusSessionResponse(
        url: url ?? this.url,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        drmContentId: drmContentId ?? this.drmContentId,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        productExpiration: productExpiration ?? this.productExpiration);
  }

  ReviewBufferPerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? drmContentId,
      Wrapped<bool?>? deviceRegistrationRequired,
      Wrapped<DateTime?>? productExpiration}) {
    return ReviewBufferPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        productExpiration: (productExpiration != null
            ? productExpiration.value
            : this.productExpiration));
  }
}

@JsonSerializable(explicitToJson: true)
class LivePerseusSessionResponse {
  LivePerseusSessionResponse({
    this.drmContentId,
    this.deviceRegistrationRequired,
    this.productExpiration,
    this.pauseAdUrl,
    this.parentalGuidance,
    this.isAdult,
    this.ageRating,
  });

  factory LivePerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$LivePerseusSessionResponseFromJson(json);

  static const toJsonFactory = _$LivePerseusSessionResponseToJson;
  Map<String, dynamic> toJson() => _$LivePerseusSessionResponseToJson(this);

  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool? deviceRegistrationRequired;
  @JsonKey(name: 'productExpiration', includeIfNull: false)
  final DateTime? productExpiration;
  @JsonKey(name: 'pauseAdUrl', includeIfNull: false)
  final String? pauseAdUrl;
  @JsonKey(name: 'parentalGuidance', includeIfNull: false)
  final String? parentalGuidance;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  static const fromJsonFactory = _$LivePerseusSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LivePerseusSessionResponse &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.deviceRegistrationRequired,
                    deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.productExpiration, productExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.productExpiration, productExpiration)) &&
            (identical(other.pauseAdUrl, pauseAdUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pauseAdUrl, pauseAdUrl)) &&
            (identical(other.parentalGuidance, parentalGuidance) ||
                const DeepCollectionEquality()
                    .equals(other.parentalGuidance, parentalGuidance)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(productExpiration) ^
      const DeepCollectionEquality().hash(pauseAdUrl) ^
      const DeepCollectionEquality().hash(parentalGuidance) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(ageRating) ^
      runtimeType.hashCode;
}

extension $LivePerseusSessionResponseExtension on LivePerseusSessionResponse {
  LivePerseusSessionResponse copyWith(
      {String? drmContentId,
      bool? deviceRegistrationRequired,
      DateTime? productExpiration,
      String? pauseAdUrl,
      String? parentalGuidance,
      bool? isAdult,
      int? ageRating}) {
    return LivePerseusSessionResponse(
        drmContentId: drmContentId ?? this.drmContentId,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        productExpiration: productExpiration ?? this.productExpiration,
        pauseAdUrl: pauseAdUrl ?? this.pauseAdUrl,
        parentalGuidance: parentalGuidance ?? this.parentalGuidance,
        isAdult: isAdult ?? this.isAdult,
        ageRating: ageRating ?? this.ageRating);
  }

  LivePerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? drmContentId,
      Wrapped<bool?>? deviceRegistrationRequired,
      Wrapped<DateTime?>? productExpiration,
      Wrapped<String?>? pauseAdUrl,
      Wrapped<String?>? parentalGuidance,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? ageRating}) {
    return LivePerseusSessionResponse(
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        productExpiration: (productExpiration != null
            ? productExpiration.value
            : this.productExpiration),
        pauseAdUrl: (pauseAdUrl != null ? pauseAdUrl.value : this.pauseAdUrl),
        parentalGuidance: (parentalGuidance != null
            ? parentalGuidance.value
            : this.parentalGuidance),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating));
  }
}

@JsonSerializable(explicitToJson: true)
class VodSessionResponse {
  VodSessionResponse({
    required this.url,
    this.sessionId,
    this.contentId,
    required this.trickPlayControl,
    this.trickPlayControl2,
    this.thumbnailServiceUrl,
    this.fallbackUrl,
    this.isAvad,
  });

  factory VodSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$VodSessionResponseFromJson(json);

  static const toJsonFactory = _$VodSessionResponseToJson;
  Map<String, dynamic> toJson() => _$VodSessionResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String? sessionId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String? contentId;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'trickPlayControl2', includeIfNull: false)
  final TrickPlayControls2? trickPlayControl2;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'fallbackUrl', includeIfNull: false)
  final String? fallbackUrl;
  @JsonKey(name: 'isAvad', includeIfNull: false)
  final bool? isAvad;
  static const fromJsonFactory = _$VodSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.trickPlayControl2, trickPlayControl2) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl2, trickPlayControl2)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.fallbackUrl, fallbackUrl) ||
                const DeepCollectionEquality()
                    .equals(other.fallbackUrl, fallbackUrl)) &&
            (identical(other.isAvad, isAvad) ||
                const DeepCollectionEquality().equals(other.isAvad, isAvad)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(sessionId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(trickPlayControl2) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(fallbackUrl) ^
      const DeepCollectionEquality().hash(isAvad) ^
      runtimeType.hashCode;
}

extension $VodSessionResponseExtension on VodSessionResponse {
  VodSessionResponse copyWith(
      {String? url,
      String? sessionId,
      String? contentId,
      List<enums.TrickPlayControl>? trickPlayControl,
      TrickPlayControls2? trickPlayControl2,
      String? thumbnailServiceUrl,
      String? fallbackUrl,
      bool? isAvad}) {
    return VodSessionResponse(
        url: url ?? this.url,
        sessionId: sessionId ?? this.sessionId,
        contentId: contentId ?? this.contentId,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        trickPlayControl2: trickPlayControl2 ?? this.trickPlayControl2,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        fallbackUrl: fallbackUrl ?? this.fallbackUrl,
        isAvad: isAvad ?? this.isAvad);
  }

  VodSessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? sessionId,
      Wrapped<String?>? contentId,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<TrickPlayControls2?>? trickPlayControl2,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? fallbackUrl,
      Wrapped<bool?>? isAvad}) {
    return VodSessionResponse(
        url: (url != null ? url.value : this.url),
        sessionId: (sessionId != null ? sessionId.value : this.sessionId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        trickPlayControl2: (trickPlayControl2 != null
            ? trickPlayControl2.value
            : this.trickPlayControl2),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        fallbackUrl:
            (fallbackUrl != null ? fallbackUrl.value : this.fallbackUrl),
        isAvad: (isAvad != null ? isAvad.value : this.isAvad));
  }
}

@JsonSerializable(explicitToJson: true)
class VodSessionForHznGoResponse {
  VodSessionForHznGoResponse({
    required this.url,
    this.thumbnailServiceUrl,
    this.contentLocator,
    this.protectionKey,
    this.drmScheme,
    this.drmContentId,
    required this.trickPlayControl,
  });

  factory VodSessionForHznGoResponse.fromJson(Map<String, dynamic> json) =>
      _$VodSessionForHznGoResponseFromJson(json);

  static const toJsonFactory = _$VodSessionForHznGoResponseToJson;
  Map<String, dynamic> toJson() => _$VodSessionForHznGoResponseToJson(this);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'contentLocator', includeIfNull: false, defaultValue: '')
  final String? contentLocator;
  @JsonKey(name: 'protectionKey', includeIfNull: false, defaultValue: '')
  final String? protectionKey;
  @JsonKey(name: 'drmScheme', includeIfNull: false, defaultValue: '')
  final String? drmScheme;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  static const fromJsonFactory = _$VodSessionForHznGoResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodSessionForHznGoResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.contentLocator, contentLocator) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocator, contentLocator)) &&
            (identical(other.protectionKey, protectionKey) ||
                const DeepCollectionEquality()
                    .equals(other.protectionKey, protectionKey)) &&
            (identical(other.drmScheme, drmScheme) ||
                const DeepCollectionEquality()
                    .equals(other.drmScheme, drmScheme)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(contentLocator) ^
      const DeepCollectionEquality().hash(protectionKey) ^
      const DeepCollectionEquality().hash(drmScheme) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      runtimeType.hashCode;
}

extension $VodSessionForHznGoResponseExtension on VodSessionForHznGoResponse {
  VodSessionForHznGoResponse copyWith(
      {String? url,
      String? thumbnailServiceUrl,
      String? contentLocator,
      String? protectionKey,
      String? drmScheme,
      String? drmContentId,
      List<enums.TrickPlayControl>? trickPlayControl}) {
    return VodSessionForHznGoResponse(
        url: url ?? this.url,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        contentLocator: contentLocator ?? this.contentLocator,
        protectionKey: protectionKey ?? this.protectionKey,
        drmScheme: drmScheme ?? this.drmScheme,
        drmContentId: drmContentId ?? this.drmContentId,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl);
  }

  VodSessionForHznGoResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? contentLocator,
      Wrapped<String?>? protectionKey,
      Wrapped<String?>? drmScheme,
      Wrapped<String?>? drmContentId,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl}) {
    return VodSessionForHznGoResponse(
        url: (url != null ? url.value : this.url),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        contentLocator: (contentLocator != null
            ? contentLocator.value
            : this.contentLocator),
        protectionKey:
            (protectionKey != null ? protectionKey.value : this.protectionKey),
        drmScheme: (drmScheme != null ? drmScheme.value : this.drmScheme),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteSessionResponse {
  DeleteSessionResponse({
    required this.status,
    required this.sessionId,
  });

  factory DeleteSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$DeleteSessionResponseFromJson(json);

  static const toJsonFactory = _$DeleteSessionResponseToJson;
  Map<String, dynamic> toJson() => _$DeleteSessionResponseToJson(this);

  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String status;
  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String sessionId;
  static const fromJsonFactory = _$DeleteSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteSessionResponse &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(sessionId) ^
      runtimeType.hashCode;
}

extension $DeleteSessionResponseExtension on DeleteSessionResponse {
  DeleteSessionResponse copyWith({String? status, String? sessionId}) {
    return DeleteSessionResponse(
        status: status ?? this.status, sessionId: sessionId ?? this.sessionId);
  }

  DeleteSessionResponse copyWithWrapped(
      {Wrapped<String>? status, Wrapped<String>? sessionId}) {
    return DeleteSessionResponse(
        status: (status != null ? status.value : this.status),
        sessionId: (sessionId != null ? sessionId.value : this.sessionId));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizedForAssetResponse {
  AuthorizedForAssetResponse({
    this.entitlementId,
    this.entitlementTimeout,
    this.customerId,
  });

  factory AuthorizedForAssetResponse.fromJson(Map<String, dynamic> json) =>
      _$AuthorizedForAssetResponseFromJson(json);

  static const toJsonFactory = _$AuthorizedForAssetResponseToJson;
  Map<String, dynamic> toJson() => _$AuthorizedForAssetResponseToJson(this);

  @JsonKey(name: 'entitlementId', includeIfNull: false, defaultValue: '')
  final String? entitlementId;
  @JsonKey(name: 'entitlementTimeout', includeIfNull: false, defaultValue: '')
  final String? entitlementTimeout;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  static const fromJsonFactory = _$AuthorizedForAssetResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizedForAssetResponse &&
            (identical(other.entitlementId, entitlementId) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementId, entitlementId)) &&
            (identical(other.entitlementTimeout, entitlementTimeout) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementTimeout, entitlementTimeout)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlementId) ^
      const DeepCollectionEquality().hash(entitlementTimeout) ^
      const DeepCollectionEquality().hash(customerId) ^
      runtimeType.hashCode;
}

extension $AuthorizedForAssetResponseExtension on AuthorizedForAssetResponse {
  AuthorizedForAssetResponse copyWith(
      {String? entitlementId, String? entitlementTimeout, String? customerId}) {
    return AuthorizedForAssetResponse(
        entitlementId: entitlementId ?? this.entitlementId,
        entitlementTimeout: entitlementTimeout ?? this.entitlementTimeout,
        customerId: customerId ?? this.customerId);
  }

  AuthorizedForAssetResponse copyWithWrapped(
      {Wrapped<String?>? entitlementId,
      Wrapped<String?>? entitlementTimeout,
      Wrapped<String?>? customerId}) {
    return AuthorizedForAssetResponse(
        entitlementId:
            (entitlementId != null ? entitlementId.value : this.entitlementId),
        entitlementTimeout: (entitlementTimeout != null
            ? entitlementTimeout.value
            : this.entitlementTimeout),
        customerId: (customerId != null ? customerId.value : this.customerId));
  }
}

@JsonSerializable(explicitToJson: true)
class LocalRecordingResponse {
  LocalRecordingResponse({
    this.thumbnailServiceUrl,
    this.prePaddingTime,
    this.postPaddingTime,
    this.drmContentId,
  });

  factory LocalRecordingResponse.fromJson(Map<String, dynamic> json) =>
      _$LocalRecordingResponseFromJson(json);

  static const toJsonFactory = _$LocalRecordingResponseToJson;
  Map<String, dynamic> toJson() => _$LocalRecordingResponseToJson(this);

  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false, defaultValue: '')
  final String? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false, defaultValue: '')
  final String? postPaddingTime;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$LocalRecordingResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalRecordingResponse &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $LocalRecordingResponseExtension on LocalRecordingResponse {
  LocalRecordingResponse copyWith(
      {String? thumbnailServiceUrl,
      String? prePaddingTime,
      String? postPaddingTime,
      String? drmContentId}) {
    return LocalRecordingResponse(
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  LocalRecordingResponse copyWithWrapped(
      {Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? prePaddingTime,
      Wrapped<String?>? postPaddingTime,
      Wrapped<String?>? drmContentId}) {
    return LocalRecordingResponse(
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class ResolveAttributes {
  ResolveAttributes({
    this.assetId,
    this.type,
  });

  factory ResolveAttributes.fromJson(Map<String, dynamic> json) =>
      _$ResolveAttributesFromJson(json);

  static const toJsonFactory = _$ResolveAttributesToJson;
  Map<String, dynamic> toJson() => _$ResolveAttributesToJson(this);

  @JsonKey(name: 'asset_id', includeIfNull: false, defaultValue: '')
  final String? assetId;
  @JsonKey(name: 'type', includeIfNull: false)
  final int? type;
  static const fromJsonFactory = _$ResolveAttributesFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ResolveAttributes &&
            (identical(other.assetId, assetId) ||
                const DeepCollectionEquality()
                    .equals(other.assetId, assetId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(assetId) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ResolveAttributesExtension on ResolveAttributes {
  ResolveAttributes copyWith({String? assetId, int? type}) {
    return ResolveAttributes(
        assetId: assetId ?? this.assetId, type: type ?? this.type);
  }

  ResolveAttributes copyWithWrapped(
      {Wrapped<String?>? assetId, Wrapped<int?>? type}) {
    return ResolveAttributes(
        assetId: (assetId != null ? assetId.value : this.assetId),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class TsbResolveContentRequest {
  TsbResolveContentRequest({
    this.resolveAttributes,
  });

  factory TsbResolveContentRequest.fromJson(Map<String, dynamic> json) =>
      _$TsbResolveContentRequestFromJson(json);

  static const toJsonFactory = _$TsbResolveContentRequestToJson;
  Map<String, dynamic> toJson() => _$TsbResolveContentRequestToJson(this);

  @JsonKey(name: 'resolve_attributes', includeIfNull: false)
  final ResolveAttributes? resolveAttributes;
  static const fromJsonFactory = _$TsbResolveContentRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TsbResolveContentRequest &&
            (identical(other.resolveAttributes, resolveAttributes) ||
                const DeepCollectionEquality()
                    .equals(other.resolveAttributes, resolveAttributes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(resolveAttributes) ^
      runtimeType.hashCode;
}

extension $TsbResolveContentRequestExtension on TsbResolveContentRequest {
  TsbResolveContentRequest copyWith({ResolveAttributes? resolveAttributes}) {
    return TsbResolveContentRequest(
        resolveAttributes: resolveAttributes ?? this.resolveAttributes);
  }

  TsbResolveContentRequest copyWithWrapped(
      {Wrapped<ResolveAttributes?>? resolveAttributes}) {
    return TsbResolveContentRequest(
        resolveAttributes: (resolveAttributes != null
            ? resolveAttributes.value
            : this.resolveAttributes));
  }
}

@JsonSerializable(explicitToJson: true)
class TrickPlayControls2 {
  TrickPlayControls2({
    this.preRoll,
    this.midRoll,
    this.postRoll,
    this.ffwdAd,
    this.allBreaks,
    this.mainAsset,
  });

  factory TrickPlayControls2.fromJson(Map<String, dynamic> json) =>
      _$TrickPlayControls2FromJson(json);

  static const toJsonFactory = _$TrickPlayControls2ToJson;
  Map<String, dynamic> toJson() => _$TrickPlayControls2ToJson(this);

  @JsonKey(
      name: 'preRoll',
      includeIfNull: false,
      defaultValue: <TrickPlayControl2>[])
  final List<TrickPlayControl2>? preRoll;
  @JsonKey(
      name: 'midRoll',
      includeIfNull: false,
      defaultValue: <TrickPlayControl2>[])
  final List<TrickPlayControl2>? midRoll;
  @JsonKey(
      name: 'postRoll',
      includeIfNull: false,
      defaultValue: <TrickPlayControl2>[])
  final List<TrickPlayControl2>? postRoll;
  @JsonKey(
      name: 'ffwdAd', includeIfNull: false, defaultValue: <TrickPlayControl2>[])
  final List<TrickPlayControl2>? ffwdAd;
  @JsonKey(
      name: 'allBreaks',
      includeIfNull: false,
      defaultValue: <TrickPlayControl2>[])
  final List<TrickPlayControl2>? allBreaks;
  @JsonKey(
      name: 'mainAsset',
      includeIfNull: false,
      defaultValue: <TrickPlayControl2>[])
  final List<TrickPlayControl2>? mainAsset;
  static const fromJsonFactory = _$TrickPlayControls2FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TrickPlayControls2 &&
            (identical(other.preRoll, preRoll) ||
                const DeepCollectionEquality()
                    .equals(other.preRoll, preRoll)) &&
            (identical(other.midRoll, midRoll) ||
                const DeepCollectionEquality()
                    .equals(other.midRoll, midRoll)) &&
            (identical(other.postRoll, postRoll) ||
                const DeepCollectionEquality()
                    .equals(other.postRoll, postRoll)) &&
            (identical(other.ffwdAd, ffwdAd) ||
                const DeepCollectionEquality().equals(other.ffwdAd, ffwdAd)) &&
            (identical(other.allBreaks, allBreaks) ||
                const DeepCollectionEquality()
                    .equals(other.allBreaks, allBreaks)) &&
            (identical(other.mainAsset, mainAsset) ||
                const DeepCollectionEquality()
                    .equals(other.mainAsset, mainAsset)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(preRoll) ^
      const DeepCollectionEquality().hash(midRoll) ^
      const DeepCollectionEquality().hash(postRoll) ^
      const DeepCollectionEquality().hash(ffwdAd) ^
      const DeepCollectionEquality().hash(allBreaks) ^
      const DeepCollectionEquality().hash(mainAsset) ^
      runtimeType.hashCode;
}

extension $TrickPlayControls2Extension on TrickPlayControls2 {
  TrickPlayControls2 copyWith(
      {List<TrickPlayControl2>? preRoll,
      List<TrickPlayControl2>? midRoll,
      List<TrickPlayControl2>? postRoll,
      List<TrickPlayControl2>? ffwdAd,
      List<TrickPlayControl2>? allBreaks,
      List<TrickPlayControl2>? mainAsset}) {
    return TrickPlayControls2(
        preRoll: preRoll ?? this.preRoll,
        midRoll: midRoll ?? this.midRoll,
        postRoll: postRoll ?? this.postRoll,
        ffwdAd: ffwdAd ?? this.ffwdAd,
        allBreaks: allBreaks ?? this.allBreaks,
        mainAsset: mainAsset ?? this.mainAsset);
  }

  TrickPlayControls2 copyWithWrapped(
      {Wrapped<List<TrickPlayControl2>?>? preRoll,
      Wrapped<List<TrickPlayControl2>?>? midRoll,
      Wrapped<List<TrickPlayControl2>?>? postRoll,
      Wrapped<List<TrickPlayControl2>?>? ffwdAd,
      Wrapped<List<TrickPlayControl2>?>? allBreaks,
      Wrapped<List<TrickPlayControl2>?>? mainAsset}) {
    return TrickPlayControls2(
        preRoll: (preRoll != null ? preRoll.value : this.preRoll),
        midRoll: (midRoll != null ? midRoll.value : this.midRoll),
        postRoll: (postRoll != null ? postRoll.value : this.postRoll),
        ffwdAd: (ffwdAd != null ? ffwdAd.value : this.ffwdAd),
        allBreaks: (allBreaks != null ? allBreaks.value : this.allBreaks),
        mainAsset: (mainAsset != null ? mainAsset.value : this.mainAsset));
  }
}

@JsonSerializable(explicitToJson: true)
class TrickPlayControl2 {
  TrickPlayControl2({
    this.scteMarkers,
    this.controls,
    this.skipTime,
    this.adCounter,
  });

  factory TrickPlayControl2.fromJson(Map<String, dynamic> json) =>
      _$TrickPlayControl2FromJson(json);

  static const toJsonFactory = _$TrickPlayControl2ToJson;
  Map<String, dynamic> toJson() => _$TrickPlayControl2ToJson(this);

  @JsonKey(name: 'scteMarkers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? scteMarkers;
  @JsonKey(
    name: 'controls',
    includeIfNull: false,
    toJson: trickPlayControl2ControlsListToJson,
    fromJson: trickPlayControl2ControlsListFromJson,
  )
  final List<enums.TrickPlayControl2Controls>? controls;
  @JsonKey(name: 'skipTime', includeIfNull: false)
  final int? skipTime;
  @JsonKey(name: 'adCounter', includeIfNull: false)
  final bool? adCounter;
  static const fromJsonFactory = _$TrickPlayControl2FromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TrickPlayControl2 &&
            (identical(other.scteMarkers, scteMarkers) ||
                const DeepCollectionEquality()
                    .equals(other.scteMarkers, scteMarkers)) &&
            (identical(other.controls, controls) ||
                const DeepCollectionEquality()
                    .equals(other.controls, controls)) &&
            (identical(other.skipTime, skipTime) ||
                const DeepCollectionEquality()
                    .equals(other.skipTime, skipTime)) &&
            (identical(other.adCounter, adCounter) ||
                const DeepCollectionEquality()
                    .equals(other.adCounter, adCounter)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(scteMarkers) ^
      const DeepCollectionEquality().hash(controls) ^
      const DeepCollectionEquality().hash(skipTime) ^
      const DeepCollectionEquality().hash(adCounter) ^
      runtimeType.hashCode;
}

extension $TrickPlayControl2Extension on TrickPlayControl2 {
  TrickPlayControl2 copyWith(
      {List<String>? scteMarkers,
      List<enums.TrickPlayControl2Controls>? controls,
      int? skipTime,
      bool? adCounter}) {
    return TrickPlayControl2(
        scteMarkers: scteMarkers ?? this.scteMarkers,
        controls: controls ?? this.controls,
        skipTime: skipTime ?? this.skipTime,
        adCounter: adCounter ?? this.adCounter);
  }

  TrickPlayControl2 copyWithWrapped(
      {Wrapped<List<String>?>? scteMarkers,
      Wrapped<List<enums.TrickPlayControl2Controls>?>? controls,
      Wrapped<int?>? skipTime,
      Wrapped<bool?>? adCounter}) {
    return TrickPlayControl2(
        scteMarkers:
            (scteMarkers != null ? scteMarkers.value : this.scteMarkers),
        controls: (controls != null ? controls.value : this.controls),
        skipTime: (skipTime != null ? skipTime.value : this.skipTime),
        adCounter: (adCounter != null ? adCounter.value : this.adCounter));
  }
}

@JsonSerializable(explicitToJson: true)
class TsbResolveContentReply {
  TsbResolveContentReply({
    this.resolveAttributes,
    this.tsbPlayoutInfo,
    this.expirationTime,
  });

  factory TsbResolveContentReply.fromJson(Map<String, dynamic> json) =>
      _$TsbResolveContentReplyFromJson(json);

  static const toJsonFactory = _$TsbResolveContentReplyToJson;
  Map<String, dynamic> toJson() => _$TsbResolveContentReplyToJson(this);

  @JsonKey(name: 'resolve_attributes', includeIfNull: false)
  final ResolveAttributes? resolveAttributes;
  @JsonKey(name: 'tsb_playout_info', includeIfNull: false)
  final TsbResolveContentReply$TsbPlayoutInfo? tsbPlayoutInfo;
  @JsonKey(name: 'expiration_time', includeIfNull: false, defaultValue: '')
  final String? expirationTime;
  static const fromJsonFactory = _$TsbResolveContentReplyFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TsbResolveContentReply &&
            (identical(other.resolveAttributes, resolveAttributes) ||
                const DeepCollectionEquality()
                    .equals(other.resolveAttributes, resolveAttributes)) &&
            (identical(other.tsbPlayoutInfo, tsbPlayoutInfo) ||
                const DeepCollectionEquality()
                    .equals(other.tsbPlayoutInfo, tsbPlayoutInfo)) &&
            (identical(other.expirationTime, expirationTime) ||
                const DeepCollectionEquality()
                    .equals(other.expirationTime, expirationTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(resolveAttributes) ^
      const DeepCollectionEquality().hash(tsbPlayoutInfo) ^
      const DeepCollectionEquality().hash(expirationTime) ^
      runtimeType.hashCode;
}

extension $TsbResolveContentReplyExtension on TsbResolveContentReply {
  TsbResolveContentReply copyWith(
      {ResolveAttributes? resolveAttributes,
      TsbResolveContentReply$TsbPlayoutInfo? tsbPlayoutInfo,
      String? expirationTime}) {
    return TsbResolveContentReply(
        resolveAttributes: resolveAttributes ?? this.resolveAttributes,
        tsbPlayoutInfo: tsbPlayoutInfo ?? this.tsbPlayoutInfo,
        expirationTime: expirationTime ?? this.expirationTime);
  }

  TsbResolveContentReply copyWithWrapped(
      {Wrapped<ResolveAttributes?>? resolveAttributes,
      Wrapped<TsbResolveContentReply$TsbPlayoutInfo?>? tsbPlayoutInfo,
      Wrapped<String?>? expirationTime}) {
    return TsbResolveContentReply(
        resolveAttributes: (resolveAttributes != null
            ? resolveAttributes.value
            : this.resolveAttributes),
        tsbPlayoutInfo: (tsbPlayoutInfo != null
            ? tsbPlayoutInfo.value
            : this.tsbPlayoutInfo),
        expirationTime: (expirationTime != null
            ? expirationTime.value
            : this.expirationTime));
  }
}

@JsonSerializable(explicitToJson: true)
class UidInfoResponse {
  UidInfoResponse({
    this.startTimeOffset,
    this.duration,
    this.resolution,
    this.repetitionInterval,
    this.displayDuration,
    this.fontColor,
    this.backgroundColor,
    this.fontSize,
    this.xAlignment,
    this.yAlignment,
    this.displayZoneXStartPx,
    this.displayZoneYStartPx,
    this.displayZoneXEndPx,
    this.displayZoneYEndPx,
    this.xStartPositionPx,
    this.yStartPositionPx,
  });

  factory UidInfoResponse.fromJson(Map<String, dynamic> json) =>
      _$UidInfoResponseFromJson(json);

  static const toJsonFactory = _$UidInfoResponseToJson;
  Map<String, dynamic> toJson() => _$UidInfoResponseToJson(this);

  @JsonKey(name: 'start_time_offset', includeIfNull: false)
  final int? startTimeOffset;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(
    name: 'resolution',
    includeIfNull: false,
    toJson: uidInfoResponseResolutionToJson,
    fromJson: uidInfoResponseResolutionFromJson,
  )
  final enums.UidInfoResponseResolution? resolution;
  @JsonKey(name: 'repetition_interval', includeIfNull: false)
  final int? repetitionInterval;
  @JsonKey(name: 'display_duration', includeIfNull: false)
  final int? displayDuration;
  @JsonKey(name: 'font_color', includeIfNull: false, defaultValue: '')
  final String? fontColor;
  @JsonKey(name: 'background_color', includeIfNull: false, defaultValue: '')
  final String? backgroundColor;
  @JsonKey(
    name: 'font_size',
    includeIfNull: false,
    toJson: uidInfoResponseFontSizeToJson,
    fromJson: uidInfoResponseFontSizeFromJson,
  )
  final enums.UidInfoResponseFontSize? fontSize;
  @JsonKey(
    name: 'x_alignment',
    includeIfNull: false,
    toJson: uidInfoResponseXAlignmentToJson,
    fromJson: uidInfoResponseXAlignmentFromJson,
  )
  final enums.UidInfoResponseXAlignment? xAlignment;
  @JsonKey(
    name: 'y_alignment',
    includeIfNull: false,
    toJson: uidInfoResponseYAlignmentToJson,
    fromJson: uidInfoResponseYAlignmentFromJson,
  )
  final enums.UidInfoResponseYAlignment? yAlignment;
  @JsonKey(name: 'display_zone_x_start_px', includeIfNull: false)
  final int? displayZoneXStartPx;
  @JsonKey(name: 'display_zone_y_start_px', includeIfNull: false)
  final int? displayZoneYStartPx;
  @JsonKey(name: 'display_zone_x_end_px', includeIfNull: false)
  final int? displayZoneXEndPx;
  @JsonKey(name: 'display_zone_y_end_px', includeIfNull: false)
  final int? displayZoneYEndPx;
  @JsonKey(name: 'x_start_position_px', includeIfNull: false)
  final int? xStartPositionPx;
  @JsonKey(name: 'y_start_position_px', includeIfNull: false)
  final int? yStartPositionPx;
  static const fromJsonFactory = _$UidInfoResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UidInfoResponse &&
            (identical(other.startTimeOffset, startTimeOffset) ||
                const DeepCollectionEquality()
                    .equals(other.startTimeOffset, startTimeOffset)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.repetitionInterval, repetitionInterval) ||
                const DeepCollectionEquality()
                    .equals(other.repetitionInterval, repetitionInterval)) &&
            (identical(other.displayDuration, displayDuration) ||
                const DeepCollectionEquality()
                    .equals(other.displayDuration, displayDuration)) &&
            (identical(other.fontColor, fontColor) ||
                const DeepCollectionEquality()
                    .equals(other.fontColor, fontColor)) &&
            (identical(other.backgroundColor, backgroundColor) ||
                const DeepCollectionEquality()
                    .equals(other.backgroundColor, backgroundColor)) &&
            (identical(other.fontSize, fontSize) ||
                const DeepCollectionEquality()
                    .equals(other.fontSize, fontSize)) &&
            (identical(other.xAlignment, xAlignment) ||
                const DeepCollectionEquality()
                    .equals(other.xAlignment, xAlignment)) &&
            (identical(other.yAlignment, yAlignment) ||
                const DeepCollectionEquality()
                    .equals(other.yAlignment, yAlignment)) &&
            (identical(other.displayZoneXStartPx, displayZoneXStartPx) ||
                const DeepCollectionEquality()
                    .equals(other.displayZoneXStartPx, displayZoneXStartPx)) &&
            (identical(other.displayZoneYStartPx, displayZoneYStartPx) ||
                const DeepCollectionEquality()
                    .equals(other.displayZoneYStartPx, displayZoneYStartPx)) &&
            (identical(other.displayZoneXEndPx, displayZoneXEndPx) ||
                const DeepCollectionEquality()
                    .equals(other.displayZoneXEndPx, displayZoneXEndPx)) &&
            (identical(other.displayZoneYEndPx, displayZoneYEndPx) ||
                const DeepCollectionEquality()
                    .equals(other.displayZoneYEndPx, displayZoneYEndPx)) &&
            (identical(other.xStartPositionPx, xStartPositionPx) ||
                const DeepCollectionEquality()
                    .equals(other.xStartPositionPx, xStartPositionPx)) &&
            (identical(other.yStartPositionPx, yStartPositionPx) ||
                const DeepCollectionEquality()
                    .equals(other.yStartPositionPx, yStartPositionPx)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTimeOffset) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(repetitionInterval) ^
      const DeepCollectionEquality().hash(displayDuration) ^
      const DeepCollectionEquality().hash(fontColor) ^
      const DeepCollectionEquality().hash(backgroundColor) ^
      const DeepCollectionEquality().hash(fontSize) ^
      const DeepCollectionEquality().hash(xAlignment) ^
      const DeepCollectionEquality().hash(yAlignment) ^
      const DeepCollectionEquality().hash(displayZoneXStartPx) ^
      const DeepCollectionEquality().hash(displayZoneYStartPx) ^
      const DeepCollectionEquality().hash(displayZoneXEndPx) ^
      const DeepCollectionEquality().hash(displayZoneYEndPx) ^
      const DeepCollectionEquality().hash(xStartPositionPx) ^
      const DeepCollectionEquality().hash(yStartPositionPx) ^
      runtimeType.hashCode;
}

extension $UidInfoResponseExtension on UidInfoResponse {
  UidInfoResponse copyWith(
      {int? startTimeOffset,
      int? duration,
      enums.UidInfoResponseResolution? resolution,
      int? repetitionInterval,
      int? displayDuration,
      String? fontColor,
      String? backgroundColor,
      enums.UidInfoResponseFontSize? fontSize,
      enums.UidInfoResponseXAlignment? xAlignment,
      enums.UidInfoResponseYAlignment? yAlignment,
      int? displayZoneXStartPx,
      int? displayZoneYStartPx,
      int? displayZoneXEndPx,
      int? displayZoneYEndPx,
      int? xStartPositionPx,
      int? yStartPositionPx}) {
    return UidInfoResponse(
        startTimeOffset: startTimeOffset ?? this.startTimeOffset,
        duration: duration ?? this.duration,
        resolution: resolution ?? this.resolution,
        repetitionInterval: repetitionInterval ?? this.repetitionInterval,
        displayDuration: displayDuration ?? this.displayDuration,
        fontColor: fontColor ?? this.fontColor,
        backgroundColor: backgroundColor ?? this.backgroundColor,
        fontSize: fontSize ?? this.fontSize,
        xAlignment: xAlignment ?? this.xAlignment,
        yAlignment: yAlignment ?? this.yAlignment,
        displayZoneXStartPx: displayZoneXStartPx ?? this.displayZoneXStartPx,
        displayZoneYStartPx: displayZoneYStartPx ?? this.displayZoneYStartPx,
        displayZoneXEndPx: displayZoneXEndPx ?? this.displayZoneXEndPx,
        displayZoneYEndPx: displayZoneYEndPx ?? this.displayZoneYEndPx,
        xStartPositionPx: xStartPositionPx ?? this.xStartPositionPx,
        yStartPositionPx: yStartPositionPx ?? this.yStartPositionPx);
  }

  UidInfoResponse copyWithWrapped(
      {Wrapped<int?>? startTimeOffset,
      Wrapped<int?>? duration,
      Wrapped<enums.UidInfoResponseResolution?>? resolution,
      Wrapped<int?>? repetitionInterval,
      Wrapped<int?>? displayDuration,
      Wrapped<String?>? fontColor,
      Wrapped<String?>? backgroundColor,
      Wrapped<enums.UidInfoResponseFontSize?>? fontSize,
      Wrapped<enums.UidInfoResponseXAlignment?>? xAlignment,
      Wrapped<enums.UidInfoResponseYAlignment?>? yAlignment,
      Wrapped<int?>? displayZoneXStartPx,
      Wrapped<int?>? displayZoneYStartPx,
      Wrapped<int?>? displayZoneXEndPx,
      Wrapped<int?>? displayZoneYEndPx,
      Wrapped<int?>? xStartPositionPx,
      Wrapped<int?>? yStartPositionPx}) {
    return UidInfoResponse(
        startTimeOffset: (startTimeOffset != null
            ? startTimeOffset.value
            : this.startTimeOffset),
        duration: (duration != null ? duration.value : this.duration),
        resolution: (resolution != null ? resolution.value : this.resolution),
        repetitionInterval: (repetitionInterval != null
            ? repetitionInterval.value
            : this.repetitionInterval),
        displayDuration: (displayDuration != null
            ? displayDuration.value
            : this.displayDuration),
        fontColor: (fontColor != null ? fontColor.value : this.fontColor),
        backgroundColor: (backgroundColor != null
            ? backgroundColor.value
            : this.backgroundColor),
        fontSize: (fontSize != null ? fontSize.value : this.fontSize),
        xAlignment: (xAlignment != null ? xAlignment.value : this.xAlignment),
        yAlignment: (yAlignment != null ? yAlignment.value : this.yAlignment),
        displayZoneXStartPx: (displayZoneXStartPx != null
            ? displayZoneXStartPx.value
            : this.displayZoneXStartPx),
        displayZoneYStartPx: (displayZoneYStartPx != null
            ? displayZoneYStartPx.value
            : this.displayZoneYStartPx),
        displayZoneXEndPx: (displayZoneXEndPx != null
            ? displayZoneXEndPx.value
            : this.displayZoneXEndPx),
        displayZoneYEndPx: (displayZoneYEndPx != null
            ? displayZoneYEndPx.value
            : this.displayZoneYEndPx),
        xStartPositionPx: (xStartPositionPx != null
            ? xStartPositionPx.value
            : this.xStartPositionPx),
        yStartPositionPx: (yStartPositionPx != null
            ? yStartPositionPx.value
            : this.yStartPositionPx));
  }
}

@JsonSerializable(explicitToJson: true)
class LocalRecordingPerseusSessionResponse {
  LocalRecordingPerseusSessionResponse({
    this.thumbnailServiceUrl,
    this.prePaddingTime,
    this.postPaddingTime,
    this.drmContentId,
    this.deviceRegistrationRequired,
    this.productExpiration,
  });

  factory LocalRecordingPerseusSessionResponse.fromJson(
          Map<String, dynamic> json) =>
      _$LocalRecordingPerseusSessionResponseFromJson(json);

  static const toJsonFactory = _$LocalRecordingPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$LocalRecordingPerseusSessionResponseToJson(this);

  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  @JsonKey(name: 'deviceRegistrationRequired', includeIfNull: false)
  final bool? deviceRegistrationRequired;
  @JsonKey(name: 'productExpiration', includeIfNull: false)
  final DateTime? productExpiration;
  static const fromJsonFactory = _$LocalRecordingPerseusSessionResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalRecordingPerseusSessionResponse &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)) &&
            (identical(other.deviceRegistrationRequired,
                    deviceRegistrationRequired) ||
                const DeepCollectionEquality().equals(
                    other.deviceRegistrationRequired,
                    deviceRegistrationRequired)) &&
            (identical(other.productExpiration, productExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.productExpiration, productExpiration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      const DeepCollectionEquality().hash(deviceRegistrationRequired) ^
      const DeepCollectionEquality().hash(productExpiration) ^
      runtimeType.hashCode;
}

extension $LocalRecordingPerseusSessionResponseExtension
    on LocalRecordingPerseusSessionResponse {
  LocalRecordingPerseusSessionResponse copyWith(
      {String? thumbnailServiceUrl,
      int? prePaddingTime,
      int? postPaddingTime,
      String? drmContentId,
      bool? deviceRegistrationRequired,
      DateTime? productExpiration}) {
    return LocalRecordingPerseusSessionResponse(
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        drmContentId: drmContentId ?? this.drmContentId,
        deviceRegistrationRequired:
            deviceRegistrationRequired ?? this.deviceRegistrationRequired,
        productExpiration: productExpiration ?? this.productExpiration);
  }

  LocalRecordingPerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<String?>? drmContentId,
      Wrapped<bool?>? deviceRegistrationRequired,
      Wrapped<DateTime?>? productExpiration}) {
    return LocalRecordingPerseusSessionResponse(
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId),
        deviceRegistrationRequired: (deviceRegistrationRequired != null
            ? deviceRegistrationRequired.value
            : this.deviceRegistrationRequired),
        productExpiration: (productExpiration != null
            ? productExpiration.value
            : this.productExpiration));
  }
}

@JsonSerializable(explicitToJson: true)
class TsbResolveContentReply$TsbPlayoutInfo {
  TsbResolveContentReply$TsbPlayoutInfo({
    this.channelName,
    this.endTime,
    this.startTime,
  });

  factory TsbResolveContentReply$TsbPlayoutInfo.fromJson(
          Map<String, dynamic> json) =>
      _$TsbResolveContentReply$TsbPlayoutInfoFromJson(json);

  static const toJsonFactory = _$TsbResolveContentReply$TsbPlayoutInfoToJson;
  Map<String, dynamic> toJson() =>
      _$TsbResolveContentReply$TsbPlayoutInfoToJson(this);

  @JsonKey(name: 'channel_name', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'end_time', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'start_time', includeIfNull: false, defaultValue: '')
  final String? startTime;
  static const fromJsonFactory =
      _$TsbResolveContentReply$TsbPlayoutInfoFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TsbResolveContentReply$TsbPlayoutInfo &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(startTime) ^
      runtimeType.hashCode;
}

extension $TsbResolveContentReply$TsbPlayoutInfoExtension
    on TsbResolveContentReply$TsbPlayoutInfo {
  TsbResolveContentReply$TsbPlayoutInfo copyWith(
      {String? channelName, String? endTime, String? startTime}) {
    return TsbResolveContentReply$TsbPlayoutInfo(
        channelName: channelName ?? this.channelName,
        endTime: endTime ?? this.endTime,
        startTime: startTime ?? this.startTime);
  }

  TsbResolveContentReply$TsbPlayoutInfo copyWithWrapped(
      {Wrapped<String?>? channelName,
      Wrapped<String?>? endTime,
      Wrapped<String?>? startTime}) {
    return TsbResolveContentReply$TsbPlayoutInfo(
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        endTime: (endTime != null ? endTime.value : this.endTime),
        startTime: (startTime != null ? startTime.value : this.startTime));
  }
}

String? trickPlayControlToJson(enums.TrickPlayControl? trickPlayControl) {
  return trickPlayControl?.value;
}

enums.TrickPlayControl trickPlayControlFromJson(
  Object? trickPlayControl, [
  enums.TrickPlayControl? defaultValue,
]) {
  return enums.TrickPlayControl.values
          .firstWhereOrNull((e) => e.value == trickPlayControl) ??
      defaultValue ??
      enums.TrickPlayControl.swaggerGeneratedUnknown;
}

List<String> trickPlayControlListToJson(
    List<enums.TrickPlayControl>? trickPlayControl) {
  if (trickPlayControl == null) {
    return [];
  }

  return trickPlayControl.map((e) => e.value!).toList();
}

List<enums.TrickPlayControl> trickPlayControlListFromJson(
  List? trickPlayControl, [
  List<enums.TrickPlayControl>? defaultValue,
]) {
  if (trickPlayControl == null) {
    return defaultValue ?? [];
  }

  return trickPlayControl
      .map((e) => trickPlayControlFromJson(e.toString()))
      .toList();
}

List<enums.TrickPlayControl>? trickPlayControlNullableListFromJson(
  List? trickPlayControl, [
  List<enums.TrickPlayControl>? defaultValue,
]) {
  if (trickPlayControl == null) {
    return defaultValue;
  }

  return trickPlayControl
      .map((e) => trickPlayControlFromJson(e.toString()))
      .toList();
}

String? trickPlayControl2ControlsToJson(
    enums.TrickPlayControl2Controls? trickPlayControl2Controls) {
  return trickPlayControl2Controls?.value;
}

enums.TrickPlayControl2Controls trickPlayControl2ControlsFromJson(
  Object? trickPlayControl2Controls, [
  enums.TrickPlayControl2Controls? defaultValue,
]) {
  return enums.TrickPlayControl2Controls.values
          .firstWhereOrNull((e) => e.value == trickPlayControl2Controls) ??
      defaultValue ??
      enums.TrickPlayControl2Controls.swaggerGeneratedUnknown;
}

List<String> trickPlayControl2ControlsListToJson(
    List<enums.TrickPlayControl2Controls>? trickPlayControl2Controls) {
  if (trickPlayControl2Controls == null) {
    return [];
  }

  return trickPlayControl2Controls.map((e) => e.value!).toList();
}

List<enums.TrickPlayControl2Controls> trickPlayControl2ControlsListFromJson(
  List? trickPlayControl2Controls, [
  List<enums.TrickPlayControl2Controls>? defaultValue,
]) {
  if (trickPlayControl2Controls == null) {
    return defaultValue ?? [];
  }

  return trickPlayControl2Controls
      .map((e) => trickPlayControl2ControlsFromJson(e.toString()))
      .toList();
}

List<enums.TrickPlayControl2Controls>?
    trickPlayControl2ControlsNullableListFromJson(
  List? trickPlayControl2Controls, [
  List<enums.TrickPlayControl2Controls>? defaultValue,
]) {
  if (trickPlayControl2Controls == null) {
    return defaultValue;
  }

  return trickPlayControl2Controls
      .map((e) => trickPlayControl2ControlsFromJson(e.toString()))
      .toList();
}

String? uidInfoResponseResolutionToJson(
    enums.UidInfoResponseResolution? uidInfoResponseResolution) {
  return uidInfoResponseResolution?.value;
}

enums.UidInfoResponseResolution uidInfoResponseResolutionFromJson(
  Object? uidInfoResponseResolution, [
  enums.UidInfoResponseResolution? defaultValue,
]) {
  return enums.UidInfoResponseResolution.values
          .firstWhereOrNull((e) => e.value == uidInfoResponseResolution) ??
      defaultValue ??
      enums.UidInfoResponseResolution.swaggerGeneratedUnknown;
}

List<String> uidInfoResponseResolutionListToJson(
    List<enums.UidInfoResponseResolution>? uidInfoResponseResolution) {
  if (uidInfoResponseResolution == null) {
    return [];
  }

  return uidInfoResponseResolution.map((e) => e.value!).toList();
}

List<enums.UidInfoResponseResolution> uidInfoResponseResolutionListFromJson(
  List? uidInfoResponseResolution, [
  List<enums.UidInfoResponseResolution>? defaultValue,
]) {
  if (uidInfoResponseResolution == null) {
    return defaultValue ?? [];
  }

  return uidInfoResponseResolution
      .map((e) => uidInfoResponseResolutionFromJson(e.toString()))
      .toList();
}

List<enums.UidInfoResponseResolution>?
    uidInfoResponseResolutionNullableListFromJson(
  List? uidInfoResponseResolution, [
  List<enums.UidInfoResponseResolution>? defaultValue,
]) {
  if (uidInfoResponseResolution == null) {
    return defaultValue;
  }

  return uidInfoResponseResolution
      .map((e) => uidInfoResponseResolutionFromJson(e.toString()))
      .toList();
}

String? uidInfoResponseFontSizeToJson(
    enums.UidInfoResponseFontSize? uidInfoResponseFontSize) {
  return uidInfoResponseFontSize?.value;
}

enums.UidInfoResponseFontSize uidInfoResponseFontSizeFromJson(
  Object? uidInfoResponseFontSize, [
  enums.UidInfoResponseFontSize? defaultValue,
]) {
  return enums.UidInfoResponseFontSize.values
          .firstWhereOrNull((e) => e.value == uidInfoResponseFontSize) ??
      defaultValue ??
      enums.UidInfoResponseFontSize.swaggerGeneratedUnknown;
}

List<String> uidInfoResponseFontSizeListToJson(
    List<enums.UidInfoResponseFontSize>? uidInfoResponseFontSize) {
  if (uidInfoResponseFontSize == null) {
    return [];
  }

  return uidInfoResponseFontSize.map((e) => e.value!).toList();
}

List<enums.UidInfoResponseFontSize> uidInfoResponseFontSizeListFromJson(
  List? uidInfoResponseFontSize, [
  List<enums.UidInfoResponseFontSize>? defaultValue,
]) {
  if (uidInfoResponseFontSize == null) {
    return defaultValue ?? [];
  }

  return uidInfoResponseFontSize
      .map((e) => uidInfoResponseFontSizeFromJson(e.toString()))
      .toList();
}

List<enums.UidInfoResponseFontSize>?
    uidInfoResponseFontSizeNullableListFromJson(
  List? uidInfoResponseFontSize, [
  List<enums.UidInfoResponseFontSize>? defaultValue,
]) {
  if (uidInfoResponseFontSize == null) {
    return defaultValue;
  }

  return uidInfoResponseFontSize
      .map((e) => uidInfoResponseFontSizeFromJson(e.toString()))
      .toList();
}

String? uidInfoResponseXAlignmentToJson(
    enums.UidInfoResponseXAlignment? uidInfoResponseXAlignment) {
  return uidInfoResponseXAlignment?.value;
}

enums.UidInfoResponseXAlignment uidInfoResponseXAlignmentFromJson(
  Object? uidInfoResponseXAlignment, [
  enums.UidInfoResponseXAlignment? defaultValue,
]) {
  return enums.UidInfoResponseXAlignment.values
          .firstWhereOrNull((e) => e.value == uidInfoResponseXAlignment) ??
      defaultValue ??
      enums.UidInfoResponseXAlignment.swaggerGeneratedUnknown;
}

List<String> uidInfoResponseXAlignmentListToJson(
    List<enums.UidInfoResponseXAlignment>? uidInfoResponseXAlignment) {
  if (uidInfoResponseXAlignment == null) {
    return [];
  }

  return uidInfoResponseXAlignment.map((e) => e.value!).toList();
}

List<enums.UidInfoResponseXAlignment> uidInfoResponseXAlignmentListFromJson(
  List? uidInfoResponseXAlignment, [
  List<enums.UidInfoResponseXAlignment>? defaultValue,
]) {
  if (uidInfoResponseXAlignment == null) {
    return defaultValue ?? [];
  }

  return uidInfoResponseXAlignment
      .map((e) => uidInfoResponseXAlignmentFromJson(e.toString()))
      .toList();
}

List<enums.UidInfoResponseXAlignment>?
    uidInfoResponseXAlignmentNullableListFromJson(
  List? uidInfoResponseXAlignment, [
  List<enums.UidInfoResponseXAlignment>? defaultValue,
]) {
  if (uidInfoResponseXAlignment == null) {
    return defaultValue;
  }

  return uidInfoResponseXAlignment
      .map((e) => uidInfoResponseXAlignmentFromJson(e.toString()))
      .toList();
}

String? uidInfoResponseYAlignmentToJson(
    enums.UidInfoResponseYAlignment? uidInfoResponseYAlignment) {
  return uidInfoResponseYAlignment?.value;
}

enums.UidInfoResponseYAlignment uidInfoResponseYAlignmentFromJson(
  Object? uidInfoResponseYAlignment, [
  enums.UidInfoResponseYAlignment? defaultValue,
]) {
  return enums.UidInfoResponseYAlignment.values
          .firstWhereOrNull((e) => e.value == uidInfoResponseYAlignment) ??
      defaultValue ??
      enums.UidInfoResponseYAlignment.swaggerGeneratedUnknown;
}

List<String> uidInfoResponseYAlignmentListToJson(
    List<enums.UidInfoResponseYAlignment>? uidInfoResponseYAlignment) {
  if (uidInfoResponseYAlignment == null) {
    return [];
  }

  return uidInfoResponseYAlignment.map((e) => e.value!).toList();
}

List<enums.UidInfoResponseYAlignment> uidInfoResponseYAlignmentListFromJson(
  List? uidInfoResponseYAlignment, [
  List<enums.UidInfoResponseYAlignment>? defaultValue,
]) {
  if (uidInfoResponseYAlignment == null) {
    return defaultValue ?? [];
  }

  return uidInfoResponseYAlignment
      .map((e) => uidInfoResponseYAlignmentFromJson(e.toString()))
      .toList();
}

List<enums.UidInfoResponseYAlignment>?
    uidInfoResponseYAlignmentNullableListFromJson(
  List? uidInfoResponseYAlignment, [
  List<enums.UidInfoResponseYAlignment>? defaultValue,
]) {
  if (uidInfoResponseYAlignment == null) {
    return defaultValue;
  }

  return uidInfoResponseYAlignment
      .map((e) => uidInfoResponseYAlignmentFromJson(e.toString()))
      .toList();
}

String? sessionModeToJson(enums.SessionMode? sessionMode) {
  return sessionMode?.value;
}

enums.SessionMode sessionModeFromJson(
  Object? sessionMode, [
  enums.SessionMode? defaultValue,
]) {
  return enums.SessionMode.values
          .firstWhereOrNull((e) => e.value == sessionMode) ??
      defaultValue ??
      enums.SessionMode.swaggerGeneratedUnknown;
}

List<String> sessionModeListToJson(List<enums.SessionMode>? sessionMode) {
  if (sessionMode == null) {
    return [];
  }

  return sessionMode.map((e) => e.value!).toList();
}

List<enums.SessionMode> sessionModeListFromJson(
  List? sessionMode, [
  List<enums.SessionMode>? defaultValue,
]) {
  if (sessionMode == null) {
    return defaultValue ?? [];
  }

  return sessionMode.map((e) => sessionModeFromJson(e.toString())).toList();
}

List<enums.SessionMode>? sessionModeNullableListFromJson(
  List? sessionMode, [
  List<enums.SessionMode>? defaultValue,
]) {
  if (sessionMode == null) {
    return defaultValue;
  }

  return sessionMode.map((e) => sessionModeFromJson(e.toString())).toList();
}

String? customplayreadyRightsmanagerAsmxPostSubContentTypeToJson(
    enums.CustomplayreadyRightsmanagerAsmxPostSubContentType?
        customplayreadyRightsmanagerAsmxPostSubContentType) {
  return customplayreadyRightsmanagerAsmxPostSubContentType?.value;
}

enums.CustomplayreadyRightsmanagerAsmxPostSubContentType
    customplayreadyRightsmanagerAsmxPostSubContentTypeFromJson(
  Object? customplayreadyRightsmanagerAsmxPostSubContentType, [
  enums.CustomplayreadyRightsmanagerAsmxPostSubContentType? defaultValue,
]) {
  return enums.CustomplayreadyRightsmanagerAsmxPostSubContentType.values
          .firstWhereOrNull((e) =>
              e.value == customplayreadyRightsmanagerAsmxPostSubContentType) ??
      defaultValue ??
      enums.CustomplayreadyRightsmanagerAsmxPostSubContentType
          .swaggerGeneratedUnknown;
}

List<String> customplayreadyRightsmanagerAsmxPostSubContentTypeListToJson(
    List<enums.CustomplayreadyRightsmanagerAsmxPostSubContentType>?
        customplayreadyRightsmanagerAsmxPostSubContentType) {
  if (customplayreadyRightsmanagerAsmxPostSubContentType == null) {
    return [];
  }

  return customplayreadyRightsmanagerAsmxPostSubContentType
      .map((e) => e.value!)
      .toList();
}

List<enums.CustomplayreadyRightsmanagerAsmxPostSubContentType>
    customplayreadyRightsmanagerAsmxPostSubContentTypeListFromJson(
  List? customplayreadyRightsmanagerAsmxPostSubContentType, [
  List<enums.CustomplayreadyRightsmanagerAsmxPostSubContentType>? defaultValue,
]) {
  if (customplayreadyRightsmanagerAsmxPostSubContentType == null) {
    return defaultValue ?? [];
  }

  return customplayreadyRightsmanagerAsmxPostSubContentType
      .map((e) => customplayreadyRightsmanagerAsmxPostSubContentTypeFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomplayreadyRightsmanagerAsmxPostSubContentType>?
    customplayreadyRightsmanagerAsmxPostSubContentTypeNullableListFromJson(
  List? customplayreadyRightsmanagerAsmxPostSubContentType, [
  List<enums.CustomplayreadyRightsmanagerAsmxPostSubContentType>? defaultValue,
]) {
  if (customplayreadyRightsmanagerAsmxPostSubContentType == null) {
    return defaultValue;
  }

  return customplayreadyRightsmanagerAsmxPostSubContentType
      .map((e) => customplayreadyRightsmanagerAsmxPostSubContentTypeFromJson(
          e.toString()))
      .toList();
}

String? sessionV1ChannelsChannelIdPostSourceToJson(
    enums.SessionV1ChannelsChannelIdPostSource?
        sessionV1ChannelsChannelIdPostSource) {
  return sessionV1ChannelsChannelIdPostSource?.value;
}

enums.SessionV1ChannelsChannelIdPostSource
    sessionV1ChannelsChannelIdPostSourceFromJson(
  Object? sessionV1ChannelsChannelIdPostSource, [
  enums.SessionV1ChannelsChannelIdPostSource? defaultValue,
]) {
  return enums.SessionV1ChannelsChannelIdPostSource.values.firstWhereOrNull(
          (e) => e.value == sessionV1ChannelsChannelIdPostSource) ??
      defaultValue ??
      enums.SessionV1ChannelsChannelIdPostSource.swaggerGeneratedUnknown;
}

List<String> sessionV1ChannelsChannelIdPostSourceListToJson(
    List<enums.SessionV1ChannelsChannelIdPostSource>?
        sessionV1ChannelsChannelIdPostSource) {
  if (sessionV1ChannelsChannelIdPostSource == null) {
    return [];
  }

  return sessionV1ChannelsChannelIdPostSource.map((e) => e.value!).toList();
}

List<enums.SessionV1ChannelsChannelIdPostSource>
    sessionV1ChannelsChannelIdPostSourceListFromJson(
  List? sessionV1ChannelsChannelIdPostSource, [
  List<enums.SessionV1ChannelsChannelIdPostSource>? defaultValue,
]) {
  if (sessionV1ChannelsChannelIdPostSource == null) {
    return defaultValue ?? [];
  }

  return sessionV1ChannelsChannelIdPostSource
      .map((e) => sessionV1ChannelsChannelIdPostSourceFromJson(e.toString()))
      .toList();
}

List<enums.SessionV1ChannelsChannelIdPostSource>?
    sessionV1ChannelsChannelIdPostSourceNullableListFromJson(
  List? sessionV1ChannelsChannelIdPostSource, [
  List<enums.SessionV1ChannelsChannelIdPostSource>? defaultValue,
]) {
  if (sessionV1ChannelsChannelIdPostSource == null) {
    return defaultValue;
  }

  return sessionV1ChannelsChannelIdPostSource
      .map((e) => sessionV1ChannelsChannelIdPostSourceFromJson(e.toString()))
      .toList();
}

String? sessionCustomersLegacyIdVodContentsCridPostSessionModeToJson(
    enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode?
        sessionCustomersLegacyIdVodContentsCridPostSessionMode) {
  return sessionCustomersLegacyIdVodContentsCridPostSessionMode?.value;
}

enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode
    sessionCustomersLegacyIdVodContentsCridPostSessionModeFromJson(
  Object? sessionCustomersLegacyIdVodContentsCridPostSessionMode, [
  enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode? defaultValue,
]) {
  return enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode.values
          .firstWhereOrNull((e) =>
              e.value ==
              sessionCustomersLegacyIdVodContentsCridPostSessionMode) ??
      defaultValue ??
      enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode
          .swaggerGeneratedUnknown;
}

List<String> sessionCustomersLegacyIdVodContentsCridPostSessionModeListToJson(
    List<enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode>?
        sessionCustomersLegacyIdVodContentsCridPostSessionMode) {
  if (sessionCustomersLegacyIdVodContentsCridPostSessionMode == null) {
    return [];
  }

  return sessionCustomersLegacyIdVodContentsCridPostSessionMode
      .map((e) => e.value!)
      .toList();
}

List<enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode>
    sessionCustomersLegacyIdVodContentsCridPostSessionModeListFromJson(
  List? sessionCustomersLegacyIdVodContentsCridPostSessionMode, [
  List<enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode>?
      defaultValue,
]) {
  if (sessionCustomersLegacyIdVodContentsCridPostSessionMode == null) {
    return defaultValue ?? [];
  }

  return sessionCustomersLegacyIdVodContentsCridPostSessionMode
      .map((e) =>
          sessionCustomersLegacyIdVodContentsCridPostSessionModeFromJson(
              e.toString()))
      .toList();
}

List<enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode>?
    sessionCustomersLegacyIdVodContentsCridPostSessionModeNullableListFromJson(
  List? sessionCustomersLegacyIdVodContentsCridPostSessionMode, [
  List<enums.SessionCustomersLegacyIdVodContentsCridPostSessionMode>?
      defaultValue,
]) {
  if (sessionCustomersLegacyIdVodContentsCridPostSessionMode == null) {
    return defaultValue;
  }

  return sessionCustomersLegacyIdVodContentsCridPostSessionMode
      .map((e) =>
          sessionCustomersLegacyIdVodContentsCridPostSessionModeFromJson(
              e.toString()))
      .toList();
}

String? sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceToJson(
    enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource?
        sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource) {
  return sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource?.value;
}

enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource
    sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceFromJson(
  Object? sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource, [
  enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource?
      defaultValue,
]) {
  return enums
          .SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource.values
          .firstWhereOrNull((e) =>
              e.value ==
              sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource) ??
      defaultValue ??
      enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource
          .swaggerGeneratedUnknown;
}

List<String>
    sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceListToJson(
        List<enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource>?
            sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource) {
  if (sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource == null) {
    return [];
  }

  return sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource
      .map((e) => e.value!)
      .toList();
}

List<enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource>
    sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceListFromJson(
  List? sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource, [
  List<enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource>?
      defaultValue,
]) {
  if (sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource == null) {
    return defaultValue ?? [];
  }

  return sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource
      .map((e) =>
          sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceFromJson(
              e.toString()))
      .toList();
}

List<enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource>?
    sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceNullableListFromJson(
  List? sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource, [
  List<enums.SessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource>?
      defaultValue,
]) {
  if (sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource == null) {
    return defaultValue;
  }

  return sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSource
      .map((e) =>
          sessionV2DeviceFamilyCustomersLegacyIdReviewBufferPostSourceFromJson(
              e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
