// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'watchlist_service.enums.swagger.dart' as enums;
export 'watchlist_service.enums.swagger.dart';

part 'watchlist_service.swagger.chopper.dart';
part 'watchlist_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class WatchlistService extends ChopperService {
  static WatchlistService create({
    ChopperClient? client,
    Authenticator? authenticator,
    Uri? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$WatchlistService(client);
    }

    final newClient = ChopperClient(
        services: [_$WatchlistService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? Uri.parse('http://'));
    return _$WatchlistService(newClient);
  }

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<WatchlistEntryResponseBase>>
      v1WatchlistsIdEntriesEntryIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? id,
    required String? entryId,
    required String? language,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(WatchlistEntryResponseBase,
        () => WatchlistEntryResponseBase.fromJsonFactory);

    return _v1WatchlistsIdEntriesEntryIdGet(
        xDev: xDev,
        xCus: xCus,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        id: id,
        entryId: entryId,
        language: language,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response<WatchlistEntryResponseBase>>
      _v1WatchlistsIdEntriesEntryIdGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Via')
        String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Path('id')
        required String? id,
    @Path('entryId')
        required String? entryId,
    @Query('language')
        required String? language,
    @Query('merged')
        String? merged,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v1WatchlistsIdEntriesEntryIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    required String? id,
    required String? entryId,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdEntriesEntryIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        id: id,
        entryId: entryId,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v1/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response> _v1WatchlistsIdEntriesEntryIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Path('entryId') required String? entryId,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete all watchlist entries for a given mergedId from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param mergedId The merged Id
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v1WatchlistsIdEntriesMergedMergedIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    required String? id,
    required String? mergedId,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdEntriesMergedMergedIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        id: id,
        mergedId: mergedId,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Delete all watchlist entries for a given mergedId from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param mergedId The merged Id
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v1/watchlists/{id}/entries/merged/{mergedId}')
  Future<chopper.Response> _v1WatchlistsIdEntriesMergedMergedIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Path('mergedId') required String? mergedId,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v1WatchlistsIdEntriesPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    required String? id,
    bool? sharedProfile,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
    required WatchlistEntryRequest? body,
  }) {
    return _v1WatchlistsIdEntriesPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        id: id,
        sharedProfile: sharedProfile,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl,
        body: body);
  }

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Post(
    path: '/v1/watchlists/{id}/entries',
    optionalBody: true,
  )
  Future<chopper.Response> _v1WatchlistsIdEntriesPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistEntryRequest? body,
  });

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v1WatchlistsIdEntriesDelete({
    String? xCus = 'X-Cus',
    String? xVia,
    required String? id,
    required bool? expired,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdEntriesDelete(
        xCus: xCus,
        xVia: xVia,
        id: id,
        expired: expired,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v1/watchlists/{id}/entries')
  Future<chopper.Response> _v1WatchlistsIdEntriesDelete({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Query('expired') required bool? expired,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<WatchlistEntryResponseBase>>
      v2WatchlistsIdEntriesEntryIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? id,
    required String? entryId,
    required String? language,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(WatchlistEntryResponseBase,
        () => WatchlistEntryResponseBase.fromJsonFactory);

    return _v2WatchlistsIdEntriesEntryIdGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        id: id,
        entryId: entryId,
        language: language,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v2/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response<WatchlistEntryResponseBase>>
      _v2WatchlistsIdEntriesEntryIdGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('X-Via')
        String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Path('id')
        required String? id,
    @Path('entryId')
        required String? entryId,
    @Query('language')
        required String? language,
    @Query('merged')
        String? merged,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v2WatchlistsIdEntriesEntryIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? id,
    required String? entryId,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdEntriesEntryIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        id: id,
        entryId: entryId,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v2/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response> _v2WatchlistsIdEntriesEntryIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Path('entryId') required String? entryId,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete all watchlist entries for a given mergedId from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param mergedId The merged Id
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v2WatchlistsIdEntriesMergedMergedIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? id,
    required String? mergedId,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdEntriesMergedMergedIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        id: id,
        mergedId: mergedId,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Delete all watchlist entries for a given mergedId from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param mergedId The merged Id
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v2/watchlists/{id}/entries/merged/{mergedId}')
  Future<chopper.Response> _v2WatchlistsIdEntriesMergedMergedIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Path('mergedId') required String? mergedId,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v3WatchlistsIdEntriesPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? id,
    bool? sharedProfile,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
    required WatchlistEntryRequest? body,
  }) {
    return _v3WatchlistsIdEntriesPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        id: id,
        sharedProfile: sharedProfile,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl,
        body: body);
  }

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Post(
    path: '/v3/watchlists/{id}/entries',
    optionalBody: true,
  )
  Future<chopper.Response> _v3WatchlistsIdEntriesPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistEntryRequest? body,
  });

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v2WatchlistsIdEntriesPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? id,
    bool? sharedProfile,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
    required WatchlistEntryRequest? body,
  }) {
    return _v2WatchlistsIdEntriesPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        id: id,
        sharedProfile: sharedProfile,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl,
        body: body);
  }

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Post(
    path: '/v2/watchlists/{id}/entries',
    optionalBody: true,
  )
  Future<chopper.Response> _v2WatchlistsIdEntriesPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistEntryRequest? body,
  });

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v2WatchlistsIdEntriesDelete({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? id,
    required bool? expired,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdEntriesDelete(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        id: id,
        expired: expired,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v2/watchlists/{id}/entries')
  Future<chopper.Response> _v2WatchlistsIdEntriesDelete({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Query('expired') required bool? expired,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param md metadata filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<WatchlistResponse>> v1WatchlistsProfileProfileIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? profileId,
    required enums.V1WatchlistsProfileProfileIdGetSort? sort,
    required enums.V1WatchlistsProfileProfileIdGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    enums.V1WatchlistsProfileProfileIdGetMd? md,
    String? type,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdGet(
        xDev: xDev,
        xCus: xCus,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        profileId: profileId,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        md: md?.value?.toString(),
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param md metadata filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/profile/{profileId}')
  Future<chopper.Response<WatchlistResponse>> _v1WatchlistsProfileProfileIdGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Via')
        String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Path('profileId')
        required String? profileId,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('md')
        String? md,
    @Query('type')
        String? type,
    @Query('startResults')
        int? startResults,
    @Query('maxResults')
        int? maxResults,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('merged')
        String? merged,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  Future<chopper.Response> v1WatchlistsProfileProfileIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    required String? profileId,
    String? cacheControl,
  }) {
    return _v1WatchlistsProfileProfileIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  @Delete(path: '/v1/watchlists/profile/{profileId}')
  Future<chopper.Response> _v1WatchlistsProfileProfileIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v1WatchlistsProfileProfileIdNameNameAssetIdGet({
    String? xCus = 'X-Cus',
    String? xVia,
    required String? profileId,
    required String? name,
    required String? id,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdNameNameAssetIdGet(
        xCus: xCus,
        xVia: xVia,
        profileId: profileId,
        name: name,
        id: id,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/profile/{profileId}/name/{name}/asset/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v1WatchlistsProfileProfileIdNameNameAssetIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Query('merged') String? merged,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v1WatchlistsProfileProfileIdNameNameSeriesIdGet({
    String? xCus = 'X-Cus',
    String? xVia,
    required String? profileId,
    required String? name,
    required String? id,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdNameNameSeriesIdGet(
        xCus: xCus,
        xVia: xVia,
        profileId: profileId,
        name: name,
        id: id,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/profile/{profileId}/name/{name}/series/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v1WatchlistsProfileProfileIdNameNameSeriesIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Query('merged') String? merged,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<GridResponse>> v1WatchlistsProfileProfileIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? profileId,
    required enums.V1WatchlistsProfileProfileIdGridGetSort? sort,
    required enums.V1WatchlistsProfileProfileIdGridGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        profileId: profileId,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/profile/{profileId}/grid')
  Future<chopper.Response<GridResponse>> _v1WatchlistsProfileProfileIdGridGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('profileId')
        required String? profileId,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('feed')
        String? feed,
    @Query('merged')
        String? merged,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  Future<chopper.Response> v2WatchlistsProfileProfileIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? profileId,
    String? cacheControl,
  }) {
    return _v2WatchlistsProfileProfileIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  @Delete(path: '/v2/watchlists/profile/{profileId}')
  Future<chopper.Response> _v2WatchlistsProfileProfileIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v2WatchlistsProfileProfileIdNameNameAssetIdGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? profileId,
    required String? name,
    required String? id,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdNameNameAssetIdGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        profileId: profileId,
        name: name,
        id: id,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v2/watchlists/profile/{profileId}/name/{name}/asset/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v2WatchlistsProfileProfileIdNameNameAssetIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Query('merged') String? merged,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v2WatchlistsProfileProfileIdNameNameSeriesIdGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? profileId,
    required String? name,
    required String? id,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdNameNameSeriesIdGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        profileId: profileId,
        name: name,
        id: id,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v2/watchlists/profile/{profileId}/name/{name}/series/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v2WatchlistsProfileProfileIdNameNameSeriesIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Query('merged') String? merged,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  Future<chopper.Response<GridResponse>> v2WatchlistsProfileProfileIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? profileId,
    required enums.V2WatchlistsProfileProfileIdGridGetSort? sort,
    required enums.V2WatchlistsProfileProfileIdGridGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? includeExternalProvider,
    String? merged,
    String? mergedOn,
    int? replayOptedInTime,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        profileId: profileId,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        includeExternalProvider: includeExternalProvider,
        merged: merged,
        mergedOn: mergedOn,
        replayOptedInTime: replayOptedInTime,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  @Get(path: '/v2/watchlists/profile/{profileId}/grid')
  Future<chopper.Response<GridResponse>> _v2WatchlistsProfileProfileIdGridGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('profileId')
        required String? profileId,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('feed')
        String? feed,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('merged')
        String? merged,
    @Query('mergedOn')
        String? mergedOn,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<SimpleWatchlistResponse>>
      v2WatchlistsProfileProfileIdSimpleGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? profileId,
    String? type,
    int? startResults,
    int? maxResults,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimpleWatchlistResponse, () => SimpleWatchlistResponse.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdSimpleGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        profileId: profileId,
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v2/watchlists/profile/{profileId}/simple')
  Future<chopper.Response<SimpleWatchlistResponse>>
      _v2WatchlistsProfileProfileIdSimpleGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('profileId') required String? profileId,
    @Query('type') String? type,
    @Query('startResults') int? startResults,
    @Query('maxResults') int? maxResults,
    @Query('merged') String? merged,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  Future<chopper.Response<WatchlistResponse>>
      v2WatchlistsProfileProfileIdExtendedGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? profileId,
    required enums.V2WatchlistsProfileProfileIdExtendedGetSort? sort,
    required enums.V2WatchlistsProfileProfileIdExtendedGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? type,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? includeExternalProvider,
    String? merged,
    String? mergedOn,
    int? replayOptedInTime,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdExtendedGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        profileId: profileId,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        includeExternalProvider: includeExternalProvider,
        merged: merged,
        mergedOn: mergedOn,
        replayOptedInTime: replayOptedInTime,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  @Get(path: '/v2/watchlists/profile/{profileId}/extended')
  Future<chopper.Response<WatchlistResponse>>
      _v2WatchlistsProfileProfileIdExtendedGet({
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('X-Via')
        String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Path('profileId')
        required String? profileId,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('type')
        String? type,
    @Query('startResults')
        int? startResults,
    @Query('maxResults')
        int? maxResults,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('merged')
        String? merged,
    @Query('mergedOn')
        String? mergedOn,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves watchlist Id (NOTE - ONLY WATCHLIST ID) by profile Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response<WatchlistId>> v1WatchlistsGet({
    String? xCus = 'X-Cus',
    String? xVia,
    required String? byProfileId,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v1WatchlistsGet(
        xCus: xCus,
        xVia: xVia,
        byProfileId: byProfileId,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist Id (NOTE - ONLY WATCHLIST ID) by profile Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Get(path: '/v1/watchlists')
  Future<chopper.Response<WatchlistId>> _v1WatchlistsGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Query('byProfileId') required String? byProfileId,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  Future<chopper.Response<WatchlistId>> v1WatchlistsPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? cacheControl,
    required WatchlistRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v1WatchlistsPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  @Post(
    path: '/v1/watchlists',
    optionalBody: true,
  )
  Future<chopper.Response<WatchlistId>> _v1WatchlistsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistRequest? body,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<WatchlistResponse>> v1WatchlistsIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? id,
    required enums.V1WatchlistsIdGetSort? sort,
    required enums.V1WatchlistsIdGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v1WatchlistsIdGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        id: id,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/{id}')
  Future<chopper.Response<WatchlistResponse>> _v1WatchlistsIdGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('id')
        required String? id,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('startResults')
        int? startResults,
    @Query('maxResults')
        int? maxResults,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('merged')
        String? merged,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v1WatchlistsIdPut({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    required String? id,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
    required WatchlistRequest? body,
  }) {
    return _v1WatchlistsIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        id: id,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Put(
    path: '/v1/watchlists/{id}',
    optionalBody: true,
  )
  Future<chopper.Response> _v1WatchlistsIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistRequest? body,
  });

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  Future<chopper.Response> v1WatchlistsIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    bool? sharedProfile,
    required String? id,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        sharedProfile: sharedProfile,
        id: id,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  @Delete(path: '/v1/watchlists/{id}')
  Future<chopper.Response> _v1WatchlistsIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Query('sharedProfile') bool? sharedProfile,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  Future<chopper.Response<GridResponse>> v1WatchlistsIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? id,
    required enums.V1WatchlistsIdGridGetSort? sort,
    required enums.V1WatchlistsIdGridGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? merged,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v1WatchlistsIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        id: id,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        merged: merged,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  @Get(path: '/v1/watchlists/{id}/grid')
  Future<chopper.Response<GridResponse>> _v1WatchlistsIdGridGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('id')
        required String? id,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('feed')
        String? feed,
    @Query('merged')
        String? merged,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves watchlist Id (NOTE - ONLY WATCHLIST ID) by a profile Id.
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response<WatchlistId>> v2WatchlistsGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? byProfileId,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v2WatchlistsGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        byProfileId: byProfileId,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist Id (NOTE - ONLY WATCHLIST ID) by a profile Id.
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Get(path: '/v2/watchlists')
  Future<chopper.Response<WatchlistId>> _v2WatchlistsGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Query('byProfileId') required String? byProfileId,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  Future<chopper.Response<WatchlistId>> v2WatchlistsPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? cacheControl,
    required WatchlistRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v2WatchlistsPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  @Post(
    path: '/v2/watchlists',
    optionalBody: true,
  )
  Future<chopper.Response<WatchlistId>> _v2WatchlistsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistRequest? body,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  Future<chopper.Response<WatchlistResponse>> v2WatchlistsIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? id,
    required enums.V2WatchlistsIdGetSort? sort,
    required enums.V2WatchlistsIdGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? includeExternalProvider,
    String? merged,
    String? mergedOn,
    int? replayOptedInTime,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v2WatchlistsIdGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        id: id,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        includeExternalProvider: includeExternalProvider,
        merged: merged,
        mergedOn: mergedOn,
        replayOptedInTime: replayOptedInTime,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  @Get(path: '/v2/watchlists/{id}')
  Future<chopper.Response<WatchlistResponse>> _v2WatchlistsIdGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('id')
        required String? id,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('startResults')
        int? startResults,
    @Query('maxResults')
        int? maxResults,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('merged')
        String? merged,
    @Query('mergedOn')
        String? mergedOn,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v2WatchlistsIdPut({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    required String? id,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
    required WatchlistRequest? body,
  }) {
    return _v2WatchlistsIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        id: id,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Put(
    path: '/v2/watchlists/{id}',
    optionalBody: true,
  )
  Future<chopper.Response> _v2WatchlistsIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Path('id') required String? id,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistRequest? body,
  });

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  Future<chopper.Response> v2WatchlistsIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    bool? sharedProfile,
    required String? id,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        sharedProfile: sharedProfile,
        id: id,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  @Delete(path: '/v2/watchlists/{id}')
  Future<chopper.Response> _v2WatchlistsIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Query('sharedProfile') bool? sharedProfile,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  Future<chopper.Response<GridResponse>> v2WatchlistsIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? id,
    required enums.V2WatchlistsIdGridGetSort? sort,
    required enums.V2WatchlistsIdGridGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? includeExternalProvider,
    String? merged,
    String? mergedOn,
    int? replayOptedInTime,
    bool? goPlayableOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v2WatchlistsIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        id: id,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        includeExternalProvider: includeExternalProvider,
        merged: merged,
        mergedOn: mergedOn,
        replayOptedInTime: replayOptedInTime,
        goPlayableOnly: goPlayableOnly,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  @Get(path: '/v2/watchlists/{id}/grid')
  Future<chopper.Response<GridResponse>> _v2WatchlistsIdGridGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('id')
        required String? id,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('feed')
        String? feed,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('merged')
        String? merged,
    @Query('mergedOn')
        String? mergedOn,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param cityId cityId assigned to the customer
  Future<chopper.Response<WatchlistResponse>> v3WatchlistsIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    required String? id,
    required enums.V3WatchlistsIdGetSort? sort,
    required enums.V3WatchlistsIdGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? includeExternalProvider,
    String? merged,
    String? mergedOn,
    int? replayOptedInTime,
    required String? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v3WatchlistsIdGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        id: id,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        includeExternalProvider: includeExternalProvider,
        merged: merged,
        mergedOn: mergedOn,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param cityId cityId assigned to the customer
  @Get(path: '/v3/watchlists/{id}')
  Future<chopper.Response<WatchlistResponse>> _v3WatchlistsIdGet({
    @Header('X-Dev')
        String? xDev,
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via')
        String? xVia,
    @Path('id')
        required String? id,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('startResults')
        int? startResults,
    @Query('maxResults')
        int? maxResults,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('merged')
        String? merged,
    @Query('mergedOn')
        String? mergedOn,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('cityId')
        required String? cityId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  ///@param cityId cityId assigned to the customer
  Future<chopper.Response<WatchlistResponse>>
      v3WatchlistsProfileProfileIdExtendedGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? profileId,
    required enums.V3WatchlistsProfileProfileIdExtendedGetSort? sort,
    required enums.V3WatchlistsProfileProfileIdExtendedGetOrder? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? type,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? includeExternalProvider,
    String? merged,
    String? mergedOn,
    int? replayOptedInTime,
    bool? goPlayableOnly,
    required String? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v3WatchlistsProfileProfileIdExtendedGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        profileId: profileId,
        sort: sort?.value?.toString(),
        order: order?.value?.toString(),
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        includeExternalProvider: includeExternalProvider,
        merged: merged,
        mergedOn: mergedOn,
        replayOptedInTime: replayOptedInTime,
        goPlayableOnly: goPlayableOnly,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  ///@param includeExternalProvider Comma separated list of external provider brandingProviderIds that will be included. "ALL" does not filter out contents.
  ///@param merged deduplicate watchlist entries with the same mergedId when this parameter is present or set to true
  ///@param mergedOn Deduplicate watchlist entries for calculation of seasonCount response property
  ///@param replayOptedInTime timestamp to be passed to the Picker Service to get season count from
  ///@param goPlayableOnly Set to true to **only** get the content available for Go devices
  ///@param cityId cityId assigned to the customer
  @Get(path: '/v3/watchlists/profile/{profileId}/extended')
  Future<chopper.Response<WatchlistResponse>>
      _v3WatchlistsProfileProfileIdExtendedGet({
    @Header('X-Cus')
        String? xCus = 'X-Cus',
    @Header('X-Profile')
        String? xProfile,
    @Header('X-Via')
        String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Path('profileId')
        required String? profileId,
    @Query('sort')
        required String? sort,
    @Query('order')
        required String? order,
    @Query('smart')
        bool? smart,
    @Query('language')
        required String? language,
    @Query('genreFilter')
        String? genreFilter,
    @Query('statusFilter')
        String? statusFilter,
    @Query('type')
        String? type,
    @Query('startResults')
        int? startResults,
    @Query('maxResults')
        int? maxResults,
    @Query('sharedProfile')
        bool? sharedProfile,
    @Query('includeExternalProvider')
        String? includeExternalProvider,
    @Query('merged')
        String? merged,
    @Query('mergedOn')
        String? mergedOn,
    @Query('replayOptedInTime')
        int? replayOptedInTime,
    @Query('goPlayableOnly')
        bool? goPlayableOnly,
    @Query('cityId')
        required String? cityId,
    @Header('Cache-Control')
        String? cacheControl,
  });

  ///Create or update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  Future<chopper.Response<WatchlistId>> oespWatchlistPut({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? cacheControl,
    required WatchlistRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _oespWatchlistPut(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create or update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param CLAIMSTOKEN Customer Claims token. Should come with X-Via
  @Put(
    path: '/oesp/watchlist',
    optionalBody: true,
  )
  Future<chopper.Response<WatchlistId>> _oespWatchlistPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WatchlistRequest? body,
  });
}

@JsonSerializable(explicitToJson: true)
class EstContent {
  EstContent({
    this.videoHost,
    this.videoUrl,
    this.id,
  });

  factory EstContent.fromJson(Map<String, dynamic> json) =>
      _$EstContentFromJson(json);

  static const toJsonFactory = _$EstContentToJson;
  Map<String, dynamic> toJson() => _$EstContentToJson(this);

  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String? videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String? videoUrl;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$EstContentFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstContent &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $EstContentExtension on EstContent {
  EstContent copyWith({String? videoHost, String? videoUrl, String? id}) {
    return EstContent(
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        id: id ?? this.id);
  }

  EstContent copyWithWrapped(
      {Wrapped<String?>? videoHost,
      Wrapped<String?>? videoUrl,
      Wrapped<String?>? id}) {
    return EstContent(
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    this.scheme,
    this.title,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @JsonKey(name: 'scheme', includeIfNull: false, defaultValue: '')
  final String? scheme;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  static const fromJsonFactory = _$GenreFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.scheme, scheme) ||
                const DeepCollectionEquality().equals(other.scheme, scheme)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(scheme) ^
      const DeepCollectionEquality().hash(title) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith({String? scheme, String? title}) {
    return Genre(scheme: scheme ?? this.scheme, title: title ?? this.title);
  }

  Genre copyWithWrapped({Wrapped<String?>? scheme, Wrapped<String?>? title}) {
    return Genre(
        scheme: (scheme != null ? scheme.value : this.scheme),
        title: (title != null ? title.value : this.title));
  }
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    this.image,
    this.type,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  static const fromJsonFactory = _$ImageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({String? image, String? type}) {
    return Image(image: image ?? this.image, type: type ?? this.type);
  }

  Image copyWithWrapped({Wrapped<String?>? image, Wrapped<String?>? type}) {
    return Image(
        image: (image != null ? image.value : this.image),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistEntryResponseBase {
  WatchlistEntryResponseBase({
    this.imageVersion,
    this.replayAvailable,
    this.ageRating,
    this.duration,
    this.id,
    this.type,
    this.year,
    this.isBoxset,
    this.description,
    this.title,
    this.mostRelevantEpisode,
    this.titleId,
    this.channelId,
    this.seasonNumber,
    this.seasonCount,
    this.interacted,
    this.listPrice,
    this.added,
    this.seriesId,
    this.isExpired,
    this.viewState,
    this.isAdult,
    this.isSplitProgram,
    this.episodeNumber,
    this.expirationDate,
    this.isRemoved,
    this.isReplay,
    this.earliestBroadcastStartTime,
    this.eventStartTime,
    this.longDescription,
    this.categories,
    this.isHD,
    this.isGoPlayable,
    this.cast,
    this.directors,
    this.images,
    this.providerId,
    this.sortTitle,
    this.groupParentalRating,
    this.viewedState,
    this.bookmark,
    this.currency,
    this.minPriceDisplay,
    this.priceDisplay,
    this.entitlementState,
    this.entitlementEnd,
    this.productType,
    this.listingId,
    this.imdbRating,
    this.yearOfProductionStart,
    this.yearOfProductionEnd,
    this.hasMultipleProducts,
    this.isGoPlayableViaExternalApp,
    this.externalAppUrls,
    this.containsAdult,
    this.instances,
    this.mergedId,
    this.mepSeriesFinale,
    this.premiereAirings,
  });

  factory WatchlistEntryResponseBase.fromJson(Map<String, dynamic> json) =>
      _$WatchlistEntryResponseBaseFromJson(json);

  static const toJsonFactory = _$WatchlistEntryResponseBaseToJson;
  Map<String, dynamic> toJson() => _$WatchlistEntryResponseBaseToJson(this);

  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: watchlistEntryResponseBaseTypeToJson,
    fromJson: watchlistEntryResponseBaseTypeFromJson,
  )
  final enums.WatchlistEntryResponseBaseType? type;
  @JsonKey(name: 'year', includeIfNull: false, defaultValue: '')
  final String? year;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false, defaultValue: '')
  final String? mostRelevantEpisode;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'interacted', includeIfNull: false)
  final bool? interacted;
  @JsonKey(name: 'listPrice', includeIfNull: false, defaultValue: '')
  final String? listPrice;
  @JsonKey(name: 'added', includeIfNull: false)
  final DateTime? added;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'isExpired', includeIfNull: false)
  final bool? isExpired;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'isRemoved', includeIfNull: false)
  final bool? isRemoved;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'earliestBroadcastStartTime', includeIfNull: false)
  final DateTime? earliestBroadcastStartTime;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime? eventStartTime;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'categories', includeIfNull: false, defaultValue: <Genre>[])
  final List<Genre>? categories;
  @JsonKey(name: 'isHD', includeIfNull: false)
  final bool? isHD;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'cast', includeIfNull: false, defaultValue: <String>[])
  final List<String>? cast;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image>? images;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'sortTitle', includeIfNull: false, defaultValue: '')
  final String? sortTitle;
  @JsonKey(name: 'groupParentalRating', includeIfNull: false, defaultValue: '')
  final String? groupParentalRating;
  @JsonKey(name: 'viewedState', includeIfNull: false, defaultValue: '')
  final String? viewedState;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(
    name: 'entitlementState',
    includeIfNull: false,
    toJson: watchlistEntryResponseBaseEntitlementStateToJson,
    fromJson: watchlistEntryResponseBaseEntitlementStateFromJson,
  )
  final enums.WatchlistEntryResponseBaseEntitlementState? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: watchlistEntryResponseBaseProductTypeToJson,
    fromJson: watchlistEntryResponseBaseProductTypeFromJson,
  )
  final enums.WatchlistEntryResponseBaseProductType? productType;
  @JsonKey(name: 'listingId', includeIfNull: false, defaultValue: '')
  final String? listingId;
  @JsonKey(name: 'imdbRating', includeIfNull: false, defaultValue: '')
  final String? imdbRating;
  @JsonKey(name: 'yearOfProductionStart', includeIfNull: false)
  final int? yearOfProductionStart;
  @JsonKey(name: 'yearOfProductionEnd', includeIfNull: false)
  final int? yearOfProductionEnd;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'isGoPlayableViaExternalApp', includeIfNull: false)
  final bool? isGoPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrl>[])
  final List<ExternalAppUrl>? externalAppUrls;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(
      name: 'instances', includeIfNull: false, defaultValue: <EstContent>[])
  final List<EstContent>? instances;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false)
  final DateTime? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  static const fromJsonFactory = _$WatchlistEntryResponseBaseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistEntryResponseBase &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.year, year) ||
                const DeepCollectionEquality().equals(other.year, year)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.interacted, interacted) ||
                const DeepCollectionEquality()
                    .equals(other.interacted, interacted)) &&
            (identical(other.listPrice, listPrice) ||
                const DeepCollectionEquality()
                    .equals(other.listPrice, listPrice)) &&
            (identical(other.added, added) ||
                const DeepCollectionEquality().equals(other.added, added)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.isExpired, isExpired) ||
                const DeepCollectionEquality()
                    .equals(other.isExpired, isExpired)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isSplitProgram, isSplitProgram) ||
                const DeepCollectionEquality()
                    .equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.expirationDate, expirationDate) || const DeepCollectionEquality().equals(other.expirationDate, expirationDate)) &&
            (identical(other.isRemoved, isRemoved) || const DeepCollectionEquality().equals(other.isRemoved, isRemoved)) &&
            (identical(other.isReplay, isReplay) || const DeepCollectionEquality().equals(other.isReplay, isReplay)) &&
            (identical(other.earliestBroadcastStartTime, earliestBroadcastStartTime) || const DeepCollectionEquality().equals(other.earliestBroadcastStartTime, earliestBroadcastStartTime)) &&
            (identical(other.eventStartTime, eventStartTime) || const DeepCollectionEquality().equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.longDescription, longDescription) || const DeepCollectionEquality().equals(other.longDescription, longDescription)) &&
            (identical(other.categories, categories) || const DeepCollectionEquality().equals(other.categories, categories)) &&
            (identical(other.isHD, isHD) || const DeepCollectionEquality().equals(other.isHD, isHD)) &&
            (identical(other.isGoPlayable, isGoPlayable) || const DeepCollectionEquality().equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.cast, cast) || const DeepCollectionEquality().equals(other.cast, cast)) &&
            (identical(other.directors, directors) || const DeepCollectionEquality().equals(other.directors, directors)) &&
            (identical(other.images, images) || const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)) &&
            (identical(other.sortTitle, sortTitle) || const DeepCollectionEquality().equals(other.sortTitle, sortTitle)) &&
            (identical(other.groupParentalRating, groupParentalRating) || const DeepCollectionEquality().equals(other.groupParentalRating, groupParentalRating)) &&
            (identical(other.viewedState, viewedState) || const DeepCollectionEquality().equals(other.viewedState, viewedState)) &&
            (identical(other.bookmark, bookmark) || const DeepCollectionEquality().equals(other.bookmark, bookmark)) &&
            (identical(other.currency, currency) || const DeepCollectionEquality().equals(other.currency, currency)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) || const DeepCollectionEquality().equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.priceDisplay, priceDisplay) || const DeepCollectionEquality().equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.entitlementState, entitlementState) || const DeepCollectionEquality().equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) || const DeepCollectionEquality().equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.listingId, listingId) || const DeepCollectionEquality().equals(other.listingId, listingId)) &&
            (identical(other.imdbRating, imdbRating) || const DeepCollectionEquality().equals(other.imdbRating, imdbRating)) &&
            (identical(other.yearOfProductionStart, yearOfProductionStart) || const DeepCollectionEquality().equals(other.yearOfProductionStart, yearOfProductionStart)) &&
            (identical(other.yearOfProductionEnd, yearOfProductionEnd) || const DeepCollectionEquality().equals(other.yearOfProductionEnd, yearOfProductionEnd)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) || const DeepCollectionEquality().equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.isGoPlayableViaExternalApp, isGoPlayableViaExternalApp) || const DeepCollectionEquality().equals(other.isGoPlayableViaExternalApp, isGoPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) || const DeepCollectionEquality().equals(other.externalAppUrls, externalAppUrls)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.instances, instances) || const DeepCollectionEquality().equals(other.instances, instances)) &&
            (identical(other.mergedId, mergedId) || const DeepCollectionEquality().equals(other.mergedId, mergedId)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) || const DeepCollectionEquality().equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) || const DeepCollectionEquality().equals(other.premiereAirings, premiereAirings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(year) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(interacted) ^
      const DeepCollectionEquality().hash(listPrice) ^
      const DeepCollectionEquality().hash(added) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(isExpired) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(isRemoved) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(earliestBroadcastStartTime) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(categories) ^
      const DeepCollectionEquality().hash(isHD) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(cast) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(sortTitle) ^
      const DeepCollectionEquality().hash(groupParentalRating) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(listingId) ^
      const DeepCollectionEquality().hash(imdbRating) ^
      const DeepCollectionEquality().hash(yearOfProductionStart) ^
      const DeepCollectionEquality().hash(yearOfProductionEnd) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(isGoPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(instances) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      runtimeType.hashCode;
}

extension $WatchlistEntryResponseBaseExtension on WatchlistEntryResponseBase {
  WatchlistEntryResponseBase copyWith(
      {String? imageVersion,
      bool? replayAvailable,
      int? ageRating,
      int? duration,
      String? id,
      enums.WatchlistEntryResponseBaseType? type,
      String? year,
      bool? isBoxset,
      String? description,
      String? title,
      String? mostRelevantEpisode,
      String? titleId,
      String? channelId,
      int? seasonNumber,
      int? seasonCount,
      bool? interacted,
      String? listPrice,
      DateTime? added,
      String? seriesId,
      bool? isExpired,
      String? viewState,
      bool? isAdult,
      bool? isSplitProgram,
      int? episodeNumber,
      DateTime? expirationDate,
      bool? isRemoved,
      bool? isReplay,
      DateTime? earliestBroadcastStartTime,
      DateTime? eventStartTime,
      String? longDescription,
      List<Genre>? categories,
      bool? isHD,
      bool? isGoPlayable,
      List<String>? cast,
      List<String>? directors,
      List<Image>? images,
      String? providerId,
      String? sortTitle,
      String? groupParentalRating,
      String? viewedState,
      int? bookmark,
      String? currency,
      String? minPriceDisplay,
      String? priceDisplay,
      enums.WatchlistEntryResponseBaseEntitlementState? entitlementState,
      DateTime? entitlementEnd,
      enums.WatchlistEntryResponseBaseProductType? productType,
      String? listingId,
      String? imdbRating,
      int? yearOfProductionStart,
      int? yearOfProductionEnd,
      bool? hasMultipleProducts,
      bool? isGoPlayableViaExternalApp,
      List<ExternalAppUrl>? externalAppUrls,
      bool? containsAdult,
      List<EstContent>? instances,
      String? mergedId,
      DateTime? mepSeriesFinale,
      bool? premiereAirings}) {
    return WatchlistEntryResponseBase(
        imageVersion: imageVersion ?? this.imageVersion,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        ageRating: ageRating ?? this.ageRating,
        duration: duration ?? this.duration,
        id: id ?? this.id,
        type: type ?? this.type,
        year: year ?? this.year,
        isBoxset: isBoxset ?? this.isBoxset,
        description: description ?? this.description,
        title: title ?? this.title,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        titleId: titleId ?? this.titleId,
        channelId: channelId ?? this.channelId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        seasonCount: seasonCount ?? this.seasonCount,
        interacted: interacted ?? this.interacted,
        listPrice: listPrice ?? this.listPrice,
        added: added ?? this.added,
        seriesId: seriesId ?? this.seriesId,
        isExpired: isExpired ?? this.isExpired,
        viewState: viewState ?? this.viewState,
        isAdult: isAdult ?? this.isAdult,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        expirationDate: expirationDate ?? this.expirationDate,
        isRemoved: isRemoved ?? this.isRemoved,
        isReplay: isReplay ?? this.isReplay,
        earliestBroadcastStartTime:
            earliestBroadcastStartTime ?? this.earliestBroadcastStartTime,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        longDescription: longDescription ?? this.longDescription,
        categories: categories ?? this.categories,
        isHD: isHD ?? this.isHD,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        cast: cast ?? this.cast,
        directors: directors ?? this.directors,
        images: images ?? this.images,
        providerId: providerId ?? this.providerId,
        sortTitle: sortTitle ?? this.sortTitle,
        groupParentalRating: groupParentalRating ?? this.groupParentalRating,
        viewedState: viewedState ?? this.viewedState,
        bookmark: bookmark ?? this.bookmark,
        currency: currency ?? this.currency,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        productType: productType ?? this.productType,
        listingId: listingId ?? this.listingId,
        imdbRating: imdbRating ?? this.imdbRating,
        yearOfProductionStart:
            yearOfProductionStart ?? this.yearOfProductionStart,
        yearOfProductionEnd: yearOfProductionEnd ?? this.yearOfProductionEnd,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        isGoPlayableViaExternalApp:
            isGoPlayableViaExternalApp ?? this.isGoPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls,
        containsAdult: containsAdult ?? this.containsAdult,
        instances: instances ?? this.instances,
        mergedId: mergedId ?? this.mergedId,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings);
  }

  WatchlistEntryResponseBase copyWithWrapped(
      {Wrapped<String?>? imageVersion,
      Wrapped<bool?>? replayAvailable,
      Wrapped<int?>? ageRating,
      Wrapped<int?>? duration,
      Wrapped<String?>? id,
      Wrapped<enums.WatchlistEntryResponseBaseType?>? type,
      Wrapped<String?>? year,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? description,
      Wrapped<String?>? title,
      Wrapped<String?>? mostRelevantEpisode,
      Wrapped<String?>? titleId,
      Wrapped<String?>? channelId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? seasonCount,
      Wrapped<bool?>? interacted,
      Wrapped<String?>? listPrice,
      Wrapped<DateTime?>? added,
      Wrapped<String?>? seriesId,
      Wrapped<bool?>? isExpired,
      Wrapped<String?>? viewState,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<int?>? episodeNumber,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<bool?>? isRemoved,
      Wrapped<bool?>? isReplay,
      Wrapped<DateTime?>? earliestBroadcastStartTime,
      Wrapped<DateTime?>? eventStartTime,
      Wrapped<String?>? longDescription,
      Wrapped<List<Genre>?>? categories,
      Wrapped<bool?>? isHD,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<List<String>?>? cast,
      Wrapped<List<String>?>? directors,
      Wrapped<List<Image>?>? images,
      Wrapped<String?>? providerId,
      Wrapped<String?>? sortTitle,
      Wrapped<String?>? groupParentalRating,
      Wrapped<String?>? viewedState,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? currency,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? priceDisplay,
      Wrapped<enums.WatchlistEntryResponseBaseEntitlementState?>?
          entitlementState,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<enums.WatchlistEntryResponseBaseProductType?>? productType,
      Wrapped<String?>? listingId,
      Wrapped<String?>? imdbRating,
      Wrapped<int?>? yearOfProductionStart,
      Wrapped<int?>? yearOfProductionEnd,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<bool?>? isGoPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrl>?>? externalAppUrls,
      Wrapped<bool?>? containsAdult,
      Wrapped<List<EstContent>?>? instances,
      Wrapped<String?>? mergedId,
      Wrapped<DateTime?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings}) {
    return WatchlistEntryResponseBase(
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        duration: (duration != null ? duration.value : this.duration),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        year: (year != null ? year.value : this.year),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        description:
            (description != null ? description.value : this.description),
        title: (title != null ? title.value : this.title),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        titleId: (titleId != null ? titleId.value : this.titleId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        interacted: (interacted != null ? interacted.value : this.interacted),
        listPrice: (listPrice != null ? listPrice.value : this.listPrice),
        added: (added != null ? added.value : this.added),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        isExpired: (isExpired != null ? isExpired.value : this.isExpired),
        viewState: (viewState != null ? viewState.value : this.viewState),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        isRemoved: (isRemoved != null ? isRemoved.value : this.isRemoved),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        earliestBroadcastStartTime: (earliestBroadcastStartTime != null
            ? earliestBroadcastStartTime.value
            : this.earliestBroadcastStartTime),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        categories: (categories != null ? categories.value : this.categories),
        isHD: (isHD != null ? isHD.value : this.isHD),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        cast: (cast != null ? cast.value : this.cast),
        directors: (directors != null ? directors.value : this.directors),
        images: (images != null ? images.value : this.images),
        providerId: (providerId != null ? providerId.value : this.providerId),
        sortTitle: (sortTitle != null ? sortTitle.value : this.sortTitle),
        groupParentalRating: (groupParentalRating != null
            ? groupParentalRating.value
            : this.groupParentalRating),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        currency: (currency != null ? currency.value : this.currency),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        productType:
            (productType != null ? productType.value : this.productType),
        listingId: (listingId != null ? listingId.value : this.listingId),
        imdbRating: (imdbRating != null ? imdbRating.value : this.imdbRating),
        yearOfProductionStart: (yearOfProductionStart != null
            ? yearOfProductionStart.value
            : this.yearOfProductionStart),
        yearOfProductionEnd: (yearOfProductionEnd != null
            ? yearOfProductionEnd.value
            : this.yearOfProductionEnd),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        isGoPlayableViaExternalApp: (isGoPlayableViaExternalApp != null
            ? isGoPlayableViaExternalApp.value
            : this.isGoPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        instances: (instances != null ? instances.value : this.instances),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistEntryRequest {
  WatchlistEntryRequest({
    this.id,
    this.type,
    this.title,
    this.watchlistId,
    this.showId,
    this.serviceId,
    this.reminderSet,
    this.remindBefore,
  });

  factory WatchlistEntryRequest.fromJson(Map<String, dynamic> json) =>
      _$WatchlistEntryRequestFromJson(json);

  static const toJsonFactory = _$WatchlistEntryRequestToJson;
  Map<String, dynamic> toJson() => _$WatchlistEntryRequestToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: watchlistEntryRequestTypeToJson,
    fromJson: watchlistEntryRequestTypeFromJson,
  )
  final enums.WatchlistEntryRequestType? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'serviceId', includeIfNull: false, defaultValue: '')
  final String? serviceId;
  @JsonKey(name: 'reminderSet', includeIfNull: false)
  final bool? reminderSet;
  @JsonKey(name: 'remindBefore', includeIfNull: false)
  final int? remindBefore;
  static const fromJsonFactory = _$WatchlistEntryRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistEntryRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.reminderSet, reminderSet) ||
                const DeepCollectionEquality()
                    .equals(other.reminderSet, reminderSet)) &&
            (identical(other.remindBefore, remindBefore) ||
                const DeepCollectionEquality()
                    .equals(other.remindBefore, remindBefore)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(reminderSet) ^
      const DeepCollectionEquality().hash(remindBefore) ^
      runtimeType.hashCode;
}

extension $WatchlistEntryRequestExtension on WatchlistEntryRequest {
  WatchlistEntryRequest copyWith(
      {String? id,
      enums.WatchlistEntryRequestType? type,
      String? title,
      String? watchlistId,
      String? showId,
      String? serviceId,
      bool? reminderSet,
      int? remindBefore}) {
    return WatchlistEntryRequest(
        id: id ?? this.id,
        type: type ?? this.type,
        title: title ?? this.title,
        watchlistId: watchlistId ?? this.watchlistId,
        showId: showId ?? this.showId,
        serviceId: serviceId ?? this.serviceId,
        reminderSet: reminderSet ?? this.reminderSet,
        remindBefore: remindBefore ?? this.remindBefore);
  }

  WatchlistEntryRequest copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<enums.WatchlistEntryRequestType?>? type,
      Wrapped<String?>? title,
      Wrapped<String?>? watchlistId,
      Wrapped<String?>? showId,
      Wrapped<String?>? serviceId,
      Wrapped<bool?>? reminderSet,
      Wrapped<int?>? remindBefore}) {
    return WatchlistEntryRequest(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        showId: (showId != null ? showId.value : this.showId),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        reminderSet:
            (reminderSet != null ? reminderSet.value : this.reminderSet),
        remindBefore:
            (remindBefore != null ? remindBefore.value : this.remindBefore));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleWatchlistEntryResponseBase {
  SimpleWatchlistEntryResponseBase({
    this.id,
    this.type,
    this.title,
    this.watchlistId,
    this.isExpired,
    this.isRemoved,
    this.added,
    this.showId,
    this.serviceId,
    this.reminderSet,
    this.remindBefore,
    this.mergedId,
  });

  factory SimpleWatchlistEntryResponseBase.fromJson(
          Map<String, dynamic> json) =>
      _$SimpleWatchlistEntryResponseBaseFromJson(json);

  static const toJsonFactory = _$SimpleWatchlistEntryResponseBaseToJson;
  Map<String, dynamic> toJson() =>
      _$SimpleWatchlistEntryResponseBaseToJson(this);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: simpleWatchlistEntryResponseBaseTypeToJson,
    fromJson: simpleWatchlistEntryResponseBaseTypeFromJson,
  )
  final enums.SimpleWatchlistEntryResponseBaseType? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'isExpired', includeIfNull: false)
  final bool? isExpired;
  @JsonKey(name: 'isRemoved', includeIfNull: false)
  final bool? isRemoved;
  @JsonKey(name: 'added', includeIfNull: false)
  final DateTime? added;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'serviceId', includeIfNull: false, defaultValue: '')
  final String? serviceId;
  @JsonKey(name: 'reminderSet', includeIfNull: false)
  final bool? reminderSet;
  @JsonKey(name: 'remindBefore', includeIfNull: false)
  final int? remindBefore;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$SimpleWatchlistEntryResponseBaseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleWatchlistEntryResponseBase &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.isExpired, isExpired) ||
                const DeepCollectionEquality()
                    .equals(other.isExpired, isExpired)) &&
            (identical(other.isRemoved, isRemoved) ||
                const DeepCollectionEquality()
                    .equals(other.isRemoved, isRemoved)) &&
            (identical(other.added, added) ||
                const DeepCollectionEquality().equals(other.added, added)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.reminderSet, reminderSet) ||
                const DeepCollectionEquality()
                    .equals(other.reminderSet, reminderSet)) &&
            (identical(other.remindBefore, remindBefore) ||
                const DeepCollectionEquality()
                    .equals(other.remindBefore, remindBefore)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(isExpired) ^
      const DeepCollectionEquality().hash(isRemoved) ^
      const DeepCollectionEquality().hash(added) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(reminderSet) ^
      const DeepCollectionEquality().hash(remindBefore) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $SimpleWatchlistEntryResponseBaseExtension
    on SimpleWatchlistEntryResponseBase {
  SimpleWatchlistEntryResponseBase copyWith(
      {String? id,
      enums.SimpleWatchlistEntryResponseBaseType? type,
      String? title,
      String? watchlistId,
      bool? isExpired,
      bool? isRemoved,
      DateTime? added,
      String? showId,
      String? serviceId,
      bool? reminderSet,
      int? remindBefore,
      String? mergedId}) {
    return SimpleWatchlistEntryResponseBase(
        id: id ?? this.id,
        type: type ?? this.type,
        title: title ?? this.title,
        watchlistId: watchlistId ?? this.watchlistId,
        isExpired: isExpired ?? this.isExpired,
        isRemoved: isRemoved ?? this.isRemoved,
        added: added ?? this.added,
        showId: showId ?? this.showId,
        serviceId: serviceId ?? this.serviceId,
        reminderSet: reminderSet ?? this.reminderSet,
        remindBefore: remindBefore ?? this.remindBefore,
        mergedId: mergedId ?? this.mergedId);
  }

  SimpleWatchlistEntryResponseBase copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<enums.SimpleWatchlistEntryResponseBaseType?>? type,
      Wrapped<String?>? title,
      Wrapped<String?>? watchlistId,
      Wrapped<bool?>? isExpired,
      Wrapped<bool?>? isRemoved,
      Wrapped<DateTime?>? added,
      Wrapped<String?>? showId,
      Wrapped<String?>? serviceId,
      Wrapped<bool?>? reminderSet,
      Wrapped<int?>? remindBefore,
      Wrapped<String?>? mergedId}) {
    return SimpleWatchlistEntryResponseBase(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        isExpired: (isExpired != null ? isExpired.value : this.isExpired),
        isRemoved: (isRemoved != null ? isRemoved.value : this.isRemoved),
        added: (added != null ? added.value : this.added),
        showId: (showId != null ? showId.value : this.showId),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        reminderSet:
            (reminderSet != null ? reminderSet.value : this.reminderSet),
        remindBefore:
            (remindBefore != null ? remindBefore.value : this.remindBefore),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class GridEntryResponse {
  GridEntryResponse({
    this.feedType,
    this.feedTitle,
    this.entryCount,
    this.totalResults,
    this.entries,
  });

  factory GridEntryResponse.fromJson(Map<String, dynamic> json) =>
      _$GridEntryResponseFromJson(json);

  static const toJsonFactory = _$GridEntryResponseToJson;
  Map<String, dynamic> toJson() => _$GridEntryResponseToJson(this);

  @JsonKey(
    name: 'feedType',
    includeIfNull: false,
    toJson: gridEntryResponseFeedTypeToJson,
    fromJson: gridEntryResponseFeedTypeFromJson,
  )
  final enums.GridEntryResponseFeedType? feedType;
  @JsonKey(name: 'feedTitle', includeIfNull: false, defaultValue: '')
  final String? feedTitle;
  @JsonKey(name: 'entryCount', includeIfNull: false)
  final int? entryCount;
  @JsonKey(name: 'totalResults', includeIfNull: false)
  final int? totalResults;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <WatchlistEntryResponseBase>[])
  final List<WatchlistEntryResponseBase>? entries;
  static const fromJsonFactory = _$GridEntryResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridEntryResponse &&
            (identical(other.feedType, feedType) ||
                const DeepCollectionEquality()
                    .equals(other.feedType, feedType)) &&
            (identical(other.feedTitle, feedTitle) ||
                const DeepCollectionEquality()
                    .equals(other.feedTitle, feedTitle)) &&
            (identical(other.entryCount, entryCount) ||
                const DeepCollectionEquality()
                    .equals(other.entryCount, entryCount)) &&
            (identical(other.totalResults, totalResults) ||
                const DeepCollectionEquality()
                    .equals(other.totalResults, totalResults)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality().equals(other.entries, entries)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(feedType) ^
      const DeepCollectionEquality().hash(feedTitle) ^
      const DeepCollectionEquality().hash(entryCount) ^
      const DeepCollectionEquality().hash(totalResults) ^
      const DeepCollectionEquality().hash(entries) ^
      runtimeType.hashCode;
}

extension $GridEntryResponseExtension on GridEntryResponse {
  GridEntryResponse copyWith(
      {enums.GridEntryResponseFeedType? feedType,
      String? feedTitle,
      int? entryCount,
      int? totalResults,
      List<WatchlistEntryResponseBase>? entries}) {
    return GridEntryResponse(
        feedType: feedType ?? this.feedType,
        feedTitle: feedTitle ?? this.feedTitle,
        entryCount: entryCount ?? this.entryCount,
        totalResults: totalResults ?? this.totalResults,
        entries: entries ?? this.entries);
  }

  GridEntryResponse copyWithWrapped(
      {Wrapped<enums.GridEntryResponseFeedType?>? feedType,
      Wrapped<String?>? feedTitle,
      Wrapped<int?>? entryCount,
      Wrapped<int?>? totalResults,
      Wrapped<List<WatchlistEntryResponseBase>?>? entries}) {
    return GridEntryResponse(
        feedType: (feedType != null ? feedType.value : this.feedType),
        feedTitle: (feedTitle != null ? feedTitle.value : this.feedTitle),
        entryCount: (entryCount != null ? entryCount.value : this.entryCount),
        totalResults:
            (totalResults != null ? totalResults.value : this.totalResults),
        entries: (entries != null ? entries.value : this.entries));
  }
}

@JsonSerializable(explicitToJson: true)
class GridResponse {
  GridResponse({
    this.feeds,
  });

  factory GridResponse.fromJson(Map<String, dynamic> json) =>
      _$GridResponseFromJson(json);

  static const toJsonFactory = _$GridResponseToJson;
  Map<String, dynamic> toJson() => _$GridResponseToJson(this);

  @JsonKey(
      name: 'feeds', includeIfNull: false, defaultValue: <GridEntryResponse>[])
  final List<GridEntryResponse>? feeds;
  static const fromJsonFactory = _$GridResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridResponse &&
            (identical(other.feeds, feeds) ||
                const DeepCollectionEquality().equals(other.feeds, feeds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(feeds) ^ runtimeType.hashCode;
}

extension $GridResponseExtension on GridResponse {
  GridResponse copyWith({List<GridEntryResponse>? feeds}) {
    return GridResponse(feeds: feeds ?? this.feeds);
  }

  GridResponse copyWithWrapped({Wrapped<List<GridEntryResponse>?>? feeds}) {
    return GridResponse(feeds: (feeds != null ? feeds.value : this.feeds));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistResponse {
  WatchlistResponse({
    this.name,
    this.entries,
    this.description,
    this.watchlistId,
    this.totalResults,
  });

  factory WatchlistResponse.fromJson(Map<String, dynamic> json) =>
      _$WatchlistResponseFromJson(json);

  static const toJsonFactory = _$WatchlistResponseToJson;
  Map<String, dynamic> toJson() => _$WatchlistResponseToJson(this);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <WatchlistEntryResponseBase>[])
  final List<WatchlistEntryResponseBase>? entries;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'totalResults', includeIfNull: false)
  final int? totalResults;
  static const fromJsonFactory = _$WatchlistResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistResponse &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality()
                    .equals(other.entries, entries)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.totalResults, totalResults) ||
                const DeepCollectionEquality()
                    .equals(other.totalResults, totalResults)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(entries) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(totalResults) ^
      runtimeType.hashCode;
}

extension $WatchlistResponseExtension on WatchlistResponse {
  WatchlistResponse copyWith(
      {String? name,
      List<WatchlistEntryResponseBase>? entries,
      String? description,
      String? watchlistId,
      int? totalResults}) {
    return WatchlistResponse(
        name: name ?? this.name,
        entries: entries ?? this.entries,
        description: description ?? this.description,
        watchlistId: watchlistId ?? this.watchlistId,
        totalResults: totalResults ?? this.totalResults);
  }

  WatchlistResponse copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<List<WatchlistEntryResponseBase>?>? entries,
      Wrapped<String?>? description,
      Wrapped<String?>? watchlistId,
      Wrapped<int?>? totalResults}) {
    return WatchlistResponse(
        name: (name != null ? name.value : this.name),
        entries: (entries != null ? entries.value : this.entries),
        description:
            (description != null ? description.value : this.description),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        totalResults:
            (totalResults != null ? totalResults.value : this.totalResults));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistId {
  WatchlistId({
    this.watchlistId,
  });

  factory WatchlistId.fromJson(Map<String, dynamic> json) =>
      _$WatchlistIdFromJson(json);

  static const toJsonFactory = _$WatchlistIdToJson;
  Map<String, dynamic> toJson() => _$WatchlistIdToJson(this);

  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  static const fromJsonFactory = _$WatchlistIdFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistId &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(watchlistId) ^ runtimeType.hashCode;
}

extension $WatchlistIdExtension on WatchlistId {
  WatchlistId copyWith({String? watchlistId}) {
    return WatchlistId(watchlistId: watchlistId ?? this.watchlistId);
  }

  WatchlistId copyWithWrapped({Wrapped<String?>? watchlistId}) {
    return WatchlistId(
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistRequest {
  WatchlistRequest({
    this.name,
    this.entries,
    this.description,
    this.watchlistId,
    this.profileId,
  });

  factory WatchlistRequest.fromJson(Map<String, dynamic> json) =>
      _$WatchlistRequestFromJson(json);

  static const toJsonFactory = _$WatchlistRequestToJson;
  Map<String, dynamic> toJson() => _$WatchlistRequestToJson(this);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <WatchlistEntryRequest>[])
  final List<WatchlistEntryRequest>? entries;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  static const fromJsonFactory = _$WatchlistRequestFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistRequest &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality()
                    .equals(other.entries, entries)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(entries) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(profileId) ^
      runtimeType.hashCode;
}

extension $WatchlistRequestExtension on WatchlistRequest {
  WatchlistRequest copyWith(
      {String? name,
      List<WatchlistEntryRequest>? entries,
      String? description,
      String? watchlistId,
      String? profileId}) {
    return WatchlistRequest(
        name: name ?? this.name,
        entries: entries ?? this.entries,
        description: description ?? this.description,
        watchlistId: watchlistId ?? this.watchlistId,
        profileId: profileId ?? this.profileId);
  }

  WatchlistRequest copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<List<WatchlistEntryRequest>?>? entries,
      Wrapped<String?>? description,
      Wrapped<String?>? watchlistId,
      Wrapped<String?>? profileId}) {
    return WatchlistRequest(
        name: (name != null ? name.value : this.name),
        entries: (entries != null ? entries.value : this.entries),
        description:
            (description != null ? description.value : this.description),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        profileId: (profileId != null ? profileId.value : this.profileId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class ValidationErrorMessage {
  ValidationErrorMessage({
    required this.errors,
  });

  factory ValidationErrorMessage.fromJson(Map<String, dynamic> json) =>
      _$ValidationErrorMessageFromJson(json);

  static const toJsonFactory = _$ValidationErrorMessageToJson;
  Map<String, dynamic> toJson() => _$ValidationErrorMessageToJson(this);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ValidationErrorMessageFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidationErrorMessage &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ValidationErrorMessageExtension on ValidationErrorMessage {
  ValidationErrorMessage copyWith({List<String>? errors}) {
    return ValidationErrorMessage(errors: errors ?? this.errors);
  }

  ValidationErrorMessage copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ValidationErrorMessage(
        errors: (errors != null ? errors.value : this.errors));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleWatchlistResponse {
  SimpleWatchlistResponse({
    this.watchlistId,
    this.profileId,
    this.name,
    this.description,
    this.entries,
  });

  factory SimpleWatchlistResponse.fromJson(Map<String, dynamic> json) =>
      _$SimpleWatchlistResponseFromJson(json);

  static const toJsonFactory = _$SimpleWatchlistResponseToJson;
  Map<String, dynamic> toJson() => _$SimpleWatchlistResponseToJson(this);

  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <SimpleWatchlistEntryResponseBase>[])
  final List<SimpleWatchlistEntryResponseBase>? entries;
  static const fromJsonFactory = _$SimpleWatchlistResponseFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleWatchlistResponse &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality().equals(other.entries, entries)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(entries) ^
      runtimeType.hashCode;
}

extension $SimpleWatchlistResponseExtension on SimpleWatchlistResponse {
  SimpleWatchlistResponse copyWith(
      {String? watchlistId,
      String? profileId,
      String? name,
      String? description,
      List<SimpleWatchlistEntryResponseBase>? entries}) {
    return SimpleWatchlistResponse(
        watchlistId: watchlistId ?? this.watchlistId,
        profileId: profileId ?? this.profileId,
        name: name ?? this.name,
        description: description ?? this.description,
        entries: entries ?? this.entries);
  }

  SimpleWatchlistResponse copyWithWrapped(
      {Wrapped<String?>? watchlistId,
      Wrapped<String?>? profileId,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<List<SimpleWatchlistEntryResponseBase>?>? entries}) {
    return SimpleWatchlistResponse(
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        entries: (entries != null ? entries.value : this.entries));
  }
}

@JsonSerializable(explicitToJson: true)
class ExternalAppUrl {
  ExternalAppUrl({
    this.deviceCode,
    this.url,
  });

  factory ExternalAppUrl.fromJson(Map<String, dynamic> json) =>
      _$ExternalAppUrlFromJson(json);

  static const toJsonFactory = _$ExternalAppUrlToJson;
  Map<String, dynamic> toJson() => _$ExternalAppUrlToJson(this);

  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String? deviceCode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$ExternalAppUrlFromJson;

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ExternalAppUrl &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ExternalAppUrlExtension on ExternalAppUrl {
  ExternalAppUrl copyWith({String? deviceCode, String? url}) {
    return ExternalAppUrl(
        deviceCode: deviceCode ?? this.deviceCode, url: url ?? this.url);
  }

  ExternalAppUrl copyWithWrapped(
      {Wrapped<String?>? deviceCode, Wrapped<String?>? url}) {
    return ExternalAppUrl(
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        url: (url != null ? url.value : this.url));
  }
}

String? watchlistEntryResponseBaseTypeToJson(
    enums.WatchlistEntryResponseBaseType? watchlistEntryResponseBaseType) {
  return watchlistEntryResponseBaseType?.value;
}

enums.WatchlistEntryResponseBaseType watchlistEntryResponseBaseTypeFromJson(
  Object? watchlistEntryResponseBaseType, [
  enums.WatchlistEntryResponseBaseType? defaultValue,
]) {
  return enums.WatchlistEntryResponseBaseType.values
          .firstWhereOrNull((e) => e.value == watchlistEntryResponseBaseType) ??
      defaultValue ??
      enums.WatchlistEntryResponseBaseType.swaggerGeneratedUnknown;
}

List<String> watchlistEntryResponseBaseTypeListToJson(
    List<enums.WatchlistEntryResponseBaseType>?
        watchlistEntryResponseBaseType) {
  if (watchlistEntryResponseBaseType == null) {
    return [];
  }

  return watchlistEntryResponseBaseType.map((e) => e.value!).toList();
}

List<enums.WatchlistEntryResponseBaseType>
    watchlistEntryResponseBaseTypeListFromJson(
  List? watchlistEntryResponseBaseType, [
  List<enums.WatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseType == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryResponseBaseType
      .map((e) => watchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryResponseBaseType>?
    watchlistEntryResponseBaseTypeNullableListFromJson(
  List? watchlistEntryResponseBaseType, [
  List<enums.WatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseType == null) {
    return defaultValue;
  }

  return watchlistEntryResponseBaseType
      .map((e) => watchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

String? watchlistEntryResponseBaseEntitlementStateToJson(
    enums.WatchlistEntryResponseBaseEntitlementState?
        watchlistEntryResponseBaseEntitlementState) {
  return watchlistEntryResponseBaseEntitlementState?.value;
}

enums.WatchlistEntryResponseBaseEntitlementState
    watchlistEntryResponseBaseEntitlementStateFromJson(
  Object? watchlistEntryResponseBaseEntitlementState, [
  enums.WatchlistEntryResponseBaseEntitlementState? defaultValue,
]) {
  return enums.WatchlistEntryResponseBaseEntitlementState.values
          .firstWhereOrNull(
              (e) => e.value == watchlistEntryResponseBaseEntitlementState) ??
      defaultValue ??
      enums.WatchlistEntryResponseBaseEntitlementState.swaggerGeneratedUnknown;
}

List<String> watchlistEntryResponseBaseEntitlementStateListToJson(
    List<enums.WatchlistEntryResponseBaseEntitlementState>?
        watchlistEntryResponseBaseEntitlementState) {
  if (watchlistEntryResponseBaseEntitlementState == null) {
    return [];
  }

  return watchlistEntryResponseBaseEntitlementState
      .map((e) => e.value!)
      .toList();
}

List<enums.WatchlistEntryResponseBaseEntitlementState>
    watchlistEntryResponseBaseEntitlementStateListFromJson(
  List? watchlistEntryResponseBaseEntitlementState, [
  List<enums.WatchlistEntryResponseBaseEntitlementState>? defaultValue,
]) {
  if (watchlistEntryResponseBaseEntitlementState == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryResponseBaseEntitlementState
      .map((e) =>
          watchlistEntryResponseBaseEntitlementStateFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryResponseBaseEntitlementState>?
    watchlistEntryResponseBaseEntitlementStateNullableListFromJson(
  List? watchlistEntryResponseBaseEntitlementState, [
  List<enums.WatchlistEntryResponseBaseEntitlementState>? defaultValue,
]) {
  if (watchlistEntryResponseBaseEntitlementState == null) {
    return defaultValue;
  }

  return watchlistEntryResponseBaseEntitlementState
      .map((e) =>
          watchlistEntryResponseBaseEntitlementStateFromJson(e.toString()))
      .toList();
}

String? watchlistEntryResponseBaseProductTypeToJson(
    enums.WatchlistEntryResponseBaseProductType?
        watchlistEntryResponseBaseProductType) {
  return watchlistEntryResponseBaseProductType?.value;
}

enums.WatchlistEntryResponseBaseProductType
    watchlistEntryResponseBaseProductTypeFromJson(
  Object? watchlistEntryResponseBaseProductType, [
  enums.WatchlistEntryResponseBaseProductType? defaultValue,
]) {
  return enums.WatchlistEntryResponseBaseProductType.values.firstWhereOrNull(
          (e) => e.value == watchlistEntryResponseBaseProductType) ??
      defaultValue ??
      enums.WatchlistEntryResponseBaseProductType.swaggerGeneratedUnknown;
}

List<String> watchlistEntryResponseBaseProductTypeListToJson(
    List<enums.WatchlistEntryResponseBaseProductType>?
        watchlistEntryResponseBaseProductType) {
  if (watchlistEntryResponseBaseProductType == null) {
    return [];
  }

  return watchlistEntryResponseBaseProductType.map((e) => e.value!).toList();
}

List<enums.WatchlistEntryResponseBaseProductType>
    watchlistEntryResponseBaseProductTypeListFromJson(
  List? watchlistEntryResponseBaseProductType, [
  List<enums.WatchlistEntryResponseBaseProductType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseProductType == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryResponseBaseProductType
      .map((e) => watchlistEntryResponseBaseProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryResponseBaseProductType>?
    watchlistEntryResponseBaseProductTypeNullableListFromJson(
  List? watchlistEntryResponseBaseProductType, [
  List<enums.WatchlistEntryResponseBaseProductType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseProductType == null) {
    return defaultValue;
  }

  return watchlistEntryResponseBaseProductType
      .map((e) => watchlistEntryResponseBaseProductTypeFromJson(e.toString()))
      .toList();
}

String? watchlistEntryRequestTypeToJson(
    enums.WatchlistEntryRequestType? watchlistEntryRequestType) {
  return watchlistEntryRequestType?.value;
}

enums.WatchlistEntryRequestType watchlistEntryRequestTypeFromJson(
  Object? watchlistEntryRequestType, [
  enums.WatchlistEntryRequestType? defaultValue,
]) {
  return enums.WatchlistEntryRequestType.values
          .firstWhereOrNull((e) => e.value == watchlistEntryRequestType) ??
      defaultValue ??
      enums.WatchlistEntryRequestType.swaggerGeneratedUnknown;
}

List<String> watchlistEntryRequestTypeListToJson(
    List<enums.WatchlistEntryRequestType>? watchlistEntryRequestType) {
  if (watchlistEntryRequestType == null) {
    return [];
  }

  return watchlistEntryRequestType.map((e) => e.value!).toList();
}

List<enums.WatchlistEntryRequestType> watchlistEntryRequestTypeListFromJson(
  List? watchlistEntryRequestType, [
  List<enums.WatchlistEntryRequestType>? defaultValue,
]) {
  if (watchlistEntryRequestType == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryRequestType
      .map((e) => watchlistEntryRequestTypeFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryRequestType>?
    watchlistEntryRequestTypeNullableListFromJson(
  List? watchlistEntryRequestType, [
  List<enums.WatchlistEntryRequestType>? defaultValue,
]) {
  if (watchlistEntryRequestType == null) {
    return defaultValue;
  }

  return watchlistEntryRequestType
      .map((e) => watchlistEntryRequestTypeFromJson(e.toString()))
      .toList();
}

String? simpleWatchlistEntryResponseBaseTypeToJson(
    enums.SimpleWatchlistEntryResponseBaseType?
        simpleWatchlistEntryResponseBaseType) {
  return simpleWatchlistEntryResponseBaseType?.value;
}

enums.SimpleWatchlistEntryResponseBaseType
    simpleWatchlistEntryResponseBaseTypeFromJson(
  Object? simpleWatchlistEntryResponseBaseType, [
  enums.SimpleWatchlistEntryResponseBaseType? defaultValue,
]) {
  return enums.SimpleWatchlistEntryResponseBaseType.values.firstWhereOrNull(
          (e) => e.value == simpleWatchlistEntryResponseBaseType) ??
      defaultValue ??
      enums.SimpleWatchlistEntryResponseBaseType.swaggerGeneratedUnknown;
}

List<String> simpleWatchlistEntryResponseBaseTypeListToJson(
    List<enums.SimpleWatchlistEntryResponseBaseType>?
        simpleWatchlistEntryResponseBaseType) {
  if (simpleWatchlistEntryResponseBaseType == null) {
    return [];
  }

  return simpleWatchlistEntryResponseBaseType.map((e) => e.value!).toList();
}

List<enums.SimpleWatchlistEntryResponseBaseType>
    simpleWatchlistEntryResponseBaseTypeListFromJson(
  List? simpleWatchlistEntryResponseBaseType, [
  List<enums.SimpleWatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (simpleWatchlistEntryResponseBaseType == null) {
    return defaultValue ?? [];
  }

  return simpleWatchlistEntryResponseBaseType
      .map((e) => simpleWatchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

List<enums.SimpleWatchlistEntryResponseBaseType>?
    simpleWatchlistEntryResponseBaseTypeNullableListFromJson(
  List? simpleWatchlistEntryResponseBaseType, [
  List<enums.SimpleWatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (simpleWatchlistEntryResponseBaseType == null) {
    return defaultValue;
  }

  return simpleWatchlistEntryResponseBaseType
      .map((e) => simpleWatchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

String? gridEntryResponseFeedTypeToJson(
    enums.GridEntryResponseFeedType? gridEntryResponseFeedType) {
  return gridEntryResponseFeedType?.value;
}

enums.GridEntryResponseFeedType gridEntryResponseFeedTypeFromJson(
  Object? gridEntryResponseFeedType, [
  enums.GridEntryResponseFeedType? defaultValue,
]) {
  return enums.GridEntryResponseFeedType.values
          .firstWhereOrNull((e) => e.value == gridEntryResponseFeedType) ??
      defaultValue ??
      enums.GridEntryResponseFeedType.swaggerGeneratedUnknown;
}

List<String> gridEntryResponseFeedTypeListToJson(
    List<enums.GridEntryResponseFeedType>? gridEntryResponseFeedType) {
  if (gridEntryResponseFeedType == null) {
    return [];
  }

  return gridEntryResponseFeedType.map((e) => e.value!).toList();
}

List<enums.GridEntryResponseFeedType> gridEntryResponseFeedTypeListFromJson(
  List? gridEntryResponseFeedType, [
  List<enums.GridEntryResponseFeedType>? defaultValue,
]) {
  if (gridEntryResponseFeedType == null) {
    return defaultValue ?? [];
  }

  return gridEntryResponseFeedType
      .map((e) => gridEntryResponseFeedTypeFromJson(e.toString()))
      .toList();
}

List<enums.GridEntryResponseFeedType>?
    gridEntryResponseFeedTypeNullableListFromJson(
  List? gridEntryResponseFeedType, [
  List<enums.GridEntryResponseFeedType>? defaultValue,
]) {
  if (gridEntryResponseFeedType == null) {
    return defaultValue;
  }

  return gridEntryResponseFeedType
      .map((e) => gridEntryResponseFeedTypeFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsProfileProfileIdGetSortToJson(
    enums.V1WatchlistsProfileProfileIdGetSort?
        v1WatchlistsProfileProfileIdGetSort) {
  return v1WatchlistsProfileProfileIdGetSort?.value;
}

enums.V1WatchlistsProfileProfileIdGetSort
    v1WatchlistsProfileProfileIdGetSortFromJson(
  Object? v1WatchlistsProfileProfileIdGetSort, [
  enums.V1WatchlistsProfileProfileIdGetSort? defaultValue,
]) {
  return enums.V1WatchlistsProfileProfileIdGetSort.values.firstWhereOrNull(
          (e) => e.value == v1WatchlistsProfileProfileIdGetSort) ??
      defaultValue ??
      enums.V1WatchlistsProfileProfileIdGetSort.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsProfileProfileIdGetSortListToJson(
    List<enums.V1WatchlistsProfileProfileIdGetSort>?
        v1WatchlistsProfileProfileIdGetSort) {
  if (v1WatchlistsProfileProfileIdGetSort == null) {
    return [];
  }

  return v1WatchlistsProfileProfileIdGetSort.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsProfileProfileIdGetSort>
    v1WatchlistsProfileProfileIdGetSortListFromJson(
  List? v1WatchlistsProfileProfileIdGetSort, [
  List<enums.V1WatchlistsProfileProfileIdGetSort>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGetSort == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsProfileProfileIdGetSort
      .map((e) => v1WatchlistsProfileProfileIdGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsProfileProfileIdGetSort>?
    v1WatchlistsProfileProfileIdGetSortNullableListFromJson(
  List? v1WatchlistsProfileProfileIdGetSort, [
  List<enums.V1WatchlistsProfileProfileIdGetSort>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGetSort == null) {
    return defaultValue;
  }

  return v1WatchlistsProfileProfileIdGetSort
      .map((e) => v1WatchlistsProfileProfileIdGetSortFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsProfileProfileIdGetOrderToJson(
    enums.V1WatchlistsProfileProfileIdGetOrder?
        v1WatchlistsProfileProfileIdGetOrder) {
  return v1WatchlistsProfileProfileIdGetOrder?.value;
}

enums.V1WatchlistsProfileProfileIdGetOrder
    v1WatchlistsProfileProfileIdGetOrderFromJson(
  Object? v1WatchlistsProfileProfileIdGetOrder, [
  enums.V1WatchlistsProfileProfileIdGetOrder? defaultValue,
]) {
  return enums.V1WatchlistsProfileProfileIdGetOrder.values.firstWhereOrNull(
          (e) => e.value == v1WatchlistsProfileProfileIdGetOrder) ??
      defaultValue ??
      enums.V1WatchlistsProfileProfileIdGetOrder.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsProfileProfileIdGetOrderListToJson(
    List<enums.V1WatchlistsProfileProfileIdGetOrder>?
        v1WatchlistsProfileProfileIdGetOrder) {
  if (v1WatchlistsProfileProfileIdGetOrder == null) {
    return [];
  }

  return v1WatchlistsProfileProfileIdGetOrder.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsProfileProfileIdGetOrder>
    v1WatchlistsProfileProfileIdGetOrderListFromJson(
  List? v1WatchlistsProfileProfileIdGetOrder, [
  List<enums.V1WatchlistsProfileProfileIdGetOrder>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGetOrder == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsProfileProfileIdGetOrder
      .map((e) => v1WatchlistsProfileProfileIdGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsProfileProfileIdGetOrder>?
    v1WatchlistsProfileProfileIdGetOrderNullableListFromJson(
  List? v1WatchlistsProfileProfileIdGetOrder, [
  List<enums.V1WatchlistsProfileProfileIdGetOrder>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGetOrder == null) {
    return defaultValue;
  }

  return v1WatchlistsProfileProfileIdGetOrder
      .map((e) => v1WatchlistsProfileProfileIdGetOrderFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsProfileProfileIdGetMdToJson(
    enums.V1WatchlistsProfileProfileIdGetMd?
        v1WatchlistsProfileProfileIdGetMd) {
  return v1WatchlistsProfileProfileIdGetMd?.value;
}

enums.V1WatchlistsProfileProfileIdGetMd
    v1WatchlistsProfileProfileIdGetMdFromJson(
  Object? v1WatchlistsProfileProfileIdGetMd, [
  enums.V1WatchlistsProfileProfileIdGetMd? defaultValue,
]) {
  return enums.V1WatchlistsProfileProfileIdGetMd.values.firstWhereOrNull(
          (e) => e.value == v1WatchlistsProfileProfileIdGetMd) ??
      defaultValue ??
      enums.V1WatchlistsProfileProfileIdGetMd.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsProfileProfileIdGetMdListToJson(
    List<enums.V1WatchlistsProfileProfileIdGetMd>?
        v1WatchlistsProfileProfileIdGetMd) {
  if (v1WatchlistsProfileProfileIdGetMd == null) {
    return [];
  }

  return v1WatchlistsProfileProfileIdGetMd.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsProfileProfileIdGetMd>
    v1WatchlistsProfileProfileIdGetMdListFromJson(
  List? v1WatchlistsProfileProfileIdGetMd, [
  List<enums.V1WatchlistsProfileProfileIdGetMd>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGetMd == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsProfileProfileIdGetMd
      .map((e) => v1WatchlistsProfileProfileIdGetMdFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsProfileProfileIdGetMd>?
    v1WatchlistsProfileProfileIdGetMdNullableListFromJson(
  List? v1WatchlistsProfileProfileIdGetMd, [
  List<enums.V1WatchlistsProfileProfileIdGetMd>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGetMd == null) {
    return defaultValue;
  }

  return v1WatchlistsProfileProfileIdGetMd
      .map((e) => v1WatchlistsProfileProfileIdGetMdFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsProfileProfileIdGridGetSortToJson(
    enums.V1WatchlistsProfileProfileIdGridGetSort?
        v1WatchlistsProfileProfileIdGridGetSort) {
  return v1WatchlistsProfileProfileIdGridGetSort?.value;
}

enums.V1WatchlistsProfileProfileIdGridGetSort
    v1WatchlistsProfileProfileIdGridGetSortFromJson(
  Object? v1WatchlistsProfileProfileIdGridGetSort, [
  enums.V1WatchlistsProfileProfileIdGridGetSort? defaultValue,
]) {
  return enums.V1WatchlistsProfileProfileIdGridGetSort.values.firstWhereOrNull(
          (e) => e.value == v1WatchlistsProfileProfileIdGridGetSort) ??
      defaultValue ??
      enums.V1WatchlistsProfileProfileIdGridGetSort.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsProfileProfileIdGridGetSortListToJson(
    List<enums.V1WatchlistsProfileProfileIdGridGetSort>?
        v1WatchlistsProfileProfileIdGridGetSort) {
  if (v1WatchlistsProfileProfileIdGridGetSort == null) {
    return [];
  }

  return v1WatchlistsProfileProfileIdGridGetSort.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsProfileProfileIdGridGetSort>
    v1WatchlistsProfileProfileIdGridGetSortListFromJson(
  List? v1WatchlistsProfileProfileIdGridGetSort, [
  List<enums.V1WatchlistsProfileProfileIdGridGetSort>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGridGetSort == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsProfileProfileIdGridGetSort
      .map((e) => v1WatchlistsProfileProfileIdGridGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsProfileProfileIdGridGetSort>?
    v1WatchlistsProfileProfileIdGridGetSortNullableListFromJson(
  List? v1WatchlistsProfileProfileIdGridGetSort, [
  List<enums.V1WatchlistsProfileProfileIdGridGetSort>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGridGetSort == null) {
    return defaultValue;
  }

  return v1WatchlistsProfileProfileIdGridGetSort
      .map((e) => v1WatchlistsProfileProfileIdGridGetSortFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsProfileProfileIdGridGetOrderToJson(
    enums.V1WatchlistsProfileProfileIdGridGetOrder?
        v1WatchlistsProfileProfileIdGridGetOrder) {
  return v1WatchlistsProfileProfileIdGridGetOrder?.value;
}

enums.V1WatchlistsProfileProfileIdGridGetOrder
    v1WatchlistsProfileProfileIdGridGetOrderFromJson(
  Object? v1WatchlistsProfileProfileIdGridGetOrder, [
  enums.V1WatchlistsProfileProfileIdGridGetOrder? defaultValue,
]) {
  return enums.V1WatchlistsProfileProfileIdGridGetOrder.values.firstWhereOrNull(
          (e) => e.value == v1WatchlistsProfileProfileIdGridGetOrder) ??
      defaultValue ??
      enums.V1WatchlistsProfileProfileIdGridGetOrder.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsProfileProfileIdGridGetOrderListToJson(
    List<enums.V1WatchlistsProfileProfileIdGridGetOrder>?
        v1WatchlistsProfileProfileIdGridGetOrder) {
  if (v1WatchlistsProfileProfileIdGridGetOrder == null) {
    return [];
  }

  return v1WatchlistsProfileProfileIdGridGetOrder.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsProfileProfileIdGridGetOrder>
    v1WatchlistsProfileProfileIdGridGetOrderListFromJson(
  List? v1WatchlistsProfileProfileIdGridGetOrder, [
  List<enums.V1WatchlistsProfileProfileIdGridGetOrder>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGridGetOrder == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsProfileProfileIdGridGetOrder
      .map(
          (e) => v1WatchlistsProfileProfileIdGridGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsProfileProfileIdGridGetOrder>?
    v1WatchlistsProfileProfileIdGridGetOrderNullableListFromJson(
  List? v1WatchlistsProfileProfileIdGridGetOrder, [
  List<enums.V1WatchlistsProfileProfileIdGridGetOrder>? defaultValue,
]) {
  if (v1WatchlistsProfileProfileIdGridGetOrder == null) {
    return defaultValue;
  }

  return v1WatchlistsProfileProfileIdGridGetOrder
      .map(
          (e) => v1WatchlistsProfileProfileIdGridGetOrderFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsProfileProfileIdGridGetSortToJson(
    enums.V2WatchlistsProfileProfileIdGridGetSort?
        v2WatchlistsProfileProfileIdGridGetSort) {
  return v2WatchlistsProfileProfileIdGridGetSort?.value;
}

enums.V2WatchlistsProfileProfileIdGridGetSort
    v2WatchlistsProfileProfileIdGridGetSortFromJson(
  Object? v2WatchlistsProfileProfileIdGridGetSort, [
  enums.V2WatchlistsProfileProfileIdGridGetSort? defaultValue,
]) {
  return enums.V2WatchlistsProfileProfileIdGridGetSort.values.firstWhereOrNull(
          (e) => e.value == v2WatchlistsProfileProfileIdGridGetSort) ??
      defaultValue ??
      enums.V2WatchlistsProfileProfileIdGridGetSort.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsProfileProfileIdGridGetSortListToJson(
    List<enums.V2WatchlistsProfileProfileIdGridGetSort>?
        v2WatchlistsProfileProfileIdGridGetSort) {
  if (v2WatchlistsProfileProfileIdGridGetSort == null) {
    return [];
  }

  return v2WatchlistsProfileProfileIdGridGetSort.map((e) => e.value!).toList();
}

List<enums.V2WatchlistsProfileProfileIdGridGetSort>
    v2WatchlistsProfileProfileIdGridGetSortListFromJson(
  List? v2WatchlistsProfileProfileIdGridGetSort, [
  List<enums.V2WatchlistsProfileProfileIdGridGetSort>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdGridGetSort == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsProfileProfileIdGridGetSort
      .map((e) => v2WatchlistsProfileProfileIdGridGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsProfileProfileIdGridGetSort>?
    v2WatchlistsProfileProfileIdGridGetSortNullableListFromJson(
  List? v2WatchlistsProfileProfileIdGridGetSort, [
  List<enums.V2WatchlistsProfileProfileIdGridGetSort>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdGridGetSort == null) {
    return defaultValue;
  }

  return v2WatchlistsProfileProfileIdGridGetSort
      .map((e) => v2WatchlistsProfileProfileIdGridGetSortFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsProfileProfileIdGridGetOrderToJson(
    enums.V2WatchlistsProfileProfileIdGridGetOrder?
        v2WatchlistsProfileProfileIdGridGetOrder) {
  return v2WatchlistsProfileProfileIdGridGetOrder?.value;
}

enums.V2WatchlistsProfileProfileIdGridGetOrder
    v2WatchlistsProfileProfileIdGridGetOrderFromJson(
  Object? v2WatchlistsProfileProfileIdGridGetOrder, [
  enums.V2WatchlistsProfileProfileIdGridGetOrder? defaultValue,
]) {
  return enums.V2WatchlistsProfileProfileIdGridGetOrder.values.firstWhereOrNull(
          (e) => e.value == v2WatchlistsProfileProfileIdGridGetOrder) ??
      defaultValue ??
      enums.V2WatchlistsProfileProfileIdGridGetOrder.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsProfileProfileIdGridGetOrderListToJson(
    List<enums.V2WatchlistsProfileProfileIdGridGetOrder>?
        v2WatchlistsProfileProfileIdGridGetOrder) {
  if (v2WatchlistsProfileProfileIdGridGetOrder == null) {
    return [];
  }

  return v2WatchlistsProfileProfileIdGridGetOrder.map((e) => e.value!).toList();
}

List<enums.V2WatchlistsProfileProfileIdGridGetOrder>
    v2WatchlistsProfileProfileIdGridGetOrderListFromJson(
  List? v2WatchlistsProfileProfileIdGridGetOrder, [
  List<enums.V2WatchlistsProfileProfileIdGridGetOrder>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdGridGetOrder == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsProfileProfileIdGridGetOrder
      .map(
          (e) => v2WatchlistsProfileProfileIdGridGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsProfileProfileIdGridGetOrder>?
    v2WatchlistsProfileProfileIdGridGetOrderNullableListFromJson(
  List? v2WatchlistsProfileProfileIdGridGetOrder, [
  List<enums.V2WatchlistsProfileProfileIdGridGetOrder>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdGridGetOrder == null) {
    return defaultValue;
  }

  return v2WatchlistsProfileProfileIdGridGetOrder
      .map(
          (e) => v2WatchlistsProfileProfileIdGridGetOrderFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsProfileProfileIdExtendedGetSortToJson(
    enums.V2WatchlistsProfileProfileIdExtendedGetSort?
        v2WatchlistsProfileProfileIdExtendedGetSort) {
  return v2WatchlistsProfileProfileIdExtendedGetSort?.value;
}

enums.V2WatchlistsProfileProfileIdExtendedGetSort
    v2WatchlistsProfileProfileIdExtendedGetSortFromJson(
  Object? v2WatchlistsProfileProfileIdExtendedGetSort, [
  enums.V2WatchlistsProfileProfileIdExtendedGetSort? defaultValue,
]) {
  return enums.V2WatchlistsProfileProfileIdExtendedGetSort.values
          .firstWhereOrNull(
              (e) => e.value == v2WatchlistsProfileProfileIdExtendedGetSort) ??
      defaultValue ??
      enums.V2WatchlistsProfileProfileIdExtendedGetSort.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsProfileProfileIdExtendedGetSortListToJson(
    List<enums.V2WatchlistsProfileProfileIdExtendedGetSort>?
        v2WatchlistsProfileProfileIdExtendedGetSort) {
  if (v2WatchlistsProfileProfileIdExtendedGetSort == null) {
    return [];
  }

  return v2WatchlistsProfileProfileIdExtendedGetSort
      .map((e) => e.value!)
      .toList();
}

List<enums.V2WatchlistsProfileProfileIdExtendedGetSort>
    v2WatchlistsProfileProfileIdExtendedGetSortListFromJson(
  List? v2WatchlistsProfileProfileIdExtendedGetSort, [
  List<enums.V2WatchlistsProfileProfileIdExtendedGetSort>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdExtendedGetSort == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsProfileProfileIdExtendedGetSort
      .map((e) =>
          v2WatchlistsProfileProfileIdExtendedGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsProfileProfileIdExtendedGetSort>?
    v2WatchlistsProfileProfileIdExtendedGetSortNullableListFromJson(
  List? v2WatchlistsProfileProfileIdExtendedGetSort, [
  List<enums.V2WatchlistsProfileProfileIdExtendedGetSort>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdExtendedGetSort == null) {
    return defaultValue;
  }

  return v2WatchlistsProfileProfileIdExtendedGetSort
      .map((e) =>
          v2WatchlistsProfileProfileIdExtendedGetSortFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsProfileProfileIdExtendedGetOrderToJson(
    enums.V2WatchlistsProfileProfileIdExtendedGetOrder?
        v2WatchlistsProfileProfileIdExtendedGetOrder) {
  return v2WatchlistsProfileProfileIdExtendedGetOrder?.value;
}

enums.V2WatchlistsProfileProfileIdExtendedGetOrder
    v2WatchlistsProfileProfileIdExtendedGetOrderFromJson(
  Object? v2WatchlistsProfileProfileIdExtendedGetOrder, [
  enums.V2WatchlistsProfileProfileIdExtendedGetOrder? defaultValue,
]) {
  return enums.V2WatchlistsProfileProfileIdExtendedGetOrder.values
          .firstWhereOrNull(
              (e) => e.value == v2WatchlistsProfileProfileIdExtendedGetOrder) ??
      defaultValue ??
      enums
          .V2WatchlistsProfileProfileIdExtendedGetOrder.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsProfileProfileIdExtendedGetOrderListToJson(
    List<enums.V2WatchlistsProfileProfileIdExtendedGetOrder>?
        v2WatchlistsProfileProfileIdExtendedGetOrder) {
  if (v2WatchlistsProfileProfileIdExtendedGetOrder == null) {
    return [];
  }

  return v2WatchlistsProfileProfileIdExtendedGetOrder
      .map((e) => e.value!)
      .toList();
}

List<enums.V2WatchlistsProfileProfileIdExtendedGetOrder>
    v2WatchlistsProfileProfileIdExtendedGetOrderListFromJson(
  List? v2WatchlistsProfileProfileIdExtendedGetOrder, [
  List<enums.V2WatchlistsProfileProfileIdExtendedGetOrder>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdExtendedGetOrder == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsProfileProfileIdExtendedGetOrder
      .map((e) =>
          v2WatchlistsProfileProfileIdExtendedGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsProfileProfileIdExtendedGetOrder>?
    v2WatchlistsProfileProfileIdExtendedGetOrderNullableListFromJson(
  List? v2WatchlistsProfileProfileIdExtendedGetOrder, [
  List<enums.V2WatchlistsProfileProfileIdExtendedGetOrder>? defaultValue,
]) {
  if (v2WatchlistsProfileProfileIdExtendedGetOrder == null) {
    return defaultValue;
  }

  return v2WatchlistsProfileProfileIdExtendedGetOrder
      .map((e) =>
          v2WatchlistsProfileProfileIdExtendedGetOrderFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsIdGetSortToJson(
    enums.V1WatchlistsIdGetSort? v1WatchlistsIdGetSort) {
  return v1WatchlistsIdGetSort?.value;
}

enums.V1WatchlistsIdGetSort v1WatchlistsIdGetSortFromJson(
  Object? v1WatchlistsIdGetSort, [
  enums.V1WatchlistsIdGetSort? defaultValue,
]) {
  return enums.V1WatchlistsIdGetSort.values
          .firstWhereOrNull((e) => e.value == v1WatchlistsIdGetSort) ??
      defaultValue ??
      enums.V1WatchlistsIdGetSort.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsIdGetSortListToJson(
    List<enums.V1WatchlistsIdGetSort>? v1WatchlistsIdGetSort) {
  if (v1WatchlistsIdGetSort == null) {
    return [];
  }

  return v1WatchlistsIdGetSort.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsIdGetSort> v1WatchlistsIdGetSortListFromJson(
  List? v1WatchlistsIdGetSort, [
  List<enums.V1WatchlistsIdGetSort>? defaultValue,
]) {
  if (v1WatchlistsIdGetSort == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsIdGetSort
      .map((e) => v1WatchlistsIdGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsIdGetSort>? v1WatchlistsIdGetSortNullableListFromJson(
  List? v1WatchlistsIdGetSort, [
  List<enums.V1WatchlistsIdGetSort>? defaultValue,
]) {
  if (v1WatchlistsIdGetSort == null) {
    return defaultValue;
  }

  return v1WatchlistsIdGetSort
      .map((e) => v1WatchlistsIdGetSortFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsIdGetOrderToJson(
    enums.V1WatchlistsIdGetOrder? v1WatchlistsIdGetOrder) {
  return v1WatchlistsIdGetOrder?.value;
}

enums.V1WatchlistsIdGetOrder v1WatchlistsIdGetOrderFromJson(
  Object? v1WatchlistsIdGetOrder, [
  enums.V1WatchlistsIdGetOrder? defaultValue,
]) {
  return enums.V1WatchlistsIdGetOrder.values
          .firstWhereOrNull((e) => e.value == v1WatchlistsIdGetOrder) ??
      defaultValue ??
      enums.V1WatchlistsIdGetOrder.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsIdGetOrderListToJson(
    List<enums.V1WatchlistsIdGetOrder>? v1WatchlistsIdGetOrder) {
  if (v1WatchlistsIdGetOrder == null) {
    return [];
  }

  return v1WatchlistsIdGetOrder.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsIdGetOrder> v1WatchlistsIdGetOrderListFromJson(
  List? v1WatchlistsIdGetOrder, [
  List<enums.V1WatchlistsIdGetOrder>? defaultValue,
]) {
  if (v1WatchlistsIdGetOrder == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsIdGetOrder
      .map((e) => v1WatchlistsIdGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsIdGetOrder>? v1WatchlistsIdGetOrderNullableListFromJson(
  List? v1WatchlistsIdGetOrder, [
  List<enums.V1WatchlistsIdGetOrder>? defaultValue,
]) {
  if (v1WatchlistsIdGetOrder == null) {
    return defaultValue;
  }

  return v1WatchlistsIdGetOrder
      .map((e) => v1WatchlistsIdGetOrderFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsIdGridGetSortToJson(
    enums.V1WatchlistsIdGridGetSort? v1WatchlistsIdGridGetSort) {
  return v1WatchlistsIdGridGetSort?.value;
}

enums.V1WatchlistsIdGridGetSort v1WatchlistsIdGridGetSortFromJson(
  Object? v1WatchlistsIdGridGetSort, [
  enums.V1WatchlistsIdGridGetSort? defaultValue,
]) {
  return enums.V1WatchlistsIdGridGetSort.values
          .firstWhereOrNull((e) => e.value == v1WatchlistsIdGridGetSort) ??
      defaultValue ??
      enums.V1WatchlistsIdGridGetSort.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsIdGridGetSortListToJson(
    List<enums.V1WatchlistsIdGridGetSort>? v1WatchlistsIdGridGetSort) {
  if (v1WatchlistsIdGridGetSort == null) {
    return [];
  }

  return v1WatchlistsIdGridGetSort.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsIdGridGetSort> v1WatchlistsIdGridGetSortListFromJson(
  List? v1WatchlistsIdGridGetSort, [
  List<enums.V1WatchlistsIdGridGetSort>? defaultValue,
]) {
  if (v1WatchlistsIdGridGetSort == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsIdGridGetSort
      .map((e) => v1WatchlistsIdGridGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsIdGridGetSort>?
    v1WatchlistsIdGridGetSortNullableListFromJson(
  List? v1WatchlistsIdGridGetSort, [
  List<enums.V1WatchlistsIdGridGetSort>? defaultValue,
]) {
  if (v1WatchlistsIdGridGetSort == null) {
    return defaultValue;
  }

  return v1WatchlistsIdGridGetSort
      .map((e) => v1WatchlistsIdGridGetSortFromJson(e.toString()))
      .toList();
}

String? v1WatchlistsIdGridGetOrderToJson(
    enums.V1WatchlistsIdGridGetOrder? v1WatchlistsIdGridGetOrder) {
  return v1WatchlistsIdGridGetOrder?.value;
}

enums.V1WatchlistsIdGridGetOrder v1WatchlistsIdGridGetOrderFromJson(
  Object? v1WatchlistsIdGridGetOrder, [
  enums.V1WatchlistsIdGridGetOrder? defaultValue,
]) {
  return enums.V1WatchlistsIdGridGetOrder.values
          .firstWhereOrNull((e) => e.value == v1WatchlistsIdGridGetOrder) ??
      defaultValue ??
      enums.V1WatchlistsIdGridGetOrder.swaggerGeneratedUnknown;
}

List<String> v1WatchlistsIdGridGetOrderListToJson(
    List<enums.V1WatchlistsIdGridGetOrder>? v1WatchlistsIdGridGetOrder) {
  if (v1WatchlistsIdGridGetOrder == null) {
    return [];
  }

  return v1WatchlistsIdGridGetOrder.map((e) => e.value!).toList();
}

List<enums.V1WatchlistsIdGridGetOrder> v1WatchlistsIdGridGetOrderListFromJson(
  List? v1WatchlistsIdGridGetOrder, [
  List<enums.V1WatchlistsIdGridGetOrder>? defaultValue,
]) {
  if (v1WatchlistsIdGridGetOrder == null) {
    return defaultValue ?? [];
  }

  return v1WatchlistsIdGridGetOrder
      .map((e) => v1WatchlistsIdGridGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V1WatchlistsIdGridGetOrder>?
    v1WatchlistsIdGridGetOrderNullableListFromJson(
  List? v1WatchlistsIdGridGetOrder, [
  List<enums.V1WatchlistsIdGridGetOrder>? defaultValue,
]) {
  if (v1WatchlistsIdGridGetOrder == null) {
    return defaultValue;
  }

  return v1WatchlistsIdGridGetOrder
      .map((e) => v1WatchlistsIdGridGetOrderFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsIdGetSortToJson(
    enums.V2WatchlistsIdGetSort? v2WatchlistsIdGetSort) {
  return v2WatchlistsIdGetSort?.value;
}

enums.V2WatchlistsIdGetSort v2WatchlistsIdGetSortFromJson(
  Object? v2WatchlistsIdGetSort, [
  enums.V2WatchlistsIdGetSort? defaultValue,
]) {
  return enums.V2WatchlistsIdGetSort.values
          .firstWhereOrNull((e) => e.value == v2WatchlistsIdGetSort) ??
      defaultValue ??
      enums.V2WatchlistsIdGetSort.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsIdGetSortListToJson(
    List<enums.V2WatchlistsIdGetSort>? v2WatchlistsIdGetSort) {
  if (v2WatchlistsIdGetSort == null) {
    return [];
  }

  return v2WatchlistsIdGetSort.map((e) => e.value!).toList();
}

List<enums.V2WatchlistsIdGetSort> v2WatchlistsIdGetSortListFromJson(
  List? v2WatchlistsIdGetSort, [
  List<enums.V2WatchlistsIdGetSort>? defaultValue,
]) {
  if (v2WatchlistsIdGetSort == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsIdGetSort
      .map((e) => v2WatchlistsIdGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsIdGetSort>? v2WatchlistsIdGetSortNullableListFromJson(
  List? v2WatchlistsIdGetSort, [
  List<enums.V2WatchlistsIdGetSort>? defaultValue,
]) {
  if (v2WatchlistsIdGetSort == null) {
    return defaultValue;
  }

  return v2WatchlistsIdGetSort
      .map((e) => v2WatchlistsIdGetSortFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsIdGetOrderToJson(
    enums.V2WatchlistsIdGetOrder? v2WatchlistsIdGetOrder) {
  return v2WatchlistsIdGetOrder?.value;
}

enums.V2WatchlistsIdGetOrder v2WatchlistsIdGetOrderFromJson(
  Object? v2WatchlistsIdGetOrder, [
  enums.V2WatchlistsIdGetOrder? defaultValue,
]) {
  return enums.V2WatchlistsIdGetOrder.values
          .firstWhereOrNull((e) => e.value == v2WatchlistsIdGetOrder) ??
      defaultValue ??
      enums.V2WatchlistsIdGetOrder.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsIdGetOrderListToJson(
    List<enums.V2WatchlistsIdGetOrder>? v2WatchlistsIdGetOrder) {
  if (v2WatchlistsIdGetOrder == null) {
    return [];
  }

  return v2WatchlistsIdGetOrder.map((e) => e.value!).toList();
}

List<enums.V2WatchlistsIdGetOrder> v2WatchlistsIdGetOrderListFromJson(
  List? v2WatchlistsIdGetOrder, [
  List<enums.V2WatchlistsIdGetOrder>? defaultValue,
]) {
  if (v2WatchlistsIdGetOrder == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsIdGetOrder
      .map((e) => v2WatchlistsIdGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsIdGetOrder>? v2WatchlistsIdGetOrderNullableListFromJson(
  List? v2WatchlistsIdGetOrder, [
  List<enums.V2WatchlistsIdGetOrder>? defaultValue,
]) {
  if (v2WatchlistsIdGetOrder == null) {
    return defaultValue;
  }

  return v2WatchlistsIdGetOrder
      .map((e) => v2WatchlistsIdGetOrderFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsIdGridGetSortToJson(
    enums.V2WatchlistsIdGridGetSort? v2WatchlistsIdGridGetSort) {
  return v2WatchlistsIdGridGetSort?.value;
}

enums.V2WatchlistsIdGridGetSort v2WatchlistsIdGridGetSortFromJson(
  Object? v2WatchlistsIdGridGetSort, [
  enums.V2WatchlistsIdGridGetSort? defaultValue,
]) {
  return enums.V2WatchlistsIdGridGetSort.values
          .firstWhereOrNull((e) => e.value == v2WatchlistsIdGridGetSort) ??
      defaultValue ??
      enums.V2WatchlistsIdGridGetSort.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsIdGridGetSortListToJson(
    List<enums.V2WatchlistsIdGridGetSort>? v2WatchlistsIdGridGetSort) {
  if (v2WatchlistsIdGridGetSort == null) {
    return [];
  }

  return v2WatchlistsIdGridGetSort.map((e) => e.value!).toList();
}

List<enums.V2WatchlistsIdGridGetSort> v2WatchlistsIdGridGetSortListFromJson(
  List? v2WatchlistsIdGridGetSort, [
  List<enums.V2WatchlistsIdGridGetSort>? defaultValue,
]) {
  if (v2WatchlistsIdGridGetSort == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsIdGridGetSort
      .map((e) => v2WatchlistsIdGridGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsIdGridGetSort>?
    v2WatchlistsIdGridGetSortNullableListFromJson(
  List? v2WatchlistsIdGridGetSort, [
  List<enums.V2WatchlistsIdGridGetSort>? defaultValue,
]) {
  if (v2WatchlistsIdGridGetSort == null) {
    return defaultValue;
  }

  return v2WatchlistsIdGridGetSort
      .map((e) => v2WatchlistsIdGridGetSortFromJson(e.toString()))
      .toList();
}

String? v2WatchlistsIdGridGetOrderToJson(
    enums.V2WatchlistsIdGridGetOrder? v2WatchlistsIdGridGetOrder) {
  return v2WatchlistsIdGridGetOrder?.value;
}

enums.V2WatchlistsIdGridGetOrder v2WatchlistsIdGridGetOrderFromJson(
  Object? v2WatchlistsIdGridGetOrder, [
  enums.V2WatchlistsIdGridGetOrder? defaultValue,
]) {
  return enums.V2WatchlistsIdGridGetOrder.values
          .firstWhereOrNull((e) => e.value == v2WatchlistsIdGridGetOrder) ??
      defaultValue ??
      enums.V2WatchlistsIdGridGetOrder.swaggerGeneratedUnknown;
}

List<String> v2WatchlistsIdGridGetOrderListToJson(
    List<enums.V2WatchlistsIdGridGetOrder>? v2WatchlistsIdGridGetOrder) {
  if (v2WatchlistsIdGridGetOrder == null) {
    return [];
  }

  return v2WatchlistsIdGridGetOrder.map((e) => e.value!).toList();
}

List<enums.V2WatchlistsIdGridGetOrder> v2WatchlistsIdGridGetOrderListFromJson(
  List? v2WatchlistsIdGridGetOrder, [
  List<enums.V2WatchlistsIdGridGetOrder>? defaultValue,
]) {
  if (v2WatchlistsIdGridGetOrder == null) {
    return defaultValue ?? [];
  }

  return v2WatchlistsIdGridGetOrder
      .map((e) => v2WatchlistsIdGridGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V2WatchlistsIdGridGetOrder>?
    v2WatchlistsIdGridGetOrderNullableListFromJson(
  List? v2WatchlistsIdGridGetOrder, [
  List<enums.V2WatchlistsIdGridGetOrder>? defaultValue,
]) {
  if (v2WatchlistsIdGridGetOrder == null) {
    return defaultValue;
  }

  return v2WatchlistsIdGridGetOrder
      .map((e) => v2WatchlistsIdGridGetOrderFromJson(e.toString()))
      .toList();
}

String? v3WatchlistsIdGetSortToJson(
    enums.V3WatchlistsIdGetSort? v3WatchlistsIdGetSort) {
  return v3WatchlistsIdGetSort?.value;
}

enums.V3WatchlistsIdGetSort v3WatchlistsIdGetSortFromJson(
  Object? v3WatchlistsIdGetSort, [
  enums.V3WatchlistsIdGetSort? defaultValue,
]) {
  return enums.V3WatchlistsIdGetSort.values
          .firstWhereOrNull((e) => e.value == v3WatchlistsIdGetSort) ??
      defaultValue ??
      enums.V3WatchlistsIdGetSort.swaggerGeneratedUnknown;
}

List<String> v3WatchlistsIdGetSortListToJson(
    List<enums.V3WatchlistsIdGetSort>? v3WatchlistsIdGetSort) {
  if (v3WatchlistsIdGetSort == null) {
    return [];
  }

  return v3WatchlistsIdGetSort.map((e) => e.value!).toList();
}

List<enums.V3WatchlistsIdGetSort> v3WatchlistsIdGetSortListFromJson(
  List? v3WatchlistsIdGetSort, [
  List<enums.V3WatchlistsIdGetSort>? defaultValue,
]) {
  if (v3WatchlistsIdGetSort == null) {
    return defaultValue ?? [];
  }

  return v3WatchlistsIdGetSort
      .map((e) => v3WatchlistsIdGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V3WatchlistsIdGetSort>? v3WatchlistsIdGetSortNullableListFromJson(
  List? v3WatchlistsIdGetSort, [
  List<enums.V3WatchlistsIdGetSort>? defaultValue,
]) {
  if (v3WatchlistsIdGetSort == null) {
    return defaultValue;
  }

  return v3WatchlistsIdGetSort
      .map((e) => v3WatchlistsIdGetSortFromJson(e.toString()))
      .toList();
}

String? v3WatchlistsIdGetOrderToJson(
    enums.V3WatchlistsIdGetOrder? v3WatchlistsIdGetOrder) {
  return v3WatchlistsIdGetOrder?.value;
}

enums.V3WatchlistsIdGetOrder v3WatchlistsIdGetOrderFromJson(
  Object? v3WatchlistsIdGetOrder, [
  enums.V3WatchlistsIdGetOrder? defaultValue,
]) {
  return enums.V3WatchlistsIdGetOrder.values
          .firstWhereOrNull((e) => e.value == v3WatchlistsIdGetOrder) ??
      defaultValue ??
      enums.V3WatchlistsIdGetOrder.swaggerGeneratedUnknown;
}

List<String> v3WatchlistsIdGetOrderListToJson(
    List<enums.V3WatchlistsIdGetOrder>? v3WatchlistsIdGetOrder) {
  if (v3WatchlistsIdGetOrder == null) {
    return [];
  }

  return v3WatchlistsIdGetOrder.map((e) => e.value!).toList();
}

List<enums.V3WatchlistsIdGetOrder> v3WatchlistsIdGetOrderListFromJson(
  List? v3WatchlistsIdGetOrder, [
  List<enums.V3WatchlistsIdGetOrder>? defaultValue,
]) {
  if (v3WatchlistsIdGetOrder == null) {
    return defaultValue ?? [];
  }

  return v3WatchlistsIdGetOrder
      .map((e) => v3WatchlistsIdGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V3WatchlistsIdGetOrder>? v3WatchlistsIdGetOrderNullableListFromJson(
  List? v3WatchlistsIdGetOrder, [
  List<enums.V3WatchlistsIdGetOrder>? defaultValue,
]) {
  if (v3WatchlistsIdGetOrder == null) {
    return defaultValue;
  }

  return v3WatchlistsIdGetOrder
      .map((e) => v3WatchlistsIdGetOrderFromJson(e.toString()))
      .toList();
}

String? v3WatchlistsProfileProfileIdExtendedGetSortToJson(
    enums.V3WatchlistsProfileProfileIdExtendedGetSort?
        v3WatchlistsProfileProfileIdExtendedGetSort) {
  return v3WatchlistsProfileProfileIdExtendedGetSort?.value;
}

enums.V3WatchlistsProfileProfileIdExtendedGetSort
    v3WatchlistsProfileProfileIdExtendedGetSortFromJson(
  Object? v3WatchlistsProfileProfileIdExtendedGetSort, [
  enums.V3WatchlistsProfileProfileIdExtendedGetSort? defaultValue,
]) {
  return enums.V3WatchlistsProfileProfileIdExtendedGetSort.values
          .firstWhereOrNull(
              (e) => e.value == v3WatchlistsProfileProfileIdExtendedGetSort) ??
      defaultValue ??
      enums.V3WatchlistsProfileProfileIdExtendedGetSort.swaggerGeneratedUnknown;
}

List<String> v3WatchlistsProfileProfileIdExtendedGetSortListToJson(
    List<enums.V3WatchlistsProfileProfileIdExtendedGetSort>?
        v3WatchlistsProfileProfileIdExtendedGetSort) {
  if (v3WatchlistsProfileProfileIdExtendedGetSort == null) {
    return [];
  }

  return v3WatchlistsProfileProfileIdExtendedGetSort
      .map((e) => e.value!)
      .toList();
}

List<enums.V3WatchlistsProfileProfileIdExtendedGetSort>
    v3WatchlistsProfileProfileIdExtendedGetSortListFromJson(
  List? v3WatchlistsProfileProfileIdExtendedGetSort, [
  List<enums.V3WatchlistsProfileProfileIdExtendedGetSort>? defaultValue,
]) {
  if (v3WatchlistsProfileProfileIdExtendedGetSort == null) {
    return defaultValue ?? [];
  }

  return v3WatchlistsProfileProfileIdExtendedGetSort
      .map((e) =>
          v3WatchlistsProfileProfileIdExtendedGetSortFromJson(e.toString()))
      .toList();
}

List<enums.V3WatchlistsProfileProfileIdExtendedGetSort>?
    v3WatchlistsProfileProfileIdExtendedGetSortNullableListFromJson(
  List? v3WatchlistsProfileProfileIdExtendedGetSort, [
  List<enums.V3WatchlistsProfileProfileIdExtendedGetSort>? defaultValue,
]) {
  if (v3WatchlistsProfileProfileIdExtendedGetSort == null) {
    return defaultValue;
  }

  return v3WatchlistsProfileProfileIdExtendedGetSort
      .map((e) =>
          v3WatchlistsProfileProfileIdExtendedGetSortFromJson(e.toString()))
      .toList();
}

String? v3WatchlistsProfileProfileIdExtendedGetOrderToJson(
    enums.V3WatchlistsProfileProfileIdExtendedGetOrder?
        v3WatchlistsProfileProfileIdExtendedGetOrder) {
  return v3WatchlistsProfileProfileIdExtendedGetOrder?.value;
}

enums.V3WatchlistsProfileProfileIdExtendedGetOrder
    v3WatchlistsProfileProfileIdExtendedGetOrderFromJson(
  Object? v3WatchlistsProfileProfileIdExtendedGetOrder, [
  enums.V3WatchlistsProfileProfileIdExtendedGetOrder? defaultValue,
]) {
  return enums.V3WatchlistsProfileProfileIdExtendedGetOrder.values
          .firstWhereOrNull(
              (e) => e.value == v3WatchlistsProfileProfileIdExtendedGetOrder) ??
      defaultValue ??
      enums
          .V3WatchlistsProfileProfileIdExtendedGetOrder.swaggerGeneratedUnknown;
}

List<String> v3WatchlistsProfileProfileIdExtendedGetOrderListToJson(
    List<enums.V3WatchlistsProfileProfileIdExtendedGetOrder>?
        v3WatchlistsProfileProfileIdExtendedGetOrder) {
  if (v3WatchlistsProfileProfileIdExtendedGetOrder == null) {
    return [];
  }

  return v3WatchlistsProfileProfileIdExtendedGetOrder
      .map((e) => e.value!)
      .toList();
}

List<enums.V3WatchlistsProfileProfileIdExtendedGetOrder>
    v3WatchlistsProfileProfileIdExtendedGetOrderListFromJson(
  List? v3WatchlistsProfileProfileIdExtendedGetOrder, [
  List<enums.V3WatchlistsProfileProfileIdExtendedGetOrder>? defaultValue,
]) {
  if (v3WatchlistsProfileProfileIdExtendedGetOrder == null) {
    return defaultValue ?? [];
  }

  return v3WatchlistsProfileProfileIdExtendedGetOrder
      .map((e) =>
          v3WatchlistsProfileProfileIdExtendedGetOrderFromJson(e.toString()))
      .toList();
}

List<enums.V3WatchlistsProfileProfileIdExtendedGetOrder>?
    v3WatchlistsProfileProfileIdExtendedGetOrderNullableListFromJson(
  List? v3WatchlistsProfileProfileIdExtendedGetOrder, [
  List<enums.V3WatchlistsProfileProfileIdExtendedGetOrder>? defaultValue,
]) {
  if (v3WatchlistsProfileProfileIdExtendedGetOrder == null) {
    return defaultValue;
  }

  return v3WatchlistsProfileProfileIdExtendedGetOrder
      .map((e) =>
          v3WatchlistsProfileProfileIdExtendedGetOrderFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
